(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    500691,      10054]*)
(*NotebookOutlinePosition[    501334,      10076]*)
(*  CellTagsIndexPosition[    501290,      10072]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(He\^3\ spectral\ function\)], "Title",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics3D`\), "\[IndentingNewLine]", 
    \(<< NumericalMath`NIntegrateInterpolatingFunct`\)}], "Input"],

Cell[BoxData[
    \(Off[NIntegrate::"\<slwcon\>"]\)], "Input"],

Cell[BoxData[
    \(\(sty = {{}, Hue[1], Hue[0.3], Hue[0.6]};\)\)], "Input"],

Cell[BoxData[
    \(\(intops = {PrecisionGoal \[Rule] 4, \ MinRecursion \[Rule] 3, \ 
          MaxRecursion \[Rule] 30};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<e:/kulagin/phys/spin/SpFn\>"]\)], "Input"],

Cell[BoxData[
    \("e:\\kulagin\\phys\\spin\\SpFn"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read in and interpolate the spectral function", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
Read spectral function from data file. Note the following rules:
C     The spectral function is given for the pair-isospin 
C     T=0 and T=1
C     The two-body breakup is given in the first columne, i.e.,
C     R0T0(1,J) etc.
C     R0T0(2..NERG,J) contains the three-body breakup.
C     The normalization is chosen such that the proton and  neutron \
contribution is given by:
C
C      R0P = (F0T0 + F0T1)*4.*PI/3.
C      R0N = 2.*F0T1*4.*PI/3.
C
C     with R0P = 2/3
C     and  R0N = 1/3
C     
C     Since the spectral function is given on a finite mesh the sumrule is \
not exactly fullfilled !
C     The mesh was chosen for a particular kinematic situation.
C     The momentum mesh is given for Gaussian points.        \
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(nmesh = 30;\)\), "\[IndentingNewLine]", 
    \(\(r0t0 = 
        Table[0, {i, 1, nmesh}, {j, 1, nmesh}];\)\), "\[IndentingNewLine]", 
    \(r1t0 = r0t0; r2t0 = r0t0;\), "\[IndentingNewLine]", 
    \(r0t1 = r0t0; r1t1 = r0t0; r2t1 = r0t0;\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rawdat = OpenRead["\<spfn.dat\>"]\), "\[IndentingNewLine]", 
    \(\(nerg = Read[rawdat, Number];\)\), "\[IndentingNewLine]", 
    \(\(nq = Read[rawdat, Number];\)\), "\[IndentingNewLine]", 
    \(\(ener = ReadList[rawdat, Number, nerg];\)\), "\[IndentingNewLine]", 
    \(\(qmesh = ReadList[rawdat, Number, nq];\)\), "\[IndentingNewLine]", 
    \(\(qweigh = ReadList[rawdat, Number, nq];\)\), "\[IndentingNewLine]", 
    \(\(Do[\((\[IndentingNewLine]Do[\ \((\[IndentingNewLine]r0t0[\([i, 
                    j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r1t0[\([i, j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r2t0[\([i, j]\)] = 
                Read[rawdat, 
                  Number]\[IndentingNewLine])\)\[IndentingNewLine], {j, 1, 
              nq}])\)\[IndentingNewLine], {i, 1, 
          nerg}];\)\), "\[IndentingNewLine]", 
    \(\(Do[\((\[IndentingNewLine]Do[\ \((\[IndentingNewLine]r0t1[\([i, 
                    j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r1t1[\([i, j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r2t1[\([i, j]\)] = 
                Read[rawdat, 
                  Number]\[IndentingNewLine])\)\[IndentingNewLine], {j, 1, 
              nq}])\)\[IndentingNewLine], {i, 1, 
          nerg}];\)\), "\[IndentingNewLine]", 
    \(Close[rawdat]\)}], "Input"],

Cell[BoxData[
    \(InputStream["spfn.dat", 8]\)], "Output"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(qmesh\)\" is similar to \
existing symbol \"\!\(nmesh\)\"."\)], "Message"],

Cell[BoxData[
    \("spfn.dat"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear interpolation (bad)", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["Isospin 0", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron in the final state (2-body breakup) corresponds to i=1. We treat \
it separately.\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(deut0 = 
        Table[{qmesh[\([j]\)], r0t0[\([1, j]\)]}, {j, 1, nq}];\)\), "\n", 
    \(\(deut1 = 
        Table[{qmesh[\([j]\)], r1t0[\([1, j]\)]}, {j, 1, nq}];\)\), "\n", 
    \(\(deut2 = 
        Table[{qmesh[\([j]\)], r2t0[\([1, j]\)]}, {j, 1, nq}];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d0 = 
      Interpolation[deut0, 
        InterpolationOrder \[Rule] intord]\ \), "\[IndentingNewLine]", 
    \(d1 = 
      Interpolation[deut1, 
        InterpolationOrder \[Rule] intord]\), "\[IndentingNewLine]", 
    \(d2 = 
      Interpolation[deut2, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t0[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t0[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t0[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t0 = Flatten[con0t0, 1];\)\), "\n", 
    \(\(con1t0 = Flatten[con1t0, 1];\)\), "\n", 
    \(\(con2t0 = Flatten[con2t0, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c0t0 = 
      Interpolation[con0t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c1t0 = 
      Interpolation[con1t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c2t0 = 
      Interpolation[con2t0, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Isospin 1.", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron (two-body breakup) does not contribute in this channel.
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t1[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t1[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t1[\([i, j]\)]}, {i, 2, 
            nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t1 = Flatten[con0t1, 1];\)\), "\n", 
    \(\(con1t1 = Flatten[con1t1, 1];\)\), "\n", 
    \(\(con2t1 = Flatten[con2t1, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c0t1 = 
      Interpolation[con0t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c1t1 = 
      Interpolation[con1t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c2t1 = 
      Interpolation[con2t1, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Log interpolation", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["Isospin 0", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron in the final state (2-body breakup) corresponds to i=1. We treat \
it separately.\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(deut0 = 
        Table[{qmesh[\([j]\)], r0t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\), "\n", 
    \(\(deut1 = 
        Table[{qmesh[\([j]\)], r1t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\), "\n", 
    \(\(deut2 = 
        Table[{qmesh[\([j]\)], r2t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(logd0 = 
      Interpolation[deut0, 
        InterpolationOrder \[Rule] intord]\ \), "\[IndentingNewLine]", 
    \(logd1 = 
      Interpolation[deut1, 
        InterpolationOrder \[Rule] intord]\), "\[IndentingNewLine]", 
    \(logd2 = 
      Interpolation[deut2, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.003699`, 29.324699999999996`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(d0[p_] := \(\((logd0[p])\) // Exp\) // Re\), "\[IndentingNewLine]", 
    \(d1[p_] := \(\((logd1[p])\) // Exp\) // Re\), "\[IndentingNewLine]", 
    \(d2[p_] := \(\((logd2[p])\) // Exp\) // Re\)}], "Input"],

Cell["\<\
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t0 = Flatten[con0t0, 1];\)\), "\n", 
    \(\(con1t0 = Flatten[con1t0, 1];\)\), "\n", 
    \(\(con2t0 = Flatten[con2t0, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(logc0t0 = 
      Interpolation[con0t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(logc1t0 = 
      Interpolation[con1t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(logc2t0 = 
      Interpolation[con2t0, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c0t0[e_, p_] := \(\((logc0t0[e, p])\) // Exp\) // 
        Re\), "\[IndentingNewLine]", 
    \(c1t0[e_, p_] := \(\((logc1t0[e, p])\) // Exp\) // 
        Re\), "\[IndentingNewLine]", 
    \(c2t0[e_, p_] := \(\((logc2t0[e, p])\) // Exp\) // Re\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c0t0\)\" is similar to \
existing symbol \"\!\(r0t0\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c1t0\)\" is similar to \
existing symbol \"\!\(r1t0\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c2t0\)\" is similar to \
existing symbol \"\!\(r2t0\)\"."\)], "Message"]
}, Open  ]],

Cell["Isospin 1.", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron (two-body breakup) does not contribute in this channel.
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t1 = Flatten[con0t1, 1];\)\), "\n", 
    \(\(con1t1 = Flatten[con1t1, 1];\)\), "\n", 
    \(\(con2t1 = Flatten[con2t1, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(logc0t1 = 
      Interpolation[con0t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(logc1t1 = 
      Interpolation[con1t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(logc2t1 = 
      Interpolation[con2t1, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.01`, 190.`}, {0.003699`, 
            29.324699999999996`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c0t1[e_, p_] := \(\((logc0t1[e, p])\) // Exp\) // 
        Re\), "\[IndentingNewLine]", 
    \(c1t1[e_, p_] := \(\((logc1t1[e, p])\) // Exp\) // 
        Re\), "\[IndentingNewLine]", 
    \(c2t1[e_, p_] := \(\((logc2t1[e, p])\) // Exp\) // Re\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c0t1\)\" is similar to \
existing symbol \"\!\(r0t1\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c1t1\)\" is similar to \
existing symbol \"\!\(r1t1\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(c2t1\)\" is similar to \
existing symbol \"\!\(r2t1\)\"."\)], "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(\(\(pmin = First[qmesh];\)\[IndentingNewLine]
    pmax = Last[qmesh]; \ pmax = 6.5;\[IndentingNewLine]
    emin0 = ener[\([1]\)]; emin1 = ener[\([2]\)];\ \[IndentingNewLine]
    \(emax = 
        Last[ener];\)\)\(\ \)\( (*\ \(emax = 100. ;\)\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{d0[p], d1[p], d2[p]}\[IndentingNewLine], {p, pmin, 
        pmax/5}\[IndentingNewLine], 
      PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0210919 0.734691 0.161866 0.078915 [
[.16803 .14937 -9 -9 ]
[.16803 .14937 9 0 ]
[.31497 .14937 -9 -9 ]
[.31497 .14937 9 0 ]
[.46191 .14937 -9 -9 ]
[.46191 .14937 9 0 ]
[.60884 .14937 -9 -9 ]
[.60884 .14937 9 0 ]
[.75578 .14937 -3 -9 ]
[.75578 .14937 3 0 ]
[.90272 .14937 -9 -9 ]
[.90272 .14937 9 0 ]
[.00859 .00404 -12 -4.5 ]
[.00859 .00404 0 4.5 ]
[.00859 .08295 -12 -4.5 ]
[.00859 .08295 0 4.5 ]
[.00859 .24078 -6 -4.5 ]
[.00859 .24078 0 4.5 ]
[.00859 .3197 -6 -4.5 ]
[.00859 .3197 0 4.5 ]
[.00859 .39861 -6 -4.5 ]
[.00859 .39861 0 4.5 ]
[.00859 .47753 -6 -4.5 ]
[.00859 .47753 0 4.5 ]
[.00859 .55644 -6 -4.5 ]
[.00859 .55644 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16803 .16187 m
.16803 .16812 L
s
[(0.2)] .16803 .14937 0 1 Mshowa
.31497 .16187 m
.31497 .16812 L
s
[(0.4)] .31497 .14937 0 1 Mshowa
.46191 .16187 m
.46191 .16812 L
s
[(0.6)] .46191 .14937 0 1 Mshowa
.60884 .16187 m
.60884 .16812 L
s
[(0.8)] .60884 .14937 0 1 Mshowa
.75578 .16187 m
.75578 .16812 L
s
[(1)] .75578 .14937 0 1 Mshowa
.90272 .16187 m
.90272 .16812 L
s
[(1.2)] .90272 .14937 0 1 Mshowa
.125 Mabswid
.05783 .16187 m
.05783 .16562 L
s
.09456 .16187 m
.09456 .16562 L
s
.1313 .16187 m
.1313 .16562 L
s
.20476 .16187 m
.20476 .16562 L
s
.2415 .16187 m
.2415 .16562 L
s
.27823 .16187 m
.27823 .16562 L
s
.3517 .16187 m
.3517 .16562 L
s
.38844 .16187 m
.38844 .16562 L
s
.42517 .16187 m
.42517 .16562 L
s
.49864 .16187 m
.49864 .16562 L
s
.53538 .16187 m
.53538 .16562 L
s
.57211 .16187 m
.57211 .16562 L
s
.64558 .16187 m
.64558 .16562 L
s
.68231 .16187 m
.68231 .16562 L
s
.71905 .16187 m
.71905 .16562 L
s
.79252 .16187 m
.79252 .16562 L
s
.82925 .16187 m
.82925 .16562 L
s
.86599 .16187 m
.86599 .16562 L
s
.93946 .16187 m
.93946 .16562 L
s
.97619 .16187 m
.97619 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
.02109 .00404 m
.02734 .00404 L
s
[(-2)] .00859 .00404 1 0 Mshowa
.02109 .08295 m
.02734 .08295 L
s
[(-1)] .00859 .08295 1 0 Mshowa
.02109 .24078 m
.02734 .24078 L
s
[(1)] .00859 .24078 1 0 Mshowa
.02109 .3197 m
.02734 .3197 L
s
[(2)] .00859 .3197 1 0 Mshowa
.02109 .39861 m
.02734 .39861 L
s
[(3)] .00859 .39861 1 0 Mshowa
.02109 .47753 m
.02734 .47753 L
s
[(4)] .00859 .47753 1 0 Mshowa
.02109 .55644 m
.02734 .55644 L
s
[(5)] .00859 .55644 1 0 Mshowa
.125 Mabswid
.02109 .01982 m
.02484 .01982 L
s
.02109 .0356 m
.02484 .0356 L
s
.02109 .05139 m
.02484 .05139 L
s
.02109 .06717 m
.02484 .06717 L
s
.02109 .09873 m
.02484 .09873 L
s
.02109 .11452 m
.02484 .11452 L
s
.02109 .1303 m
.02484 .1303 L
s
.02109 .14608 m
.02484 .14608 L
s
.02109 .17765 m
.02484 .17765 L
s
.02109 .19343 m
.02484 .19343 L
s
.02109 .20922 m
.02484 .20922 L
s
.02109 .225 m
.02484 .225 L
s
.02109 .25656 m
.02484 .25656 L
s
.02109 .27235 m
.02484 .27235 L
s
.02109 .28813 m
.02484 .28813 L
s
.02109 .30391 m
.02484 .30391 L
s
.02109 .33548 m
.02484 .33548 L
s
.02109 .35126 m
.02484 .35126 L
s
.02109 .36705 m
.02484 .36705 L
s
.02109 .38283 m
.02484 .38283 L
s
.02109 .41439 m
.02484 .41439 L
s
.02109 .43018 m
.02484 .43018 L
s
.02109 .44596 m
.02484 .44596 L
s
.02109 .46174 m
.02484 .46174 L
s
.02109 .49331 m
.02484 .49331 L
s
.02109 .50909 m
.02484 .50909 L
s
.02109 .52488 m
.02484 .52488 L
s
.02109 .54066 m
.02484 .54066 L
s
.02109 .57222 m
.02484 .57222 L
s
.02109 .58801 m
.02484 .58801 L
s
.02109 .60379 m
.02484 .60379 L
s
.25 Mabswid
.02109 0 m
.02109 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02846 .60244 L
.03279 .60161 L
.03406 .60137 L
.03527 .60114 L
.03636 .60062 L
.03754 .59997 L
.04262 .59719 L
.05205 .59207 L
.05464 .59068 L
.05532 .59031 L
.05606 .58991 L
.05677 .58953 L
.05742 .58885 L
.06004 .58603 L
.06244 .58347 L
.07308 .5723 L
.08435 .56078 L
.09414 .54743 L
.10458 .53116 L
.14616 .46495 L
.18623 .40169 L
.22478 .34316 L
.26578 .29507 L
.30527 .25832 L
.34324 .23245 L
.38367 .21182 L
.42257 .19769 L
.46394 .18701 L
.50378 .17974 L
.54211 .17474 L
.58289 .17096 L
.62216 .1684 L
.65991 .16661 L
.70011 .16525 L
.7388 .16431 L
.77994 .1636 L
.81956 .16311 L
.85767 .16277 L
.89823 .16251 L
.93728 .16233 L
.97619 .1622 L
s
1 0 0 r
.02381 .01472 m
.02846 .01501 L
.03279 .01528 L
.03406 .01536 L
.03527 .01544 L
.03636 .01561 L
.03754 .01583 L
.04262 .01676 L
.05205 .01847 L
.05464 .01893 L
.05532 .01905 L
.05606 .01918 L
.05677 .01931 L
.05742 .01954 L
.06004 .02048 L
.06244 .02133 L
.07308 .02505 L
.08435 .02889 L
.09414 .03334 L
.10458 .03877 L
.14616 .06084 L
.18623 .08193 L
.22478 .10143 L
.26578 .11747 L
.30527 .12971 L
.34324 .13834 L
.38367 .14521 L
.42257 .14993 L
.46394 .15349 L
.50378 .15591 L
.54211 .15758 L
.58289 .15883 L
.62216 .15969 L
.65991 .16028 L
.70011 .16074 L
.7388 .16105 L
.77994 .16129 L
.81956 .16145 L
.85767 .16157 L
.89823 .16165 L
.93728 .16171 L
.97619 .16175 L
s
.2 1 0 r
.02381 .16186 m
.02499 .16186 L
.02605 .16186 L
.02729 .16186 L
.02846 .16185 L
.02954 .16185 L
.03053 .16184 L
.03163 .16183 L
.03279 .16182 L
.03786 .16174 L
.04035 .16171 L
.04262 .16168 L
.04716 .16159 L
.04967 .16152 L
.05205 .16145 L
.06244 .16109 L
.10458 .15909 L
.14277 .15679 L
.16409 .15574 L
.17416 .15516 L
.17857 .1549 L
.18108 .15474 L
.18342 .15459 L
.18458 .15451 L
.18569 .15444 L
.18696 .15442 L
.18812 .15439 L
.1931 .15429 L
.20357 .15407 L
.22255 .15364 L
.24077 .15321 L
.24576 .15309 L
.24838 .15303 L
.25114 .15296 L
.25231 .15293 L
.25357 .1529 L
.25429 .15289 L
.25494 .1529 L
.25622 .15291 L
.26088 .15295 L
.28065 .15312 L
.30166 .15331 L
.32246 .15348 L
.33159 .15356 L
.3341 .15358 L
.33548 .15359 L
.33679 .1536 L
.338 .15361 L
.33869 .15363 L
.33932 .15365 L
Mistroke
.34164 .15371 L
.36033 .15419 L
.38011 .15467 L
.41929 .15554 L
.46092 .1565 L
.50104 .1574 L
.53965 .15813 L
.5807 .15881 L
.62024 .1594 L
.65826 .15986 L
.69874 .16026 L
.7377 .16059 L
.77912 .16087 L
.81901 .16109 L
.85739 .16125 L
.89823 .16139 L
.93755 .1615 L
.97535 .16159 L
.97619 .16159 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{475.5, 293.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007K00019A000`40O003h00Oogomg7om003oOogL
Ood00?mooMaoo@001gom10001Wom00<007omOod0ogomb7om0007Ood00`00Ooeoo@07Ood00`00Ooeo
o@3oOog8Ood000Qoo@03001ooGom00Ioo@@00?mooLMoo@0000=oo@0000000P0017om00<007omOod0
1Gom00<007omOod0ogomb7om0007Ood01000Ooeoo@001Wom00<007omOod0ogomb7om0008Ood20007
Ood00`00Ooeoo@3oOog8Ood0015oo@03001ooGom0?mooLQoo@004Gom00<007omO0001G`0ogom`gom
000AOod00`00Ooeoo@05Ood5O03oOofnOod0015oo@<000Yoo@El0?mooKUoo@004Gom00<007omOod0
3gom17`0ogom]Gom000AOod00`00Ooeoo@0COod2O03oOofcOod0015oo@03001ooGom01Eoo@=l0?mo
oK1oo@004Gom00<007omOod067om0W`0ogom[Wom000AOod00`00Ooeoo@0JOod2O03oOof/Ood0015o
o@03001ooGom01aoo@9l0?mooJYoo@004Gom00<007omOod07Wom0g`0ogomYgom000AOod3000QOod2
O03oOofUOod0015oo@03001ooGom02=oo@9l0?mooJ=oo@004Gom00<007omOod09Gom0W`0ogomXGom
000AOod00`00Ooeoo@0WOod2O03oOofOOod0015oo@03001ooGom02Uoo@9l0?mooIeoo@004Gom00<0
07omOod0:gom0W`0ogomVgom000AOod00`00Ooeoo@0]Ood00g`0Ooeoo@3oOofHOod0015oo@<002io
o@9l0?mooIQoo@004Gom00<007omOod0<7om0W`0ogomUWom000AOod00`00Ooeoo@0bOod2O03oOofD
Ood0015oo@03001ooGom03Aoo@9l0?mooI9oo@004Gom00<007omOod0=Wom0W`0ogomT7om000AOod0
0`00Ooeoo@0hOod00g`0Ooeoo@3oOof=Ood0015oo@03001ooGom03Uoo@9l0?mooHeoo@004Gom00<0
07omOod0>gom0W`0ogomRgom000AOod3000mOod2O03oOof9Ood0015oo@03001ooGom03moo@9l0?mo
oHMoo@004Gom00<007omOod0@Gom0W`0ogomQGom000AOod00`00Ooeoo@13Ood2O03oOof3Ood0015o
o@03001ooGom04Eoo@9l0?mooH5oo@001gom1@001Gom00<007omOod0Agom0W`0ogomOgom0009Ood0
0`00Ooeoo@05Ood00`00Ooeoo@19Ood2O03oOoemOod000Uoo@03001ooGom00Eoo@@004Yoo@9l0?mo
oG]oo@0000=oo@0000000P0017om00<007omOod01Gom00<007omOod0CGom0W`0ogomNGom0009Ood0
0`00Ooeoo@05Ood00`00Ooeoo@1?Ood2O03oOoegOod000Qoo@8000Moo@03001ooGom055oo@9l0?mo
oGEoo@004Gom00<007omOod0Dgom00=l07omOod0ogomLWom000AOod00`00Ooeoo@1DOod2O03oOoeb
Ood0015oo@03001ooGom05Ioo@9l0?mooG1oo@004Gom0`00F7om0W`0ogomKWom000AOod00`00Ooeo
o@1JOod2O03oOoe/Ood0015oo@03001ooGom05aoo@9l0?mooFYoo@004Gom00<007omOod0GWom0g`0
ogomIgom000AOod00`00Ooeoo@1QOod2O03oOoeUOod0015oo@03001ooGom06=oo@=l0?mooF9oo@00
4Gom00<007omOod0IWom0g`0ogomGgom000AOod00`00Ooeoo@1YOod2O03oOoeMOod0015oo@<006]o
o@=l0?mooEYoo@004Gom00<007omOod0KWom0g`0ogomEgom000AOod00`00Ooeoo@1aOod3O03oOoeD
Ood0015oo@03001ooGom07Aoo@=l0?mooE5oo@004Gom00<007omOod0Mgom17`0ogomCGom000AOod0
0`00Ooeoo@1kOod3O03oOoe:Ood0015oo@03001ooGom07ioo@=l0?mooDMoo@004Gom0`00PGom17`0
ogom@gom000AOod00`00Ooeoo@0kOod20004Ood20003Ood4000eOod20004Ood4O003Ood3000eOod2
0004Ood20003Ood3000gOod20004Ood20004Ood2000kOod5000jOod50002Ood20003Ood4000VOod0
015oo@03001ooGom03Yoo@04001ooGom0008Ood00`00Ooeoo@0eOod01000Ooeoo@001gom1G`0=Gom
00@007omOod000Qoo@04001ooGom000eOod01000Ooeoo@0027om00@007omOod003aoo@03001ooGom
03aoo@03001ooGom00Moo@03001ooGom02Moo@004Gom00<007omOod0>Wom00@007omOod000Uoo@03
001ooGom03Aoo@04001ooGom0008Ood40004O00aOod01000Ooeoo@0027om00@007omOod003Eoo@04
001ooGom0008Ood01000Ooeoo@00?7om00<007omOod0?7om00<007omOod027om00<007omOod09Wom
000AOod00`00Ooeoo@0jOod01000Ooeoo@002Wom00<007omOod0<gom00@007omOod000Qoo@04001o
oGom0004Ood5O00/Ood01000Ooeoo@0027om0`00=Wom00@007omOod000Uoo@8003eoo@03001ooGom
03aoo@03001ooGom00Uoo@03001ooGom02Eoo@004Gom00<007omOod0>Wom00@007omOod000Qoo@04
001ooGom000dOod01000Ooeoo@002Gom00<007om00002Gom1W`09Wom00@007omOod000Uoo@03001o
oGom03Eoo@04001ooGom0008Ood01000Ooeoo@00?7om00<007omOod0?7om00<007omOod01gom00@0
07omOod002Ioo@004Gom00<007omOod0>gom0P002Wom0P00=Wom0P002gom0P003gom1W`08Gom0P00
2Wom0`00=Wom0P002Wom0P00?7om0P00?Gom0P002Wom0P009gom000AOod3002SOod8O03oOodMOod0
015oo@03001ooGom0:]oo@Yl0?mooA=oo@004Gom00<007omOod0]Gom2G`0ogom2Wom000AOod00`00
Ooeoo@2nOod:O03oOod0015oo@03001ooGom04IooFPGh1Yoo@il0?5oo@004Gom00<007omOod0;Gom
6AOPJ7om9QOP0Wom4W`0ggom000AOod00`00Ooeoo@0KOodB5n2WOodh5n000g`0Ooeoo@2hOod0015o
o@03001ooGom00moo@`Gh?5ooH4Gh3Yoo@001gom300041OPo`00F`0097`0;aOP2`00000AOod00`00
Ooeoo@0>Ood00`00Ooeoo@0?Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00
Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0?Ood00`00Ooeoo@0>Ood00`00
Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00
Ooeoo@0?Ood00`00Ooeoo@0>Ood00`00Ooeoo@0=Oodh000=Ood00`00Ooeoo@0>Ood00`00Ooeoo@0?
Ood00`00Ooeoo@0>Ood00`00Ooeoo@0>Ood00`00Ooeoo@09Ood0015oo@03001ooGom049oo@03001o
oGom045oo@03001ooGom049oo@03001ooGom049oo@03001ooGom00aooA8002=oo@03001ooGom049o
o@03001ooGom02]oo@004Gom00<007omOod0@Wom00<007omOod0@Gom00<007omOod0@Wom00<007om
Ood0?gom4P00=Gom00<007omOod0@Wom00<007omOod0:gom000AOod00`00Ooeoo@3oOod>002jOod0
015oo@03001ooGom0?Eoo@X00<Qoo@004Gom00<007omOod0k7om2@00dWom000AOod3003TOod8003K
Ood0015oo@03001ooGom0=aoo@P00>=oo@004Gom00<007omOod0eWom1P00jgom000AOod00`00Ooeo
o@3@Ood6003aOod0015oo@03001ooGom0<]oo@D00?Moo@004Gom00<007omOod0agom1000o7om000A
Ood00`00Ooeoo@33Ood4003oOod1Ood0015oo@<00;moo@@00?moo@Eoo@004Gom00<007omOod0^gom
1000ogom2Gom000AOod00`00Ooeoo@2hOod3003oOod=Ood0015oo@03001ooGom0;Eoo@<00?mooA1o
o@004Gom00<007omOod0/gom0P00ogom4gom000AOod00`00Ooeoo@2`Ood3003oOodEOod0015oo@03
001ooGom0:eoo@<00?mooAQoo@004Gom00<007omOod0Zgom0P00ogom6gom000AOod3002XOod3003o
OodMOod0015oo@03001ooGom0:Ioo@800?mooB1oo@004Gom00<007omOod0Y7om0P00ogom8Wom000A
Ood00`00Ooeoo@2ROod2003oOodTOod0015oo@03001ooGom0:1oo@800?mooBIoo@004Gom00<007om
Ood0WWom0P00ogom:7om000AOod00`00Ooeoo@2MOod00`00Ooeoo@3oOodXOod0015oo@<009]oo@80
0?mooB]oo@004Gom00<007omOod0VGom0P00ogom;Gom000AOod00`00Ooeoo@2GOod2003oOod_Ood0
015oo@03001ooGom09Eoo@800?mooC5oo@004Gom00<007omOod0U7om00<007omOod0ogom<Gom000A
Ood00`00Ooeoo@2BOod2003oOoddOod000Moo@D000Eoo@03001ooGom095oo@03001ooGom0?mooCAo
o@002Gom00<007omOod01Gom00<007omOod0Sgom0P00ogom=gom0009Ood00`00Ooeoo@05Ood4002=
Ood00`00Ooeoo@3oOodgOod000Uoo@03001ooGom00Eoo@03001ooGom08aoo@800?mooCYoo@002Gom
00<007omOod01Gom00<007omOod0Rgom00<007omOod0ogom>Wom0008Ood20007Ood00`00Ooeoo@29
Ood2003oOodmOod0015oo@03001ooGom08Qoo@03001ooGom0?mooCeoo@004Gom00<007omOod0QWom
0P00ogom@7om000AOod00`00Ooeoo@25Ood00`00Ooeoo@3oOoe0Ood0015oo@<008=oo@800?mooD=o
o@004Gom00<007omOod0PWom00<007omOod0ogom@gom000AOod00`00Ooeoo@21Ood00`00Ooeoo@3o
Ooe4Ood0015oo@03001ooGom081oo@03001ooGom0?mooDEoo@004Gom00<007omOod0Ogom00<007om
Ood0ogomAWom000AOod00`00Ooeoo@1mOod2003oOoe9Ood0015oo@03001ooGom07aoo@03001ooGom
0?mooDUoo@004Gom0`00Ngom00<007omOod0ogomBWom000AOod00`00Ooeoo@1jOod00`00Ooeoo@3o
Ooe;Ood0015oo@03001ooGom07Uoo@03001ooGom0?mooDaoo@004Gom00<007omOod0N7om00<007om
Ood0ogomCGom000AOod00`00Ooeoo@1gOod00`00Ooeoo@3oOoe>Ood0015oo@03001ooGom07Ioo@03
001ooGom0?mooDmoo@004Gom00<007omOod0MGom00<007omOod0ogomD7om000AOod00`00Ooeoo@1c
Ood2003oOoeCOod0015oo@<0079oo@03001ooGom0?mooE=oo@004Gom00<007omOod0LGom00<007om
Ood0ogomE7om000AOod00`00Ooeoo@1`Ood00`00Ooeoo@3oOoeEOod0015oo@03001ooGom06moo@03
001ooGom0?mooEIoo@004Gom00<007omOod0KWom00<007omOod0ogomEgom000AOod00`00Ooeoo@1]
Ood00`00Ooeoo@3oOoeHOod0015oo@03001ooGom06aoo@03001ooGom0?mooEUoo@004Gom0`00K7om
00<007omOod0ogomFGom000AOod00`00Ooeoo@1[Ood00`00Ooeoo@3oOoeJOod0015oo@03001ooGom
06Yoo@03001ooGom0?mooE]oo@004Gom00<007omOod0JGom00<007omOod0ogomG7om000AOod00`00
Ooeoo@1XOod00`00Ooeoo@3oOoeMOod000Moo@@000Ioo@03001ooGom06Moo@03001ooGom0?mooEio
o@001gom00<007omOod01gom00<007omOod0IWom00<007omOod0ogomGgom0008Ood00`00Ooeoo@06
Ood4001UOod00`00Ooeoo@3oOoeOOod000Uoo@03001ooGom00Eoo@03001ooGom06Eoo@03001ooGom
0?mooF1oo@001gom00@007omOod000Ioo@03001ooGom06Aoo@03001ooGom0?mooF5oo@0027om0P00
1gom00<007omOod0Hgom00<007omOod0ogomHWom000AOod00`00Ooeoo@1ROod00`00Ooeoo@3oOoeS
Ood0015oo@03001ooGom065oo@03001ooGom0?mooFAoo@004Gom00<007omOod0H7om00<007omOod0
ogomIGom000AOod00`00Ooeoo@1OOod00`00Ooeoo@3oOoeVOod0015oo@<005moo@03001ooGom0?mo
oFIoo@004Gom00<007omOod0GWom00<007omOod0ogomIgom000AOod00`00Ooeoo@1MOod00`00Ooeo
o@3oOoeXOod0015oo@03001ooGom05aoo@03001ooGom0?mooFUoo@004Gom00<007omOod0Fgom00<0
07omOod0ogomJWom000AOod00`00Ooeoo@1KOod00`00Ooeoo@3oOoeZOod0015oo@03001ooGom05Yo
o@03001ooGom0?mooF]oo@004Gom0`00FGom00<007omOod0ogomK7om000AOod00`00Ooeoo@1IOod0
0`00Ooeoo@3oOoe/Ood0015oo@03001ooGom05Qoo@03001ooGom0?mooFeoo@004Gom00<007omOod0
F7om00<007omOod0ogomKGom000AOod00`00Ooeoo@1GOod00`00Ooeoo@3oOoe^Ood0015oo@03001o
oGom05Ioo@03001ooGom0?mooFmoo@004Gom00<007omOod0EWom00<007omOod0ogomKgom000AOod3
001EOod00`00Ooeoo@3oOoe`Ood0015oo@03001ooGom05Aoo@03001ooGom0?mooG5oo@004Gom00<0
07omOod0E7om00<007omOod0ogomLGom000AOod00`00Ooeoo@1COod00`00Ooeoo@3oOoebOod0015o
o@03001ooGom059oo@03001ooGom0?mooG=oo@004Gom00<007omOod0DWom00<007omOod0ogomLgom
000AOod00`00Ooeoo@1AOod00`00Ooeoo@3oOoedOod0015oo@03001ooGom051oo@03001ooGom0?mo
oGEoo@004Gom0`00D7om00<007omOod0ogomMGom000AOod00`00Ooeoo@1?Ood00`00Ooeoo@3oOoef
Ood0015oo@03001ooGom04moo@03001ooGom0?mooGIoo@004Gom00<007omOod0CWom00<007omOod0
ogomMgom000AOod00`00Ooeoo@1=Ood00`00Ooeoo@3oOoehOod000Qoo@8000Moo@03001ooGom04eo
o@03001ooGom0?mooGQoo@001gom00@007omOod000Ioo@03001ooGom04aoo@03001ooGom0?mooGUo
o@002Gom00<007omOod01Gom1000BWom00<007omOod0ogomNWom000:Ood00`00Ooeoo@04Ood00`00
Ooeoo@1;Ood00`00Ooeoo@3oOoejOod000Moo@04001ooGom0006Ood00`00Ooeoo@1:Ood00`00Ooeo
o@3oOoekOod000Qoo@8000Moo@03001ooGom04Uoo@03001ooGom0?mooGaoo@004Gom00<007omOod0
BGom00<007omOod0ogomO7om000AOod00`00Ooeoo@18Ood00`00Ooeoo@3oOoemOod0015oo@03001o
oGom04Qoo@03001ooGom0?mooGeoo@004Gom00<007omOod0Agom00<007omOod0ogomOWom000AOod3
0016Ood00`00Ooeoo@3oOoeoOod0015oo@03001ooGom04Ioo@03001ooGom0?mooGmoo@004Gom00<0
07omOod0AGom00<007omOod0ogomP7om000AOod00`00Ooeoo@14Ood00`00Ooeoo@3oOof1Ood0015o
o@03001ooGom04Aoo@03001ooGom0?mooH5oo@004Gom00<007omOod0@gom00<007omOod0ogomPWom
000AOod00`00Ooeoo@13Ood00`00Ooeoo@3oOof2Ood0015oo@<0049oo@03001ooGom0?mooH=oo@00
4Gom00<007omOod0@Gom00<007omOod0ogomQ7om000AOod00`00Ooeoo@11Ood00`00Ooeoo@3oOof4
Ood0015oo@03001ooGom041oo@03001ooGom0?mooHEoo@004Gom00<007omOod0?gom00<007omOod0
ogomQWom000AOod00`00Ooeoo@0oOod00`00Ooeoo@3oOof6Ood0015oo@03001ooGom03ioo@03001o
oGom0?mooHMoo@004Gom0`00?Wom00<007omOod0ogomQgom000AOod00`00Ooeoo@0mOod00`00Ooeo
o@3oOof8Ood0015oo@03001ooGom03aoo@03001ooGom0?mooHUoo@004Gom00<007omOod0?7om00<0
07omOod0ogomRGom000AOod00`00Ooeoo@0kOod00`00Ooeoo@3oOof:Ood0015oo@03001ooGom03Yo
o@03001ooGom0?mooH]oo@004Gom00<007omOod0>Wom00<007omOod0ogomRgom000AOod00`00Ooeo
o@0iOod00`00Ooeoo@3oOof<Ood0015oo@<003Uoo@03001ooGom0?mooHaoo@004Gom00<007omOod0
>7om00<007omOod0ogomSGom000AOod00`00Ooeoo@0gOod00`00Ooeoo@3oOof>Ood0015oo@03001o
oGom03Moo@03001ooGom0?mooHioo@004Gom00<007omOod0=Wom00<007omOod0ogomSgom0009Ood3
0005Ood00`00Ooeoo@0eOod00`00Ooeoo@3oOof@Ood000Yoo@03001ooGom00Aoo@03001ooGom03Eo
o@03001ooGom0?mooI1oo@001gom1@001Gom1000<gom00<007omOod0ogomTGom0007Ood01000Ooeo
o@001Wom00<007omOod0<gom00<007omOod0ogomTWom0008Ood00`00Ood00006Ood00`00Ooeoo@0c
Ood00`00Ooeoo@3oOofBOod000Uoo@8000Ioo@03001ooGom039oo@03001ooGom0?mooI=oo@004Gom
00<007omOod0<Wom00<007omOod0ogomTgom000AOod00`00Ooeoo@0aOod00`00Ooeoo@3oOofDOod0
015oo@03001ooGom031oo@03001ooGom0?mooIEoo@004Gom0`00<7om00<007omOod0ogomUGom000A
Ood00`00Ooeoo@0_Ood00`00Ooeoo@3oOofFOod0015oo@03001ooGom02ioo@03001ooGom0?mooIMo
o@004Gom00<007omOod0;Wom00<007omOod0ogomUgom000AOod00`00Ooeoo@0]Ood00`00Ooeoo@3o
OofHOod0015oo@03001ooGom02aoo@03001ooGom0?mooIUoo@004Gom00<007omOod0;7om00<007om
Ood0ogomVGom000AOod00`00Ooeoo@0[Ood00`00Ooeoo@3oOofJOod0015oo@<002Yoo@03001ooGom
0?mooI]oo@004Gom00<007omOod0:Wom00<007omOod0ogomVgom000AOod00`00Ooeoo@0YOod00`00
Ooeoo@3oOofLOod0015oo@03001ooGom02Uoo@03001ooGom0?mooIaoo@004Gom00<007omOod0:7om
00<007omOod0ogomWGom000AOod00`00Ooeoo@0WOod00`00Ooeoo@3oOofNOod0015oo@03001ooGom
02Moo@03001ooGom0?mooIioo@004Gom0`009Wom00<007omOod0ogomWgom000AOod00`00Ooeoo@0U
Ood00`00Ooeoo@3oOofPOod0015oo@03001ooGom02Eoo@03001ooGom0?mooJ1oo@004Gom00<007om
Ood097om00<007omOod0ogomXGom000AOod00`00Ooeoo@0SOod00`00Ooeoo@3oOofROod0015oo@03
001ooGom02=oo@03001ooGom0?mooJ9oo@004Gom00<007omOod08Wom00<007omOod0ogomXgom000A
Ood3000ROod00`00Ooeoo@3oOofSOod0015oo@03001ooGom025oo@03001ooGom0?mooJAoo@004Gom
00<007omOod087om00<007omOod0ogomYGom000AOod00`00Ooeoo@0POod00`00Ooeoo@3oOofUOod0
015oo@03001ooGom01moo@03001ooGom0?mooJIoo@004Gom00<007omOod07Wom00<007omOod0ogom
Ygom0008Ood20007Ood00`00Ooeoo@0NOod00`00Ooeoo@3oOofWOod000Moo@04001ooGom0006Ood0
0`00Ooeoo@0MOod00`00Ooeoo@3oOofXOod000Yoo@03001ooGom00Aoo@@001]oo@03001ooGom0?mo
oJUoo@0027om0P001gom00<007omOod077om00<007omOod0ogomZGom0008Ood00`00Ooeoo@06Ood0
0`00Ooeoo@0KOod00`00Ooeoo@3oOofZOod000Qoo@<000Ioo@03001ooGom01Yoo@03001ooGom0?mo
oJ]oo@004Gom00<007omOod06Gom00<007omOod0ogom[7om000AOod00`00Ooeoo@0HOod00`00Ooeo
o@3oOof]Ood0015oo@03001ooGom01Moo@03001ooGom0?mooJioo@004Gom0`005Wom00<007omOod0
ogom[gom000AOod00`00Ooeoo@0EOod00`00Ooeoo@3oOof`Ood0015oo@03001ooGom01Aoo@03001o
oGom0?mooK5oo@004Gom00<007omOod04gom00<007omOod0ogom/Wom000AOod00`00Ooeoo@0BOod0
0`00Ooeoo@3oOofcOod0015oo@03001ooGom015oo@03001ooGom0?mooKAoo@004Gom00<007omOod0
4Gom00<007omOod0ogom]7om000AOod00`00Ooeoo@0?Ood2003oOofgOod0015oo@<000ioo@03001o
oGom0?mooKMoo@004Gom00<007omOod037om0P00ogom^Wom000AOod00`00Ooeoo@0:Ood2003oOofl
Ood0015oo@03001ooGom00Qoo@800?mooKioo@004Gom00<007omOod01Wom0P00ogom`7om000AOod0
0`00Ooeoo@04Ood2003oOog2Ood0015oo@03001ooGom00D00?mooL=oo@004Gom0`00ogomb7om000A
Ood00`00Ooeoo@3oOog8Ood0015oo@03001ooGom0?mooLQoo@004Gom00<007omOod0ogomb7om000A
Ood00`00Ooeoo@3oOog8Ood0015oo@03001ooGom0?mooLQoo@004Gom00<007omOod0ogomb7om000A
Ood00`00Ooeoo@3oOog8Ood00001\
\>"],
  ImageRangeCache->{{{0, 474.5}, {292.875, 0}} -> {-0.0520357, -2.14863, \
0.0029177, 0.0271635}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = 0.2;\)\), "\[IndentingNewLine]", 
    \(Plot[{c0t0[e, 
          p], \((c1t0[e, p])\), \((c2t0[e, p])\)}\[IndentingNewLine], {e, 
        emin1, emax/10}\[IndentingNewLine], 
      PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty]\), "\[IndentingNewLine]", 
    \(p =. \)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.023308 0.0501517 0.158746 19.0258 [
[.14869 .14625 -9 -9 ]
[.14869 .14625 9 0 ]
[.27407 .14625 -3 -9 ]
[.27407 .14625 3 0 ]
[.39945 .14625 -9 -9 ]
[.39945 .14625 9 0 ]
[.52483 .14625 -6 -9 ]
[.52483 .14625 6 0 ]
[.6502 .14625 -12 -9 ]
[.6502 .14625 12 0 ]
[.77558 .14625 -6 -9 ]
[.77558 .14625 6 0 ]
[.90096 .14625 -12 -9 ]
[.90096 .14625 12 0 ]
[.01081 .06362 -36 -4.5 ]
[.01081 .06362 0 4.5 ]
[.01081 .25387 -30 -4.5 ]
[.01081 .25387 0 4.5 ]
[.01081 .349 -24 -4.5 ]
[.01081 .349 0 4.5 ]
[.01081 .44413 -30 -4.5 ]
[.01081 .44413 0 4.5 ]
[.01081 .53926 -24 -4.5 ]
[.01081 .53926 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14869 .15875 m
.14869 .165 L
s
[(2.5)] .14869 .14625 0 1 Mshowa
.27407 .15875 m
.27407 .165 L
s
[(5)] .27407 .14625 0 1 Mshowa
.39945 .15875 m
.39945 .165 L
s
[(7.5)] .39945 .14625 0 1 Mshowa
.52483 .15875 m
.52483 .165 L
s
[(10)] .52483 .14625 0 1 Mshowa
.6502 .15875 m
.6502 .165 L
s
[(12.5)] .6502 .14625 0 1 Mshowa
.77558 .15875 m
.77558 .165 L
s
[(15)] .77558 .14625 0 1 Mshowa
.90096 .15875 m
.90096 .165 L
s
[(17.5)] .90096 .14625 0 1 Mshowa
.125 Mabswid
.04838 .15875 m
.04838 .1625 L
s
.07346 .15875 m
.07346 .1625 L
s
.09854 .15875 m
.09854 .1625 L
s
.12361 .15875 m
.12361 .1625 L
s
.17376 .15875 m
.17376 .1625 L
s
.19884 .15875 m
.19884 .1625 L
s
.22391 .15875 m
.22391 .1625 L
s
.24899 .15875 m
.24899 .1625 L
s
.29914 .15875 m
.29914 .1625 L
s
.32422 .15875 m
.32422 .1625 L
s
.34929 .15875 m
.34929 .1625 L
s
.37437 .15875 m
.37437 .1625 L
s
.42452 .15875 m
.42452 .1625 L
s
.4496 .15875 m
.4496 .1625 L
s
.47467 .15875 m
.47467 .1625 L
s
.49975 .15875 m
.49975 .1625 L
s
.5499 .15875 m
.5499 .1625 L
s
.57498 .15875 m
.57498 .1625 L
s
.60005 .15875 m
.60005 .1625 L
s
.62513 .15875 m
.62513 .1625 L
s
.67528 .15875 m
.67528 .1625 L
s
.70036 .15875 m
.70036 .1625 L
s
.72543 .15875 m
.72543 .1625 L
s
.75051 .15875 m
.75051 .1625 L
s
.80066 .15875 m
.80066 .1625 L
s
.82574 .15875 m
.82574 .1625 L
s
.85081 .15875 m
.85081 .1625 L
s
.87589 .15875 m
.87589 .1625 L
s
.92604 .15875 m
.92604 .1625 L
s
.95111 .15875 m
.95111 .1625 L
s
.97619 .15875 m
.97619 .1625 L
s
.25 Mabswid
0 .15875 m
1 .15875 L
s
.02331 .06362 m
.02956 .06362 L
s
[(-0.005)] .01081 .06362 1 0 Mshowa
.02331 .25387 m
.02956 .25387 L
s
[(0.005)] .01081 .25387 1 0 Mshowa
.02331 .349 m
.02956 .349 L
s
[(0.01)] .01081 .349 1 0 Mshowa
.02331 .44413 m
.02956 .44413 L
s
[(0.015)] .01081 .44413 1 0 Mshowa
.02331 .53926 m
.02956 .53926 L
s
[(0.02)] .01081 .53926 1 0 Mshowa
.125 Mabswid
.02331 .08264 m
.02706 .08264 L
s
.02331 .10167 m
.02706 .10167 L
s
.02331 .12069 m
.02706 .12069 L
s
.02331 .13972 m
.02706 .13972 L
s
.02331 .17777 m
.02706 .17777 L
s
.02331 .1968 m
.02706 .1968 L
s
.02331 .21582 m
.02706 .21582 L
s
.02331 .23485 m
.02706 .23485 L
s
.02331 .2729 m
.02706 .2729 L
s
.02331 .29193 m
.02706 .29193 L
s
.02331 .31095 m
.02706 .31095 L
s
.02331 .32998 m
.02706 .32998 L
s
.02331 .36803 m
.02706 .36803 L
s
.02331 .38706 m
.02706 .38706 L
s
.02331 .40608 m
.02706 .40608 L
s
.02331 .42511 m
.02706 .42511 L
s
.02331 .46316 m
.02706 .46316 L
s
.02331 .48218 m
.02706 .48218 L
s
.02331 .50121 m
.02706 .50121 L
s
.02331 .52024 m
.02706 .52024 L
s
.02331 .04459 m
.02706 .04459 L
s
.02331 .02557 m
.02706 .02557 L
s
.02331 .00654 m
.02706 .00654 L
s
.02331 .55829 m
.02706 .55829 L
s
.02331 .57731 m
.02706 .57731 L
s
.02331 .59634 m
.02706 .59634 L
s
.02331 .61536 m
.02706 .61536 L
s
.25 Mabswid
.02331 0 m
.02331 .61803 L
s
.5 Mabswid
.02381 .25244 m
.02499 .32411 L
.02605 .36636 L
.02729 .40478 L
.02846 .43266 L
.02946 .45291 L
.03053 .474 L
.0317 .48886 L
.03279 .5032 L
.03746 .54732 L
.03875 .55691 L
.04012 .56748 L
.04143 .57504 L
.04262 .57886 L
.04497 .58649 L
.04626 .59074 L
.04748 .59478 L
.04817 .5971 L
.04892 .59813 L
.05023 .59889 L
.05278 .60037 L
.05523 .6018 L
.05657 .60259 L
.05781 .60332 L
.05888 .60304 L
.06002 .60148 L
.06244 .59821 L
.08448 .56041 L
.10458 .51446 L
.14443 .42688 L
.18275 .36148 L
.22354 .30937 L
.2628 .27378 L
.30055 .24762 L
.34076 .22799 L
.37944 .2132 L
.42058 .20167 L
.46021 .19343 L
.49832 .187 L
.53888 .18147 L
.57792 .17722 L
.59927 .17557 L
.61942 .17415 L
.65789 .17176 L
.69881 .16963 L
.73821 .1679 L
.7761 .1665 L
.81644 .16525 L
.85526 .16439 L
.89654 .16365 L
Mistroke
.9363 .16303 L
.97454 .16251 L
.97619 .16249 L
Mfstroke
1 0 0 r
.02381 .12753 m
.02499 .1037 L
.02605 .0897 L
.02729 .077 L
.02846 .06782 L
.02946 .06118 L
.03053 .05428 L
.0317 .04946 L
.03279 .04482 L
.03395 .0396 L
.0352 .03588 L
.03746 .03072 L
.03876 .02767 L
.04014 .02435 L
.04144 .02203 L
.04262 .02092 L
.04516 .01851 L
.04649 .01723 L
.04719 .01656 L
.04793 .01584 L
.04857 .01538 L
.04928 .01533 L
.05052 .01524 L
.05297 .01506 L
.05534 .0149 L
.05664 .0148 L
.05787 .01472 L
.05902 .01501 L
.06026 .0157 L
.06244 .01691 L
.10458 .04765 L
.14536 .07786 L
.18463 .09934 L
.22238 .11451 L
.24173 .12032 L
.26258 .12571 L
.28223 .1301 L
.30372 .13414 L
.34335 .13969 L
.38391 .14407 L
.42295 .14707 L
.46445 .14945 L
.50443 .15128 L
.5429 .15269 L
.56238 .15331 L
.58382 .15386 L
.62322 .15463 L
.66356 .1553 L
.70238 .15584 L
.74366 .15632 L
Mistroke
.78342 .1567 L
.82167 .15702 L
.84138 .15713 L
.86236 .15724 L
.904 .15743 L
.94412 .1576 L
.97619 .15771 L
Mfstroke
.2 1 0 r
.02381 .15617 m
.02499 .1542 L
.02605 .15304 L
.02729 .15198 L
.02846 .15121 L
.02946 .15065 L
.03053 .15007 L
.0317 .14966 L
.03279 .14926 L
.03746 .14803 L
.03875 .14776 L
.04012 .14747 L
.04143 .14725 L
.04262 .14715 L
.04497 .14693 L
.04748 .14669 L
.04822 .14662 L
.04892 .14659 L
.05023 .14657 L
.05278 .14652 L
.05504 .14647 L
.05627 .14645 L
.05742 .14642 L
.05867 .14641 L
.05933 .14644 L
.06004 .14646 L
.06244 .14654 L
.08448 .14751 L
.10458 .14871 L
.14443 .15103 L
.18275 .15277 L
.22354 .15418 L
.2628 .15516 L
.30055 .1559 L
.34076 .15645 L
.37944 .15689 L
.42058 .15723 L
.46021 .15748 L
.49832 .15768 L
.53888 .15786 L
.55761 .15794 L
.57792 .15801 L
.59927 .15806 L
.61942 .15811 L
.66034 .15819 L
.69974 .15826 L
.73763 .15832 L
.77797 .15838 L
.81679 .15843 L
.83797 .15844 L
Mistroke
.85807 .15846 L
.89632 .15849 L
.93701 .15851 L
.97619 .15854 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{472, 291.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007H00018a000`40O003h00OogomfGom003oOogI
Ood00?mooMUoo@00ogomfGom003oOogIOod00?mooMUoo@00ogomfGom003oOogIOod00?mooMUoo@00
:Gom00<007omOod0ogom[Gom000YOod00`00Ooeoo@3oOof]Ood002Uoo@03001ooGom0?mooJeoo@00
:Gom0`00ogom[Gom000YOod00`00Ooeoo@3oOof]Ood002Uoo@03001ooGom0?mooJeoo@00:Gom00<0
07omOod0ogom[Gom000YOod00`00Ooeoo@08Ood6O03oOofOOod002Uoo@03001ooGom00Moo@9l00Eo
o@03O01ooGom0?mooIaoo@00:Gom00<007omOod01Wom00=l07omOod01Wom0W`0ogomW7om000YOod0
0`00Ooeoo@05Ood00g`0Ooeoo@09Ood00g`0Ooeoo@3oOofIOod002Uoo@03001ooGom00Aoo@03O01o
oGom00]oo@9l0?mooIUoo@00:Gom0`0017om00=l07omOod03Gom00=l07omOod0ogomUWom000YOod0
0`00Ooeoo@04Ood00g`0Ooeoo@0>Ood2O03oOofFOod002Uoo@03001ooGom00=oo@03O01ooGom015o
o@03O01ooGom0?mooI=oo@00:Gom00<007omOod00gom00=l07omOod04Wom00=l07omOod0ogomTWom
000YOod00`00Ooeoo@02Ood00g`0Ooeoo@0DOod2O03oOofBOod002Uoo@03001ooGom009oo@03O01o
oGom01Ioo@03O01ooGom0?mooHmoo@00:Gom00<007omOod00Wom00=l07omOod05gom0W`0ogomSgom
000YOod00`00Ooeoo@02Ood00g`0Ooeoo@0IOod00g`0Ooeoo@3oOof<Ood002Uoo@<00003Ooel07om
01aoo@9l0?mooHaoo@00:Gom00D007omOoeooG`001moo@03O01ooGom0?mooHUoo@00:Gom00D007om
OoeooG`0021oo@03O01ooGom0?mooHQoo@00:Gom00D007omOoeooG`0025oo@9l0?mooHQoo@00:Gom
00@007omOoel02Aoo@03O01ooGom0?mooHEoo@00:Gom00@007omOoel02Eoo@03O01ooGom0?mooHAo
o@0027om0P0017om0P0017om0P0017om0P0017om0P001gom00@007omOoel02Ioo@9l0?mooHAoo@00
1gom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod000Ioo@04001o
oGomO00XOod00g`0Ooeoo@3oOof1Ood000Moo@04001ooGom0008Ood01000Ooeoo@000Wom00@007om
Ood000Eoo@03001ooGom00Aoo@<00003O01ooGom02Moo@03O01ooGom0?mooH1oo@0000=oo@000000
0P000Wom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000gom0P001gom00<007omO000
:gom00=l07omOod0ogomOgom0007Ood01000Ooeoo@0027om00@007omOod0009oo@04001ooGom0003
Ood00`00Ooeoo@06Ood00`00Ooel000/Ood2O03oOoeoOod000Qoo@8000Yoo@8000Aoo@8000Aoo@<0
00Ioo@03001ooG`002ioo@03O01ooGom0?mooGaoo@00:Gom00<007omO000;gom00=l07omOod0ogom
Ngom000YOod00`00Ooel000`Ood2O03oOoekOod002Uoo@03001ooG`0039oo@03O01ooGom0?mooGQo
o@00:Gom00<007omO000<gom00=l07omOod0ogomMgom000YOod00`00Ooel000dOod2O03oOoegOod0
02Uoo@800003O01ooGom03Aoo@9l0?mooGEoo@00:Gom00<007`0Ood0>7om0W`0ogomLgom000YOod0
0`00O01oo@0jOod2O03oOoeaOod002Uoo@03001l07om03aoo@9l0?mooFmoo@00:Gom00<007`0Ood0
?Wom0W`0ogomKGom000YOod00`00O01oo@10Ood2O03oOoe[Ood002Uoo@03001l07om049oo@9l0?mo
oFUoo@00:Gom00<007`0Ood0A7om0W`0ogomIgom000YOod00`00O0000016Ood2O03oOoeUOod002Uo
o@03001l07om04Qoo@=l0?mooF9oo@00:Gom00<007`0Ood0Bgom0W`0ogomH7om000YOod00`00O01o
o@1=Ood2O03oOoeNOod002Uoo@03001l07om04moo@=l0?mooE]oo@00:Gom00<007`0Ood0DWom0W`0
ogomFGom000YOod00`00O01oo@1DOod3O03oOoeFOod002Uoo@03O01ooGom05Moo@Al0?mooE9oo@00
:Gom00=l00000000Fgom17`0ogomCWom000YOod00g`0Ooeoo@1OOod3O03oOoe;Ood002Uoo@03O01o
oGom069oo@=l0?mooDQoo@00:Gom00=l07omOod0IGom17`0ogomA7om000YOod00`00Ooeoo@0/Ood4
0003Ood20004Ood2000^Ood4O00_Ood00`00Ooeoo@02Ood20004Ood2000/Ood50002Ood2000XOod5
00000gom000000020003Ood20004Ood2000XOod50002Ood2000XOod50003Ood00`00Ooeoo@02Ood2
0004Ood2000SOod002Uoo@03001ooGom02aoo@03001ooGom00Uoo@04001ooGom000]Ood01000Ooeo
o@001g`0:7om00<007omOod01gom00@007omOod002eoo@05001ooGomOod00002Ood00`00Ooeoo@0W
Ood01@00OoeooGom00002gom00@007omOod002Uoo@05001ooGomOod00002Ood00`00Ooeoo@0WOod0
0`00Ooeoo@03Ood00`00Ooeoo@07Ood01000Ooeoo@008Wom000YOod00`00Ooeoo@0]Ood00`00Ooeo
o@0;Ood00`00Ooeoo@0^Ood00`00Ooeoo@05Ood7O00QOod00`00Ooeoo@0:Ood00`00Ooeoo@0[Ood0
1@00OoeooGom00000Wom00<007omOod09gom00<007omOod00Wom00<007omOod02gom00<007omOod0
9gom00<007omOod017om00<007omOod09gom00<007omOod00gom00<007omOod02Wom00<007omOod0
87om000YOod00`00Ooeoo@0^Ood00`00Ooeoo@08Ood2000_Ood2000?Ood6O00LOod00`00Ooeoo@07
Ood2000^Ood01@00OoeooGom00000Wom00<007omOod09gom00<007omOod00gom00<007omOod027om
0P00:Wom00<007omOod00Wom0P00:Wom00<007omOod017om00<007omOod01gom0P008gom000YOod0
0`00Ooeoo@0/Ood01000Ooeoo@002Gom00<007omOod0;Wom00<007omOod057om1W`04gom00@007om
Ood000Uoo@03001ooGom02eoo@05001ooGomOod00002Ood00`00Ooeoo@0WOod01@00OoeooGom0000
0Wom00<007omOod01gom00<007omOod0:Gom00<007omOod00Wom00<007omOod0:Gom00D007omOoeo
o@00009oo@03001ooGom00Moo@03001ooGom029oo@00:Gom0`00;Gom0P002Wom0`00;Wom0`006Wom
27`02gom10002Gom0`00;7om0P0017om0P00:Gom0P0017om0P002Wom0`00:7om0P0017om0`00:7om
0P000gom10002Gom0`008Wom000YOod00`00Ooeoo@2?Ood9O03oOodEOod002Uoo@03001ooGom09Qo
o@el0?moo@Qoo@00:Gom00<007omOod00Wom6aOPR7om4G`0mWom000YOod00`00Ooeoo@025n0KOod=
5n2<OodBO03TOod002Uoo@04001ooAOP5n0YOodA5n2=OodNO036Ood002Uoo@03000Gh7om03]ooB<G
h8QooBQl09ioo@00:Gom00<Gh7omOod0GWomEaOPFGomJG`0=Gom000OOog2003/5n0:0001Ood002Uo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Uoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qo
o@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Qoo@03001ooGom00Uoo@00:Gom00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod02Gom00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om00<007omOod027om00<007om
Ood027om00<007omOod027om00<007omOod027om00<007omOod027om;@002gom000YOod00`00Ooeo
o@0dOod00`00Ooeoo@0dOod00`00Ooeoo@0dOod00`00Ooeoo@0eOod00`00Ooeoo@0dOod00`00Ooeo
o@0dOod00`00Ooeoo@06OodS000;Ood00`00Ooeoo@0ZOod002Uoo@03001ooGom0?mooC1ooB8005]o
o@00:Gom00<007omOod0ogom7Wom4P00OGom000YOod00`00Ooeoo@3oOod=OodA002?Ood002Uoo@03
001ooGom0?moo@d00:1oo@00:Gom00<007omOod0kGom4P00[Gom000YOod3003UOod8002oOod002Uo
o@03001ooGom0=eoo@P00<Moo@00:Gom00<007omOod0egom1P00cgom000YOod00`00Ooeoo@3AOod6
003EOod002Uoo@03001ooGom0<Yoo@L00=]oo@00:Gom00<007omOod0`Wom2000hWom000YOod00`00
Ooeoo@2kOod7003ZOod002Uoo@03001ooGom0;Moo@@00?5oo@00:Gom0`00/gom1000mGom000YOod0
0`00Ooeoo@2_Ood4003iOod002Uoo@03001ooGom0:]oo@@00?eoo@00:Gom00<007omOod0Ygom1000
ogom0Wom000YOod00`00Ooeoo@2SOod4003oOod6Ood002Uoo@03001ooGom0:1oo@<00?moo@Yoo@00
:Gom00<007omOod0W7om1000ogom3Gom000YOod00`00Ooeoo@2IOod3003oOodAOod002Uoo@<009Mo
o@800?mooAAoo@00:Gom00<007omOod0U7om0`00ogom5Wom000YOod00`00Ooeoo@2BOod2003oOodI
Ood002Uoo@03001ooGom091oo@800?mooA]oo@00:Gom00<007omOod0SGom0`00ogom7Gom000YOod0
0`00Ooeoo@2;Ood2003oOodPOod002Uoo@03001ooGom08Qoo@<00?mooB9oo@00:Gom00<007omOod0
QWom0P00ogom9Gom000YOod00`00Ooeoo@24Ood2003oOodWOod002Uoo@<0089oo@800?mooBUoo@00
:Gom00<007omOod0Ogom0`00ogom:gom000YOod00`00Ooeoo@1mOod2003oOod^Ood002Uoo@03001o
oGom07]oo@800?mooC1oo@00:Gom00<007omOod0NGom0P00ogom<Wom000YOod00`00Ooeoo@1gOod2
003oOoddOod000Qoo@8000Aoo@8000Aoo@8000Aoo@8000Aoo@8000Moo@03001ooGom07Eoo@800?mo
oCIoo@001gom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod000Io
o@03001ooGom07Aoo@03001ooGom0?mooCIoo@001gom00@007omOod000Qoo@04001ooGom0002Ood0
1000Ooeoo@001Gom00<007omOod017om1000LWom00<007omOod0ogom=gom0007Ood01000Ooeoo@00
27om00@007omOod0009oo@04001ooGom0003Ood20007Ood00`00Ooeoo@1aOod2003oOodjOod000Mo
o@04001ooGom0008Ood01000Ooeoo@000Wom00@007omOod000=oo@03001ooGom00Ioo@03001ooGom
071oo@03001ooGom0?mooCYoo@0027om0P002Wom0P0017om0P0017om0`001Wom00<007omOod0KWom
0P00ogom?Gom000YOod00`00Ooeoo@1]Ood00`00Ooeoo@3oOodmOod002Uoo@03001ooGom06]oo@80
0?mooD1oo@00:Gom00<007omOod0JWom00<007omOod0ogom@7om000YOod00`00Ooeoo@1YOod00`00
Ooeoo@3oOoe1Ood002Uoo@<006Moo@800?mooDAoo@00:Gom00<007omOod0IWom00<007omOod0ogom
A7om000YOod00`00Ooeoo@1UOod00`00Ooeoo@3oOoe5Ood002Uoo@03001ooGom06Aoo@03001ooGom
0?mooDIoo@00:Gom00<007omOod0Hgom00<007omOod0ogomAgom000YOod00`00Ooeoo@1QOod2003o
Ooe:Ood002Uoo@03001ooGom061oo@03001ooGom0?mooDYoo@00:Gom0P00H7om00<007omOod0ogom
Bgom000YOod2001OOod00`00Ooeoo@3oOoe<Ood002Uoo@<005eoo@03001ooGom0?mooDeoo@00:Gom
0P00GGom00<007omOod0ogomCWom000YOod2001LOod00`00Ooeoo@3oOoe?Ood002Uoo@8005Yoo@80
0?mooE9oo@00:Gom0P00FGom00<007omOod0ogomDWom000YOod2001HOod00`00Ooeoo@3oOoeCOod0
02Uoo@8005Moo@03001ooGom0?mooEAoo@00:Gom0P00EWom00<007omOod0ogomEGom000YOod3001D
Ood00`00Ooeoo@3oOoeFOod002Uoo@8005Aoo@03001ooGom0?mooEMoo@00:Gom0P00E7om00<007om
Ood0ogomEgom000YOod2001COod00`00Ooeoo@3oOoeHOod002Uoo@80059oo@03001ooGom0?mooEUo
o@00:Gom0P00DGom00<007omOod0ogomFWom000YOod2001AOod00`00Ooeoo@3oOoeJOod002Uoo@80
051oo@03001ooGom0?mooE]oo@00:Gom0`00CWom00<007omOod0ogomG7om000YOod2001>Ood00`00
Ooeoo@3oOoeMOod002Uoo@8004eoo@03001ooGom0?mooEioo@00:Gom0P00CGom00<007omOod0ogom
GWom000YOod2001<Ood00`00Ooeoo@3oOoeOOod002Uoo@8004]oo@03001ooGom0?mooF1oo@00:Gom
0P00BWom00<007omOod0ogomHGom000>Ood20004Ood20004Ood20003Ood50005Ood20019Ood00`00
Ooeoo@3oOoeROod000eoo@04001ooGom0008Ood01000Ooeoo@0017om00<007omOod01Gom0P00BGom
00<007omOod0ogomHWom000=Ood01000Ooeoo@0027om00@007omOod000Aoo@03001ooGom00Eoo@@0
04Ioo@03001ooGom0?mooF=oo@003Gom00@007omOod000Qoo@04001ooGom0004Ood00`00Ooeoo@05
Ood20017Ood00`00Ooeoo@3oOoeTOod000eoo@04001ooGom0008Ood01000Ooeoo@0017om00<007om
Ood01Gom0P00AWom00<007omOod0ogomIGom000>Ood2000:Ood20004Ood20007Ood20016Ood00`00
Ooeoo@3oOoeUOod002Uoo@8004Eoo@03001ooGom0?mooFIoo@00:Gom0P00A7om00<007omOod0ogom
Igom000YOod20013Ood00`00Ooeoo@3oOoeXOod002Uoo@8004=oo@03001ooGom0?mooFQoo@00:Gom
0`00@Gom00<007omOod0ogomJGom000YOod20012Ood00`00Ooeoo@3oOoeYOod002Uoo@80045oo@03
001ooGom0?mooFYoo@00:Gom0P00@7om00<007omOod0ogomJgom000YOod20010Ood00`00Ooeoo@3o
Ooe[Ood002Uoo@8003moo@03001ooGom0?mooFaoo@00:Gom0P00?gom00<007omOod0ogomK7om000Y
Ood2000nOod00`00Ooeoo@3oOoe]Ood002Uoo@03001oo@0003eoo@03001ooGom0?mooFeoo@00:Gom
0`00?7om00<007omOod0ogomKWom000YOod00`00Ood0000kOod00`00Ooeoo@3oOoe_Ood002Uoo@03
001oo@0003]oo@03001ooGom0?mooFmoo@00:Gom00<007om0000>Wom00<007omOod0ogomL7om000Y
Ood00`00Ood0000jOod00`00Ooeoo@3oOoe`Ood002Uoo@03001oo@0003Uoo@03001ooGom0?mooG5o
o@00:Gom00<007om0000>7om00<007omOod0ogomLWom000YOod00`00Ood0000hOod00`00Ooeoo@3o
OoebOod002Uoo@<003Moo@03001ooGom0?mooG=oo@00:Gom00<007om0000=gom00<007omOod0ogom
Lgom000YOod00`00Ood0000fOod00`00Ooeoo@3oOoedOod002Uoo@03001oo@0003Ioo@03001ooGom
0?mooGAoo@00:Gom00<007om0000=Gom00<007omOod0ogomMGom000YOod00`00Ood0000dOod00`00
Ooeoo@3oOoefOod002Uoo@03001oo@0003Aoo@03001ooGom0?mooGIoo@00:Gom00<007om0000<gom
00<007omOod0ogomMgom000YOod3000cOod00`00Ooeoo@3oOoegOod002Uoo@03001oo@00039oo@03
001ooGom0?mooGQoo@00:Gom00<007om0000<Wom00<007omOod0ogomN7om000YOod00`00Ood0000a
Ood00`00Ooeoo@3oOoeiOod002Uoo@03001oo@00035oo@03001ooGom0?mooGUoo@00:Gom00<007om
0000<7om00<007omOod0ogomNWom000YOod00`00Ood0000`Ood00`00Ooeoo@3oOoejOod000Qoo@80
00Aoo@8000Aoo@8000=oo@D0009oo@8000Moo@03001oo@0002moo@03001ooGom0?mooG]oo@001gom
00@007omOod000Qoo@04001ooGom0004Ood01@00OoeooGom00000Wom00<007omOod017om00@007om
Ood002ioo@03001ooGom0?mooG]oo@001gom00@007omOod000Qoo@04001ooGom0004Ood00`00Ooeo
o@04Ood00`00Ooeoo@04Ood4000^Ood00`00Ooeoo@3oOoekOod000Moo@04001ooGom0008Ood01000
Ooeoo@0017om00<007omOod00Wom0P001gom00@007omOod002eoo@03001ooGom0?mooGaoo@001gom
00@007omOod000Qoo@04001ooGom0004Ood00`00Ooeoo@02Ood00`00Ooeoo@06Ood01000Ooeoo@00
;Gom00<007omOod0ogomO7om0008Ood2000:Ood20004Ood20004Ood30006Ood01000Ooeoo@00;7om
00<007omOod0ogomOGom000YOod01000Ooeoo@00;7om00<007omOod0ogomOGom000YOod01000Ooeo
o@00:gom00<007omOod0ogomOWom000YOod01000Ooeoo@00:gom00<007omOod0ogomOWom000YOod0
1000Ooeoo@00:Wom00<007omOod0ogomOgom000YOod4000ZOod00`00Ooeoo@3oOoeoOod002Uoo@04
001ooGom000ZOod00`00Ooeoo@3oOoeoOod002Uoo@04001ooGom000YOod00`00Ooeoo@3oOof0Ood0
02Uoo@04001ooGom000YOod00`00Ooeoo@3oOof0Ood002Uoo@04001ooGom000XOod00`00Ooeoo@3o
Oof1Ood002Uoo@04001ooGom000XOod00`00Ooeoo@3oOof1Ood002Uoo@04001ooGom000WOod00`00
Ooeoo@3oOof2Ood002Uoo@04001ooGom000WOod00`00Ooeoo@3oOof2Ood002Uoo@<00003Ood007om
02Eoo@03001ooGom0?mooH9oo@00:Gom00D007omOoeoo@0002Eoo@03001ooGom0?mooH=oo@00:Gom
00D007omOoeoo@0002Eoo@03001ooGom0?mooH=oo@00:Gom00D007omOoeoo@0002Aoo@03001ooGom
0?mooHAoo@00:Gom00D007omOoeoo@0002Aoo@03001ooGom0?mooHAoo@00:Gom00D007omOoeoo@00
02=oo@03001ooGom0?mooHEoo@00:Gom00D007omOoeoo@0002=oo@03001ooGom0?mooHEoo@00:Gom
00D007omOoeoo@00029oo@03001ooGom0?mooHIoo@00:Gom00D007omOoeoo@00029oo@03001ooGom
0?mooHIoo@00:Gom0`0000=oo@00Ood08Gom00<007omOod0ogomQWom000YOod01@00OoeooGom0000
8Gom00<007omOod0ogomQgom000YOod01@00OoeooGom00008Gom00<007omOod0ogomQgom000YOod0
1@00OoeooGom000087om00<007omOod0ogomR7om000YOod01@00OoeooGom000087om00<007omOod0
ogomR7om000YOod01@00OoeooGom00007gom00<007omOod0ogomRGom000YOod00`00Ooeoo@02Ood0
0`00Ooeoo@0LOod00`00Ooeoo@3oOof9Ood002Uoo@03001ooGom009oo@03001ooGom01aoo@03001o
oGom0?mooHUoo@00:Gom0`000Wom00<007omOod06gom00<007omOod0ogomRWom000YOod00`00Ooeo
o@02Ood00`00Ooeoo@0KOod00`00Ooeoo@3oOof:Ood002Uoo@03001ooGom009oo@03001ooGom01Yo
o@03001ooGom0?mooH]oo@00:Gom00<007omOod00Wom00<007omOod06Wom00<007omOod0ogomRgom
000YOod00`00Ooeoo@02Ood00`00Ooeoo@0IOod00`00Ooeoo@3oOof<Ood002Uoo@03001ooGom009o
o@03001ooGom01Uoo@03001ooGom0?mooHaoo@003Wom0P0017om0P0017om0P000gom10001Wom00<0
07omOod00Wom00<007omOod067om00<007omOod0ogomSGom000=Ood01000Ooeoo@0027om00@007om
Ood0009oo@03001ooGom00Moo@03001ooGom009oo@03001ooGom01Qoo@03001ooGom0?mooHeoo@00
3Gom00@007omOod000Qoo@04001ooGom0003Ood00`00Ooeoo@06Ood40002Ood00`00Ooeoo@0GOod0
0`00Ooeoo@3oOof=Ood000eoo@04001ooGom0008Ood01000Ooeoo@0017om00<007omOod01Gom00<0
07omOod00gom00<007omOod05Wom00<007omOod0ogomSWom000=Ood01000Ooeoo@0027om00@007om
Ood0009oo@04001ooGom0006Ood00`00Ooeoo@03Ood00`00Ooeoo@0FOod00`00Ooeoo@3oOof>Ood0
00ioo@8000Yoo@8000Aoo@8000Moo@03001ooGom00=oo@03001ooGom01Eoo@03001ooGom0?mooHmo
o@00:Gom00<007omOod00gom00<007omOod05Gom00<007omOod0ogomSgom000YOod00`00Ooeoo@03
Ood00`00Ooeoo@0DOod00`00Ooeoo@3oOof@Ood002Uoo@03001ooGom00Aoo@03001ooGom01=oo@03
001ooGom0?mooI1oo@00:Gom00<007omOod017om00<007omOod04Wom00<007omOod0ogomTGom000Y
Ood00`00Ooeoo@04Ood00`00Ooeoo@0BOod00`00Ooeoo@3oOofAOod002Uoo@<000Aoo@03001ooGom
015oo@03001ooGom0?mooI9oo@00:Gom00<007omOod017om00<007omOod04Gom00<007omOod0ogom
TWom000YOod00`00Ooeoo@04Ood00`00Ooeoo@0@Ood00`00Ooeoo@3oOofCOod002Uoo@03001ooGom
00Aoo@03001ooGom011oo@03001ooGom0?mooI=oo@00:Gom00<007omOod017om00<007omOod03gom
00<007omOod0ogomU7om000YOod00`00Ooeoo@04Ood00`00Ooeoo@0?Ood00`00Ooeoo@3oOofDOod0
02Uoo@03001ooGom00Eoo@03001ooGom00eoo@03001ooGom0?mooIEoo@00:Gom00<007omOod01Gom
00<007omOod037om00<007omOod0ogomUWom000YOod30005Ood00`00Ooeoo@0<Ood00`00Ooeoo@3o
OofFOod002Uoo@03001ooGom00Eoo@03001ooGom00]oo@03001ooGom0?mooIMoo@00:Gom00<007om
Ood01Wom00<007omOod02Gom00<007omOod0ogomV7om000YOod00`00Ooeoo@06Ood00`00Ooeoo@09
Ood00`00Ooeoo@3oOofHOod002Uoo@03001ooGom00Moo@03001ooGom00Moo@03001ooGom0?mooIUo
o@00:Gom00<007omOod01gom00<007omOod01gom00<007omOod0ogomVGom000YOod00`00Ooeoo@07
Ood00`00Ooeoo@06Ood00`00Ooeoo@3oOofJOod002Uoo@03001ooGom00Qoo@03001ooGom00Aoo@03
001ooGom0?mooI]oo@00:Gom00<007omOod027om00<007omOod017om00<007omOod0ogomVgom000Y
Ood30008Ood00`00Ooeoo@03Ood00`00Ooeoo@3oOofLOod002Uoo@03001ooGom00Uoo@8000=oo@03
001ooGom0?mooIaoo@00:Gom00<007omOod02gom0`00ogomWgom000YOod00`00Ooeoo@0<Ood2003o
OofOOod002Uoo@03001ooGom0?mooJeoo@00:Gom00<007omOod0ogom[Gom000YOod00`00Ooeoo@3o
Oof]Ood002Uoo@03001ooGom0?mooJeoo@00:Gom0`00ogom[Gom000YOod00`00Ooeoo@3oOof]Ood0
0?mooMUoo@00ogomfGom003oOogIOod00?mooMUoo@00ogomfGom003oOogIOod00?mooMUoo@00ogom
fGom003oOogIOod00001\
\>"],
  ImageRangeCache->{{{0, 471}, {290.563, 0}} -> {-1.88165, -0.0094663, \
0.0453429, 0.000119523}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(e = emin1;\)\), "\[IndentingNewLine]", 
    \(Plot[{c0t0[e, p], c1t0[e, p], c2t0[e, p]}\[IndentingNewLine], {p, pmin, 
        pmax/5}\[IndentingNewLine], 
      PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty\ ]\), "\[IndentingNewLine]", 
    \(e =. \)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0210919 0.734691 0.161866 64.7946 [
[.16803 .14937 -9 -9 ]
[.16803 .14937 9 0 ]
[.31497 .14937 -9 -9 ]
[.31497 .14937 9 0 ]
[.46191 .14937 -9 -9 ]
[.46191 .14937 9 0 ]
[.60884 .14937 -9 -9 ]
[.60884 .14937 9 0 ]
[.75578 .14937 -3 -9 ]
[.75578 .14937 3 0 ]
[.90272 .14937 -9 -9 ]
[.90272 .14937 9 0 ]
[.00859 .03228 -36 -4.5 ]
[.00859 .03228 0 4.5 ]
[.00859 .29146 -30 -4.5 ]
[.00859 .29146 0 4.5 ]
[.00859 .42104 -30 -4.5 ]
[.00859 .42104 0 4.5 ]
[.00859 .55063 -30 -4.5 ]
[.00859 .55063 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16803 .16187 m
.16803 .16812 L
s
[(0.2)] .16803 .14937 0 1 Mshowa
.31497 .16187 m
.31497 .16812 L
s
[(0.4)] .31497 .14937 0 1 Mshowa
.46191 .16187 m
.46191 .16812 L
s
[(0.6)] .46191 .14937 0 1 Mshowa
.60884 .16187 m
.60884 .16812 L
s
[(0.8)] .60884 .14937 0 1 Mshowa
.75578 .16187 m
.75578 .16812 L
s
[(1)] .75578 .14937 0 1 Mshowa
.90272 .16187 m
.90272 .16812 L
s
[(1.2)] .90272 .14937 0 1 Mshowa
.125 Mabswid
.05783 .16187 m
.05783 .16562 L
s
.09456 .16187 m
.09456 .16562 L
s
.1313 .16187 m
.1313 .16562 L
s
.20476 .16187 m
.20476 .16562 L
s
.2415 .16187 m
.2415 .16562 L
s
.27823 .16187 m
.27823 .16562 L
s
.3517 .16187 m
.3517 .16562 L
s
.38844 .16187 m
.38844 .16562 L
s
.42517 .16187 m
.42517 .16562 L
s
.49864 .16187 m
.49864 .16562 L
s
.53538 .16187 m
.53538 .16562 L
s
.57211 .16187 m
.57211 .16562 L
s
.64558 .16187 m
.64558 .16562 L
s
.68231 .16187 m
.68231 .16562 L
s
.71905 .16187 m
.71905 .16562 L
s
.79252 .16187 m
.79252 .16562 L
s
.82925 .16187 m
.82925 .16562 L
s
.86599 .16187 m
.86599 .16562 L
s
.93946 .16187 m
.93946 .16562 L
s
.97619 .16187 m
.97619 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
.02109 .03228 m
.02734 .03228 L
s
[(-0.002)] .00859 .03228 1 0 Mshowa
.02109 .29146 m
.02734 .29146 L
s
[(0.002)] .00859 .29146 1 0 Mshowa
.02109 .42104 m
.02734 .42104 L
s
[(0.004)] .00859 .42104 1 0 Mshowa
.02109 .55063 m
.02734 .55063 L
s
[(0.006)] .00859 .55063 1 0 Mshowa
.125 Mabswid
.02109 .06467 m
.02484 .06467 L
s
.02109 .09707 m
.02484 .09707 L
s
.02109 .12947 m
.02484 .12947 L
s
.02109 .19426 m
.02484 .19426 L
s
.02109 .22666 m
.02484 .22666 L
s
.02109 .25906 m
.02484 .25906 L
s
.02109 .32385 m
.02484 .32385 L
s
.02109 .35625 m
.02484 .35625 L
s
.02109 .38865 m
.02484 .38865 L
s
.02109 .45344 m
.02484 .45344 L
s
.02109 .48584 m
.02484 .48584 L
s
.02109 .51824 m
.02484 .51824 L
s
.02109 .58303 m
.02484 .58303 L
s
.02109 .61543 m
.02484 .61543 L
s
.25 Mabswid
.02109 0 m
.02109 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02846 .60277 L
.03279 .60225 L
.03406 .6021 L
.03527 .60196 L
.03636 .60163 L
.03754 .60123 L
.04262 .59948 L
.05205 .59626 L
.05464 .59538 L
.05532 .59515 L
.05606 .5949 L
.05677 .59466 L
.05742 .59423 L
.06004 .59243 L
.06244 .59079 L
.07308 .58361 L
.08435 .57613 L
.09414 .56725 L
.10458 .55623 L
.14616 .50885 L
.18623 .45924 L
.22478 .40701 L
.26578 .35922 L
.30527 .31769 L
.34324 .2856 L
.38367 .25632 L
.42257 .2347 L
.46394 .21653 L
.50378 .203 L
.54211 .19315 L
.58289 .18512 L
.62216 .17922 L
.65991 .17497 L
.70011 .17158 L
.7388 .1691 L
.77994 .16713 L
.81956 .16575 L
.85767 .16476 L
.89823 .16398 L
.93728 .16342 L
.97619 .163 L
s
1 0 0 r
.02381 .01472 m
.02846 .0149 L
.03279 .01507 L
.03406 .01512 L
.03527 .01517 L
.03636 .01528 L
.03754 .01541 L
.04262 .016 L
.05205 .01707 L
.05464 .01737 L
.05532 .01744 L
.05606 .01753 L
.05677 .01761 L
.05742 .01775 L
.06004 .01835 L
.06244 .0189 L
.07308 .02129 L
.08435 .02379 L
.09414 .02675 L
.10458 .03043 L
.14616 .04624 L
.18623 .06279 L
.22478 .0802 L
.26578 .09613 L
.30527 .10996 L
.34324 .12065 L
.38367 .13041 L
.42257 .1376 L
.46394 .14366 L
.50378 .14816 L
.54211 .15144 L
.58289 .15412 L
.62216 .15608 L
.65991 .1575 L
.70011 .15863 L
.7388 .15946 L
.77994 .16011 L
.81956 .16057 L
.85767 .1609 L
.89823 .16116 L
.93728 .16135 L
.97619 .16149 L
s
.2 1 0 r
.02381 .16186 m
.02499 .16186 L
.02605 .16186 L
.02729 .16185 L
.02846 .16185 L
.02954 .16184 L
.03053 .16184 L
.03163 .16183 L
.03279 .16181 L
.03786 .16172 L
.04035 .16168 L
.04262 .16165 L
.04716 .16154 L
.04967 .16147 L
.05205 .16138 L
.06244 .16096 L
.08259 .1599 L
.10458 .15844 L
.14523 .15502 L
.16402 .15347 L
.17391 .15251 L
.17931 .15195 L
.18435 .15139 L
.18567 .15124 L
.18692 .15117 L
.18836 .1511 L
.18967 .15102 L
.19551 .1507 L
.20577 .15011 L
.22594 .14886 L
.24416 .14762 L
.24915 .14726 L
.25177 .14706 L
.2532 .14696 L
.2539 .1469 L
.25453 .14688 L
.2557 .14686 L
.25695 .14684 L
.25961 .14679 L
.26427 .14671 L
.28404 .14637 L
.30505 .14599 L
.32423 .14564 L
.32949 .14554 L
.33236 .14549 L
.33505 .14544 L
.33623 .14541 L
.33734 .14539 L
.33863 .14538 L
.3398 .14541 L
Mistroke
.34503 .14554 L
.38328 .14644 L
.40463 .14693 L
.42397 .14735 L
.43368 .14756 L
.43878 .14767 L
.44002 .1477 L
.44071 .14771 L
.44135 .14774 L
.4428 .14781 L
.44416 .14787 L
.45406 .14832 L
.46316 .14872 L
.50305 .15034 L
.54143 .15172 L
.58227 .15319 L
.62159 .15462 L
.65939 .15577 L
.69965 .1568 L
.73839 .15773 L
.77958 .15858 L
.81925 .15924 L
.85741 .15974 L
.89803 .16018 L
.93713 .16058 L
.97619 .16088 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{526.063, 325.125},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AA000`40O003h00Oogomogom47om003o
OogoOod@Ood00?mooOmooA1oo@00ogomogom47om003oOogoOod@Ood00?mooOmooA1oo@00ogomogom
47om003oOogoOod@Ood00?mooOmooA1oo@00ogomogom47om000ZOod00`00Ooeoo@3oOogROod002Yo
o@03001ooGom0?mooN9oo@00:Wom00<007omOod0ogomhWom000ZOod00`00Ooeoo@3oOogROod002Yo
o@03001ooGom0?mooN9oo@00:Wom00<007omOod0ogomhWom000ZOod00`00Ooeoo@3oOogROod002Yo
o@03001l07`000El0?mooMeoo@00:Wom00<007omOod017om2G`0ogomeGom000ZOod00`00Ooeoo@0=
Ood6O03oOog?Ood002Yoo@03001ooGom01=oo@9l0?mooLeoo@00:Wom00<007omOod05Gom17`0ogom
bGom000ZOod00`00Ooeoo@0IOod6O03oOog3Ood002Yoo@03001ooGom01moo@Al0?mooKmoo@0027om
0P0017om0P0017om0P0017om0P000gom10001gom00<007omOod08gom0W`0ogom_Gom0007Ood01000
Ooeoo@0027om00@007omOod0009oo@04001ooGom0002Ood00`00Ooeoo@08Ood00`00Ooeoo@0UOod3
O03oOofjOod000Moo@04001ooGom0008Ood01000Ooeoo@000Wom00@007omOod000=oo@03001ooGom
00Moo@@002Moo@9l0?mooKQoo@0000=oo@0000000P000Wom00@007omOod000Qoo@04001ooGom0002
Ood01000Ooeoo@0017om00<007omOod01Wom00<007omOod0:Wom0g`0ogom]Gom0007Ood01000Ooeo
o@0027om00@007omOod0009oo@04001ooGom0002Ood01000Ooeoo@001gom00<007omOod0;Gom0W`0
ogom/gom0008Ood2000:Ood20004Ood20004Ood20008Ood00`00Ooeoo@0_Ood3O03oOof`Ood002Yo
o@03001ooGom039oo@9l0?mooJioo@00:Wom00<007omOod0=7om0g`0ogomZgom000ZOod00`00Ooeo
o@0gOod2O03oOofYOod002Yoo@03001ooGom03Uoo@=l0?mooJIoo@00:Wom00<007omOod0?7om0W`0
ogomY7om000ZOod00`00Ooeoo@0nOod3O03oOofQOod002Yoo@03001ooGom045oo@9l0?mooImoo@00
:Wom00<007omOod0@gom0g`0ogomW7om000ZOod00`00Ooeoo@16Ood2O03oOofJOod002Yoo@03001o
oGom04Qoo@=l0?mooIMoo@00:Wom00<007omOod0Bgom0W`0ogomUGom000ZOod00`00Ooeoo@1=Ood3
O03oOofBOod002Yoo@<0051oo@9l0?mooI1oo@00:Wom00<007omOod0DWom0W`0ogomSWom000ZOod0
0`00Ooeoo@1DOod2O03oOof<Ood002Yoo@03001ooGom05Ioo@9l0?mooHYoo@00:Wom00<007omOod0
F7om0W`0ogomR7om000ZOod00`00Ooeoo@1JOod2O03oOof6Ood002Yoo@03001ooGom05aoo@9l0?mo
oHAoo@00:Wom00<007omOod0GWom0W`0ogomPWom000ZOod00`00Ooeoo@1POod3O03oOoeoOod002Yo
o@03001ooGom06=oo@=l0?mooGaoo@00:Wom00<007omOod0IWom0g`0ogomNGom000ZOod00`00Ooeo
o@1YOod2O03oOoegOod002Yoo@03001ooGom06]oo@=l0?mooGAoo@00:Wom00<007omOod0KWom0g`0
ogomLGom000ZOod00`00Ooeoo@1aOod3O03oOoe^Ood002Yoo@03001ooGom07Aoo@=l0?mooF]oo@00
:Wom0`00Mgom0g`0ogomJ7om000ZOod00`00Ooeoo@1jOod3O03oOoeUOod002Yoo@03001ooGom07eo
o@9l0?mooF=oo@00:Wom00<007omOod0Ogom0g`0ogomH7om000ZOod00`00Ooeoo@22Ood3O03oOoeM
Ood002Yoo@03001ooGom08Eoo@=l0?mooEYoo@00:Wom00<007omOod0R7om0g`0ogomEgom000ZOod0
0`00Ooeoo@2;Ood3O03oOoeDOod002Yoo@03001ooGom08ioo@=l0?mooE5oo@00:Wom00<007omOod0
TGom17`0ogomCGom000ZOod00`00Ooeoo@2EOod3O03oOoe:Ood002Yoo@03001ooGom09Qoo@=l0?mo
oDMoo@00:Wom00<007omOod0Vgom17`0ogom@gom000ZOod00`00Ooeoo@2OOod5O03oOodnOod002Yo
o@03001ooGom0:Aoo@El0?mooCUoo@00:Wom00<007omOod0ZGom1G`0ogom=7om000ZOod3002^Ood5
O03oOod_Ood002Yoo@03001ooGom0;=oo@El0?mooBYoo@00:Wom00<007omOod0?Wom0P0017om0P00
0gom1000>Wom0P0017om0P001Gom0`008Gom17`04gom0P0017om0P000gom0`00>gom0P0017om0P00
17om0P00?gom1@00?Wom1@000Wom0P000gom1000:Gom000ZOod00`00Ooeoo@0mOod01000Ooeoo@00
27om00<007omOod0>Wom00@007omOod000]oo@03001ooGom02Aoo@El00eoo@04001ooGom0008Ood0
1000Ooeoo@00>Gom00@007omOod000Qoo@04001ooGom0010Ood00`00Ooeoo@10Ood00`00Ooeoo@07
Ood00`00Ooeoo@0ZOod002Yoo@03001ooGom03eoo@04001ooGom0009Ood00`00Ooeoo@0iOod01000
Ooeoo@0027om1@00:Wom1W`01gom00@007omOod000Qoo@04001ooGom000iOod01000Ooeoo@0027om
00@007omOod0041oo@03001ooGom041oo@03001ooGom00Qoo@03001ooGom02Uoo@00:Wom00<007om
Ood0?Gom00@007omOod000Yoo@03001ooGom03Qoo@04001ooGom0008Ood01000Ooeoo@00<Gom1W`0
00Eoo@00Ooeoo@0000Qoo@<003Yoo@04001ooGom0009Ood20011Ood00`00Ooeoo@10Ood00`00Ooeo
o@09Ood00`00Ooeoo@0XOod002Yoo@03001ooGom03eoo@04001ooGom0008Ood01000Ooeoo@00>Gom
00@007omOod000Uoo@03001oo@0003Moo@Ml00Moo@03001ooGom03Uoo@04001ooGom0008Ood01000
Ooeoo@00@7om00<007omOod0@7om00<007omOod01gom00@007omOod002Uoo@00:Wom00<007omOod0
?Wom0P002Wom0P00>gom0P002gom0P00>Gom0P000gom27`00P00>Wom0P002Wom0P00@7om0P00@Gom
0P002Wom0P00:Wom000ZOod00`00Ooeoo@1_Ooe@5n0MOod:O03kOod002Yoo@03001ooGom05eooA8G
h51ooB8Gh0Eoo@Yl0?5oo@00:Wom00<007omOod0D7om3AOPQ7om4aOP1W`0igom000ZOod00`00Ooeo
o@16Ood:5n2TOodC5n000g`0Ooeoo@3GOod002Yoo@03001ooGom03EooA4Gh<5ooBPGh;9oo@00:Wom
00<007omOod0:gom2QOPigom4g`09QOPS7om000ZOod00`00Ooeoo@0QOod:5n3oOod5OodVO00X5n1T
Ood002Yoo@03001ooGom00mooA8Gh?mooCIooBMl05PGh0aoo@007gom30004AOPo`00Z@007W`03000
000ZOod00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeo
o@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0@Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeo
o@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeo
o@0?Ood00`00Ooeoo@0@Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeo
o@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@0?Ood00`00Ooeoo@02Oodk0009Ood00`00Ooeoo@0:Ood0
02Yoo@03001ooGom00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom
00moo@03001ooGom00moo@03001ooGom011oo@03001ooGom00moo@03001ooGom00moo@03001ooGom
00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom
00moo@03001ooGom011oo@03001ooGom00moo@03001ooGom00moo@03001ooGom00moo@03001ooGom
00moo@03001oo@0002H000eoo@03001ooGom011oo@03001ooGom00moo@03001ooGom00moo@03001o
oGom00Yoo@00:Wom00<007omOod0AGom00<007omOod0AWom00<007omOod0AGom00<007omOod0AWom
00<007omOod0>Gom3P00Agom00<007omOod0;Wom000ZOod00`00Ooeoo@3oOoeBOod:0026Ood002Yo
o@03001ooGom0?mooD=oo@l0091oo@00:Wom00<007omOod0ogom=Gom3P00Wgom000ZOod00`00Ooeo
o@3oOod[Ood:002]Ood002Yoo@03001ooGom0?mooB=oo@P00;Moo@00:Wom00<007omOod0ogom7Gom
1P00_gom000ZOod00`00Ooeoo@3oOodGOod60035Ood002Yoo@03001ooGom0?mooA5oo@H00<]oo@00
:Wom00<007omOod0ogom37om1@00dGom000ZOod00`00Ooeoo@3oOod7Ood5003FOod002Yoo@03001o
oGom0?moo@9oo@D00=]oo@00:Wom00<007omOod0oGom1000h7om000ZOod3003iOod4003TOod002Yo
o@03001ooGom0?Eoo@@00>Qoo@00:Wom00<007omOod0lGom1000k7om000ZOod00`00Ooeoo@3]Ood4
003`Ood002Yoo@03001ooGom0>Yoo@<00?Aoo@00:Wom00<007omOod0igom0`00mgom000ZOod00`00
Ooeoo@3TOod3003jOod002Yoo@03001ooGom0>5oo@<00?eoo@00:Wom00<007omOod0ggom0P00ogom
0Gom000ZOod00`00Ooeoo@3LOod3003oOod3Ood002Yoo@03001ooGom0=Uoo@<00?moo@Ioo@00:Wom
00<007omOod0eWom0`00ogom2Gom000ZOod00`00Ooeoo@3DOod2003oOod<Ood002Yoo@03001ooGom
0=9oo@800?moo@ioo@00:Wom00<007omOod0d7om0P00ogom47om000ZOod00`00Ooeoo@3=Ood3003o
OodBOod002Yoo@<00<]oo@800?mooAEoo@00:Wom00<007omOod0bGom0P00ogom5gom000ZOod00`00
Ooeoo@37Ood2003oOodIOod002Yoo@03001ooGom0<Eoo@800?mooA]oo@00:Wom00<007omOod0`gom
0P00ogom7Gom000ZOod00`00Ooeoo@31Ood2003oOodOOod002Yoo@03001ooGom0;moo@800?mooB5o
o@00:Wom00<007omOod0_Gom0P00ogom8gom000ZOod00`00Ooeoo@2kOod2003oOodUOod002Yoo@03
001ooGom0;Uoo@800?mooBMoo@00:Wom00<007omOod0]gom0P00ogom:Gom000ZOod00`00Ooeoo@2e
Ood2003oOod[Ood002Yoo@03001ooGom0;=oo@800?mooBeoo@00:Wom00<007omOod0/Gom0P00ogom
;gom000ZOod00`00Ooeoo@2`Ood00`00Ooeoo@3oOod_Ood002Yoo@03001ooGom0:ioo@800?mooC9o
o@00:Wom0`00[Gom00<007omOod0ogom<Wom000ZOod00`00Ooeoo@2/Ood00`00Ooeoo@3oOodcOod0
02Yoo@03001ooGom0:Yoo@800?mooCIoo@00:Wom00<007omOod0ZGom00<007omOod0ogom=Wom000Z
Ood00`00Ooeoo@2XOod00`00Ooeoo@3oOodgOod002Yoo@03001ooGom0:Ioo@800?mooCYoo@00:Wom
00<007omOod0YGom00<007omOod0ogom>Wom000ZOod00`00Ooeoo@2TOod00`00Ooeoo@3oOodkOod0
02Yoo@03001ooGom0:9oo@800?mooCioo@00:Wom00<007omOod0XGom00<007omOod0ogom?Wom000Z
Ood00`00Ooeoo@2POod00`00Ooeoo@3oOodoOod002Yoo@03001ooGom09ioo@800?mooD9oo@00:Wom
00<007omOod0WGom00<007omOod0ogom@Wom000ZOod00`00Ooeoo@2LOod00`00Ooeoo@3oOoe3Ood0
00Qoo@8000Aoo@8000Aoo@8000Aoo@8000=oo@@000Moo@03001ooGom09]oo@03001ooGom0?mooDAo
o@001gom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000Wom00<007omOod027om00<0
07omOod0VWom00<007omOod0ogomAGom0007Ood01000Ooeoo@0027om00@007omOod0009oo@04001o
oGom0003Ood00`00Ooeoo@07Ood4002GOod2003oOoe8Ood000Moo@04001ooGom0008Ood01000Ooeo
o@000Wom00@007omOod000Aoo@03001ooGom00Ioo@03001ooGom09Moo@03001ooGom0?mooDQoo@00
1gom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod000Moo@03001o
oGom09Ioo@03001ooGom0?mooDUoo@0027om0P002Wom0P0017om0P0017om0P0027om00<007omOod0
UGom00<007omOod0ogomBWom000ZOod00`00Ooeoo@2DOod00`00Ooeoo@3oOoe;Ood002Yoo@03001o
oGom099oo@800?mooDioo@00:Wom00<007omOod0TGom00<007omOod0ogomCWom000ZOod00`00Ooeo
o@2@Ood00`00Ooeoo@3oOoe?Ood002Yoo@03001ooGom08moo@03001ooGom0?mooE1oo@00:Wom00<0
07omOod0SWom00<007omOod0ogomDGom000ZOod00`00Ooeoo@2<Ood2003oOoeDOod002Yoo@03001o
oGom08]oo@03001ooGom0?mooEAoo@00:Wom00<007omOod0RWom00<007omOod0ogomEGom000ZOod0
0`00Ooeoo@29Ood00`00Ooeoo@3oOoeFOod002Yoo@03001ooGom08Qoo@03001ooGom0?mooEMoo@00
:Wom00<007omOod0Qgom00<007omOod0ogomF7om000ZOod30026Ood00`00Ooeoo@3oOoeIOod002Yo
o@03001ooGom08Eoo@03001ooGom0?mooEYoo@00:Wom00<007omOod0Q7om00<007omOod0ogomFgom
000ZOod00`00Ooeoo@23Ood00`00Ooeoo@3oOoeLOod002Yoo@03001ooGom089oo@03001ooGom0?mo
oEeoo@00:Wom00<007omOod0PGom00<007omOod0ogomGWom000ZOod00`00Ooeoo@20Ood00`00Ooeo
o@3oOoeOOod002Yoo@03001ooGom07moo@03001ooGom0?mooF1oo@00:Wom00<007omOod0OWom00<0
07omOod0ogomHGom000ZOod00`00Ooeoo@1mOod00`00Ooeoo@3oOoeROod002Yoo@03001ooGom07ao
o@03001ooGom0?mooF=oo@00:Wom00<007omOod0Ngom00<007omOod0ogomI7om000ZOod00`00Ooeo
o@1jOod00`00Ooeoo@3oOoeUOod002Yoo@03001ooGom07Uoo@03001ooGom0?mooFIoo@00:Wom00<0
07omOod0N7om00<007omOod0ogomIgom000ZOod00`00Ooeoo@1gOod00`00Ooeoo@3oOoeXOod002Yo
o@<007Ioo@03001ooGom0?mooFUoo@00:Wom00<007omOod0MGom00<007omOod0ogomJWom000ZOod0
0`00Ooeoo@1dOod00`00Ooeoo@3oOoe[Ood002Yoo@03001ooGom07=oo@03001ooGom0?mooFaoo@00
:Wom00<007omOod0Lgom00<007omOod0ogomK7om000ZOod00`00Ooeoo@1bOod00`00Ooeoo@3oOoe]
Ood002Yoo@03001ooGom075oo@03001ooGom0?mooFioo@00:Wom00<007omOod0L7om00<007omOod0
ogomKgom000ZOod00`00Ooeoo@1_Ood00`00Ooeoo@3oOoe`Ood002Yoo@03001ooGom06ioo@03001o
oGom0?mooG5oo@00:Wom00<007omOod0KWom00<007omOod0ogomLGom000ZOod00`00Ooeoo@1]Ood0
0`00Ooeoo@3oOoebOod002Yoo@03001ooGom06aoo@03001ooGom0?mooG=oo@00:Wom00<007omOod0
Jgom00<007omOod0ogomM7om000ZOod00`00Ooeoo@1ZOod00`00Ooeoo@3oOoeeOod002Yoo@03001o
oGom06Uoo@03001ooGom0?mooGIoo@00:Wom0`00JGom00<007omOod0ogomMWom000ZOod00`00Ooeo
o@1XOod00`00Ooeoo@3oOoegOod002Yoo@03001ooGom06Moo@03001ooGom0?mooGQoo@00:Wom00<0
07omOod0IWom00<007omOod0ogomNGom000ZOod00`00Ooeoo@1UOod00`00Ooeoo@3oOoejOod002Yo
o@03001ooGom06Aoo@03001ooGom0?mooG]oo@00:Wom00<007omOod0I7om00<007omOod0ogomNgom
000ZOod00`00Ooeoo@1SOod00`00Ooeoo@3oOoelOod002Yoo@03001ooGom069oo@03001ooGom0?mo
oGeoo@00:Wom00<007omOod0HGom00<007omOod0ogomOWom000ZOod00`00Ooeoo@1POod00`00Ooeo
o@3oOoeoOod002Yoo@03001ooGom061oo@03001ooGom0?mooGmoo@00:Wom00<007omOod0Ggom00<0
07omOod0ogomP7om000ZOod00`00Ooeoo@1NOod00`00Ooeoo@3oOof1Ood000Qoo@8000Aoo@8000Ao
o@8000Aoo@8000Eoo@<000Ioo@03001ooGom05eoo@03001ooGom0?mooH9oo@001gom00@007omOod0
00Qoo@04001ooGom0002Ood01000Ooeoo@001Gom00<007omOod01Gom00<007omOod0GGom00<007om
Ood0ogomPWom0007Ood01000Ooeoo@0027om00@007omOod0009oo@04001ooGom0002Ood50006Ood4
001KOod00`00Ooeoo@3oOof3Ood000Moo@04001ooGom0008Ood01000Ooeoo@000Wom00@007omOod0
009oo@04001ooGom0007Ood00`00Ooeoo@1KOod00`00Ooeoo@3oOof4Ood000Moo@04001ooGom0008
Ood01000Ooeoo@000Wom00@007omOod000=oo@03001oo@0000Moo@03001ooGom05Yoo@03001ooGom
0?mooHEoo@0027om0P002Wom0P0017om0P001Gom0P001gom00<007omOod0FWom00<007omOod0ogom
QGom000ZOod00`00Ooeoo@1IOod00`00Ooeoo@3oOof6Ood002Yoo@03001ooGom05Qoo@03001ooGom
0?mooHMoo@00:Wom00<007omOod0F7om00<007omOod0ogomQgom000ZOod00`00Ooeoo@1GOod00`00
Ooeoo@3oOof8Ood002Yoo@03001ooGom05Ioo@03001ooGom0?mooHUoo@00:Wom00<007omOod0EGom
00<007omOod0ogomRWom000ZOod00`00Ooeoo@1EOod00`00Ooeoo@3oOof:Ood002Yoo@03001ooGom
05Aoo@03001ooGom0?mooH]oo@00:Wom00<007omOod0Dgom00<007omOod0ogomS7om000ZOod00`00
Ooeoo@1BOod00`00Ooeoo@3oOof=Ood002Yoo@03001ooGom059oo@03001ooGom0?mooHeoo@00:Wom
00<007omOod0DGom00<007omOod0ogomSWom000ZOod3001@Ood00`00Ooeoo@3oOof?Ood002Yoo@03
001ooGom04moo@03001ooGom0?mooI1oo@00:Wom00<007omOod0Cgom00<007omOod0ogomT7om000Z
Ood00`00Ooeoo@1>Ood00`00Ooeoo@3oOofAOod002Yoo@03001ooGom04eoo@03001ooGom0?mooI9o
o@00:Wom00<007omOod0C7om00<007omOod0ogomTgom000ZOod00`00Ooeoo@1<Ood00`00Ooeoo@3o
OofCOod002Yoo@03001ooGom04]oo@03001ooGom0?mooIAoo@00:Wom00<007omOod0BWom00<007om
Ood0ogomUGom000ZOod00`00Ooeoo@19Ood00`00Ooeoo@3oOofFOod002Yoo@03001ooGom04Qoo@03
001ooGom0?mooIMoo@00:Wom00<007omOod0Agom00<007omOod0ogomV7om000ZOod00`00Ooeoo@17
Ood00`00Ooeoo@3oOofHOod002Yoo@03001ooGom04Ioo@03001ooGom0?mooIUoo@00:Wom00<007om
Ood0AGom00<007omOod0ogomVWom000ZOod00`00Ooeoo@14Ood00`00Ooeoo@3oOofKOod002Yoo@<0
04=oo@03001ooGom0?mooIaoo@00:Wom00<007omOod0@Wom00<007omOod0ogomWGom000ZOod00`00
Ooeoo@12Ood00`00Ooeoo@3oOofMOod002Yoo@03001ooGom045oo@03001ooGom0?mooIioo@00:Wom
00<007omOod0@7om00<007omOod0ogomWgom000ZOod00`00Ooeoo@0oOod00`00Ooeoo@3oOofPOod0
02Yoo@03001ooGom03ioo@03001ooGom0?mooJ5oo@00:Wom00<007omOod0?Gom00<007omOod0ogom
XWom000ZOod00`00Ooeoo@0mOod00`00Ooeoo@3oOofROod002Yoo@03001ooGom03aoo@03001ooGom
0?mooJ=oo@00:Wom00<007omOod0>gom00<007omOod0ogomY7om000ZOod00`00Ooeoo@0jOod00`00
Ooeoo@3oOofUOod002Yoo@03001ooGom03Uoo@03001ooGom0?mooJIoo@00:Wom00<007omOod0>7om
00<007omOod0ogomYgom000ZOod00`00Ooeoo@0gOod00`00Ooeoo@3oOofXOod002Yoo@03001ooGom
03Moo@03001ooGom0?mooJQoo@00:Wom0`00=Wom00<007omOod0ogomZGom000ZOod00`00Ooeoo@0e
Ood00`00Ooeoo@3oOofZOod002Yoo@03001ooGom03Aoo@03001ooGom0?mooJ]oo@00:Wom00<007om
Ood0<gom00<007omOod0ogom[7om000ZOod00`00Ooeoo@0bOod00`00Ooeoo@3oOof]Ood002Yoo@03
001ooGom035oo@03001ooGom0?mooJioo@00:Wom00<007omOod0<7om00<007omOod0ogom[gom000Z
Ood00`00Ooeoo@0`Ood00`00Ooeoo@3oOof_Ood002Yoo@03001ooGom02moo@03001ooGom0?mooK1o
o@00:Wom00<007omOod0;Wom00<007omOod0ogom/Gom000ZOod00`00Ooeoo@0]Ood00`00Ooeoo@3o
OofbOod002Yoo@03001ooGom02aoo@03001ooGom0?mooK=oo@00:Wom00<007omOod0:gom00<007om
Ood0ogom]7om000ZOod00`00Ooeoo@0ZOod00`00Ooeoo@3oOofeOod000Qoo@8000Aoo@8000Aoo@80
00Aoo@8000=oo@<000Qoo@03001ooGom02Uoo@03001ooGom0?mooKIoo@001gom00@007omOod000Qo
o@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod000Moo@03001ooGom02Uoo@03001ooGom
0?mooKIoo@001gom00@007omOod000Qoo@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod0
00Moo@@002Moo@03001ooGom0?mooKMoo@001gom00@007omOod000Qoo@04001ooGom0002Ood01000
Ooeoo@000Wom0`0027om00<007omOod09gom00<007omOod0ogom^7om0007Ood01000Ooeoo@0027om
00@007omOod0009oo@04001ooGom0003Ood00`00Ooeoo@07Ood00`00Ooeoo@0VOod00`00Ooeoo@3o
OofiOod000Qoo@8000Yoo@8000Aoo@8000Aoo@<000Moo@03001ooGom02Eoo@03001ooGom0?mooKYo
o@00:Wom00<007omOod097om00<007omOod0ogom^gom000ZOod00`00Ooeoo@0TOod00`00Ooeoo@3o
OofkOod002Yoo@03001ooGom02=oo@03001ooGom0?mooKaoo@00:Wom00<007omOod08Wom00<007om
Ood0ogom_Gom000ZOod00`00Ooeoo@0QOod00`00Ooeoo@3oOofnOod002Yoo@03001ooGom021oo@03
001ooGom0?mooKmoo@00:Wom00<007omOod07Wom0P00ogom`Wom000ZOod00`00Ooeoo@0MOod00`00
Ooeoo@3oOog2Ood002Yoo@03001ooGom01aoo@03001ooGom0?mooL=oo@00:Wom00<007omOod06Wom
0P00ogomaWom000ZOod00`00Ooeoo@0IOod00`00Ooeoo@3oOog6Ood002Yoo@03001ooGom01Moo@80
0?mooLUoo@00:Wom0`005Wom00<007omOod0ogombGom000ZOod00`00Ooeoo@0DOod2003oOog<Ood0
02Yoo@03001ooGom019oo@800?mooLioo@00:Wom00<007omOod04Gom00<007omOod0ogomcWom000Z
Ood00`00Ooeoo@0@Ood00`00Ooeoo@3oOog?Ood002Yoo@03001ooGom00ioo@800?mooM9oo@00:Wom
00<007omOod02gom1000ogomdgom000ZOod00`00Ooeoo@09Ood2003oOogGOod002Yoo@03001ooGom
00Ioo@<00?mooMUoo@00:Wom00<007om00001P00ogomg7om000ZOod2003oOogSOod002Yoo@03001o
oGom0?mooN9oo@00:Wom00<007omOod0ogomhWom000ZOod00`00Ooeoo@3oOogROod002Yoo@03001o
oGom0?mooN9oo@00:Wom00<007omOod0ogomhWom000ZOod3003oOogROod002Yoo@03001ooGom0?mo
oN9oo@00ogomogom47om003oOogoOod@Ood00?mooOmooA1oo@00ogomogom47om003oOogoOod@Ood0
0?mooOmooA1oo@00ogomogom47om003oOogoOod@Ood00?mooOmooA1oo@00\
\>"],
  ImageRangeCache->{{{0, 525.063}, {324.125, 0}} -> {-0.116356, -0.00279933, \
0.00275923, 3.12863*^-05}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\[IndentingNewLine]logc0t0[e, p] // Re, {p, pmin, pmax}, {e, 
        emin1, emax/20}, PlotPoints \[Rule] 40, 
      AxesLabel \[Rule] {"\<p\>", "\<E\>", "\<S(E,p)//Log\>"}\
\[IndentingNewLine], 
      PlotRange \[Rule] 
        All\[IndentingNewLine] (*\ \(,\)\(Shading \[Rule] 
          False\)\ *) \[IndentingNewLine] (*\(,\)\(ViewPoint -> {1.2, 0.9, 
            1.1}\)*) \[IndentingNewLine]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.21185 .17366 -5.82776 -9 ]
[.21185 .17366 .17224 0 ]
[.41061 .09549 -5.44263 -9 ]
[.41061 .09549 .55737 0 ]
[.62521 .01115 -5.05751 -9 ]
[.62521 .01115 .94249 0 ]
[.29165 .07573 -9.31117 -12.5625 ]
[.29165 .07573 .68883 0 ]
[.77052 .10173 0 -6.1573 ]
[.77052 .10173 6 2.8427 ]
[.83402 .19896 0 -6.06386 ]
[.83402 .19896 6 2.93614 ]
[.89194 .28766 0 -5.98039 ]
[.89194 .28766 6 3.01961 ]
[.94498 .36889 0 -5.90539 ]
[.94498 .36889 6 3.09461 ]
[.91861 .21225 0 -8.41865 ]
[.91861 .21225 10 4.14385 ]
[.02144 .28186 -18 -2.75646 ]
[.02144 .28186 0 6.24354 ]
[.01417 .3274 -18 -2.795 ]
[.01417 .3274 0 6.205 ]
[.00669 .3743 -18 -2.8348 ]
[.00669 .3743 0 6.1652 ]
[-0.00102 .42262 -18 -2.87594 ]
[-0.00102 .42262 0 6.12406 ]
[-0.00897 .47243 -12 -2.91848 ]
[-0.00897 .47243 0 6.08152 ]
[-0.05457 .39542 -70 -3.95494 ]
[-0.05457 .39542 0 8.60756 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.22085 .18321 m
.22535 .18799 L
s
[(2)] .21185 .17366 .94259 1 Mshowa
.41889 .10566 m
.42303 .11075 L
s
[(4)] .41061 .09549 .81421 1 Mshowa
.63263 .02197 m
.63634 .02738 L
s
[(6)] .62521 .01115 .68584 1 Mshowa
.125 Mabswid
.0816 .23773 m
.08444 .24046 L
s
.12718 .21989 m
.12997 .22266 L
s
.17359 .20172 m
.17634 .20454 L
s
.26898 .16436 m
.27163 .16727 L
s
.31802 .14516 m
.32061 .14812 L
s
.36798 .1256 m
.37052 .1286 L
s
.47078 .08534 m
.47321 .08844 L
s
.52368 .06463 m
.52605 .06778 L
s
.57762 .04351 m
.57992 .04671 L
s
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75821 .10626 m
.75205 .10853 L
s
[(2)] .77052 .10173 -1 .36829 Mshowa
.82162 .20327 m
.81543 .20543 L
s
[(4)] .83402 .19896 -1 .34752 Mshowa
.87947 .29176 m
.87324 .29381 L
s
[(6)] .89194 .28766 -1 .32898 Mshowa
.93245 .3728 m
.92619 .37475 L
s
[(8)] .94498 .36889 -1 .31231 Mshowa
.125 Mabswid
.70648 .02715 m
.70281 .02856 L
s
.72415 .05417 m
.72047 .05557 L
s
.74138 .08053 m
.7377 .08191 L
s
.77463 .13138 m
.77093 .13272 L
s
.79066 .15591 m
.78695 .15723 L
s
.80632 .17986 m
.80261 .18117 L
s
.83658 .22615 m
.83285 .22742 L
s
.8512 .24851 m
.84747 .24977 L
s
.86549 .27037 m
.86176 .27162 L
s
.89315 .31268 m
.8894 .31389 L
s
.90653 .33315 m
.90278 .33435 L
s
.91963 .35318 m
.91587 .35437 L
s
.94501 .392 m
.94124 .39316 L
s
.9573 .41081 m
.95354 .41196 L
s
gsave
.91861 .21225 -61 -12.4187 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27712 m
.03979 .27475 L
s
[(-25)] .02144 .28186 1 -0.38745 Mshowa
.02645 .32275 m
.03258 .32042 L
s
[(-20)] .01417 .3274 1 -0.37889 Mshowa
.019 .36975 m
.02515 .36747 L
s
[(-15)] .00669 .3743 1 -0.37004 Mshowa
.01132 .41817 m
.0175 .41594 L
s
[(-10)] -0.00102 .42262 1 -0.3609 Mshowa
.00341 .46808 m
.0096 .46591 L
s
[(-5)] -0.00897 .47243 1 -0.35145 Mshowa
.125 Mabswid
.03225 .28614 m
.03592 .28472 L
s
.03081 .29521 m
.03448 .2938 L
s
.02936 .30434 m
.03304 .30293 L
s
.02791 .31352 m
.03159 .31212 L
s
.02497 .33204 m
.02866 .33065 L
s
.02349 .34138 m
.02718 .34 L
s
.022 .35078 m
.02569 .3494 L
s
.02051 .36023 m
.0242 .35886 L
s
.01748 .37931 m
.02118 .37795 L
s
.01596 .38894 m
.01965 .38759 L
s
.01442 .39862 m
.01812 .39728 L
s
.01288 .40837 m
.01658 .40702 L
s
.00976 .42803 m
.01347 .4267 L
s
.00819 .43795 m
.0119 .43663 L
s
.00661 .44793 m
.01032 .44662 L
s
.00502 .45798 m
.00873 .45667 L
s
.0351 .26815 m
.03877 .26672 L
s
.03651 .25923 m
.04018 .2578 L
s
.0018 .47825 m
.00552 .47695 L
s
.00018 .48848 m
.0039 .48719 L
s
gsave
-0.05457 .39542 -131 -7.95494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 12.813 moveto
(H) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 12.813 moveto
(L) show
99.000 12.813 moveto
(\\220\\220) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.668 .781 .934 r
.39071 .77283 .39899 .77905 .41281 .77467 .40458 .7684 Metetra
.695 .785 .921 r
.40458 .7684 .41281 .77467 .42673 .76933 .41854 .76298 Metetra
.713 .787 .91 r
.41854 .76298 .42673 .76933 .44071 .76325 .43258 .75679 Metetra
.73 .788 .898 r
.43258 .75679 .44071 .76325 .45477 .75634 .4467 .74975 Metetra
.749 .787 .884 r
.4467 .74975 .45477 .75634 .46889 .74843 .46088 .7417 Metetra
.764 .786 .871 r
.46088 .7417 .46889 .74843 .48306 .73956 .47511 .7327 Metetra
.775 .785 .861 r
.47511 .7327 .48306 .73956 .49728 .72986 .48938 .72286 Metetra
.787 .783 .85 r
.48938 .72286 .49728 .72986 .51152 .71921 .50369 .71211 Metetra
.787 .782 .848 r
.50369 .71211 .51152 .71921 .52578 .70844 .51802 .70124 Metetra
.785 .781 .849 r
.51802 .70124 .52578 .70844 .54006 .69777 .53236 .69048 Metetra
.785 .78 .848 r
.53236 .69048 .54006 .69777 .55436 .68708 .54672 .67971 Metetra
.751 .776 .874 r
.54672 .67971 .55436 .68708 .56871 .6787 .56113 .67128 Metetra
.749 .776 .875 r
.56113 .67128 .56871 .6787 .5831 .67038 .57558 .66291 Metetra
.74 .775 .881 r
.57558 .66291 .5831 .67038 .59754 .66254 .59008 .65502 Metetra
.724 .771 .89 r
.59008 .65502 .59754 .66254 .61204 .65553 .60464 .64797 Metetra
.724 .772 .89 r
.60464 .64797 .61204 .65553 .6266 .64849 .61925 .64089 Metetra
.727 .772 .889 r
.61925 .64089 .6266 .64849 .6412 .64126 .63391 .63362 Metetra
.738 .775 .882 r
.63391 .63362 .6412 .64126 .65583 .63344 .6486 .62575 Metetra
.738 .775 .882 r
.6486 .62575 .65583 .63344 .67051 .6256 .66334 .61786 Metetra
.738 .775 .882 r
.66334 .61786 .67051 .6256 .68523 .61773 .67812 .60994 Metetra
.749 .777 .876 r
.67812 .60994 .68523 .61773 .69997 .60923 .69292 .60138 Metetra
.762 .78 .868 r
.69292 .60138 .69997 .60923 .7147 .59994 .70772 .59204 Metetra
.762 .78 .868 r
.70772 .59204 .7147 .59994 .72947 .59063 .72256 .58267 Metetra
.762 .78 .868 r
.72256 .58267 .72947 .59063 .74428 .58129 .73743 .57328 Metetra
.762 .78 .868 r
.73743 .57328 .74428 .58129 .75912 .57194 .75234 .56386 Metetra
.822 .789 .822 r
.75234 .56386 .75912 .57194 .77366 .55798 .76695 .54979 Metetra
.825 .789 .818 r
.76695 .54979 .77366 .55798 .78817 .54366 .78152 .53535 Metetra
.825 .788 .817 r
.78152 .53535 .78817 .54366 .80266 .52934 .79608 .52091 Metetra
.824 .786 .816 r
.79608 .52091 .80266 .52934 .81715 .51503 .81064 .50648 Metetra
.824 .785 .816 r
.81064 .50648 .81715 .51503 .83163 .50073 .82519 .49206 Metetra
.715 .757 .885 r
.82519 .49206 .83163 .50073 .84681 .49375 .84043 .48504 Metetra
.595 .71 .924 r
.84043 .48504 .84681 .49375 .86254 .49158 .85622 .48288 Metetra
.595 .711 .925 r
.85622 .48288 .86254 .49158 .87838 .4894 .87213 .48071 Metetra
.595 .712 .926 r
.87213 .48071 .87838 .4894 .89433 .4872 .88814 .47852 Metetra
.594 .713 .927 r
.88814 .47852 .89433 .4872 .91039 .48498 .90426 .47632 Metetra
.594 .715 .928 r
.90426 .47632 .91039 .48498 .92656 .48275 .92049 .4741 Metetra
.655 .743 .914 r
.92049 .4741 .92656 .48275 .94255 .47826 .93656 .46959 Metetra
.704 .763 .898 r
.93656 .46959 .94255 .47826 .95837 .47169 .95244 .46296 Metetra
.704 .763 .898 r
.95244 .46296 .95837 .47169 .97425 .46508 .96838 .45631 Metetra
.668 .781 .934 r
.38234 .76654 .39071 .77283 .40458 .7684 .39626 .76206 Metetra
.696 .786 .92 r
.39626 .76206 .40458 .7684 .41854 .76298 .41027 .75657 Metetra
.714 .787 .909 r
.41027 .75657 .41854 .76298 .43258 .75679 .42437 .75026 Metetra
.732 .788 .897 r
.42437 .75026 .43258 .75679 .4467 .74975 .43854 .74309 Metetra
.75 .787 .883 r
.43854 .74309 .4467 .74975 .46088 .7417 .45278 .7349 Metetra
.765 .786 .87 r
.45278 .7349 .46088 .7417 .47511 .7327 .46708 .72576 Metetra
.776 .785 .86 r
.46708 .72576 .47511 .7327 .48938 .72286 .48142 .7158 Metetra
.787 .783 .849 r
.48142 .7158 .48938 .72286 .50369 .71211 .49579 .70494 Metetra
.788 .782 .847 r
.49579 .70494 .50369 .71211 .51802 .70124 .51018 .69396 Metetra
.786 .781 .848 r
.51018 .69396 .51802 .70124 .53236 .69048 .52459 .68312 Metetra
.786 .781 .848 r
.52459 .68312 .53236 .69048 .54672 .67971 .53901 .67227 Metetra
.751 .776 .874 r
.53901 .67227 .54672 .67971 .56113 .67128 .55348 .66378 Metetra
.749 .776 .875 r
.55348 .66378 .56113 .67128 .57558 .66291 .56799 .65537 Metetra
.74 .774 .881 r
.56799 .65537 .57558 .66291 .59008 .65502 .58255 .64744 Metetra
.724 .771 .89 r
.58255 .64744 .59008 .65502 .60464 .64797 .59716 .64034 Metetra
.724 .772 .89 r
.59716 .64034 .60464 .64797 .61925 .64089 .61184 .63322 Metetra
.727 .772 .889 r
.61184 .63322 .61925 .64089 .63391 .63362 .62656 .62591 Metetra
.738 .775 .882 r
.62656 .62591 .63391 .63362 .6486 .62575 .64131 .61799 Metetra
.738 .775 .882 r
.64131 .61799 .6486 .62575 .66334 .61786 .6561 .61004 Metetra
.738 .775 .882 r
.6561 .61004 .66334 .61786 .67812 .60994 .67095 .60207 Metetra
.749 .777 .876 r
.67095 .60207 .67812 .60994 .69292 .60138 .68581 .59346 Metetra
.762 .78 .868 r
.68581 .59346 .69292 .60138 .70772 .59204 .70068 .58406 Metetra
.762 .78 .868 r
.70068 .58406 .70772 .59204 .72256 .58267 .71558 .57463 Metetra
.762 .78 .868 r
.71558 .57463 .72256 .58267 .73743 .57328 .73051 .56518 Metetra
.762 .78 .868 r
.73051 .56518 .73743 .57328 .75234 .56386 .74549 .55571 Metetra
.822 .79 .821 r
.74549 .55571 .75234 .56386 .76695 .54979 .76016 .54152 Metetra
.826 .789 .817 r
.76016 .54152 .76695 .54979 .78152 .53535 .77481 .52696 Metetra
.825 .788 .816 r
.77481 .52696 .78152 .53535 .79608 .52091 .78944 .5124 Metetra
.825 .787 .816 r
.78944 .5124 .79608 .52091 .81064 .50648 .80407 .49785 Metetra
.824 .785 .815 r
.80407 .49785 .81064 .50648 .82519 .49206 .81868 .48331 Metetra
.715 .757 .885 r
.81868 .48331 .82519 .49206 .84043 .48504 .83399 .47625 Metetra
.594 .709 .924 r
.83399 .47625 .84043 .48504 .85622 .48288 .84984 .4741 Metetra
.594 .71 .925 r
.84984 .4741 .85622 .48288 .87213 .48071 .86581 .47194 Metetra
.593 .712 .926 r
.86581 .47194 .87213 .48071 .88814 .47852 .88188 .46976 Metetra
.593 .713 .927 r
.88188 .46976 .88814 .47852 .90426 .47632 .89807 .46757 Metetra
.592 .714 .928 r
.89807 .46757 .90426 .47632 .92049 .4741 .91437 .46536 Metetra
.655 .743 .915 r
.91437 .46536 .92049 .4741 .93656 .46959 .9305 .46083 Metetra
.704 .763 .898 r
.9305 .46083 .93656 .46959 .95244 .46296 .94644 .45415 Metetra
.704 .763 .898 r
.94644 .45415 .95244 .46296 .96838 .45631 .96246 .44744 Metetra
.668 .781 .933 r
.37388 .76019 .38234 .76654 .39626 .76206 .38785 .75567 Metetra
.697 .786 .92 r
.38785 .75567 .39626 .76206 .41027 .75657 .40192 .75009 Metetra
.716 .788 .908 r
.40192 .75009 .41027 .75657 .42437 .75026 .41608 .74367 Metetra
.734 .788 .896 r
.41608 .74367 .42437 .75026 .43854 .74309 .43031 .73637 Metetra
.752 .787 .882 r
.43031 .73637 .43854 .74309 .45278 .7349 .44461 .72804 Metetra
.766 .786 .869 r
.44461 .72804 .45278 .7349 .46708 .72576 .45897 .71876 Metetra
.777 .785 .859 r
.45897 .71876 .46708 .72576 .48142 .7158 .47337 .70867 Metetra
.788 .783 .849 r
.47337 .70867 .48142 .7158 .49579 .70494 .48781 .6977 Metetra
.789 .782 .847 r
.48781 .6977 .49579 .70494 .51018 .69396 .50226 .68662 Metetra
.786 .781 .848 r
.50226 .68662 .51018 .69396 .52459 .68312 .51674 .67569 Metetra
.786 .781 .848 r
.51674 .67569 .52459 .68312 .53901 .67227 .53123 .66476 Metetra
.751 .776 .874 r
.53123 .66476 .53901 .67227 .55348 .66378 .54576 .65622 Metetra
.749 .776 .875 r
.54576 .65622 .55348 .66378 .56799 .65537 .56032 .64776 Metetra
.74 .774 .881 r
.56032 .64776 .56799 .65537 .58255 .64744 .57494 .63978 Metetra
.724 .771 .89 r
.57494 .63978 .58255 .64744 .59716 .64034 .58962 .63264 Metetra
.724 .771 .89 r
.58962 .63264 .59716 .64034 .61184 .63322 .60435 .62547 Metetra
.727 .772 .889 r
.60435 .62547 .61184 .63322 .62656 .62591 .61913 .61811 Metetra
.738 .775 .882 r
.61913 .61811 .62656 .62591 .64131 .61799 .63394 .61014 Metetra
.738 .775 .882 r
.63394 .61014 .64131 .61799 .6561 .61004 .6488 .60215 Metetra
.738 .775 .882 r
.6488 .60215 .6561 .61004 .67095 .60207 .6637 .59413 Metetra
.749 .777 .876 r
.6637 .59413 .67095 .60207 .68581 .59346 .67863 .58546 Metetra
.762 .78 .868 r
.67863 .58546 .68581 .59346 .70068 .58406 .69356 .576 Metetra
.762 .78 .868 r
.69356 .576 .70068 .58406 .71558 .57463 .70853 .56651 Metetra
.762 .78 .868 r
.70853 .56651 .71558 .57463 .73051 .56518 .72353 .55701 Metetra
.762 .78 .868 r
.72353 .55701 .73051 .56518 .74549 .55571 .73857 .54748 Metetra
.823 .79 .821 r
.73857 .54748 .74549 .55571 .76016 .54152 .75332 .53317 Metetra
.826 .789 .817 r
.75332 .53317 .76016 .54152 .77481 .52696 .76803 .51848 Metetra
.826 .788 .816 r
.76803 .51848 .77481 .52696 .78944 .5124 .78274 .5038 Metetra
.825 .787 .815 r
.78274 .5038 .78944 .5124 .80407 .49785 .79743 .48913 Metetra
.825 .785 .815 r
.79743 .48913 .80407 .49785 .81868 .48331 .81212 .47447 Metetra
.715 .757 .885 r
.81212 .47447 .81868 .48331 .83399 .47625 .82749 .46737 Metetra
.592 .709 .924 r
.82749 .46737 .83399 .47625 .84984 .4741 .8434 .46523 Metetra
.592 .71 .925 r
.8434 .46523 .84984 .4741 .86581 .47194 .85942 .46308 Metetra
.592 .711 .926 r
.85942 .46308 .86581 .47194 .88188 .46976 .87556 .46091 Metetra
.591 .712 .927 r
.87556 .46091 .88188 .46976 .89807 .46757 .89181 .45873 Metetra
.591 .713 .928 r
.89181 .45873 .89807 .46757 .91437 .46536 .90818 .45653 Metetra
.654 .743 .915 r
.90818 .45653 .91437 .46536 .9305 .46083 .92438 .45198 Metetra
.704 .763 .898 r
.92438 .45198 .9305 .46083 .94644 .45415 .94039 .44524 Metetra
.704 .763 .898 r
.94039 .44524 .94644 .45415 .96246 .44744 .95648 .43848 Metetra
.669 .781 .933 r
.36535 .75378 .37388 .76019 .38785 .75567 .37937 .7492 Metetra
.698 .786 .919 r
.37937 .7492 .38785 .75567 .40192 .75009 .39349 .74355 Metetra
.718 .788 .907 r
.39349 .74355 .40192 .75009 .41608 .74367 .4077 .73702 Metetra
.736 .788 .895 r
.4077 .73702 .41608 .74367 .43031 .73637 .42199 .72958 Metetra
.754 .788 .881 r
.42199 .72958 .43031 .73637 .44461 .72804 .43636 .7211 Metetra
.768 .786 .868 r
.43636 .7211 .44461 .72804 .45897 .71876 .45078 .71169 Metetra
.778 .785 .858 r
.45078 .71169 .45897 .71876 .47337 .70867 .46525 .70147 Metetra
.789 .783 .848 r
.46525 .70147 .47337 .70867 .48781 .6977 .47975 .69038 Metetra
.789 .782 .846 r
.47975 .69038 .48781 .6977 .50226 .68662 .49427 .6792 Metetra
.786 .781 .848 r
.49427 .6792 .50226 .68662 .51674 .67569 .50881 .66819 Metetra
.786 .781 .848 r
.50881 .66819 .51674 .67569 .53123 .66476 .52337 .65717 Metetra
.751 .776 .874 r
.52337 .65717 .53123 .66476 .54576 .65622 .53796 .64858 Metetra
.749 .776 .875 r
.53796 .64858 .54576 .65622 .56032 .64776 .55258 .64007 Metetra
.74 .774 .881 r
.55258 .64007 .56032 .64776 .57494 .63978 .56726 .63204 Metetra
.724 .771 .89 r
.56726 .63204 .57494 .63978 .58962 .63264 .582 .62486 Metetra
.724 .771 .891 r
.582 .62486 .58962 .63264 .60435 .62547 .59679 .61765 Metetra
.727 .772 .889 r
.59679 .61765 .60435 .62547 .61913 .61811 .61162 .61024 Metetra
.738 .775 .882 r
.61162 .61024 .61913 .61811 .63394 .61014 .6265 .60222 Metetra
.738 .775 .882 r
.6265 .60222 .63394 .61014 .6488 .60215 .64142 .59417 Metetra
.738 .775 .882 r
.64142 .59417 .6488 .60215 .6637 .59413 .65639 .5861 Metetra
.749 .777 .876 r
.65639 .5861 .6637 .59413 .67863 .58546 .67138 .57738 Metetra
.762 .78 .868 r
.67138 .57738 .67863 .58546 .69356 .576 .68637 .56786 Metetra
.762 .78 .868 r
.68637 .56786 .69356 .576 .70853 .56651 .70141 .55832 Metetra
.762 .78 .868 r
.70141 .55832 .70853 .56651 .72353 .55701 .71647 .54875 Metetra
.762 .78 .868 r
.71647 .54875 .72353 .55701 .73857 .54748 .73158 .53916 Metetra
.823 .79 .82 r
.73158 .53916 .73857 .54748 .75332 .53317 .7464 .52474 Metetra
.827 .789 .816 r
.7464 .52474 .75332 .53317 .76803 .51848 .76119 .50992 Metetra
.827 .788 .816 r
.76119 .50992 .76803 .51848 .78274 .5038 .77596 .49512 Metetra
.826 .787 .815 r
.77596 .49512 .78274 .5038 .79743 .48913 .79073 .48033 Metetra
.825 .786 .814 r
.79073 .48033 .79743 .48913 .81212 .47447 .80548 .46555 Metetra
.715 .757 .885 r
.80548 .46555 .81212 .47447 .82749 .46737 .82092 .4584 Metetra
.591 .708 .925 r
.82092 .4584 .82749 .46737 .8434 .46523 .83689 .45627 Metetra
.59 .709 .926 r
.83689 .45627 .8434 .46523 .85942 .46308 .85298 .45413 Metetra
.59 .71 .927 r
.85298 .45413 .85942 .46308 .87556 .46091 .86918 .45197 Metetra
.59 .711 .928 r
.86918 .45197 .87556 .46091 .89181 .45873 .8855 .4498 Metetra
.589 .712 .929 r
.8855 .4498 .89181 .45873 .90818 .45653 .90193 .44761 Metetra
.653 .742 .915 r
.90193 .44761 .90818 .45653 .92438 .45198 .91819 .44303 Metetra
.704 .763 .898 r
.91819 .44303 .92438 .45198 .94039 .44524 .93428 .43624 Metetra
.704 .763 .898 r
.93428 .43624 .94039 .44524 .95648 .43848 .95043 .42943 Metetra
.669 .781 .933 r
.35673 .7473 .36535 .75378 .37937 .7492 .37079 .74267 Metetra
.699 .786 .919 r
.37079 .74267 .37937 .7492 .39349 .74355 .38497 .73694 Metetra
.719 .788 .906 r
.38497 .73694 .39349 .74355 .4077 .73702 .39924 .73029 Metetra
.737 .788 .894 r
.39924 .73029 .4077 .73702 .42199 .72958 .41359 .72272 Metetra
.755 .788 .88 r
.41359 .72272 .42199 .72958 .43636 .7211 .42802 .7141 Metetra
.769 .786 .867 r
.42802 .7141 .43636 .7211 .45078 .71169 .44251 .70455 Metetra
.779 .785 .857 r
.44251 .70455 .45078 .71169 .46525 .70147 .45704 .69419 Metetra
.789 .783 .847 r
.45704 .69419 .46525 .70147 .47975 .69038 .47161 .683 Metetra
.79 .782 .846 r
.47161 .683 .47975 .69038 .49427 .6792 .4862 .67171 Metetra
.787 .781 .848 r
.4862 .67171 .49427 .6792 .50881 .66819 .50081 .66061 Metetra
.787 .781 .847 r
.50081 .66061 .50881 .66819 .52337 .65717 .51543 .64951 Metetra
.751 .776 .874 r
.51543 .64951 .52337 .65717 .53796 .64858 .53008 .64087 Metetra
.749 .776 .875 r
.53008 .64087 .53796 .64858 .55258 .64007 .54477 .63231 Metetra
.74 .774 .881 r
.54477 .63231 .55258 .64007 .56726 .63204 .5595 .62423 Metetra
.724 .771 .89 r
.5595 .62423 .56726 .63204 .582 .62486 .5743 .617 Metetra
.724 .771 .891 r
.5743 .617 .582 .62486 .59679 .61765 .58915 .60975 Metetra
.727 .772 .889 r
.58915 .60975 .59679 .61765 .61162 .61024 .60405 .6023 Metetra
.738 .775 .882 r
.60405 .6023 .61162 .61024 .6265 .60222 .61898 .59422 Metetra
.738 .775 .882 r
.61898 .59422 .6265 .60222 .64142 .59417 .63397 .58612 Metetra
.738 .775 .882 r
.63397 .58612 .64142 .59417 .65639 .5861 .649 .578 Metetra
.749 .777 .876 r
.649 .578 .65639 .5861 .67138 .57738 .66405 .56922 Metetra
.762 .78 .868 r
.66405 .56922 .67138 .57738 .68637 .56786 .67911 .55964 Metetra
.762 .78 .868 r
.67911 .55964 .68637 .56786 .70141 .55832 .69421 .55004 Metetra
.762 .78 .868 r
.69421 .55004 .70141 .55832 .71647 .54875 .70935 .54041 Metetra
.762 .78 .868 r
.70935 .54041 .71647 .54875 .73158 .53916 .72452 .53076 Metetra
.824 .79 .82 r
.72452 .53076 .73158 .53916 .7464 .52474 .73941 .51622 Metetra
.828 .789 .816 r
.73941 .51622 .7464 .52474 .76119 .50992 .75427 .50128 Metetra
.827 .788 .815 r
.75427 .50128 .76119 .50992 .77596 .49512 .76912 .48635 Metetra
.827 .787 .815 r
.76912 .48635 .77596 .49512 .79073 .48033 .78396 .47144 Metetra
.826 .786 .814 r
.78396 .47144 .79073 .48033 .80548 .46555 .79879 .45653 Metetra
.715 .757 .885 r
.79879 .45653 .80548 .46555 .82092 .4584 .81428 .44935 Metetra
.589 .707 .925 r
.81428 .44935 .82092 .4584 .83689 .45627 .83032 .44723 Metetra
.589 .708 .926 r
.83032 .44723 .83689 .45627 .85298 .45413 .84647 .44509 Metetra
.588 .709 .927 r
.84647 .44509 .85298 .45413 .86918 .45197 .86273 .44295 Metetra
.588 .711 .928 r
.86273 .44295 .86918 .45197 .8855 .4498 .87911 .44078 Metetra
.588 .712 .929 r
.87911 .44078 .8855 .4498 .90193 .44761 .89561 .4386 Metetra
.653 .742 .915 r
.89561 .4386 .90193 .44761 .91819 .44303 .91195 .434 Metetra
.704 .763 .898 r
.91195 .434 .91819 .44303 .93428 .43624 .9281 .42715 Metetra
.704 .763 .898 r
.9281 .42715 .93428 .43624 .95043 .42943 .94432 .42028 Metetra
.669 .781 .933 r
.34802 .74076 .35673 .7473 .37079 .74267 .36213 .73608 Metetra
.699 .786 .918 r
.36213 .73608 .37079 .74267 .38497 .73694 .37637 .73026 Metetra
.721 .788 .905 r
.37637 .73026 .38497 .73694 .39924 .73029 .3907 .7235 Metetra
.739 .788 .892 r
.3907 .7235 .39924 .73029 .41359 .72272 .40511 .7158 Metetra
.757 .788 .878 r
.40511 .7158 .41359 .72272 .42802 .7141 .4196 .70703 Metetra
.77 .786 .866 r
.4196 .70703 .42802 .7141 .44251 .70455 .43415 .69734 Metetra
.78 .785 .857 r
.43415 .69734 .44251 .70455 .45704 .69419 .44875 .68685 Metetra
.79 .783 .847 r
.44875 .68685 .45704 .69419 .47161 .683 .46339 .67554 Metetra
.79 .782 .845 r
.46339 .67554 .47161 .683 .4862 .67171 .47805 .66414 Metetra
.787 .781 .847 r
.47805 .66414 .4862 .67171 .50081 .66061 .49272 .65296 Metetra
.787 .781 .847 r
.49272 .65296 .50081 .66061 .51543 .64951 .50741 .64177 Metetra
.751 .776 .874 r
.50741 .64177 .51543 .64951 .53008 .64087 .52212 .63308 Metetra
.749 .776 .875 r
.52212 .63308 .53008 .64087 .54477 .63231 .53688 .62446 Metetra
.74 .774 .881 r
.53688 .62446 .54477 .63231 .5595 .62423 .55167 .61633 Metetra
.724 .771 .891 r
.55167 .61633 .5595 .62423 .5743 .617 .56653 .60907 Metetra
.724 .771 .891 r
.56653 .60907 .5743 .617 .58915 .60975 .58143 .60177 Metetra
.727 .772 .889 r
.58143 .60177 .58915 .60975 .60405 .6023 .59639 .59427 Metetra
.738 .775 .882 r
.59639 .59427 .60405 .6023 .61898 .59422 .61139 .58614 Metetra
.738 .775 .882 r
.61139 .58614 .61898 .59422 .63397 .58612 .62644 .57799 Metetra
.738 .775 .882 r
.62644 .57799 .63397 .58612 .649 .578 .64153 .56981 Metetra
.749 .777 .876 r
.64153 .56981 .649 .578 .66405 .56922 .65665 .56098 Metetra
.762 .78 .868 r
.65665 .56098 .66405 .56922 .67911 .55964 .67178 .55134 Metetra
.762 .78 .868 r
.67178 .55134 .67911 .55964 .69421 .55004 .68695 .54167 Metetra
.762 .78 .868 r
.68695 .54167 .69421 .55004 .70935 .54041 .70215 .53198 Metetra
.762 .78 .868 r
.70215 .53198 .70935 .54041 .72452 .53076 .71739 .52227 Metetra
.824 .79 .819 r
.71739 .52227 .72452 .53076 .73941 .51622 .73236 .50761 Metetra
.828 .789 .815 r
.73236 .50761 .73941 .51622 .75427 .50128 .74729 .49255 Metetra
.828 .788 .815 r
.74729 .49255 .75427 .50128 .76912 .48635 .76221 .4775 Metetra
.827 .787 .814 r
.76221 .4775 .76912 .48635 .78396 .47144 .77712 .46246 Metetra
.827 .786 .814 r
.77712 .46246 .78396 .47144 .79879 .45653 .79202 .44743 Metetra
.714 .757 .886 r
.79202 .44743 .79879 .45653 .81428 .44935 .80758 .4402 Metetra
.588 .706 .925 r
.80758 .4402 .81428 .44935 .83032 .44723 .82368 .43809 Metetra
.587 .708 .926 r
.82368 .43809 .83032 .44723 .84647 .44509 .83989 .43597 Metetra
.587 .709 .927 r
.83989 .43597 .84647 .44509 .86273 .44295 .85622 .43383 Metetra
.587 .71 .928 r
.85622 .43383 .86273 .44295 .87911 .44078 .87267 .43167 Metetra
.586 .711 .929 r
.87267 .43167 .87911 .44078 .89561 .4386 .88923 .4295 Metetra
.652 .742 .915 r
.88923 .4295 .89561 .4386 .91195 .434 .90564 .42487 Metetra
.704 .763 .898 r
.90564 .42487 .91195 .434 .9281 .42715 .92186 .41797 Metetra
.704 .763 .898 r
.92186 .41797 .9281 .42715 .94432 .42028 .93815 .41104 Metetra
.67 .781 .933 r
.33922 .73415 .34802 .74076 .36213 .73608 .35339 .72942 Metetra
.7 .786 .918 r
.35339 .72942 .36213 .73608 .37637 .73026 .36768 .72352 Metetra
.722 .788 .905 r
.36768 .72352 .37637 .73026 .3907 .7235 .38207 .71665 Metetra
.741 .789 .891 r
.38207 .71665 .3907 .7235 .40511 .7158 .39654 .7088 Metetra
.758 .788 .877 r
.39654 .7088 .40511 .7158 .4196 .70703 .4111 .69989 Metetra
.771 .786 .865 r
.4111 .69989 .4196 .70703 .43415 .69734 .42572 .69005 Metetra
.781 .785 .856 r
.42572 .69005 .43415 .69734 .44875 .68685 .44038 .67943 Metetra
.79 .783 .846 r
.44038 .67943 .44875 .68685 .46339 .67554 .45509 .66801 Metetra
.791 .782 .845 r
.45509 .66801 .46339 .67554 .47805 .66414 .46982 .6565 Metetra
.787 .781 .847 r
.46982 .6565 .47805 .66414 .49272 .65296 .48456 .64524 Metetra
.787 .781 .847 r
.48456 .64524 .49272 .65296 .50741 .64177 .49932 .63395 Metetra
.751 .776 .874 r
.49932 .63395 .50741 .64177 .52212 .63308 .51409 .62521 Metetra
.749 .776 .875 r
.51409 .62521 .52212 .63308 .53688 .62446 .5289 .61654 Metetra
.74 .774 .881 r
.5289 .61654 .53688 .62446 .55167 .61633 .54376 .60837 Metetra
.723 .771 .891 r
.54376 .60837 .55167 .61633 .56653 .60907 .55867 .60105 Metetra
.723 .771 .891 r
.55867 .60105 .56653 .60907 .58143 .60177 .57364 .59371 Metetra
.727 .772 .889 r
.57364 .59371 .58143 .60177 .59639 .59427 .58866 .58616 Metetra
.738 .775 .882 r
.58866 .58616 .59639 .59427 .61139 .58614 .60373 .57798 Metetra
.738 .775 .882 r
.60373 .57798 .61139 .58614 .62644 .57799 .61883 .56977 Metetra
.738 .775 .882 r
.61883 .56977 .62644 .57799 .64153 .56981 .63399 .56154 Metetra
.749 .777 .876 r
.63399 .56154 .64153 .56981 .65665 .56098 .64918 .55265 Metetra
.762 .78 .868 r
.64918 .55265 .65665 .56098 .67178 .55134 .66438 .54295 Metetra
.762 .78 .868 r
.66438 .54295 .67178 .55134 .68695 .54167 .67961 .53322 Metetra
.762 .78 .868 r
.67961 .53322 .68695 .54167 .70215 .53198 .69488 .52348 Metetra
.762 .78 .868 r
.69488 .52348 .70215 .53198 .71739 .52227 .71019 .5137 Metetra
.825 .79 .819 r
.71019 .5137 .71739 .52227 .73236 .50761 .72523 .49892 Metetra
.829 .789 .815 r
.72523 .49892 .73236 .50761 .74729 .49255 .74024 .48373 Metetra
.828 .788 .814 r
.74024 .48373 .74729 .49255 .76221 .4775 .75523 .46855 Metetra
.828 .787 .814 r
.75523 .46855 .76221 .4775 .77712 .46246 .77022 .45339 Metetra
.827 .786 .813 r
.77022 .45339 .77712 .46246 .79202 .44743 .78519 .43824 Metetra
.714 .757 .886 r
.78519 .43824 .79202 .44743 .80758 .4402 .80082 .43096 Metetra
.586 .706 .925 r
.80082 .43096 .80758 .4402 .82368 .43809 .81697 .42886 Metetra
.586 .707 .926 r
.81697 .42886 .82368 .43809 .83989 .43597 .83325 .42674 Metetra
.585 .708 .927 r
.83325 .42674 .83989 .43597 .85622 .43383 .84964 .42461 Metetra
.585 .709 .929 r
.84964 .42461 .85622 .43383 .87267 .43167 .86615 .42247 Metetra
.585 .71 .93 r
.86615 .42247 .87267 .43167 .88923 .4295 .88279 .4203 Metetra
.652 .742 .915 r
.88279 .4203 .88923 .4295 .90564 .42487 .89926 .41565 Metetra
.704 .763 .898 r
.89926 .41565 .90564 .42487 .92186 .41797 .91555 .40869 Metetra
.704 .763 .898 r
.91555 .40869 .92186 .41797 .93815 .41104 .93192 .4017 Metetra
.67 .781 .933 r
.33033 .72747 .33922 .73415 .35339 .72942 .34455 .72269 Metetra
.701 .786 .917 r
.34455 .72269 .35339 .72942 .36768 .72352 .3589 .71671 Metetra
.723 .788 .904 r
.3589 .71671 .36768 .72352 .38207 .71665 .37335 .70972 Metetra
.742 .789 .89 r
.37335 .70972 .38207 .71665 .39654 .7088 .38788 .70173 Metetra
.76 .788 .876 r
.38788 .70173 .39654 .7088 .4111 .69989 .40251 .69268 Metetra
.773 .787 .864 r
.40251 .69268 .4111 .69989 .42572 .69005 .41719 .68269 Metetra
.782 .785 .855 r
.41719 .68269 .42572 .69005 .44038 .67943 .43193 .67193 Metetra
.791 .783 .846 r
.43193 .67193 .44038 .67943 .45509 .66801 .44671 .6604 Metetra
.791 .782 .844 r
.44671 .6604 .45509 .66801 .46982 .6565 .4615 .64878 Metetra
.788 .781 .847 r
.4615 .64878 .46982 .6565 .48456 .64524 .47631 .63743 Metetra
.788 .781 .846 r
.47631 .63743 .48456 .64524 .49932 .63395 .49114 .62606 Metetra
.751 .776 .874 r
.49114 .62606 .49932 .63395 .51409 .62521 .50598 .61726 Metetra
.749 .776 .875 r
.50598 .61726 .51409 .62521 .5289 .61654 .52085 .60855 Metetra
.74 .774 .881 r
.52085 .60855 .5289 .61654 .54376 .60837 .53577 .60032 Metetra
.723 .771 .891 r
.53577 .60032 .54376 .60837 .55867 .60105 .55074 .59296 Metetra
.723 .771 .891 r
.55074 .59296 .55867 .60105 .57364 .59371 .56577 .58557 Metetra
.727 .772 .889 r
.56577 .58557 .57364 .59371 .58866 .58616 .58086 .57797 Metetra
.738 .775 .882 r
.58086 .57797 .58866 .58616 .60373 .57798 .59598 .56974 Metetra
.738 .775 .882 r
.59598 .56974 .60373 .57798 .61883 .56977 .61115 .56148 Metetra
.738 .775 .882 r
.61115 .56148 .61883 .56977 .63399 .56154 .62638 .55319 Metetra
.749 .777 .876 r
.62638 .55319 .63399 .56154 .64918 .55265 .64163 .54424 Metetra
.762 .78 .868 r
.64163 .54424 .64918 .55265 .66438 .54295 .65689 .53448 Metetra
.762 .78 .868 r
.65689 .53448 .66438 .54295 .67961 .53322 .6722 .52469 Metetra
.762 .78 .868 r
.6722 .52469 .67961 .53322 .69488 .52348 .68753 .51488 Metetra
.762 .78 .868 r
.68753 .51488 .69488 .52348 .71019 .5137 .70291 .50504 Metetra
.825 .79 .818 r
.70291 .50504 .71019 .5137 .72523 .49892 .71803 .49014 Metetra
.829 .789 .814 r
.71803 .49014 .72523 .49892 .74024 .48373 .73311 .47482 Metetra
.829 .788 .814 r
.73311 .47482 .74024 .48373 .75523 .46855 .74819 .45952 Metetra
.828 .787 .813 r
.74819 .45952 .75523 .46855 .77022 .45339 .76324 .44423 Metetra
.828 .786 .813 r
.76324 .44423 .77022 .45339 .78519 .43824 .77829 .42895 Metetra
.714 .756 .886 r
.77829 .42895 .78519 .43824 .80082 .43096 .79398 .42163 Metetra
.585 .705 .926 r
.79398 .42163 .80082 .43096 .81697 .42886 .8102 .41954 Metetra
.584 .706 .927 r
.8102 .41954 .81697 .42886 .83325 .42674 .82654 .41743 Metetra
.584 .707 .928 r
.82654 .41743 .83325 .42674 .84964 .42461 .84299 .41531 Metetra
.583 .708 .929 r
.84299 .41531 .84964 .42461 .86615 .42247 .85957 .41317 Metetra
.583 .71 .93 r
.85957 .41317 .86615 .42247 .88279 .4203 .87628 .41101 Metetra
.651 .741 .916 r
.87628 .41101 .88279 .4203 .89926 .41565 .89282 .40633 Metetra
.704 .763 .898 r
.89282 .40633 .89926 .41565 .91555 .40869 .90918 .39932 Metetra
.704 .763 .898 r
.90918 .39932 .91555 .40869 .93192 .4017 .92562 .39227 Metetra
.67 .784 .934 r
.32135 .72081 .33033 .72747 .34455 .72269 .33562 .71597 Metetra
.703 .789 .918 r
.33562 .71597 .34455 .72269 .3589 .71671 .35002 .70988 Metetra
.725 .79 .903 r
.35002 .70988 .3589 .71671 .37335 .70972 .36453 .70275 Metetra
.744 .79 .89 r
.36453 .70275 .37335 .70972 .38788 .70173 .37914 .69461 Metetra
.761 .789 .875 r
.37914 .69461 .38788 .70173 .40251 .69268 .39383 .6854 Metetra
.774 .787 .864 r
.39383 .6854 .40251 .69268 .41719 .68269 .40858 .67527 Metetra
.783 .785 .854 r
.40858 .67527 .41719 .68269 .43193 .67193 .42339 .66438 Metetra
.792 .784 .845 r
.42339 .66438 .43193 .67193 .44671 .6604 .43824 .65274 Metetra
.792 .783 .844 r
.43824 .65274 .44671 .6604 .4615 .64878 .45311 .64102 Metetra
.788 .782 .847 r
.45311 .64102 .4615 .64878 .47631 .63743 .46798 .62957 Metetra
.788 .781 .846 r
.46798 .62957 .47631 .63743 .49114 .62606 .48288 .61811 Metetra
.751 .777 .874 r
.48288 .61811 .49114 .62606 .50598 .61726 .49778 .60925 Metetra
.749 .776 .875 r
.49778 .60925 .50598 .61726 .52085 .60855 .51272 .60048 Metetra
.74 .775 .881 r
.51272 .60048 .52085 .60855 .53577 .60032 .5277 .59219 Metetra
.723 .771 .891 r
.5277 .59219 .53577 .60032 .55074 .59296 .54273 .58479 Metetra
.723 .772 .891 r
.54273 .58479 .55074 .59296 .56577 .58557 .55782 .57735 Metetra
.727 .772 .889 r
.55782 .57735 .56577 .58557 .58086 .57797 .57297 .56971 Metetra
.738 .775 .883 r
.57297 .56971 .58086 .57797 .59598 .56974 .58816 .56142 Metetra
.738 .775 .883 r
.58816 .56142 .59598 .56974 .61115 .56148 .6034 .5531 Metetra
.738 .775 .883 r
.6034 .5531 .61115 .56148 .62638 .55319 .61868 .54476 Metetra
.749 .777 .876 r
.61868 .54476 .62638 .55319 .64163 .54424 .634 .53575 Metetra
.762 .78 .868 r
.634 .53575 .64163 .54424 .65689 .53448 .64934 .52592 Metetra
.762 .78 .868 r
.64934 .52592 .65689 .53448 .6722 .52469 .66471 .51608 Metetra
.762 .78 .868 r
.66471 .51608 .6722 .52469 .68753 .51488 .68011 .5062 Metetra
.762 .78 .868 r
.68011 .5062 .68753 .51488 .70291 .50504 .69556 .49631 Metetra
.826 .79 .818 r
.69556 .49631 .70291 .50504 .71803 .49014 .71076 .48128 Metetra
.83 .79 .814 r
.71076 .48128 .71803 .49014 .73311 .47482 .72592 .46584 Metetra
.829 .789 .813 r
.72592 .46584 .73311 .47482 .74819 .45952 .74107 .45042 Metetra
.829 .788 .813 r
.74107 .45042 .74819 .45952 .76324 .44423 .7562 .43501 Metetra
.828 .787 .813 r
.7562 .43501 .76324 .44423 .77829 .42895 .77132 .41962 Metetra
.714 .758 .887 r
.77132 .41962 .77829 .42895 .79398 .42163 .78708 .41225 Metetra
.583 .705 .927 r
.78708 .41225 .79398 .42163 .8102 .41954 .80336 .41016 Metetra
.583 .706 .928 r
.80336 .41016 .8102 .41954 .82654 .41743 .81976 .40805 Metetra
.582 .707 .929 r
.81976 .40805 .82654 .41743 .84299 .41531 .83628 .40593 Metetra
.582 .708 .93 r
.83628 .40593 .84299 .41531 .85957 .41317 .85293 .40379 Metetra
.581 .709 .93 r
.85293 .40379 .85957 .41317 .87628 .41101 .8697 .40163 Metetra
.65 .741 .916 r
.8697 .40163 .87628 .41101 .89282 .40633 .88631 .39692 Metetra
.704 .763 .898 r
.88631 .39692 .89282 .40633 .90918 .39932 .90274 .38985 Metetra
.704 .763 .898 r
.90274 .38985 .90918 .39932 .92562 .39227 .91925 .38274 Metetra
.671 .784 .934 r
.31227 .71411 .32135 .72081 .33562 .71597 .3266 .7092 Metetra
.704 .789 .917 r
.3266 .7092 .33562 .71597 .35002 .70988 .34106 .70301 Metetra
.728 .791 .902 r
.34106 .70301 .35002 .70988 .36453 .70275 .35563 .69573 Metetra
.746 .79 .888 r
.35563 .69573 .36453 .70275 .37914 .69461 .3703 .68743 Metetra
.763 .789 .874 r
.3703 .68743 .37914 .69461 .39383 .6854 .38506 .67806 Metetra
.775 .787 .863 r
.38506 .67806 .39383 .6854 .40858 .67527 .39989 .66778 Metetra
.784 .785 .854 r
.39989 .66778 .40858 .67527 .42339 .66438 .41476 .65676 Metetra
.792 .784 .845 r
.41476 .65676 .42339 .66438 .43824 .65274 .42968 .645 Metetra
.793 .783 .844 r
.42968 .645 .43824 .65274 .45311 .64102 .44462 .63318 Metetra
.789 .782 .847 r
.44462 .63318 .45311 .64102 .46798 .62957 .45957 .62164 Metetra
.789 .781 .846 r
.45957 .62164 .46798 .62957 .48288 .61811 .47454 .61008 Metetra
.751 .777 .874 r
.47454 .61008 .48288 .61811 .49778 .60925 .4895 .60116 Metetra
.749 .776 .875 r
.4895 .60116 .49778 .60925 .51272 .60048 .5045 .59233 Metetra
.74 .775 .881 r
.5045 .59233 .51272 .60048 .5277 .59219 .51955 .58399 Metetra
.723 .771 .891 r
.51955 .58399 .5277 .59219 .54273 .58479 .53464 .57654 Metetra
.723 .772 .891 r
.53464 .57654 .54273 .58479 .55782 .57735 .54979 .56905 Metetra
.727 .772 .889 r
.54979 .56905 .55782 .57735 .57297 .56971 .565 .56136 Metetra
.738 .775 .883 r
.565 .56136 .57297 .56971 .58816 .56142 .58025 .55301 Metetra
.738 .775 .883 r
.58025 .55301 .58816 .56142 .6034 .5531 .59556 .54464 Metetra
.738 .775 .883 r
.59556 .54464 .6034 .5531 .61868 .54476 .61091 .53624 Metetra
.749 .777 .876 r
.61091 .53624 .61868 .54476 .634 .53575 .6263 .52718 Metetra
.762 .78 .868 r
.6263 .52718 .634 .53575 .64934 .52592 .6417 .51729 Metetra
.762 .78 .868 r
.6417 .51729 .64934 .52592 .66471 .51608 .65714 .50738 Metetra
.762 .78 .868 r
.65714 .50738 .66471 .51608 .68011 .5062 .67262 .49744 Metetra
.762 .78 .868 r
.67262 .49744 .68011 .5062 .69556 .49631 .68813 .48748 Metetra
.826 .79 .818 r
.68813 .48748 .69556 .49631 .71076 .48128 .70341 .47234 Metetra
.83 .79 .813 r
.70341 .47234 .71076 .48128 .72592 .46584 .71865 .45678 Metetra
.83 .789 .813 r
.71865 .45678 .72592 .46584 .74107 .45042 .73388 .44124 Metetra
.829 .788 .813 r
.73388 .44124 .74107 .45042 .7562 .43501 .74909 .42572 Metetra
.829 .787 .812 r
.74909 .42572 .7562 .43501 .77132 .41962 .76429 .4102 Metetra
.714 .758 .887 r
.76429 .4102 .77132 .41962 .78708 .41225 .78011 .40279 Metetra
.581 .705 .927 r
.78011 .40279 .78708 .41225 .80336 .41016 .79645 .40069 Metetra
.581 .706 .928 r
.79645 .40069 .80336 .41016 .81976 .40805 .81291 .39858 Metetra
.581 .707 .929 r
.81291 .39858 .81976 .40805 .83628 .40593 .8295 .39646 Metetra
.58 .708 .93 r
.8295 .39646 .83628 .40593 .85293 .40379 .84621 .39431 Metetra
.58 .709 .931 r
.84621 .39431 .85293 .40379 .8697 .40163 .86305 .39215 Metetra
.65 .741 .916 r
.86305 .39215 .8697 .40163 .88631 .39692 .87973 .38741 Metetra
.704 .763 .898 r
.87973 .38741 .88631 .39692 .90274 .38985 .89623 .38028 Metetra
.704 .763 .898 r
.89623 .38028 .90274 .38985 .91925 .38274 .91282 .37312 Metetra
.672 .784 .934 r
.3031 .70733 .31227 .71411 .3266 .7092 .31748 .70236 Metetra
.706 .79 .916 r
.31748 .70236 .3266 .7092 .34106 .70301 .332 .69606 Metetra
.73 .791 .901 r
.332 .69606 .34106 .70301 .35563 .69573 .34664 .68863 Metetra
.748 .79 .887 r
.34664 .68863 .35563 .69573 .3703 .68743 .36138 .68017 Metetra
.764 .789 .873 r
.36138 .68017 .3703 .68743 .38506 .67806 .3762 .67064 Metetra
.776 .787 .862 r
.3762 .67064 .38506 .67806 .39989 .66778 .3911 .66021 Metetra
.785 .785 .853 r
.3911 .66021 .39989 .66778 .41476 .65676 .40605 .64906 Metetra
.793 .784 .845 r
.40605 .64906 .41476 .65676 .42968 .645 .42104 .63719 Metetra
.793 .783 .843 r
.42104 .63719 .42968 .645 .44462 .63318 .43605 .62526 Metetra
.789 .782 .846 r
.43605 .62526 .44462 .63318 .45957 .62164 .45107 .61362 Metetra
.789 .781 .846 r
.45107 .61362 .45957 .62164 .47454 .61008 .46611 .60197 Metetra
.751 .777 .874 r
.46611 .60197 .47454 .61008 .4895 .60116 .48114 .59299 Metetra
.749 .776 .875 r
.48114 .59299 .4895 .60116 .5045 .59233 .4962 .5841 Metetra
.74 .775 .881 r
.4962 .5841 .5045 .59233 .51955 .58399 .51131 .57571 Metetra
.723 .771 .891 r
.51131 .57571 .51955 .58399 .53464 .57654 .52647 .5682 Metetra
.723 .772 .891 r
.52647 .5682 .53464 .57654 .54979 .56905 .54168 .56067 Metetra
.727 .772 .889 r
.54168 .56067 .54979 .56905 .565 .56136 .55695 .55293 Metetra
.738 .775 .883 r
.55695 .55293 .565 .56136 .58025 .55301 .57227 .54452 Metetra
.738 .775 .883 r
.57227 .54452 .58025 .55301 .59556 .54464 .58764 .5361 Metetra
.738 .775 .883 r
.58764 .5361 .59556 .54464 .61091 .53624 .60306 .52764 Metetra
.749 .777 .876 r
.60306 .52764 .61091 .53624 .6263 .52718 .61851 .51851 Metetra
.762 .78 .868 r
.61851 .51851 .6263 .52718 .6417 .51729 .63398 .50856 Metetra
.762 .78 .868 r
.63398 .50856 .6417 .51729 .65714 .50738 .6495 .49859 Metetra
.762 .78 .868 r
.6495 .49859 .65714 .50738 .67262 .49744 .66504 .48859 Metetra
.762 .78 .868 r
.66504 .48859 .67262 .49744 .68813 .48748 .68063 .47856 Metetra
.827 .79 .817 r
.68063 .47856 .68813 .48748 .70341 .47234 .69599 .46331 Metetra
.831 .79 .813 r
.69599 .46331 .70341 .47234 .71865 .45678 .71131 .44763 Metetra
.83 .789 .813 r
.71131 .44763 .71865 .45678 .73388 .44124 .72661 .43197 Metetra
.83 .788 .812 r
.72661 .43197 .73388 .44124 .74909 .42572 .7419 .41632 Metetra
.829 .787 .812 r
.7419 .41632 .74909 .42572 .76429 .4102 .75718 .40069 Metetra
.714 .758 .887 r
.75718 .40069 .76429 .4102 .78011 .40279 .77307 .39323 Metetra
.58 .704 .928 r
.77307 .39323 .78011 .40279 .79645 .40069 .78947 .39113 Metetra
.58 .705 .928 r
.78947 .39113 .79645 .40069 .81291 .39858 .806 .38902 Metetra
.579 .706 .929 r
.806 .38902 .81291 .39858 .8295 .39646 .82265 .38689 Metetra
.579 .707 .93 r
.82265 .38689 .8295 .39646 .84621 .39431 .83942 .38474 Metetra
.579 .708 .931 r
.83942 .38474 .84621 .39431 .86305 .39215 .85633 .38258 Metetra
.649 .741 .916 r
.85633 .38258 .86305 .39215 .87973 .38741 .87308 .3778 Metetra
.704 .763 .898 r
.87308 .3778 .87973 .38741 .89623 .38028 .88966 .37061 Metetra
.704 .763 .898 r
.88966 .37061 .89623 .38028 .91282 .37312 .90631 .36339 Metetra
.672 .785 .934 r
.29383 .70048 .3031 .70733 .31748 .70236 .30826 .69545 Metetra
.707 .79 .916 r
.30826 .69545 .31748 .70236 .332 .69606 .32285 .68903 Metetra
.731 .791 .9 r
.32285 .68903 .332 .69606 .34664 .68863 .33755 .68146 Metetra
.75 .791 .886 r
.33755 .68146 .34664 .68863 .36138 .68017 .35236 .67283 Metetra
.766 .789 .872 r
.35236 .67283 .36138 .68017 .3762 .67064 .36725 .66314 Metetra
.777 .787 .861 r
.36725 .66314 .3762 .67064 .3911 .66021 .38222 .65257 Metetra
.786 .785 .852 r
.38222 .65257 .3911 .66021 .40605 .64906 .39724 .64128 Metetra
.793 .784 .844 r
.39724 .64128 .40605 .64906 .42104 .63719 .41231 .6293 Metetra
.794 .783 .843 r
.41231 .6293 .42104 .63719 .43605 .62526 .4274 .61726 Metetra
.789 .782 .846 r
.4274 .61726 .43605 .62526 .45107 .61362 .44249 .60553 Metetra
.789 .781 .846 r
.44249 .60553 .45107 .61362 .46611 .60197 .4576 .59378 Metetra
.751 .777 .874 r
.4576 .59378 .46611 .60197 .48114 .59299 .47269 .58474 Metetra
.749 .776 .875 r
.47269 .58474 .48114 .59299 .4962 .5841 .48782 .57579 Metetra
.74 .775 .881 r
.48782 .57579 .4962 .5841 .51131 .57571 .50299 .56734 Metetra
.723 .771 .891 r
.50299 .56734 .51131 .57571 .52647 .5682 .51821 .55978 Metetra
.723 .772 .891 r
.51821 .55978 .52647 .5682 .54168 .56067 .53349 .5522 Metetra
.727 .772 .889 r
.53349 .5522 .54168 .56067 .55695 .55293 .54882 .54441 Metetra
.738 .775 .883 r
.54882 .54441 .55695 .55293 .57227 .54452 .5642 .53595 Metetra
.738 .775 .883 r
.5642 .53595 .57227 .54452 .58764 .5361 .57964 .52746 Metetra
.738 .775 .883 r
.57964 .52746 .58764 .5361 .60306 .52764 .59513 .51895 Metetra
.749 .777 .876 r
.59513 .51895 .60306 .52764 .61851 .51851 .61065 .50976 Metetra
.762 .78 .868 r
.61065 .50976 .61851 .51851 .63398 .50856 .62619 .49975 Metetra
.762 .78 .868 r
.62619 .49975 .63398 .50856 .6495 .49859 .64177 .48971 Metetra
.762 .78 .868 r
.64177 .48971 .6495 .49859 .66504 .48859 .65739 .47964 Metetra
.762 .78 .868 r
.65739 .47964 .66504 .48859 .68063 .47856 .67305 .46955 Metetra
.827 .79 .817 r
.67305 .46955 .68063 .47856 .69599 .46331 .68849 .45418 Metetra
.831 .79 .813 r
.68849 .45418 .69599 .46331 .71131 .44763 .70389 .43838 Metetra
.831 .789 .812 r
.70389 .43838 .71131 .44763 .72661 .43197 .71927 .4226 Metetra
.83 .788 .812 r
.71927 .4226 .72661 .43197 .7419 .41632 .73464 .40683 Metetra
.83 .787 .811 r
.73464 .40683 .7419 .41632 .75718 .40069 .75 .39108 Metetra
.713 .758 .887 r
.75 .39108 .75718 .40069 .77307 .39323 .76596 .38357 Metetra
.579 .704 .928 r
.76596 .38357 .77307 .39323 .78947 .39113 .78242 .38147 Metetra
.578 .705 .929 r
.78242 .38147 .78947 .39113 .806 .38902 .79901 .37935 Metetra
.578 .706 .929 r
.79901 .37935 .806 .38902 .82265 .38689 .81572 .37722 Metetra
.578 .707 .93 r
.81572 .37722 .82265 .38689 .83942 .38474 .83256 .37507 Metetra
.577 .707 .931 r
.83256 .37507 .83942 .38474 .85633 .38258 .84954 .3729 Metetra
.649 .741 .917 r
.84954 .3729 .85633 .38258 .87308 .3778 .86636 .36809 Metetra
.704 .763 .898 r
.86636 .36809 .87308 .3778 .88966 .37061 .88301 .36084 Metetra
.704 .763 .898 r
.88301 .36084 .88966 .37061 .90631 .36339 .89974 .35355 Metetra
.673 .785 .933 r
.28446 .69356 .29383 .70048 .30826 .69545 .29895 .68846 Metetra
.709 .79 .915 r
.29895 .68846 .30826 .69545 .32285 .68903 .3136 .68194 Metetra
.733 .791 .899 r
.3136 .68194 .32285 .68903 .33755 .68146 .32837 .67422 Metetra
.752 .791 .884 r
.32837 .67422 .33755 .68146 .35236 .67283 .34324 .66542 Metetra
.768 .789 .871 r
.34324 .66542 .35236 .67283 .36725 .66314 .35821 .65556 Metetra
.779 .787 .86 r
.35821 .65556 .36725 .66314 .38222 .65257 .37325 .64484 Metetra
.787 .785 .851 r
.37325 .64484 .38222 .65257 .39724 .64128 .38835 .63343 Metetra
.794 .784 .844 r
.38835 .63343 .39724 .64128 .41231 .6293 .40349 .62133 Metetra
.794 .783 .843 r
.40349 .62133 .41231 .6293 .4274 .61726 .41865 .60917 Metetra
.79 .782 .846 r
.41865 .60917 .4274 .61726 .44249 .60553 .43381 .59735 Metetra
.79 .781 .845 r
.43381 .59735 .44249 .60553 .4576 .59378 .449 .58551 Metetra
.751 .777 .874 r
.449 .58551 .4576 .59378 .47269 .58474 .46415 .5764 Metetra
.749 .776 .875 r
.46415 .5764 .47269 .58474 .48782 .57579 .47935 .56739 Metetra
.74 .775 .881 r
.47935 .56739 .48782 .57579 .50299 .56734 .49459 .55888 Metetra
.723 .771 .891 r
.49459 .55888 .50299 .56734 .51821 .55978 .50987 .55128 Metetra
.723 .772 .891 r
.50987 .55128 .51821 .55978 .53349 .5522 .52521 .54365 Metetra
.726 .772 .889 r
.52521 .54365 .53349 .5522 .54882 .54441 .54061 .5358 Metetra
.738 .775 .883 r
.54061 .5358 .54882 .54441 .5642 .53595 .55605 .52728 Metetra
.738 .775 .883 r
.55605 .52728 .5642 .53595 .57964 .52746 .57156 .51874 Metetra
.738 .775 .883 r
.57156 .51874 .57964 .52746 .59513 .51895 .58711 .51016 Metetra
.749 .777 .876 r
.58711 .51016 .59513 .51895 .61065 .50976 .6027 .50092 Metetra
.762 .78 .868 r
.6027 .50092 .61065 .50976 .62619 .49975 .61831 .49084 Metetra
.762 .78 .868 r
.61831 .49084 .62619 .49975 .64177 .48971 .63397 .48073 Metetra
.762 .78 .868 r
.63397 .48073 .64177 .48971 .65739 .47964 .64966 .4706 Metetra
.762 .78 .868 r
.64966 .4706 .65739 .47964 .67305 .46955 .66539 .46045 Metetra
.828 .79 .817 r
.66539 .46045 .67305 .46955 .68849 .45418 .68091 .44495 Metetra
.831 .79 .812 r
.68091 .44495 .68849 .45418 .70389 .43838 .69639 .42903 Metetra
.831 .789 .812 r
.69639 .42903 .70389 .43838 .71927 .4226 .71186 .41313 Metetra
.831 .788 .811 r
.71186 .41313 .71927 .4226 .73464 .40683 .72731 .39724 Metetra
.83 .787 .811 r
.72731 .39724 .73464 .40683 .75 .39108 .74274 .38137 Metetra
.713 .758 .887 r
.74274 .38137 .75 .39108 .76596 .38357 .75877 .37381 Metetra
.577 .703 .928 r
.75877 .37381 .76596 .38357 .78242 .38147 .77529 .3717 Metetra
.577 .704 .929 r
.77529 .3717 .78242 .38147 .79901 .37935 .79195 .36958 Metetra
.577 .705 .93 r
.79195 .36958 .79901 .37935 .81572 .37722 .80872 .36744 Metetra
.576 .706 .931 r
.80872 .36744 .81572 .37722 .83256 .37507 .82563 .36529 Metetra
.576 .707 .931 r
.82563 .36529 .83256 .37507 .84954 .3729 .84267 .36312 Metetra
.648 .74 .917 r
.84267 .36312 .84954 .3729 .86636 .36809 .85957 .35828 Metetra
.704 .763 .898 r
.85957 .35828 .86636 .36809 .88301 .36084 .87629 .35096 Metetra
.704 .763 .898 r
.87629 .35096 .88301 .36084 .89974 .35355 .8931 .34361 Metetra
.674 .785 .933 r
.275 .68657 .28446 .69356 .29895 .68846 .28954 .6814 Metetra
.71 .79 .914 r
.28954 .6814 .29895 .68846 .3136 .68194 .30425 .67477 Metetra
.735 .792 .898 r
.30425 .67477 .3136 .68194 .32837 .67422 .31908 .66689 Metetra
.754 .791 .883 r
.31908 .66689 .32837 .67422 .34324 .66542 .33403 .65793 Metetra
.769 .789 .869 r
.33403 .65793 .34324 .66542 .35821 .65556 .34908 .64791 Metetra
.78 .787 .859 r
.34908 .64791 .35821 .65556 .37325 .64484 .36419 .63704 Metetra
.788 .785 .851 r
.36419 .63704 .37325 .64484 .38835 .63343 .37936 .62549 Metetra
.795 .784 .843 r
.37936 .62549 .38835 .63343 .40349 .62133 .39458 .61327 Metetra
.795 .783 .842 r
.39458 .61327 .40349 .62133 .41865 .60917 .40981 .60101 Metetra
.79 .782 .845 r
.40981 .60101 .41865 .60917 .43381 .59735 .42505 .58908 Metetra
.79 .781 .845 r
.42505 .58908 .43381 .59735 .449 .58551 .44031 .57714 Metetra
.751 .777 .874 r
.44031 .57714 .449 .58551 .46415 .5764 .45553 .56798 Metetra
.749 .776 .875 r
.45553 .56798 .46415 .5764 .47935 .56739 .47079 .5589 Metetra
.74 .775 .881 r
.47079 .5589 .47935 .56739 .49459 .55888 .48609 .55034 Metetra
.723 .771 .891 r
.48609 .55034 .49459 .55888 .50987 .55128 .50144 .54268 Metetra
.723 .771 .891 r
.50144 .54268 .50987 .55128 .52521 .54365 .51684 .535 Metetra
.726 .772 .889 r
.51684 .535 .52521 .54365 .54061 .5358 .5323 .5271 Metetra
.738 .775 .883 r
.5323 .5271 .54061 .5358 .55605 .52728 .54782 .51853 Metetra
.738 .775 .883 r
.54782 .51853 .55605 .52728 .57156 .51874 .56339 .50992 Metetra
.738 .775 .883 r
.56339 .50992 .57156 .51874 .58711 .51016 .57901 .50129 Metetra
.749 .777 .876 r
.57901 .50129 .58711 .51016 .6027 .50092 .59467 .49198 Metetra
.762 .78 .868 r
.59467 .49198 .6027 .50092 .61831 .49084 .61035 .48184 Metetra
.762 .78 .868 r
.61035 .48184 .61831 .49084 .63397 .48073 .62608 .47166 Metetra
.762 .78 .868 r
.62608 .47166 .63397 .48073 .64966 .4706 .64184 .46147 Metetra
.762 .78 .868 r
.64184 .46147 .64966 .4706 .66539 .46045 .65765 .45125 Metetra
.828 .79 .816 r
.65765 .45125 .66539 .46045 .68091 .44495 .67325 .43563 Metetra
.832 .79 .812 r
.67325 .43563 .68091 .44495 .69639 .42903 .68881 .41959 Metetra
.831 .789 .811 r
.68881 .41959 .69639 .42903 .71186 .41313 .70436 .40356 Metetra
.831 .788 .811 r
.70436 .40356 .71186 .41313 .72731 .39724 .7199 .38756 Metetra
.831 .787 .811 r
.7199 .38756 .72731 .39724 .74274 .38137 .73541 .37156 Metetra
.713 .758 .887 r
.73541 .37156 .74274 .38137 .75877 .37381 .75151 .36395 Metetra
.576 .703 .928 r
.75151 .36395 .75877 .37381 .77529 .3717 .76809 .36184 Metetra
.576 .703 .929 r
.76809 .36184 .77529 .3717 .79195 .36958 .78481 .35971 Metetra
.575 .704 .93 r
.78481 .35971 .79195 .36958 .80872 .36744 .80165 .35757 Metetra
.575 .705 .931 r
.80165 .35757 .80872 .36744 .82563 .36529 .81863 .35541 Metetra
.575 .706 .932 r
.81863 .35541 .82563 .36529 .84267 .36312 .83574 .35323 Metetra
.648 .74 .917 r
.83574 .35323 .84267 .36312 .85957 .35828 .8527 .34835 Metetra
.704 .763 .898 r
.8527 .34835 .85957 .35828 .87629 .35096 .8695 .34098 Metetra
.704 .763 .898 r
.8695 .34098 .87629 .35096 .8931 .34361 .88638 .33356 Metetra
.674 .785 .933 r
.26543 .67951 .275 .68657 .28954 .6814 .28003 .67427 Metetra
.711 .79 .913 r
.28003 .67427 .28954 .6814 .30425 .67477 .2948 .66752 Metetra
.737 .792 .896 r
.2948 .66752 .30425 .67477 .31908 .66689 .30971 .65949 Metetra
.756 .791 .882 r
.30971 .65949 .31908 .66689 .33403 .65793 .32473 .65036 Metetra
.771 .789 .868 r
.32473 .65036 .33403 .65793 .34908 .64791 .33984 .64017 Metetra
.781 .787 .858 r
.33984 .64017 .34908 .64791 .36419 .63704 .35503 .62915 Metetra
.788 .785 .85 r
.35503 .62915 .36419 .63704 .37936 .62549 .37028 .61746 Metetra
.795 .784 .843 r
.37028 .61746 .37936 .62549 .39458 .61327 .38557 .60513 Metetra
.795 .783 .842 r
.38557 .60513 .39458 .61327 .40981 .60101 .40088 .59276 Metetra
.791 .782 .845 r
.40088 .59276 .40981 .60101 .42505 .58908 .4162 .58073 Metetra
.79 .781 .845 r
.4162 .58073 .42505 .58908 .44031 .57714 .43153 .5687 Metetra
.751 .777 .874 r
.43153 .5687 .44031 .57714 .45553 .56798 .44682 .55947 Metetra
.749 .776 .875 r
.44682 .55947 .45553 .56798 .47079 .5589 .46215 .55033 Metetra
.74 .775 .881 r
.46215 .55033 .47079 .5589 .48609 .55034 .47751 .5417 Metetra
.723 .771 .891 r
.47751 .5417 .48609 .55034 .50144 .54268 .49292 .534 Metetra
.723 .771 .891 r
.49292 .534 .50144 .54268 .51684 .535 .50839 .52626 Metetra
.726 .772 .889 r
.50839 .52626 .51684 .535 .5323 .5271 .52391 .51831 Metetra
.738 .775 .883 r
.52391 .51831 .5323 .5271 .54782 .51853 .5395 .50968 Metetra
.738 .775 .883 r
.5395 .50968 .54782 .51853 .56339 .50992 .55513 .50101 Metetra
.738 .775 .883 r
.55513 .50101 .56339 .50992 .57901 .50129 .57082 .49232 Metetra
.749 .777 .876 r
.57082 .49232 .57901 .50129 .59467 .49198 .58655 .48295 Metetra
.762 .78 .868 r
.58655 .48295 .59467 .49198 .61035 .48184 .60231 .47274 Metetra
.762 .78 .868 r
.60231 .47274 .61035 .48184 .62608 .47166 .61811 .4625 Metetra
.762 .78 .868 r
.61811 .4625 .62608 .47166 .64184 .46147 .63395 .45224 Metetra
.762 .78 .868 r
.63395 .45224 .64184 .46147 .65765 .45125 .64983 .44195 Metetra
.828 .79 .816 r
.64983 .44195 .65765 .45125 .67325 .43563 .66551 .42622 Metetra
.832 .79 .811 r
.66551 .42622 .67325 .43563 .68881 .41959 .68116 .41005 Metetra
.832 .789 .811 r
.68116 .41005 .68881 .41959 .70436 .40356 .69679 .3939 Metetra
.831 .788 .811 r
.69679 .3939 .70436 .40356 .7199 .38756 .71241 .37777 Metetra
.831 .787 .81 r
.71241 .37777 .7199 .38756 .73541 .37156 .72801 .36165 Metetra
.713 .757 .887 r
.72801 .36165 .73541 .37156 .75151 .36395 .74417 .35399 Metetra
.575 .702 .928 r
.74417 .35399 .75151 .36395 .76809 .36184 .76082 .35187 Metetra
.574 .703 .929 r
.76082 .35187 .76809 .36184 .78481 .35971 .7776 .34974 Metetra
.574 .704 .93 r
.7776 .34974 .78481 .35971 .80165 .35757 .79451 .34759 Metetra
.574 .705 .931 r
.79451 .34759 .80165 .35757 .81863 .35541 .81155 .34542 Metetra
.573 .706 .932 r
.81155 .34542 .81863 .35541 .83574 .35323 .82873 .34324 Metetra
.647 .74 .917 r
.82873 .34324 .83574 .35323 .8527 .34835 .84576 .33833 Metetra
.704 .763 .898 r
.84576 .33833 .8527 .34835 .8695 .34098 .86264 .33088 Metetra
.704 .763 .898 r
.86264 .33088 .8695 .34098 .88638 .33356 .8796 .32341 Metetra
.675 .785 .932 r
.25577 .67236 .26543 .67951 .28003 .67427 .27042 .66706 Metetra
.713 .791 .912 r
.27042 .66706 .28003 .67427 .2948 .66752 .28525 .6602 Metetra
.739 .792 .895 r
.28525 .6602 .2948 .66752 .30971 .65949 .30023 .65201 Metetra
.757 .791 .88 r
.30023 .65201 .30971 .65949 .32473 .65036 .31532 .64271 Metetra
.772 .789 .867 r
.31532 .64271 .32473 .65036 .33984 .64017 .33051 .63236 Metetra
.782 .787 .857 r
.33051 .63236 .33984 .64017 .35503 .62915 .34578 .62118 Metetra
.789 .785 .849 r
.34578 .62118 .35503 .62915 .37028 .61746 .3611 .60936 Metetra
.796 .784 .842 r
.3611 .60936 .37028 .61746 .38557 .60513 .37648 .59691 Metetra
.796 .783 .841 r
.37648 .59691 .38557 .60513 .40088 .59276 .39186 .58442 Metetra
.791 .782 .845 r
.39186 .58442 .40088 .59276 .4162 .58073 .40725 .5723 Metetra
.791 .781 .844 r
.40725 .5723 .4162 .58073 .43153 .5687 .42266 .56016 Metetra
.751 .777 .874 r
.42266 .56016 .43153 .5687 .44682 .55947 .43801 .55087 Metetra
.749 .776 .875 r
.43801 .55087 .44682 .55947 .46215 .55033 .45341 .54167 Metetra
.74 .775 .881 r
.45341 .54167 .46215 .55033 .47751 .5417 .46884 .53298 Metetra
.723 .771 .891 r
.46884 .53298 .47751 .5417 .49292 .534 .48431 .52522 Metetra
.723 .771 .891 r
.48431 .52522 .49292 .534 .50839 .52626 .49984 .51744 Metetra
.726 .772 .889 r
.49984 .51744 .50839 .52626 .52391 .51831 .51544 .50943 Metetra
.738 .775 .883 r
.51544 .50943 .52391 .51831 .5395 .50968 .53109 .50074 Metetra
.738 .775 .883 r
.53109 .50074 .5395 .50968 .55513 .50101 .54679 .49201 Metetra
.738 .775 .883 r
.54679 .49201 .55513 .50101 .57082 .49232 .56255 .48326 Metetra
.749 .777 .876 r
.56255 .48326 .57082 .49232 .58655 .48295 .57835 .47382 Metetra
.762 .78 .868 r
.57835 .47382 .58655 .48295 .60231 .47274 .59418 .46355 Metetra
.762 .78 .868 r
.59418 .46355 .60231 .47274 .61811 .4625 .61006 .45324 Metetra
.762 .78 .868 r
.61006 .45324 .61811 .4625 .63395 .45224 .62597 .44291 Metetra
.762 .78 .868 r
.62597 .44291 .63395 .45224 .64983 .44195 .64192 .43255 Metetra
.829 .79 .815 r
.64192 .43255 .64983 .44195 .66551 .42622 .65769 .4167 Metetra
.833 .79 .811 r
.65769 .4167 .66551 .42622 .68116 .41005 .67342 .4004 Metetra
.832 .789 .811 r
.67342 .4004 .68116 .41005 .69679 .3939 .68914 .38413 Metetra
.832 .788 .81 r
.68914 .38413 .69679 .3939 .71241 .37777 .70484 .36787 Metetra
.831 .787 .81 r
.70484 .36787 .71241 .37777 .72801 .36165 .72052 .35164 Metetra
.713 .757 .887 r
.72052 .35164 .72801 .36165 .74417 .35399 .73676 .34392 Metetra
.573 .701 .929 r
.73676 .34392 .74417 .35399 .76082 .35187 .75347 .3418 Metetra
.573 .702 .929 r
.75347 .3418 .76082 .35187 .7776 .34974 .77031 .33966 Metetra
.573 .703 .93 r
.77031 .33966 .7776 .34974 .79451 .34759 .78728 .3375 Metetra
.572 .704 .931 r
.78728 .3375 .79451 .34759 .81155 .34542 .80439 .33533 Metetra
.572 .705 .932 r
.80439 .33533 .81155 .34542 .82873 .34324 .82164 .33314 Metetra
.647 .74 .917 r
.82164 .33314 .82873 .34324 .84576 .33833 .83875 .32819 Metetra
.704 .763 .898 r
.83875 .32819 .84576 .33833 .86264 .33088 .8557 .32068 Metetra
.704 .763 .898 r
.8557 .32068 .86264 .33088 .8796 .32341 .87273 .31314 Metetra
.676 .786 .933 r
.24599 .6652 .25577 .67236 .27042 .66706 .2607 .65981 Metetra
.715 .792 .912 r
.2607 .65981 .27042 .66706 .28525 .6602 .2756 .65282 Metetra
.741 .793 .894 r
.2756 .65282 .28525 .6602 .30023 .65201 .29065 .64447 Metetra
.759 .791 .879 r
.29065 .64447 .30023 .65201 .31532 .64271 .30581 .63499 Metetra
.774 .789 .866 r
.30581 .63499 .31532 .64271 .33051 .63236 .32108 .62447 Metetra
.783 .787 .856 r
.32108 .62447 .33051 .63236 .34578 .62118 .33643 .61314 Metetra
.79 .786 .848 r
.33643 .61314 .34578 .62118 .3611 .60936 .35183 .60118 Metetra
.796 .784 .842 r
.35183 .60118 .3611 .60936 .37648 .59691 .36728 .58861 Metetra
.796 .783 .841 r
.36728 .58861 .37648 .59691 .39186 .58442 .38275 .57601 Metetra
.791 .782 .844 r
.38275 .57601 .39186 .58442 .40725 .5723 .39821 .56378 Metetra
.791 .782 .844 r
.39821 .56378 .40725 .5723 .42266 .56016 .4137 .55154 Metetra
.751 .777 .874 r
.4137 .55154 .42266 .56016 .43801 .55087 .42912 .54218 Metetra
.749 .776 .875 r
.42912 .54218 .43801 .55087 .45341 .54167 .44458 .53291 Metetra
.74 .775 .881 r
.44458 .53291 .45341 .54167 .46884 .53298 .46008 .52417 Metetra
.722 .771 .891 r
.46008 .52417 .46884 .53298 .48431 .52522 .47562 .51636 Metetra
.722 .771 .891 r
.47562 .51636 .48431 .52522 .49984 .51744 .49121 .50852 Metetra
.726 .772 .889 r
.49121 .50852 .49984 .51744 .51544 .50943 .50687 .50045 Metetra
.738 .775 .883 r
.50687 .50045 .51544 .50943 .53109 .50074 .52259 .4917 Metetra
.738 .775 .883 r
.52259 .4917 .53109 .50074 .54679 .49201 .53836 .48291 Metetra
.738 .775 .883 r
.53836 .48291 .54679 .49201 .56255 .48326 .55419 .4741 Metetra
.749 .777 .876 r
.55419 .4741 .56255 .48326 .57835 .47382 .57006 .4646 Metetra
.762 .78 .868 r
.57006 .4646 .57835 .47382 .59418 .46355 .58597 .45425 Metetra
.762 .78 .868 r
.58597 .45425 .59418 .46355 .61006 .45324 .60191 .44388 Metetra
.762 .78 .868 r
.60191 .44388 .61006 .45324 .62597 .44291 .6179 .43348 Metetra
.762 .78 .868 r
.6179 .43348 .62597 .44291 .64192 .43255 .63393 .42305 Metetra
.829 .79 .815 r
.63393 .42305 .64192 .43255 .65769 .4167 .64978 .40708 Metetra
.833 .79 .811 r
.64978 .40708 .65769 .4167 .67342 .4004 .6656 .39067 Metetra
.833 .789 .81 r
.6656 .39067 .67342 .4004 .68914 .38413 .68141 .37428 Metetra
.832 .789 .81 r
.68141 .37428 .68914 .38413 .70484 .36787 .69719 .35791 Metetra
.832 .788 .81 r
.69719 .35791 .70484 .36787 .72052 .35164 .71296 .34155 Metetra
.713 .758 .888 r
.71296 .34155 .72052 .35164 .73676 .34392 .72926 .33378 Metetra
.572 .702 .93 r
.72926 .33378 .73676 .34392 .75347 .3418 .74604 .33164 Metetra
.572 .702 .93 r
.74604 .33164 .75347 .3418 .77031 .33966 .76294 .32949 Metetra
.571 .703 .931 r
.76294 .32949 .77031 .33966 .78728 .3375 .77998 .32732 Metetra
.571 .704 .932 r
.77998 .32732 .78728 .3375 .80439 .33533 .79716 .32513 Metetra
.571 .705 .932 r
.79716 .32513 .80439 .33533 .82164 .33314 .81447 .32293 Metetra
.646 .74 .917 r
.81447 .32293 .82164 .33314 .83875 .32819 .83166 .31794 Metetra
.704 .763 .898 r
.83166 .31794 .83875 .32819 .8557 .32068 .84868 .31036 Metetra
.704 .763 .898 r
.84868 .31036 .8557 .32068 .87273 .31314 .86579 .30275 Metetra
.676 .788 .933 r
.23611 .65799 .24599 .6652 .2607 .65981 .25087 .65252 Metetra
.717 .793 .911 r
.25087 .65252 .2607 .65981 .2756 .65282 .26584 .64539 Metetra
.743 .793 .893 r
.26584 .64539 .2756 .65282 .29065 .64447 .28096 .63686 Metetra
.761 .792 .878 r
.28096 .63686 .29065 .64447 .30581 .63499 .29621 .62719 Metetra
.775 .79 .865 r
.29621 .62719 .30581 .63499 .32108 .62447 .31155 .6165 Metetra
.784 .787 .855 r
.31155 .6165 .32108 .62447 .33643 .61314 .32698 .60502 Metetra
.791 .786 .848 r
.32698 .60502 .33643 .61314 .35183 .60118 .34246 .59292 Metetra
.797 .784 .841 r
.34246 .59292 .35183 .60118 .36728 .58861 .35799 .58023 Metetra
.797 .784 .841 r
.35799 .58023 .36728 .58861 .38275 .57601 .37353 .56751 Metetra
.792 .782 .844 r
.37353 .56751 .38275 .57601 .39821 .56378 .38908 .55518 Metetra
.792 .782 .844 r
.38908 .55518 .39821 .56378 .4137 .55154 .40464 .54284 Metetra
.751 .777 .874 r
.40464 .54284 .4137 .55154 .42912 .54218 .42013 .53341 Metetra
.749 .777 .875 r
.42013 .53341 .42912 .54218 .44458 .53291 .43566 .52407 Metetra
.74 .775 .881 r
.43566 .52407 .44458 .53291 .46008 .52417 .45122 .51526 Metetra
.722 .771 .891 r
.45122 .51526 .46008 .52417 .47562 .51636 .46683 .5074 Metetra
.722 .771 .891 r
.46683 .5074 .47562 .51636 .49121 .50852 .48249 .4995 Metetra
.726 .772 .89 r
.48249 .4995 .49121 .50852 .50687 .50045 .49821 .49138 Metetra
.738 .775 .883 r
.49821 .49138 .50687 .50045 .52259 .4917 .514 .48256 Metetra
.738 .775 .883 r
.514 .48256 .52259 .4917 .53836 .48291 .52984 .47372 Metetra
.738 .775 .883 r
.52984 .47372 .53836 .48291 .55419 .4741 .54574 .46484 Metetra
.749 .777 .876 r
.54574 .46484 .55419 .4741 .57006 .4646 .56169 .45528 Metetra
.762 .78 .868 r
.56169 .45528 .57006 .4646 .58597 .45425 .57767 .44486 Metetra
.762 .78 .868 r
.57767 .44486 .58597 .45425 .60191 .44388 .59369 .43442 Metetra
.762 .78 .868 r
.59369 .43442 .60191 .44388 .6179 .43348 .60975 .42395 Metetra
.762 .78 .868 r
.60975 .42395 .6179 .43348 .63393 .42305 .62585 .41345 Metetra
.829 .79 .815 r
.62585 .41345 .63393 .42305 .64978 .40708 .64179 .39737 Metetra
.833 .79 .811 r
.64179 .39737 .64978 .40708 .6656 .39067 .6577 .38085 Metetra
.833 .79 .81 r
.6577 .38085 .6656 .39067 .68141 .37428 .67359 .36434 Metetra
.833 .789 .81 r
.67359 .36434 .68141 .37428 .69719 .35791 .68947 .34785 Metetra
.833 .788 .81 r
.68947 .34785 .69719 .35791 .71296 .34155 .70532 .33139 Metetra
.713 .759 .889 r
.70532 .33139 .71296 .34155 .72926 .33378 .7217 .32356 Metetra
.571 .702 .93 r
.7217 .32356 .72926 .33378 .74604 .33164 .73853 .3214 Metetra
.571 .702 .931 r
.73853 .3214 .74604 .33164 .76294 .32949 .7555 .31923 Metetra
.57 .703 .931 r
.7555 .31923 .76294 .32949 .77998 .32732 .7726 .31704 Metetra
.57 .704 .932 r
.7726 .31704 .77998 .32732 .79716 .32513 .78985 .31483 Metetra
.57 .704 .933 r
.78985 .31483 .79716 .32513 .81447 .32293 .80723 .31261 Metetra
.646 .74 .917 r
.80723 .31261 .81447 .32293 .83166 .31794 .82449 .30757 Metetra
.704 .763 .898 r
.82449 .30757 .83166 .31794 .84868 .31036 .84159 .29993 Metetra
.704 .763 .898 r
.84159 .29993 .84868 .31036 .86579 .30275 .85878 .29226 Metetra
.677 .788 .933 r
.22611 .6507 .23611 .65799 .25087 .65252 .24094 .64516 Metetra
.719 .793 .91 r
.24094 .64516 .25087 .65252 .26584 .64539 .25597 .63788 Metetra
.746 .794 .891 r
.25597 .63788 .26584 .64539 .28096 .63686 .27117 .62917 Metetra
.763 .792 .876 r
.27117 .62917 .28096 .63686 .29621 .62719 .28649 .61931 Metetra
.777 .79 .864 r
.28649 .61931 .29621 .62719 .31155 .6165 .30192 .60844 Metetra
.785 .787 .854 r
.30192 .60844 .31155 .6165 .32698 .60502 .31743 .59681 Metetra
.792 .786 .847 r
.31743 .59681 .32698 .60502 .34246 .59292 .33299 .58457 Metetra
.797 .784 .841 r
.33299 .58457 .34246 .59292 .35799 .58023 .3486 .57177 Metetra
.797 .784 .84 r
.3486 .57177 .35799 .58023 .37353 .56751 .36422 .55893 Metetra
.792 .783 .844 r
.36422 .55893 .37353 .56751 .38908 .55518 .37985 .54649 Metetra
.792 .782 .843 r
.37985 .54649 .38908 .55518 .40464 .54284 .39549 .53404 Metetra
.752 .777 .874 r
.39549 .53404 .40464 .54284 .42013 .53341 .41104 .52454 Metetra
.75 .777 .875 r
.41104 .52454 .42013 .53341 .43566 .52407 .42664 .51513 Metetra
.74 .775 .881 r
.42664 .51513 .43566 .52407 .45122 .51526 .44228 .50626 Metetra
.722 .771 .891 r
.44228 .50626 .45122 .51526 .46683 .5074 .45794 .49834 Metetra
.722 .771 .892 r
.45794 .49834 .46683 .5074 .48249 .4995 .47367 .49039 Metetra
.726 .772 .89 r
.47367 .49039 .48249 .4995 .49821 .49138 .48946 .48221 Metetra
.738 .775 .883 r
.48946 .48221 .49821 .49138 .514 .48256 .50532 .47333 Metetra
.738 .775 .883 r
.50532 .47333 .514 .48256 .52984 .47372 .52123 .46443 Metetra
.738 .775 .883 r
.52123 .46443 .52984 .47372 .54574 .46484 .5372 .45549 Metetra
.749 .777 .876 r
.5372 .45549 .54574 .46484 .56169 .45528 .55322 .44585 Metetra
.762 .78 .868 r
.55322 .44585 .56169 .45528 .57767 .44486 .56927 .43537 Metetra
.762 .78 .868 r
.56927 .43537 .57767 .44486 .59369 .43442 .58537 .42486 Metetra
.762 .78 .868 r
.58537 .42486 .59369 .43442 .60975 .42395 .60151 .41432 Metetra
.762 .78 .868 r
.60151 .41432 .60975 .42395 .62585 .41345 .61769 .40375 Metetra
.83 .79 .815 r
.61769 .40375 .62585 .41345 .64179 .39737 .63372 .38756 Metetra
.834 .79 .81 r
.63372 .38756 .64179 .39737 .6577 .38085 .64972 .37092 Metetra
.833 .79 .81 r
.64972 .37092 .6577 .38085 .67359 .36434 .6657 .3543 Metetra
.833 .789 .81 r
.6657 .3543 .67359 .36434 .68947 .34785 .68166 .3377 Metetra
.833 .788 .809 r
.68166 .3377 .68947 .34785 .70532 .33139 .6976 .32111 Metetra
.713 .759 .889 r
.6976 .32111 .70532 .33139 .7217 .32356 .71405 .31323 Metetra
.57 .701 .93 r
.71405 .31323 .7217 .32356 .73853 .3214 .73094 .31105 Metetra
.57 .702 .931 r
.73094 .31105 .73853 .3214 .7555 .31923 .74797 .30886 Metetra
.569 .702 .932 r
.74797 .30886 .7555 .31923 .7726 .31704 .76514 .30665 Metetra
.569 .703 .932 r
.76514 .30665 .7726 .31704 .78985 .31483 .78245 .30442 Metetra
.569 .704 .933 r
.78245 .30442 .78985 .31483 .80723 .31261 .7999 .30218 Metetra
.645 .739 .918 r
.7999 .30218 .80723 .31261 .82449 .30757 .81724 .29709 Metetra
.704 .763 .898 r
.81724 .29709 .82449 .30757 .84159 .29993 .83442 .28939 Metetra
.704 .763 .898 r
.83442 .28939 .84159 .29993 .85878 .29226 .85169 .28164 Metetra
.678 .788 .932 r
.21601 .64333 .22611 .6507 .24094 .64516 .2309 .63771 Metetra
.721 .793 .909 r
.2309 .63771 .24094 .64516 .25597 .63788 .246 .63029 Metetra
.748 .794 .89 r
.246 .63029 .25597 .63788 .27117 .62917 .26127 .62139 Metetra
.765 .792 .875 r
.26127 .62139 .27117 .62917 .28649 .61931 .27668 .61135 Metetra
.778 .79 .862 r
.27668 .61135 .28649 .61931 .30192 .60844 .29218 .6003 Metetra
.786 .787 .853 r
.29218 .6003 .30192 .60844 .31743 .59681 .30777 .58851 Metetra
.792 .786 .846 r
.30777 .58851 .31743 .59681 .33299 .58457 .32341 .57614 Metetra
.798 .784 .84 r
.32341 .57614 .33299 .58457 .3486 .57177 .33911 .56321 Metetra
.798 .784 .84 r
.33911 .56321 .3486 .57177 .36422 .55893 .35481 .55026 Metetra
.793 .783 .843 r
.35481 .55026 .36422 .55893 .37985 .54649 .37051 .53771 Metetra
.792 .782 .843 r
.37051 .53771 .37985 .54649 .39549 .53404 .38623 .52515 Metetra
.752 .777 .874 r
.38623 .52515 .39549 .53404 .41104 .52454 .40186 .51558 Metetra
.75 .777 .875 r
.40186 .51558 .41104 .52454 .42664 .51513 .41753 .5061 Metetra
.74 .775 .881 r
.41753 .5061 .42664 .51513 .44228 .50626 .43323 .49716 Metetra
.722 .771 .892 r
.43323 .49716 .44228 .50626 .45794 .49834 .44896 .48918 Metetra
.722 .771 .892 r
.44896 .48918 .45794 .49834 .47367 .49039 .46476 .48118 Metetra
.726 .772 .89 r
.46476 .48118 .47367 .49039 .48946 .48221 .48062 .47294 Metetra
.738 .775 .883 r
.48062 .47294 .48946 .48221 .50532 .47333 .49655 .464 Metetra
.738 .775 .883 r
.49655 .464 .50532 .47333 .52123 .46443 .51253 .45503 Metetra
.738 .775 .883 r
.51253 .45503 .52123 .46443 .5372 .45549 .52857 .44603 Metetra
.749 .777 .876 r
.52857 .44603 .5372 .45549 .55322 .44585 .54466 .43633 Metetra
.762 .78 .868 r
.54466 .43633 .55322 .44585 .56927 .43537 .56079 .42577 Metetra
.762 .78 .868 r
.56079 .42577 .56927 .43537 .58537 .42486 .57696 .41519 Metetra
.762 .78 .868 r
.57696 .41519 .58537 .42486 .60151 .41432 .59318 .40458 Metetra
.762 .78 .868 r
.59318 .40458 .60151 .41432 .61769 .40375 .60943 .39394 Metetra
.83 .79 .814 r
.60943 .39394 .61769 .40375 .63372 .38756 .62556 .37763 Metetra
.834 .79 .81 r
.62556 .37763 .63372 .38756 .64972 .37092 .64164 .36088 Metetra
.834 .79 .81 r
.64164 .36088 .64972 .37092 .6657 .3543 .65771 .34414 Metetra
.833 .789 .809 r
.65771 .34414 .6657 .3543 .68166 .3377 .67376 .32743 Metetra
.833 .788 .809 r
.67376 .32743 .68166 .3377 .6976 .32111 .6898 .31073 Metetra
.712 .759 .889 r
.6898 .31073 .6976 .32111 .71405 .31323 .70631 .30279 Metetra
.569 .701 .93 r
.70631 .30279 .71405 .31323 .73094 .31105 .72327 .30059 Metetra
.569 .701 .931 r
.72327 .30059 .73094 .31105 .74797 .30886 .74037 .29838 Metetra
.568 .702 .932 r
.74037 .29838 .74797 .30886 .76514 .30665 .7576 .29615 Metetra
.568 .703 .932 r
.7576 .29615 .76514 .30665 .78245 .30442 .77498 .2939 Metetra
.568 .703 .933 r
.77498 .2939 .78245 .30442 .7999 .30218 .7925 .29163 Metetra
.645 .739 .918 r
.7925 .29163 .7999 .30218 .81724 .29709 .8099 .2865 Metetra
.704 .763 .898 r
.8099 .2865 .81724 .29709 .83442 .28939 .82717 .27872 Metetra
.704 .763 .898 r
.82717 .27872 .83442 .28939 .85169 .28164 .84451 .27091 Metetra
.679 .788 .932 r
.2058 .63588 .21601 .64333 .2309 .63771 .22074 .63018 Metetra
.722 .794 .908 r
.22074 .63018 .2309 .63771 .246 .63029 .23591 .62261 Metetra
.75 .794 .888 r
.23591 .62261 .246 .63029 .26127 .62139 .25127 .61353 Metetra
.767 .792 .873 r
.25127 .61353 .26127 .62139 .27668 .61135 .26675 .6033 Metetra
.779 .79 .861 r
.26675 .6033 .27668 .61135 .29218 .6003 .28234 .59207 Metetra
.787 .787 .852 r
.28234 .59207 .29218 .6003 .30777 .58851 .29801 .58012 Metetra
.793 .786 .846 r
.29801 .58012 .30777 .58851 .32341 .57614 .31374 .56761 Metetra
.798 .784 .84 r
.31374 .56761 .32341 .57614 .33911 .56321 .32951 .55456 Metetra
.798 .784 .839 r
.32951 .55456 .33911 .56321 .35481 .55026 .3453 .54149 Metetra
.793 .783 .843 r
.3453 .54149 .35481 .55026 .37051 .53771 .36108 .52883 Metetra
.793 .782 .843 r
.36108 .52883 .37051 .53771 .38623 .52515 .37688 .51617 Metetra
.752 .777 .874 r
.37688 .51617 .38623 .52515 .40186 .51558 .39258 .50652 Metetra
.75 .777 .875 r
.39258 .50652 .40186 .51558 .41753 .5061 .40832 .49697 Metetra
.74 .775 .881 r
.40832 .49697 .41753 .5061 .43323 .49716 .42409 .48796 Metetra
.722 .771 .892 r
.42409 .48796 .43323 .49716 .44896 .48918 .43989 .47993 Metetra
.722 .771 .892 r
.43989 .47993 .44896 .48918 .46476 .48118 .45575 .47187 Metetra
.726 .772 .89 r
.45575 .47187 .46476 .48118 .48062 .47294 .47168 .46357 Metetra
.738 .775 .883 r
.47168 .46357 .48062 .47294 .49655 .464 .48768 .45457 Metetra
.738 .775 .883 r
.48768 .45457 .49655 .464 .51253 .45503 .50373 .44553 Metetra
.738 .775 .883 r
.50373 .44553 .51253 .45503 .52857 .44603 .51984 .43647 Metetra
.749 .777 .876 r
.51984 .43647 .52857 .44603 .54466 .43633 .53601 .4267 Metetra
.762 .78 .868 r
.53601 .4267 .54466 .43633 .56079 .42577 .55221 .41607 Metetra
.762 .78 .868 r
.55221 .41607 .56079 .42577 .57696 .41519 .56846 .40542 Metetra
.762 .78 .868 r
.56846 .40542 .57696 .41519 .59318 .40458 .58476 .39474 Metetra
.762 .78 .868 r
.58476 .39474 .59318 .40458 .60943 .39394 .60109 .38403 Metetra
.83 .79 .814 r
.60109 .38403 .60943 .39394 .62556 .37763 .6173 .3676 Metetra
.834 .79 .81 r
.6173 .3676 .62556 .37763 .64164 .36088 .63348 .35073 Metetra
.834 .79 .809 r
.63348 .35073 .64164 .36088 .65771 .34414 .64965 .33388 Metetra
.834 .789 .809 r
.64965 .33388 .65771 .34414 .67376 .32743 .66579 .31705 Metetra
.833 .788 .809 r
.66579 .31705 .67376 .32743 .6898 .31073 .68191 .30024 Metetra
.712 .759 .889 r
.68191 .30024 .6898 .31073 .70631 .30279 .6985 .29223 Metetra
.568 .7 .931 r
.6985 .29223 .70631 .30279 .72327 .30059 .71552 .29002 Metetra
.568 .701 .931 r
.71552 .29002 .72327 .30059 .74037 .29838 .73268 .28778 Metetra
.567 .701 .932 r
.73268 .28778 .74037 .29838 .7576 .29615 .74998 .28552 Metetra
.567 .702 .932 r
.74998 .28552 .7576 .29615 .77498 .2939 .76742 .28325 Metetra
.567 .703 .933 r
.76742 .28325 .77498 .2939 .7925 .29163 .78501 .28096 Metetra
.645 .739 .918 r
.78501 .28096 .7925 .29163 .8099 .2865 .80249 .27578 Metetra
.704 .763 .898 r
.80249 .27578 .8099 .2865 .82717 .27872 .81983 .26794 Metetra
.704 .763 .898 r
.81983 .26794 .82717 .27872 .84451 .27091 .83726 .26005 Metetra
.68 .788 .931 r
.19547 .62835 .2058 .63588 .22074 .63018 .21047 .62257 Metetra
.724 .794 .907 r
.21047 .62257 .22074 .63018 .23591 .62261 .22572 .61485 Metetra
.752 .794 .887 r
.22572 .61485 .23591 .62261 .25127 .61353 .24115 .60559 Metetra
.769 .792 .872 r
.24115 .60559 .25127 .61353 .26675 .6033 .25672 .59515 Metetra
.781 .79 .86 r
.25672 .59515 .26675 .6033 .28234 .59207 .27239 .58375 Metetra
.789 .787 .851 r
.27239 .58375 .28234 .59207 .29801 .58012 .28815 .57164 Metetra
.794 .786 .845 r
.28815 .57164 .29801 .58012 .31374 .56761 .30396 .55899 Metetra
.799 .784 .839 r
.30396 .55899 .31374 .56761 .32951 .55456 .31981 .54582 Metetra
.799 .784 .839 r
.31981 .54582 .32951 .55456 .3453 .54149 .33569 .53263 Metetra
.794 .783 .843 r
.33569 .53263 .3453 .54149 .36108 .52883 .35155 .51986 Metetra
.793 .782 .842 r
.35155 .51986 .36108 .52883 .37688 .51617 .36743 .50708 Metetra
.752 .777 .874 r
.36743 .50708 .37688 .51617 .39258 .50652 .3832 .49736 Metetra
.75 .777 .875 r
.3832 .49736 .39258 .50652 .40832 .49697 .39901 .48774 Metetra
.74 .775 .881 r
.39901 .48774 .40832 .49697 .42409 .48796 .41485 .47866 Metetra
.722 .771 .892 r
.41485 .47866 .42409 .48796 .43989 .47993 .43072 .47058 Metetra
.722 .771 .892 r
.43072 .47058 .43989 .47993 .45575 .47187 .44664 .46246 Metetra
.726 .772 .89 r
.44664 .46246 .45575 .47187 .47168 .46357 .46264 .45411 Metetra
.738 .775 .883 r
.46264 .45411 .47168 .46357 .48768 .45457 .47871 .44504 Metetra
.738 .775 .883 r
.47871 .44504 .48768 .45457 .50373 .44553 .49484 .43593 Metetra
.738 .775 .883 r
.49484 .43593 .50373 .44553 .51984 .43647 .51102 .4268 Metetra
.749 .777 .876 r
.51102 .4268 .51984 .43647 .53601 .4267 .52726 .41697 Metetra
.762 .78 .868 r
.52726 .41697 .53601 .4267 .55221 .41607 .54354 .40627 Metetra
.762 .78 .868 r
.54354 .40627 .55221 .41607 .56846 .40542 .55987 .39554 Metetra
.762 .78 .868 r
.55987 .39554 .56846 .40542 .58476 .39474 .57624 .38478 Metetra
.762 .78 .868 r
.57624 .38478 .58476 .39474 .60109 .38403 .59266 .374 Metetra
.83 .79 .814 r
.59266 .374 .60109 .38403 .6173 .3676 .60896 .35746 Metetra
.835 .79 .809 r
.60896 .35746 .6173 .3676 .63348 .35073 .62523 .34047 Metetra
.834 .79 .809 r
.62523 .34047 .63348 .35073 .64965 .33388 .64149 .3235 Metetra
.834 .789 .809 r
.64149 .3235 .64965 .33388 .66579 .31705 .65772 .30655 Metetra
.834 .788 .809 r
.65772 .30655 .66579 .31705 .68191 .30024 .67393 .28963 Metetra
.712 .759 .889 r
.67393 .28963 .68191 .30024 .6985 .29223 .6906 .28157 Metetra
.567 .7 .931 r
.6906 .28157 .6985 .29223 .71552 .29002 .70768 .27932 Metetra
.566 .7 .931 r
.70768 .27932 .71552 .29002 .73268 .28778 .7249 .27706 Metetra
.566 .701 .932 r
.7249 .27706 .73268 .28778 .74998 .28552 .74227 .27479 Metetra
.566 .702 .933 r
.74227 .27479 .74998 .28552 .76742 .28325 .75978 .27249 Metetra
.566 .702 .933 r
.75978 .27249 .76742 .28325 .78501 .28096 .77744 .27017 Metetra
.644 .739 .918 r
.77744 .27017 .78501 .28096 .80249 .27578 .795 .26495 Metetra
.704 .763 .898 r
.795 .26495 .80249 .27578 .81983 .26794 .81242 .25703 Metetra
.704 .763 .898 r
.81242 .25703 .81983 .26794 .83726 .26005 .82992 .24907 Metetra
.681 .789 .931 r
.18503 .62077 .19547 .62835 .21047 .62257 .20009 .61489 Metetra
.726 .794 .906 r
.20009 .61489 .21047 .62257 .22572 .61485 .21541 .60702 Metetra
.754 .794 .885 r
.21541 .60702 .22572 .61485 .24115 .60559 .23092 .59755 Metetra
.771 .792 .871 r
.23092 .59755 .24115 .60559 .25672 .59515 .24657 .58692 Metetra
.782 .79 .859 r
.24657 .58692 .25672 .59515 .27239 .58375 .26233 .57534 Metetra
.79 .787 .851 r
.26233 .57534 .27239 .58375 .28815 .57164 .27817 .56307 Metetra
.795 .786 .844 r
.27817 .56307 .28815 .57164 .30396 .55899 .29407 .55028 Metetra
.8 .784 .839 r
.29407 .55028 .30396 .55899 .31981 .54582 .31001 .53699 Metetra
.799 .784 .838 r
.31001 .53699 .31981 .54582 .33569 .53263 .32597 .52367 Metetra
.794 .783 .842 r
.32597 .52367 .33569 .53263 .35155 .51986 .34192 .51079 Metetra
.794 .782 .842 r
.34192 .51079 .35155 .51986 .36743 .50708 .35788 .4979 Metetra
.752 .777 .873 r
.35788 .4979 .36743 .50708 .3832 .49736 .37372 .4881 Metetra
.75 .777 .875 r
.37372 .4881 .3832 .49736 .39901 .48774 .3896 .4784 Metetra
.74 .775 .881 r
.3896 .4784 .39901 .48774 .41485 .47866 .40551 .46926 Metetra
.722 .771 .892 r
.40551 .46926 .41485 .47866 .43072 .47058 .42144 .46111 Metetra
.722 .771 .892 r
.42144 .46111 .43072 .47058 .44664 .46246 .43744 .45294 Metetra
.726 .772 .89 r
.43744 .45294 .44664 .46246 .46264 .45411 .45351 .44452 Metetra
.738 .775 .883 r
.45351 .44452 .46264 .45411 .47871 .44504 .46965 .43539 Metetra
.738 .775 .883 r
.46965 .43539 .47871 .44504 .49484 .43593 .48584 .42622 Metetra
.738 .775 .883 r
.48584 .42622 .49484 .43593 .51102 .4268 .5021 .41702 Metetra
.749 .777 .876 r
.5021 .41702 .51102 .4268 .52726 .41697 .51841 .40712 Metetra
.762 .78 .867 r
.51841 .40712 .52726 .41697 .54354 .40627 .53478 .39634 Metetra
.762 .78 .867 r
.53478 .39634 .54354 .40627 .55987 .39554 .55118 .38554 Metetra
.762 .78 .867 r
.55118 .38554 .55987 .39554 .57624 .38478 .56763 .37471 Metetra
.762 .78 .867 r
.56763 .37471 .57624 .38478 .59266 .374 .58413 .36386 Metetra
.831 .79 .814 r
.58413 .36386 .59266 .374 .60896 .35746 .60053 .34721 Metetra
.835 .79 .809 r
.60053 .34721 .60896 .35746 .62523 .34047 .61689 .3301 Metetra
.835 .79 .809 r
.61689 .3301 .62523 .34047 .64149 .3235 .63324 .31302 Metetra
.834 .789 .809 r
.63324 .31302 .64149 .3235 .65772 .30655 .64957 .29596 Metetra
.834 .789 .809 r
.64957 .29596 .65772 .30655 .67393 .28963 .66587 .27892 Metetra
.712 .759 .889 r
.66587 .27892 .67393 .28963 .6906 .28157 .68261 .2708 Metetra
.566 .7 .931 r
.68261 .2708 .6906 .28157 .70768 .27932 .69975 .26853 Metetra
.566 .7 .932 r
.69975 .26853 .70768 .27932 .7249 .27706 .71704 .26624 Metetra
.565 .701 .932 r
.71704 .26624 .7249 .27706 .74227 .27479 .73448 .26393 Metetra
.565 .701 .933 r
.73448 .26393 .74227 .27479 .75978 .27249 .75206 .2616 Metetra
.565 .702 .933 r
.75206 .2616 .75978 .27249 .77744 .27017 .76978 .25926 Metetra
.644 .739 .918 r
.76978 .25926 .77744 .27017 .795 .26495 .78741 .25398 Metetra
.704 .763 .898 r
.78741 .25398 .795 .26495 .81242 .25703 .80492 .24599 Metetra
.704 .763 .898 r
.80492 .24599 .81242 .25703 .82992 .24907 .8225 .23796 Metetra
.682 .79 .931 r
.17446 .61313 .18503 .62077 .20009 .61489 .18959 .60716 Metetra
.729 .795 .905 r
.18959 .60716 .20009 .61489 .21541 .60702 .20498 .59911 Metetra
.757 .795 .884 r
.20498 .59911 .21541 .60702 .23092 .59755 .22058 .58944 Metetra
.773 .792 .869 r
.22058 .58944 .23092 .59755 .24657 .58692 .23632 .5786 Metetra
.784 .79 .858 r
.23632 .5786 .24657 .58692 .26233 .57534 .25216 .56684 Metetra
.791 .787 .85 r
.25216 .56684 .26233 .57534 .27817 .56307 .26809 .55441 Metetra
.795 .786 .844 r
.26809 .55441 .27817 .56307 .29407 .55028 .28407 .54148 Metetra
.8 .784 .838 r
.28407 .54148 .29407 .55028 .31001 .53699 .3001 .52805 Metetra
.8 .783 .838 r
.3001 .52805 .31001 .53699 .32597 .52367 .31615 .51461 Metetra
.794 .783 .842 r
.31615 .51461 .32597 .52367 .34192 .51079 .33218 .50162 Metetra
.794 .782 .841 r
.33218 .50162 .34192 .51079 .35788 .4979 .34822 .48861 Metetra
.752 .777 .873 r
.34822 .48861 .35788 .4979 .37372 .4881 .36414 .47873 Metetra
.75 .776 .874 r
.36414 .47873 .37372 .4881 .3896 .4784 .38009 .46895 Metetra
.74 .774 .881 r
.38009 .46895 .3896 .4784 .40551 .46926 .39607 .45974 Metetra
.722 .771 .891 r
.39607 .45974 .40551 .46926 .42144 .46111 .41207 .45153 Metetra
.722 .771 .891 r
.41207 .45153 .42144 .46111 .43744 .45294 .42813 .4433 Metetra
.726 .772 .889 r
.42813 .4433 .43744 .45294 .45351 .44452 .44427 .43482 Metetra
.738 .775 .882 r
.44427 .43482 .45351 .44452 .46965 .43539 .46048 .42562 Metetra
.738 .775 .882 r
.46048 .42562 .46965 .43539 .48584 .42622 .47675 .41639 Metetra
.738 .775 .882 r
.47675 .41639 .48584 .42622 .5021 .41702 .49308 .40712 Metetra
.749 .777 .876 r
.49308 .40712 .5021 .41702 .51841 .40712 .50947 .39715 Metetra
.762 .78 .867 r
.50947 .39715 .51841 .40712 .53478 .39634 .52592 .3863 Metetra
.762 .78 .867 r
.52592 .3863 .53478 .39634 .55118 .38554 .5424 .37542 Metetra
.762 .78 .867 r
.5424 .37542 .55118 .38554 .56763 .37471 .55893 .36452 Metetra
.762 .78 .867 r
.55893 .36452 .56763 .37471 .58413 .36386 .5755 .35359 Metetra
.831 .79 .813 r
.5755 .35359 .58413 .36386 .60053 .34721 .592 .33684 Metetra
.835 .79 .809 r
.592 .33684 .60053 .34721 .61689 .3301 .60846 .31962 Metetra
.835 .79 .809 r
.60846 .31962 .61689 .3301 .63324 .31302 .6249 .30243 Metetra
.835 .789 .809 r
.6249 .30243 .63324 .31302 .64957 .29596 .64132 .28527 Metetra
.834 .789 .809 r
.64132 .28527 .64957 .29596 .66587 .27892 .65772 .26812 Metetra
.712 .759 .89 r
.65772 .26812 .66587 .27892 .68261 .2708 .67454 .25993 Metetra
.565 .7 .932 r
.67454 .25993 .68261 .2708 .69975 .26853 .69174 .25763 Metetra
.565 .7 .932 r
.69174 .25763 .69975 .26853 .71704 .26624 .7091 .2553 Metetra
.565 .701 .933 r
.7091 .2553 .71704 .26624 .73448 .26393 .72659 .25296 Metetra
.564 .701 .933 r
.72659 .25296 .73448 .26393 .75206 .2616 .74424 .25059 Metetra
.564 .702 .933 r
.74424 .25059 .75206 .2616 .76978 .25926 .76204 .24821 Metetra
.644 .738 .918 r
.76204 .24821 .76978 .25926 .78741 .25398 .77974 .24288 Metetra
.704 .763 .898 r
.77974 .24288 .78741 .25398 .80492 .24599 .79733 .23481 Metetra
.704 .763 .898 r
.79733 .23481 .80492 .24599 .8225 .23796 .815 .22671 Metetra
.683 .79 .931 r
.16377 .60541 .17446 .61313 .18959 .60716 .17896 .59934 Metetra
.731 .796 .903 r
.17896 .59934 .18959 .60716 .20498 .59911 .19444 .59112 Metetra
.759 .795 .882 r
.19444 .59112 .20498 .59911 .22058 .58944 .21012 .58123 Metetra
.774 .792 .868 r
.21012 .58123 .22058 .58944 .23632 .5786 .22595 .57019 Metetra
.785 .79 .856 r
.22595 .57019 .23632 .5786 .25216 .56684 .24188 .55824 Metetra
.792 .787 .849 r
.24188 .55824 .25216 .56684 .26809 .55441 .25789 .54565 Metetra
.796 .786 .843 r
.25789 .54565 .26809 .55441 .28407 .54148 .27396 .53257 Metetra
.801 .784 .838 r
.27396 .53257 .28407 .54148 .3001 .52805 .29008 .51902 Metetra
.8 .783 .837 r
.29008 .51902 .3001 .52805 .31615 .51461 .30621 .50545 Metetra
.795 .783 .841 r
.30621 .50545 .31615 .51461 .33218 .50162 .32233 .49234 Metetra
.795 .782 .841 r
.32233 .49234 .33218 .50162 .34822 .48861 .33846 .47921 Metetra
.752 .777 .873 r
.33846 .47921 .34822 .48861 .36414 .47873 .35445 .46925 Metetra
.75 .776 .874 r
.35445 .46925 .36414 .47873 .38009 .46895 .37048 .4594 Metetra
.74 .775 .88 r
.37048 .4594 .38009 .46895 .39607 .45974 .38653 .45011 Metetra
.722 .771 .891 r
.38653 .45011 .39607 .45974 .41207 .45153 .40259 .44185 Metetra
.722 .771 .892 r
.40259 .44185 .41207 .45153 .42813 .4433 .41873 .43355 Metetra
.725 .772 .889 r
.41873 .43355 .42813 .4433 .44427 .43482 .43493 .42502 Metetra
.738 .775 .882 r
.43493 .42502 .44427 .43482 .46048 .42562 .45122 .41575 Metetra
.738 .775 .882 r
.45122 .41575 .46048 .42562 .47675 .41639 .46756 .40645 Metetra
.738 .775 .882 r
.46756 .40645 .47675 .41639 .49308 .40712 .48397 .39711 Metetra
.749 .777 .876 r
.48397 .39711 .49308 .40712 .50947 .39715 .50043 .38706 Metetra
.762 .78 .867 r
.50043 .38706 .50947 .39715 .52592 .3863 .51695 .37614 Metetra
.762 .78 .867 r
.51695 .37614 .52592 .3863 .5424 .37542 .53352 .36519 Metetra
.762 .78 .867 r
.53352 .36519 .5424 .37542 .55893 .36452 .55013 .35421 Metetra
.762 .78 .867 r
.55013 .35421 .55893 .36452 .5755 .35359 .56678 .3432 Metetra
.831 .79 .813 r
.56678 .3432 .5755 .35359 .592 .33684 .58337 .32635 Metetra
.835 .79 .809 r
.58337 .32635 .592 .33684 .60846 .31962 .59993 .30903 Metetra
.835 .79 .809 r
.59993 .30903 .60846 .31962 .6249 .30243 .61647 .29173 Metetra
.835 .789 .809 r
.61647 .29173 .6249 .30243 .64132 .28527 .63299 .27445 Metetra
.835 .789 .808 r
.63299 .27445 .64132 .28527 .65772 .26812 .64949 .2572 Metetra
.712 .759 .89 r
.64949 .2572 .65772 .26812 .67454 .25993 .66637 .24895 Metetra
.564 .7 .932 r
.66637 .24895 .67454 .25993 .69174 .25763 .68364 .24661 Metetra
.564 .7 .932 r
.68364 .24661 .69174 .25763 .7091 .2553 .70106 .24425 Metetra
.564 .7 .933 r
.70106 .24425 .7091 .2553 .72659 .25296 .71862 .24186 Metetra
.564 .701 .933 r
.71862 .24186 .72659 .25296 .74424 .25059 .73634 .23946 Metetra
.564 .701 .933 r
.73634 .23946 .74424 .25059 .76204 .24821 .7542 .23704 Metetra
.643 .738 .918 r
.7542 .23704 .76204 .24821 .77974 .24288 .77199 .23164 Metetra
.704 .763 .898 r
.77199 .23164 .77974 .24288 .79733 .23481 .78965 .22351 Metetra
.704 .763 .898 r
.78965 .22351 .79733 .23481 .815 .22671 .8074 .21533 Metetra
.684 .79 .93 r
.15296 .59761 .16377 .60541 .17896 .59934 .16822 .59143 Metetra
.733 .796 .902 r
.16822 .59143 .17896 .59934 .19444 .59112 .18377 .58303 Metetra
.761 .795 .88 r
.18377 .58303 .19444 .59112 .21012 .58123 .19954 .57293 Metetra
.776 .792 .866 r
.19954 .57293 .21012 .58123 .22595 .57019 .21546 .56168 Metetra
.786 .79 .855 r
.21546 .56168 .22595 .57019 .24188 .55824 .23148 .54954 Metetra
.792 .787 .848 r
.23148 .54954 .24188 .55824 .25789 .54565 .24759 .53679 Metetra
.797 .786 .842 r
.24759 .53679 .25789 .54565 .27396 .53257 .26375 .52357 Metetra
.801 .784 .837 r
.26375 .52357 .27396 .53257 .29008 .51902 .27995 .50989 Metetra
.801 .783 .837 r
.27995 .50989 .29008 .51902 .30621 .50545 .29617 .49619 Metetra
.795 .783 .841 r
.29617 .49619 .30621 .50545 .32233 .49234 .31238 .48296 Metetra
.795 .782 .841 r
.31238 .48296 .32233 .49234 .33846 .47921 .32859 .46972 Metetra
.753 .777 .873 r
.32859 .46972 .33846 .47921 .35445 .46925 .34465 .45968 Metetra
.751 .776 .874 r
.34465 .45968 .35445 .46925 .37048 .4594 .36075 .44974 Metetra
.741 .775 .88 r
.36075 .44974 .37048 .4594 .38653 .45011 .37688 .44038 Metetra
.722 .771 .892 r
.37688 .44038 .38653 .45011 .40259 .44185 .39301 .43206 Metetra
.722 .771 .892 r
.39301 .43206 .40259 .44185 .41873 .43355 .40921 .4237 Metetra
.725 .772 .89 r
.40921 .4237 .41873 .43355 .43493 .42502 .42549 .4151 Metetra
.738 .775 .882 r
.42549 .4151 .43493 .42502 .45122 .41575 .44185 .40576 Metetra
.738 .775 .882 r
.44185 .40576 .45122 .41575 .46756 .40645 .45827 .39639 Metetra
.738 .775 .882 r
.45827 .39639 .46756 .40645 .48397 .39711 .47475 .38699 Metetra
.749 .777 .876 r
.47475 .38699 .48397 .39711 .50043 .38706 .49129 .37687 Metetra
.762 .78 .867 r
.49129 .37687 .50043 .38706 .51695 .37614 .50789 .36587 Metetra
.762 .78 .867 r
.50789 .36587 .51695 .37614 .53352 .36519 .52454 .35485 Metetra
.762 .78 .867 r
.52454 .35485 .53352 .36519 .55013 .35421 .54123 .34379 Metetra
.762 .78 .867 r
.54123 .34379 .55013 .35421 .56678 .3432 .55797 .3327 Metetra
.831 .79 .813 r
.55797 .3327 .56678 .3432 .58337 .32635 .57465 .31574 Metetra
.835 .79 .809 r
.57465 .31574 .58337 .32635 .59993 .30903 .59131 .29831 Metetra
.835 .79 .809 r
.59131 .29831 .59993 .30903 .61647 .29173 .60795 .2809 Metetra
.835 .789 .808 r
.60795 .2809 .61647 .29173 .63299 .27445 .62456 .26352 Metetra
.835 .789 .808 r
.62456 .26352 .63299 .27445 .64949 .2572 .64116 .24616 Metetra
.712 .759 .89 r
.64116 .24616 .64949 .2572 .66637 .24895 .65812 .23785 Metetra
.564 .699 .932 r
.65812 .23785 .66637 .24895 .68364 .24661 .67545 .23547 Metetra
.563 .7 .932 r
.67545 .23547 .68364 .24661 .70106 .24425 .69293 .23306 Metetra
.563 .7 .933 r
.69293 .23306 .70106 .24425 .71862 .24186 .71056 .23064 Metetra
.563 .7 .933 r
.71056 .23064 .71862 .24186 .73634 .23946 .72834 .2282 Metetra
.563 .701 .933 r
.72834 .2282 .73634 .23946 .7542 .23704 .74628 .22573 Metetra
.643 .738 .918 r
.74628 .22573 .7542 .23704 .77199 .23164 .76414 .22028 Metetra
.704 .763 .898 r
.76414 .22028 .77199 .23164 .78965 .22351 .78189 .21207 Metetra
.704 .763 .898 r
.78189 .21207 .78965 .22351 .8074 .21533 .79972 .20382 Metetra
.686 .791 .93 r
.14203 .58971 .15296 .59761 .16822 .59143 .15735 .58343 Metetra
.735 .796 .901 r
.15735 .58343 .16822 .59143 .18377 .58303 .17298 .57485 Metetra
.763 .795 .879 r
.17298 .57485 .18377 .58303 .19954 .57293 .18884 .56454 Metetra
.778 .792 .864 r
.18884 .56454 .19954 .57293 .21546 .56168 .20485 .55307 Metetra
.788 .79 .854 r
.20485 .55307 .21546 .56168 .23148 .54954 .22097 .54075 Metetra
.793 .787 .847 r
.22097 .54075 .23148 .54954 .24759 .53679 .23716 .52784 Metetra
.798 .786 .842 r
.23716 .52784 .24759 .53679 .26375 .52357 .25341 .51447 Metetra
.802 .784 .837 r
.25341 .51447 .26375 .52357 .27995 .50989 .26971 .50065 Metetra
.801 .783 .836 r
.26971 .50065 .27995 .50989 .29617 .49619 .28602 .48683 Metetra
.796 .783 .841 r
.28602 .48683 .29617 .49619 .31238 .48296 .30231 .47348 Metetra
.796 .782 .84 r
.30231 .47348 .31238 .48296 .32859 .46972 .31862 .46012 Metetra
.753 .777 .873 r
.31862 .46012 .32859 .46972 .34465 .45968 .33475 .44999 Metetra
.751 .776 .874 r
.33475 .44999 .34465 .45968 .36075 .44974 .35092 .43998 Metetra
.741 .775 .88 r
.35092 .43998 .36075 .44974 .37688 .44038 .36712 .43054 Metetra
.721 .771 .892 r
.36712 .43054 .37688 .44038 .39301 .43206 .38332 .42216 Metetra
.721 .771 .892 r
.38332 .42216 .39301 .43206 .40921 .4237 .3996 .41374 Metetra
.725 .772 .89 r
.3996 .41374 .40921 .4237 .42549 .4151 .41594 .40507 Metetra
.738 .775 .882 r
.41594 .40507 .42549 .4151 .44185 .40576 .43238 .39567 Metetra
.738 .775 .882 r
.43238 .39567 .44185 .40576 .45827 .39639 .44887 .38623 Metetra
.738 .775 .882 r
.44887 .38623 .45827 .39639 .47475 .38699 .46542 .37675 Metetra
.749 .777 .876 r
.46542 .37675 .47475 .38699 .49129 .37687 .48205 .36656 Metetra
.762 .78 .867 r
.48205 .36656 .49129 .37687 .50789 .36587 .49873 .35549 Metetra
.762 .78 .867 r
.49873 .35549 .50789 .36587 .52454 .35485 .51546 .34438 Metetra
.762 .78 .867 r
.51546 .34438 .52454 .35485 .54123 .34379 .53223 .33325 Metetra
.762 .78 .867 r
.53223 .33325 .54123 .34379 .55797 .3327 .54905 .32209 Metetra
.831 .79 .813 r
.54905 .32209 .55797 .3327 .57465 .31574 .56583 .30501 Metetra
.835 .79 .808 r
.56583 .30501 .57465 .31574 .59131 .29831 .58259 .28747 Metetra
.835 .79 .808 r
.58259 .28747 .59131 .29831 .60795 .2809 .59933 .26996 Metetra
.835 .789 .808 r
.59933 .26996 .60795 .2809 .62456 .26352 .61604 .25247 Metetra
.835 .789 .808 r
.61604 .25247 .62456 .26352 .64116 .24616 .63273 .235 Metetra
.712 .759 .89 r
.63273 .235 .64116 .24616 .65812 .23785 .64977 .22662 Metetra
.563 .699 .932 r
.64977 .22662 .65812 .23785 .67545 .23547 .66717 .2242 Metetra
.563 .699 .932 r
.66717 .2242 .67545 .23547 .69293 .23306 .68471 .22175 Metetra
.563 .7 .933 r
.68471 .22175 .69293 .23306 .71056 .23064 .70241 .21929 Metetra
.562 .7 .933 r
.70241 .21929 .71056 .23064 .72834 .2282 .72026 .21681 Metetra
.562 .701 .934 r
.72026 .21681 .72834 .2282 .74628 .22573 .73827 .2143 Metetra
.643 .738 .918 r
.73827 .2143 .74628 .22573 .76414 .22028 .7562 .20879 Metetra
.704 .763 .898 r
.7562 .20879 .76414 .22028 .78189 .21207 .77403 .2005 Metetra
.704 .763 .898 r
.77403 .2005 .78189 .21207 .79972 .20382 .79195 .19217 Metetra
.687 .791 .929 r
.13097 .58172 .14203 .58971 .15735 .58343 .14636 .57534 Metetra
.738 .796 .899 r
.14636 .57534 .15735 .58343 .17298 .57485 .16207 .56658 Metetra
.765 .795 .877 r
.16207 .56658 .17298 .57485 .18884 .56454 .17802 .55604 Metetra
.78 .792 .863 r
.17802 .55604 .18884 .56454 .20485 .55307 .19413 .54437 Metetra
.789 .79 .853 r
.19413 .54437 .20485 .55307 .22097 .54075 .21034 .53186 Metetra
.794 .787 .846 r
.21034 .53186 .22097 .54075 .23716 .52784 .22662 .51878 Metetra
.798 .786 .841 r
.22662 .51878 .23716 .52784 .25341 .51447 .24297 .50526 Metetra
.802 .784 .836 r
.24297 .50526 .25341 .51447 .26971 .50065 .25936 .49132 Metetra
.802 .783 .836 r
.25936 .49132 .26971 .50065 .28602 .48683 .27576 .47736 Metetra
.796 .783 .84 r
.27576 .47736 .28602 .48683 .30231 .47348 .29213 .46389 Metetra
.796 .782 .84 r
.29213 .46389 .30231 .47348 .31862 .46012 .30853 .45041 Metetra
.753 .777 .873 r
.30853 .45041 .31862 .46012 .33475 .44999 .32474 .4402 Metetra
.751 .776 .874 r
.32474 .4402 .33475 .44999 .35092 .43998 .34099 .4301 Metetra
.741 .774 .88 r
.34099 .4301 .35092 .43998 .36712 .43054 .35725 .42059 Metetra
.721 .771 .892 r
.35725 .42059 .36712 .43054 .38332 .42216 .37353 .41214 Metetra
.721 .771 .892 r
.37353 .41214 .38332 .42216 .3996 .41374 .38987 .40366 Metetra
.725 .772 .89 r
.38987 .40366 .3996 .41374 .41594 .40507 .40629 .39493 Metetra
.738 .774 .882 r
.40629 .39493 .41594 .40507 .43238 .39567 .4228 .38545 Metetra
.738 .774 .882 r
.4228 .38545 .43238 .39567 .44887 .38623 .43937 .37594 Metetra
.738 .774 .882 r
.43937 .37594 .44887 .38623 .46542 .37675 .456 .3664 Metetra
.749 .777 .876 r
.456 .3664 .46542 .37675 .48205 .36656 .4727 .35613 Metetra
.762 .78 .867 r
.4727 .35613 .48205 .36656 .49873 .35549 .48946 .34498 Metetra
.762 .78 .867 r
.48946 .34498 .49873 .35549 .51546 .34438 .50627 .3338 Metetra
.762 .78 .867 r
.50627 .3338 .51546 .34438 .53223 .33325 .52313 .32259 Metetra
.762 .78 .867 r
.52313 .32259 .53223 .33325 .54905 .32209 .54003 .31134 Metetra
.831 .79 .813 r
.54003 .31134 .54905 .32209 .56583 .30501 .55692 .29416 Metetra
.835 .79 .808 r
.55692 .29416 .56583 .30501 .58259 .28747 .57378 .27651 Metetra
.835 .79 .808 r
.57378 .27651 .58259 .28747 .59933 .26996 .59061 .25889 Metetra
.835 .789 .808 r
.59061 .25889 .59933 .26996 .61604 .25247 .60742 .24129 Metetra
.835 .789 .808 r
.60742 .24129 .61604 .25247 .63273 .235 .62421 .22371 Metetra
.712 .759 .89 r
.62421 .22371 .63273 .235 .64977 .22662 .64133 .21526 Metetra
.562 .699 .932 r
.64133 .21526 .64977 .22662 .66717 .2242 .65879 .2128 Metetra
.562 .699 .933 r
.65879 .2128 .66717 .2242 .68471 .22175 .6764 .21031 Metetra
.562 .699 .933 r
.6764 .21031 .68471 .22175 .70241 .21929 .69416 .20781 Metetra
.562 .7 .933 r
.69416 .20781 .70241 .21929 .72026 .21681 .71208 .20528 Metetra
.562 .7 .934 r
.71208 .20528 .72026 .21681 .73827 .2143 .73016 .20273 Metetra
.643 .738 .918 r
.73016 .20273 .73827 .2143 .7562 .20879 .74817 .19716 Metetra
.704 .763 .898 r
.74817 .19716 .7562 .20879 .77403 .2005 .76609 .1888 Metetra
.704 .763 .898 r
.76609 .1888 .77403 .2005 .79195 .19217 .78409 .18039 Metetra
.688 .792 .929 r
.11979 .57366 .13097 .58172 .14636 .57534 .13524 .56717 Metetra
.74 .796 .897 r
.13524 .56717 .14636 .57534 .16207 .56658 .15104 .55819 Metetra
.768 .795 .875 r
.15104 .55819 .16207 .56658 .17802 .55604 .16708 .54743 Metetra
.782 .792 .861 r
.16708 .54743 .17802 .55604 .19413 .54437 .18328 .53553 Metetra
.79 .789 .851 r
.18328 .53553 .19413 .54437 .21034 .53186 .19959 .52283 Metetra
.795 .787 .845 r
.19959 .52283 .21034 .53186 .22662 .51878 .21597 .50958 Metetra
.799 .785 .84 r
.21597 .50958 .22662 .51878 .24297 .50526 .2324 .49591 Metetra
.802 .784 .835 r
.2324 .49591 .24297 .50526 .25936 .49132 .24889 .48183 Metetra
.802 .783 .835 r
.24889 .48183 .25936 .49132 .27576 .47736 .26538 .46774 Metetra
.796 .782 .839 r
.26538 .46774 .27576 .47736 .29213 .46389 .28185 .45415 Metetra
.796 .781 .839 r
.28185 .45415 .29213 .46389 .30853 .45041 .29833 .44054 Metetra
.753 .776 .872 r
.29833 .44054 .30853 .45041 .32474 .4402 .31461 .43024 Metetra
.751 .775 .873 r
.31461 .43024 .32474 .4402 .34099 .4301 .33094 .42006 Metetra
.741 .773 .88 r
.33094 .42006 .34099 .4301 .35725 .42059 .34728 .41047 Metetra
.721 .769 .891 r
.34728 .41047 .35725 .42059 .37353 .41214 .36363 .40196 Metetra
.721 .769 .891 r
.36363 .40196 .37353 .41214 .38987 .40366 .38004 .39341 Metetra
.725 .77 .889 r
.38004 .39341 .38987 .40366 .40629 .39493 .39653 .38462 Metetra
.738 .773 .882 r
.39653 .38462 .40629 .39493 .4228 .38545 .41311 .37507 Metetra
.738 .773 .882 r
.41311 .37507 .4228 .38545 .43937 .37594 .42976 .36549 Metetra
.738 .773 .882 r
.42976 .36549 .43937 .37594 .456 .3664 .44646 .35587 Metetra
.749 .776 .875 r
.44646 .35587 .456 .3664 .4727 .35613 .46324 .34553 Metetra
.762 .779 .867 r
.46324 .34553 .4727 .35613 .48946 .34498 .48009 .3343 Metetra
.762 .779 .867 r
.48009 .3343 .48946 .34498 .50627 .3338 .49698 .32304 Metetra
.762 .778 .867 r
.49698 .32304 .50627 .3338 .52313 .32259 .51392 .31175 Metetra
.762 .778 .867 r
.51392 .31175 .52313 .32259 .54003 .31134 .53091 .30043 Metetra
.831 .789 .812 r
.53091 .30043 .54003 .31134 .55692 .29416 .54789 .28314 Metetra
.835 .789 .808 r
.54789 .28314 .55692 .29416 .57378 .27651 .56486 .26539 Metetra
.835 .789 .808 r
.56486 .26539 .57378 .27651 .59061 .25889 .58179 .24766 Metetra
.835 .789 .808 r
.58179 .24766 .59061 .25889 .60742 .24129 .59871 .22996 Metetra
.835 .789 .808 r
.59871 .22996 .60742 .24129 .62421 .22371 .6156 .21228 Metetra
.711 .759 .89 r
.6156 .21228 .62421 .22371 .64133 .21526 .63279 .20376 Metetra
.562 .698 .932 r
.63279 .20376 .64133 .21526 .65879 .2128 .65031 .20125 Metetra
.562 .698 .932 r
.65031 .20125 .65879 .2128 .6764 .21031 .66799 .19872 Metetra
.562 .699 .933 r
.66799 .19872 .6764 .21031 .69416 .20781 .68582 .19616 Metetra
.562 .699 .933 r
.68582 .19616 .69416 .20781 .71208 .20528 .70381 .19358 Metetra
.561 .699 .933 r
.70381 .19358 .71208 .20528 .73016 .20273 .72195 .19098 Metetra
.643 .737 .917 r
.72195 .19098 .73016 .20273 .74817 .19716 .74004 .18534 Metetra
.704 .762 .897 r
.74004 .18534 .74817 .19716 .76609 .1888 .75804 .1769 Metetra
.704 .762 .897 r
.75804 .1769 .76609 .1888 .78409 .18039 .77613 .16841 Metetra
.69 .792 .928 r
.10847 .56551 .11979 .57366 .13524 .56717 .12399 .5589 Metetra
.743 .797 .896 r
.12399 .5589 .13524 .56717 .15104 .55819 .13988 .54971 Metetra
.77 .795 .873 r
.13988 .54971 .15104 .55819 .16708 .54743 .15602 .53871 Metetra
.783 .792 .859 r
.15602 .53871 .16708 .54743 .18328 .53553 .17232 .52659 Metetra
.791 .789 .85 r
.17232 .52659 .18328 .53553 .19959 .52283 .18872 .51369 Metetra
.796 .787 .844 r
.18872 .51369 .19959 .52283 .21597 .50958 .20519 .50027 Metetra
.799 .785 .839 r
.20519 .50027 .21597 .50958 .2324 .49591 .22172 .48646 Metetra
.803 .784 .835 r
.22172 .48646 .2324 .49591 .24889 .48183 .2383 .47224 Metetra
.802 .783 .835 r
.2383 .47224 .24889 .48183 .26538 .46774 .25489 .45802 Metetra
.797 .782 .839 r
.25489 .45802 .26538 .46774 .28185 .45415 .27144 .44429 Metetra
.797 .781 .838 r
.27144 .44429 .28185 .45415 .29833 .44054 .28802 .43056 Metetra
.753 .776 .872 r
.28802 .43056 .29833 .44054 .31461 .43024 .30438 .42018 Metetra
.751 .775 .873 r
.30438 .42018 .31461 .43024 .33094 .42006 .32078 .4099 Metetra
.741 .773 .879 r
.32078 .4099 .33094 .42006 .34728 .41047 .3372 .40024 Metetra
.721 .769 .891 r
.3372 .40024 .34728 .41047 .36363 .40196 .35361 .39167 Metetra
.721 .769 .891 r
.35361 .39167 .36363 .40196 .38004 .39341 .3701 .38305 Metetra
.725 .77 .889 r
.3701 .38305 .38004 .39341 .39653 .38462 .38666 .37419 Metetra
.738 .773 .882 r
.38666 .37419 .39653 .38462 .41311 .37507 .40332 .36457 Metetra
.738 .773 .882 r
.40332 .36457 .41311 .37507 .42976 .36549 .42004 .35492 Metetra
.738 .773 .882 r
.42004 .35492 .42976 .36549 .44646 .35587 .43682 .34522 Metetra
.749 .776 .875 r
.43682 .34522 .44646 .35587 .46324 .34553 .45368 .33481 Metetra
.762 .779 .867 r
.45368 .33481 .46324 .34553 .48009 .3343 .47061 .3235 Metetra
.762 .779 .867 r
.47061 .3235 .48009 .3343 .49698 .32304 .48759 .31216 Metetra
.762 .778 .867 r
.48759 .31216 .49698 .32304 .51392 .31175 .50461 .30078 Metetra
.762 .778 .867 r
.50461 .30078 .51392 .31175 .53091 .30043 .52168 .28938 Metetra
.831 .789 .812 r
.52168 .28938 .53091 .30043 .54789 .28314 .53877 .272 Metetra
.835 .789 .808 r
.53877 .272 .54789 .28314 .56486 .26539 .55584 .25414 Metetra
.835 .789 .808 r
.55584 .25414 .56486 .26539 .58179 .24766 .57288 .23631 Metetra
.835 .789 .808 r
.57288 .23631 .58179 .24766 .59871 .22996 .58989 .21851 Metetra
.835 .789 .808 r
.58989 .21851 .59871 .22996 .6156 .21228 .60689 .20073 Metetra
.711 .759 .89 r
.60689 .20073 .6156 .21228 .63279 .20376 .62416 .19214 Metetra
.561 .698 .932 r
.62416 .19214 .63279 .20376 .65031 .20125 .64174 .18957 Metetra
.561 .698 .932 r
.64174 .18957 .65031 .20125 .66799 .19872 .65948 .18699 Metetra
.561 .699 .933 r
.65948 .18699 .66799 .19872 .68582 .19616 .67738 .18438 Metetra
.561 .699 .933 r
.67738 .18438 .68582 .19616 .70381 .19358 .69543 .18175 Metetra
.561 .699 .933 r
.69543 .18175 .70381 .19358 .72195 .19098 .71365 .17909 Metetra
.642 .737 .917 r
.71365 .17909 .72195 .19098 .74004 .18534 .73182 .17339 Metetra
.704 .762 .897 r
.73182 .17339 .74004 .18534 .75804 .1769 .7499 .16486 Metetra
.704 .762 .897 r
.7499 .16486 .75804 .1769 .77613 .16841 .76808 .15629 Metetra
.691 .792 .927 r
.09701 .55726 .10847 .56551 .12399 .5589 .11261 .55052 Metetra
.745 .797 .894 r
.11261 .55052 .12399 .5589 .13988 .54971 .12858 .54112 Metetra
.772 .795 .871 r
.12858 .54112 .13988 .54971 .15602 .53871 .14483 .52987 Metetra
.785 .791 .858 r
.14483 .52987 .15602 .53871 .17232 .52659 .16122 .51753 Metetra
.792 .788 .849 r
.16122 .51753 .17232 .52659 .18872 .51369 .17772 .50444 Metetra
.797 .786 .843 r
.17772 .50444 .18872 .51369 .20519 .50027 .1943 .49085 Metetra
.8 .785 .839 r
.1943 .49085 .20519 .50027 .22172 .48646 .21092 .47688 Metetra
.803 .783 .834 r
.21092 .47688 .22172 .48646 .2383 .47224 .22759 .46252 Metetra
.803 .782 .834 r
.22759 .46252 .2383 .47224 .25489 .45802 .24428 .44816 Metetra
.797 .781 .838 r
.24428 .44816 .25489 .45802 .27144 .44429 .26093 .43431 Metetra
.797 .781 .838 r
.26093 .43431 .27144 .44429 .28802 .43056 .27759 .42045 Metetra
.753 .776 .871 r
.27759 .42045 .28802 .43056 .30438 .42018 .29403 .40998 Metetra
.751 .775 .873 r
.29403 .40998 .30438 .42018 .32078 .4099 .31051 .39962 Metetra
.741 .773 .879 r
.31051 .39962 .32078 .4099 .3372 .40024 .327 .38988 Metetra
.721 .769 .891 r
.327 .38988 .3372 .40024 .35361 .39167 .34349 .38124 Metetra
.721 .769 .891 r
.34349 .38124 .35361 .39167 .3701 .38305 .36004 .37256 Metetra
.725 .77 .889 r
.36004 .37256 .3701 .38305 .38666 .37419 .37668 .36363 Metetra
.737 .773 .881 r
.37668 .36363 .38666 .37419 .40332 .36457 .39341 .35393 Metetra
.737 .773 .881 r
.39341 .35393 .40332 .36457 .42004 .35492 .41021 .3442 Metetra
.737 .773 .882 r
.41021 .3442 .42004 .35492 .43682 .34522 .42707 .33444 Metetra
.749 .775 .875 r
.42707 .33444 .43682 .34522 .45368 .33481 .44401 .32395 Metetra
.762 .778 .866 r
.44401 .32395 .45368 .33481 .47061 .3235 .46103 .31255 Metetra
.762 .778 .866 r
.46103 .31255 .47061 .3235 .48759 .31216 .47809 .30113 Metetra
.762 .778 .866 r
.47809 .30113 .48759 .31216 .50461 .30078 .49519 .28968 Metetra
.762 .778 .866 r
.49519 .28968 .50461 .30078 .52168 .28938 .51235 .27819 Metetra
.831 .789 .812 r
.51235 .27819 .52168 .28938 .53877 .272 .52954 .26071 Metetra
.835 .789 .808 r
.52954 .26071 .53877 .272 .55584 .25414 .54671 .24275 Metetra
.835 .789 .808 r
.54671 .24275 .55584 .25414 .57288 .23631 .56386 .22482 Metetra
.835 .789 .807 r
.56386 .22482 .57288 .23631 .58989 .21851 .58098 .20691 Metetra
.835 .789 .807 r
.58098 .20691 .58989 .21851 .60689 .20073 .59807 .18903 Metetra
.711 .759 .89 r
.59807 .18903 .60689 .20073 .62416 .19214 .61542 .18036 Metetra
.561 .698 .932 r
.61542 .18036 .62416 .19214 .64174 .18957 .63307 .17775 Metetra
.561 .698 .932 r
.63307 .17775 .64174 .18957 .65948 .18699 .65088 .17511 Metetra
.561 .698 .932 r
.65088 .17511 .65948 .18699 .67738 .18438 .66884 .17244 Metetra
.561 .698 .933 r
.66884 .17244 .67738 .18438 .69543 .18175 .68696 .16976 Metetra
.561 .699 .933 r
.68696 .16976 .69543 .18175 .71365 .17909 .70525 .16704 Metetra
.642 .736 .917 r
.70525 .16704 .71365 .17909 .73182 .17339 .72349 .16127 Metetra
.704 .761 .897 r
.72349 .16127 .73182 .17339 .7499 .16486 .74167 .15266 Metetra
.704 .761 .897 r
.74167 .15266 .7499 .16486 .76808 .15629 .75993 .14401 Metetra
.693 .792 .926 r
.08543 .54887 .09701 .55726 .11261 .55052 .1011 .542 Metetra
.748 .796 .891 r
.1011 .542 .11261 .55052 .12858 .54112 .11717 .53237 Metetra
.774 .794 .869 r
.11717 .53237 .12858 .54112 .14483 .52987 .13351 .52087 Metetra
.786 .79 .856 r
.13351 .52087 .14483 .52987 .16122 .51753 .15001 .5083 Metetra
.793 .787 .847 r
.15001 .5083 .16122 .51753 .17772 .50444 .16661 .49501 Metetra
.797 .785 .841 r
.16661 .49501 .17772 .50444 .1943 .49085 .18328 .48124 Metetra
.8 .783 .837 r
.18328 .48124 .1943 .49085 .21092 .47688 .2 .46712 Metetra
.803 .782 .833 r
.2 .46712 .21092 .47688 .22759 .46252 .21677 .45262 Metetra
.803 .781 .833 r
.21677 .45262 .22759 .46252 .24428 .44816 .23355 .43812 Metetra
.797 .78 .837 r
.23355 .43812 .24428 .44816 .26093 .43431 .25029 .42414 Metetra
.797 .779 .837 r
.25029 .42414 .26093 .43431 .27759 .42045 .26705 .41015 Metetra
.753 .774 .87 r
.26705 .41015 .27759 .42045 .29403 .40998 .28357 .39959 Metetra
.751 .774 .872 r
.28357 .39959 .29403 .40998 .31051 .39962 .30013 .38914 Metetra
.74 .772 .878 r
.30013 .38914 .31051 .39962 .327 .38988 .31669 .37932 Metetra
.72 .767 .89 r
.31669 .37932 .327 .38988 .34349 .38124 .33325 .37061 Metetra
.72 .767 .89 r
.33325 .37061 .34349 .38124 .36004 .37256 .34988 .36186 Metetra
.724 .768 .888 r
.34988 .36186 .36004 .37256 .37668 .36363 .36659 .35286 Metetra
.737 .771 .881 r
.36659 .35286 .37668 .36363 .39341 .35393 .3834 .3431 Metetra
.737 .771 .881 r
.3834 .3431 .39341 .35393 .41021 .3442 .40027 .33329 Metetra
.737 .771 .881 r
.40027 .33329 .41021 .3442 .42707 .33444 .41721 .32345 Metetra
.748 .774 .874 r
.41721 .32345 .42707 .33444 .44401 .32395 .43423 .31288 Metetra
.762 .777 .865 r
.43423 .31288 .44401 .32395 .46103 .31255 .45133 .30141 Metetra
.762 .777 .865 r
.45133 .30141 .46103 .31255 .47809 .30113 .46848 .2899 Metetra
.762 .777 .865 r
.46848 .2899 .47809 .30113 .49519 .28968 .48567 .27837 Metetra
.762 .777 .865 r
.48567 .27837 .49519 .28968 .51235 .27819 .50291 .2668 Metetra
.83 .788 .811 r
.50291 .2668 .51235 .27819 .52954 .26071 .52021 .24921 Metetra
.835 .788 .807 r
.52021 .24921 .52954 .26071 .54671 .24275 .53748 .23116 Metetra
.835 .788 .807 r
.53748 .23116 .54671 .24275 .56386 .22482 .55473 .21313 Metetra
.835 .788 .807 r
.55473 .21313 .56386 .22482 .58098 .20691 .57196 .19512 Metetra
.835 .788 .807 r
.57196 .19512 .58098 .20691 .59807 .18903 .58916 .17714 Metetra
.711 .758 .889 r
.58916 .17714 .59807 .18903 .61542 .18036 .60658 .1684 Metetra
.561 .696 .931 r
.60658 .1684 .61542 .18036 .63307 .17775 .6243 .16573 Metetra
.561 .697 .931 r
.6243 .16573 .63307 .17775 .65088 .17511 .64217 .16303 Metetra
.561 .697 .931 r
.64217 .16303 .65088 .17511 .66884 .17244 .6602 .1603 Metetra
.561 .697 .932 r
.6602 .1603 .66884 .17244 .68696 .16976 .67839 .15755 Metetra
.561 .697 .932 r
.67839 .15755 .68696 .16976 .70525 .16704 .69674 .15478 Metetra
.642 .735 .916 r
.69674 .15478 .70525 .16704 .72349 .16127 .71507 .14893 Metetra
.703 .76 .896 r
.71507 .14893 .72349 .16127 .74167 .15266 .73333 .14024 Metetra
.703 .76 .896 r
.73333 .14024 .74167 .15266 .75993 .14401 .75168 .13151 Metetra
.695 .791 .924 r
.07372 .54037 .08543 .54887 .1011 .542 .08945 .53336 Metetra
.75 .796 .889 r
.08945 .53336 .1011 .542 .11717 .53237 .10562 .5235 Metetra
.777 .793 .866 r
.10562 .5235 .11717 .53237 .13351 .52087 .12207 .51174 Metetra
.788 .79 .854 r
.12207 .51174 .13351 .52087 .15001 .5083 .13867 .49894 Metetra
.794 .787 .846 r
.13867 .49894 .15001 .5083 .16661 .49501 .15537 .48545 Metetra
.798 .785 .84 r
.15537 .48545 .16661 .49501 .18328 .48124 .17214 .47151 Metetra
.801 .783 .836 r
.17214 .47151 .18328 .48124 .2 .46712 .18896 .45722 Metetra
.804 .782 .832 r
.18896 .45722 .2 .46712 .21677 .45262 .20583 .44258 Metetra
.803 .781 .832 r
.20583 .44258 .21677 .45262 .23355 .43812 .22271 .42795 Metetra
.798 .78 .837 r
.22271 .42795 .23355 .43812 .25029 .42414 .23954 .41384 Metetra
.797 .779 .836 r
.23954 .41384 .25029 .42414 .26705 .41015 .2564 .39971 Metetra
.753 .774 .87 r
.2564 .39971 .26705 .41015 .28357 .39959 .27299 .38906 Metetra
.751 .773 .871 r
.27299 .38906 .28357 .39959 .30013 .38914 .28963 .37852 Metetra
.74 .771 .878 r
.28963 .37852 .30013 .38914 .31669 .37932 .30627 .36861 Metetra
.72 .767 .89 r
.30627 .36861 .31669 .37932 .33325 .37061 .3229 .35984 Metetra
.72 .767 .89 r
.3229 .35984 .33325 .37061 .34988 .36186 .3396 .35102 Metetra
.724 .768 .888 r
.3396 .35102 .34988 .36186 .36659 .35286 .35638 .34196 Metetra
.737 .771 .88 r
.35638 .34196 .36659 .35286 .3834 .3431 .37327 .33211 Metetra
.737 .771 .88 r
.37327 .33211 .3834 .3431 .40027 .33329 .39022 .32223 Metetra
.737 .771 .88 r
.39022 .32223 .40027 .33329 .41721 .32345 .40724 .31232 Metetra
.748 .774 .874 r
.40724 .31232 .41721 .32345 .43423 .31288 .42434 .30167 Metetra
.761 .776 .865 r
.42434 .30167 .43423 .31288 .45133 .30141 .44152 .29011 Metetra
.761 .776 .865 r
.44152 .29011 .45133 .30141 .46848 .2899 .45875 .27852 Metetra
.761 .776 .865 r
.45875 .27852 .46848 .2899 .48567 .27837 .47603 .2669 Metetra
.761 .776 .865 r
.47603 .2669 .48567 .27837 .50291 .2668 .49336 .25525 Metetra
.83 .787 .811 r
.49336 .25525 .50291 .2668 .52021 .24921 .51076 .23757 Metetra
.835 .788 .807 r
.51076 .23757 .52021 .24921 .53748 .23116 .52814 .21941 Metetra
.835 .787 .807 r
.52814 .21941 .53748 .23116 .55473 .21313 .5455 .20128 Metetra
.835 .787 .807 r
.5455 .20128 .55473 .21313 .57196 .19512 .56283 .18318 Metetra
.835 .787 .807 r
.56283 .18318 .57196 .19512 .58916 .17714 .58014 .1651 Metetra
.711 .757 .889 r
.58014 .1651 .58916 .17714 .60658 .1684 .59764 .15628 Metetra
.561 .696 .931 r
.59764 .15628 .60658 .1684 .6243 .16573 .61542 .15355 Metetra
.561 .696 .931 r
.61542 .15355 .6243 .16573 .64217 .16303 .63336 .15079 Metetra
.561 .696 .931 r
.63336 .15079 .64217 .16303 .6602 .1603 .65145 .148 Metetra
.561 .696 .931 r
.65145 .148 .6602 .1603 .67839 .15755 .66971 .14519 Metetra
.561 .697 .931 r
.66971 .14519 .67839 .15755 .69674 .15478 .68814 .14235 Metetra
.642 .734 .916 r
.68814 .14235 .69674 .15478 .71507 .14893 .70654 .13643 Metetra
.703 .759 .896 r
.70654 .13643 .71507 .14893 .73333 .14024 .72488 .12765 Metetra
.703 .759 .896 r
.72488 .12765 .73333 .14024 .75168 .13151 .74332 .11883 Metetra
.697 .789 .922 r
.06187 .53166 .07372 .54037 .08945 .53336 .07768 .5245 Metetra
.753 .793 .886 r
.07768 .5245 .08945 .53336 .10562 .5235 .09395 .51439 Metetra
.778 .791 .863 r
.09395 .51439 .10562 .5235 .12207 .51174 .1105 .50237 Metetra
.789 .787 .851 r
.1105 .50237 .12207 .51174 .13867 .49894 .12721 .48932 Metetra
.795 .784 .843 r
.12721 .48932 .13867 .49894 .15537 .48545 .14402 .47563 Metetra
.798 .782 .838 r
.14402 .47563 .15537 .48545 .17214 .47151 .16089 .46151 Metetra
.801 .78 .834 r
.16089 .46151 .17214 .47151 .18896 .45722 .17781 .44706 Metetra
.803 .779 .831 r
.17781 .44706 .18896 .45722 .20583 .44258 .19478 .43228 Metetra
.803 .778 .83 r
.19478 .43228 .20583 .44258 .22271 .42795 .21175 .41751 Metetra
.797 .777 .835 r
.21175 .41751 .22271 .42795 .23954 .41384 .22869 .40326 Metetra
.797 .776 .834 r
.22869 .40326 .23954 .41384 .2564 .39971 .24563 .389 Metetra
.753 .771 .868 r
.24563 .389 .2564 .39971 .27299 .38906 .26231 .37826 Metetra
.75 .77 .869 r
.26231 .37826 .27299 .38906 .28963 .37852 .27902 .36762 Metetra
.74 .768 .876 r
.27902 .36762 .28963 .37852 .30627 .36861 .29574 .35763 Metetra
.719 .764 .888 r
.29574 .35763 .30627 .36861 .3229 .35984 .31244 .34879 Metetra
.719 .764 .888 r
.31244 .34879 .3229 .35984 .3396 .35102 .32921 .33991 Metetra
.723 .765 .886 r
.32921 .33991 .3396 .35102 .35638 .34196 .34606 .33077 Metetra
.736 .768 .878 r
.34606 .33077 .35638 .34196 .37327 .33211 .36303 .32085 Metetra
.736 .768 .878 r
.36303 .32085 .37327 .33211 .39022 .32223 .38006 .31089 Metetra
.736 .768 .878 r
.38006 .31089 .39022 .32223 .40724 .31232 .39716 .3009 Metetra
.747 .771 .872 r
.39716 .3009 .40724 .31232 .42434 .30167 .41434 .29017 Metetra
.761 .773 .863 r
.41434 .29017 .42434 .30167 .44152 .29011 .43161 .27853 Metetra
.761 .773 .863 r
.43161 .27853 .44152 .29011 .45875 .27852 .44892 .26686 Metetra
.761 .773 .863 r
.44892 .26686 .45875 .27852 .47603 .2669 .46629 .25516 Metetra
.761 .773 .863 r
.46629 .25516 .47603 .2669 .49336 .25525 .4837 .24342 Metetra
.829 .785 .81 r
.4837 .24342 .49336 .25525 .51076 .23757 .50121 .22564 Metetra
.833 .785 .806 r
.50121 .22564 .51076 .23757 .52814 .21941 .5187 .20739 Metetra
.833 .785 .806 r
.5187 .20739 .52814 .21941 .5455 .20128 .53616 .18916 Metetra
.833 .785 .806 r
.53616 .18916 .5455 .20128 .56283 .18318 .5536 .17096 Metetra
.833 .785 .806 r
.5536 .17096 .56283 .18318 .58014 .1651 .57101 .15278 Metetra
.71 .755 .887 r
.57101 .15278 .58014 .1651 .59764 .15628 .5886 .14389 Metetra
.561 .693 .929 r
.5886 .14389 .59764 .15628 .61542 .15355 .60644 .14109 Metetra
.561 .694 .929 r
.60644 .14109 .61542 .15355 .63336 .15079 .62444 .13826 Metetra
.561 .694 .929 r
.62444 .13826 .63336 .15079 .65145 .148 .6426 .13541 Metetra
.561 .694 .929 r
.6426 .13541 .65145 .148 .66971 .14519 .66092 .13253 Metetra
.561 .694 .929 r
.66092 .13253 .66971 .14519 .68814 .14235 .67942 .12963 Metetra
.642 .731 .913 r
.67942 .12963 .68814 .14235 .70654 .13643 .6979 .12363 Metetra
.703 .756 .893 r
.6979 .12363 .70654 .13643 .72488 .12765 .71633 .11476 Metetra
.703 .756 .893 r
.71633 .11476 .72488 .12765 .74332 .11883 .73486 .10586 Metetra
.699 .788 .92 r
.0499 .52275 .06187 .53166 .07768 .5245 .06579 .51544 Metetra
.755 .792 .883 r
.06579 .51544 .07768 .5245 .09395 .51439 .08216 .50508 Metetra
.78 .789 .86 r
.08216 .50508 .09395 .51439 .1105 .50237 .09882 .49278 Metetra
.79 .785 .848 r
.09882 .49278 .1105 .50237 .12721 .48932 .11564 .4795 Metetra
.795 .783 .841 r
.11564 .4795 .12721 .48932 .14402 .47563 .13255 .4656 Metetra
.798 .78 .836 r
.13255 .4656 .14402 .47563 .16089 .46151 .14952 .4513 Metetra
.801 .779 .833 r
.14952 .4513 .16089 .46151 .17781 .44706 .16655 .43669 Metetra
.803 .778 .829 r
.16655 .43669 .17781 .44706 .19478 .43228 .18361 .42176 Metetra
.803 .777 .829 r
.18361 .42176 .19478 .43228 .21175 .41751 .20068 .40685 Metetra
.797 .776 .833 r
.20068 .40685 .21175 .41751 .22869 .40326 .21771 .39247 Metetra
.797 .775 .833 r
.21771 .39247 .22869 .40326 .24563 .389 .23476 .37808 Metetra
.752 .769 .867 r
.23476 .37808 .24563 .389 .26231 .37826 .25151 .36724 Metetra
.75 .769 .868 r
.25151 .36724 .26231 .37826 .27902 .36762 .2683 .35651 Metetra
.739 .766 .875 r
.2683 .35651 .27902 .36762 .29574 .35763 .28509 .34643 Metetra
.719 .762 .886 r
.28509 .34643 .29574 .35763 .31244 .34879 .30186 .33752 Metetra
.719 .762 .887 r
.30186 .33752 .31244 .34879 .32921 .33991 .31871 .32857 Metetra
.723 .763 .884 r
.31871 .32857 .32921 .33991 .34606 .33077 .33564 .31936 Metetra
.736 .766 .877 r
.33564 .31936 .34606 .33077 .36303 .32085 .35268 .30936 Metetra
.736 .766 .877 r
.35268 .30936 .36303 .32085 .38006 .31089 .36979 .29933 Metetra
.736 .766 .877 r
.36979 .29933 .38006 .31089 .39716 .3009 .38696 .28926 Metetra
.747 .769 .871 r
.38696 .28926 .39716 .3009 .41434 .29017 .40423 .27844 Metetra
.76 .772 .862 r
.40423 .27844 .41434 .29017 .43161 .27853 .42158 .26672 Metetra
.76 .772 .862 r
.42158 .26672 .43161 .27853 .44892 .26686 .43898 .25497 Metetra
.76 .772 .862 r
.43898 .25497 .44892 .26686 .46629 .25516 .45643 .24318 Metetra
.76 .772 .862 r
.45643 .24318 .46629 .25516 .4837 .24342 .47393 .23135 Metetra
.828 .783 .809 r
.47393 .23135 .4837 .24342 .50121 .22564 .49155 .21348 Metetra
.833 .784 .805 r
.49155 .21348 .50121 .22564 .5187 .20739 .50914 .19513 Metetra
.833 .784 .805 r
.50914 .19513 .5187 .20739 .53616 .18916 .52672 .17681 Metetra
.833 .784 .805 r
.52672 .17681 .53616 .18916 .5536 .17096 .54426 .15851 Metetra
.833 .784 .805 r
.54426 .15851 .5536 .17096 .57101 .15278 .56178 .14024 Metetra
.71 .753 .886 r
.56178 .14024 .57101 .15278 .5886 .14389 .57945 .13127 Metetra
.562 .692 .927 r
.57945 .13127 .5886 .14389 .60644 .14109 .59735 .1284 Metetra
.562 .692 .928 r
.59735 .1284 .60644 .14109 .62444 .13826 .61541 .12551 Metetra
.562 .692 .928 r
.61541 .12551 .62444 .13826 .6426 .13541 .63364 .12258 Metetra
.562 .692 .928 r
.63364 .12258 .6426 .13541 .66092 .13253 .65203 .11963 Metetra
.562 .692 .928 r
.65203 .11963 .66092 .13253 .67942 .12963 .67059 .11666 Metetra
.642 .729 .912 r
.67059 .11666 .67942 .12963 .6979 .12363 .68915 .11058 Metetra
.702 .754 .892 r
.68915 .11058 .6979 .12363 .71633 .11476 .70767 .10163 Metetra
.702 .754 .892 r
.70767 .10163 .71633 .11476 .73486 .10586 .72629 .09263 Metetra
.7 .783 .916 r
.03783 .5135 .0499 .52275 .06579 .51544 .05379 .50604 Metetra
.757 .787 .878 r
.05379 .50604 .06579 .51544 .08216 .50508 .07026 .49541 Metetra
.781 .785 .856 r
.07026 .49541 .08216 .50508 .09882 .49278 .08703 .48284 Metetra
.79 .781 .844 r
.08703 .48284 .09882 .49278 .11564 .4795 .10396 .46931 Metetra
.795 .778 .838 r
.10396 .46931 .11564 .4795 .13255 .4656 .12098 .4552 Metetra
.798 .776 .833 r
.12098 .4552 .13255 .4656 .14952 .4513 .13805 .44072 Metetra
.8 .775 .83 r
.13805 .44072 .14952 .4513 .16655 .43669 .15518 .42595 Metetra
.802 .773 .827 r
.15518 .42595 .16655 .43669 .18361 .42176 .17234 .41087 Metetra
.801 .773 .826 r
.17234 .41087 .18361 .42176 .20068 .40685 .18951 .39582 Metetra
.796 .771 .831 r
.18951 .39582 .20068 .40685 .21771 .39247 .20664 .3813 Metetra
.795 .771 .83 r
.20664 .3813 .21771 .39247 .23476 .37808 .22378 .36678 Metetra
.751 .765 .864 r
.22378 .36678 .23476 .37808 .25151 .36724 .24061 .35584 Metetra
.749 .764 .865 r
.24061 .35584 .25151 .36724 .2683 .35651 .25748 .34501 Metetra
.738 .762 .872 r
.25748 .34501 .2683 .35651 .28509 .34643 .27435 .33485 Metetra
.718 .757 .883 r
.27435 .33485 .28509 .34643 .30186 .33752 .29119 .32587 Metetra
.718 .757 .883 r
.29119 .32587 .30186 .33752 .31871 .32857 .3081 .31685 Metetra
.722 .758 .881 r
.3081 .31685 .31871 .32857 .33564 .31936 .3251 .30756 Metetra
.734 .761 .874 r
.3251 .30756 .33564 .31936 .35268 .30936 .34222 .29749 Metetra
.734 .761 .874 r
.34222 .29749 .35268 .30936 .36979 .29933 .35941 .28738 Metetra
.734 .761 .874 r
.35941 .28738 .36979 .29933 .38696 .28926 .37666 .27723 Metetra
.746 .764 .868 r
.37666 .27723 .38696 .28926 .40423 .27844 .39401 .26633 Metetra
.759 .767 .86 r
.39401 .26633 .40423 .27844 .42158 .26672 .41145 .25453 Metetra
.759 .767 .86 r
.41145 .25453 .42158 .26672 .43898 .25497 .42893 .24269 Metetra
.759 .767 .86 r
.42893 .24269 .43898 .25497 .45643 .24318 .44647 .23081 Metetra
.759 .767 .86 r
.44647 .23081 .45643 .24318 .47393 .23135 .46406 .2189 Metetra
.827 .779 .807 r
.46406 .2189 .47393 .23135 .49155 .21348 .48178 .20094 Metetra
.831 .78 .803 r
.48178 .20094 .49155 .21348 .50914 .19513 .49948 .18249 Metetra
.831 .78 .803 r
.49948 .18249 .50914 .19513 .52672 .17681 .51716 .16408 Metetra
.831 .78 .803 r
.51716 .16408 .52672 .17681 .54426 .15851 .53481 .14569 Metetra
.831 .78 .803 r
.53481 .14569 .54426 .15851 .56178 .14024 .55244 .12733 Metetra
.709 .748 .883 r
.55244 .12733 .56178 .14024 .57945 .13127 .57018 .11828 Metetra
.563 .688 .924 r
.57018 .11828 .57945 .13127 .59735 .1284 .58815 .11534 Metetra
.563 .688 .924 r
.58815 .11534 .59735 .1284 .61541 .12551 .60627 .11237 Metetra
.563 .688 .924 r
.60627 .11237 .61541 .12551 .63364 .12258 .62456 .10937 Metetra
.563 .688 .924 r
.62456 .10937 .63364 .12258 .65203 .11963 .64302 .10634 Metetra
.563 .688 .924 r
.64302 .10634 .65203 .11963 .67059 .11666 .66165 .10329 Metetra
.642 .725 .908 r
.66165 .10329 .67059 .11666 .68915 .11058 .68029 .09713 Metetra
.702 .75 .889 r
.68029 .09713 .68915 .11058 .70767 .10163 .69889 .08809 Metetra
.702 .75 .889 r
.69889 .08809 .70767 .10163 .72629 .09263 .71759 .07901 Metetra
.701 .774 .908 r
.02567 .50369 .03783 .5135 .05379 .50604 .04171 .49606 Metetra
.757 .779 .871 r
.04171 .49606 .05379 .50604 .07026 .49541 .05829 .48516 Metetra
.78 .776 .849 r
.05829 .48516 .07026 .49541 .08703 .48284 .07517 .47231 Metetra
.789 .773 .839 r
.07517 .47231 .08703 .48284 .10396 .46931 .09221 .45853 Metetra
.793 .771 .832 r
.09221 .45853 .10396 .46931 .12098 .4552 .10933 .44421 Metetra
.796 .769 .828 r
.10933 .44421 .12098 .4552 .13805 .44072 .12651 .42954 Metetra
.797 .767 .825 r
.12651 .42954 .13805 .44072 .15518 .42595 .14374 .41461 Metetra
.799 .766 .822 r
.14374 .41461 .15518 .42595 .17234 .41087 .161 .39939 Metetra
.799 .765 .822 r
.161 .39939 .17234 .41087 .18951 .39582 .17827 .38419 Metetra
.793 .764 .826 r
.17827 .38419 .18951 .39582 .20664 .3813 .19549 .36954 Metetra
.793 .763 .826 r
.19549 .36954 .20664 .3813 .22378 .36678 .21272 .35488 Metetra
.749 .756 .858 r
.21272 .35488 .22378 .36678 .24061 .35584 .22963 .34384 Metetra
.747 .756 .86 r
.22963 .34384 .24061 .35584 .25748 .34501 .24658 .33292 Metetra
.736 .753 .866 r
.24658 .33292 .25748 .34501 .27435 .33485 .26352 .32267 Metetra
.716 .748 .878 r
.26352 .32267 .27435 .33485 .29119 .32587 .28043 .31362 Metetra
.716 .748 .878 r
.28043 .31362 .29119 .32587 .3081 .31685 .29741 .30452 Metetra
.72 .749 .876 r
.29741 .30452 .3081 .31685 .3251 .30756 .31449 .29517 Metetra
.732 .753 .869 r
.31449 .29517 .3251 .30756 .34222 .29749 .33168 .28502 Metetra
.732 .753 .869 r
.33168 .28502 .34222 .29749 .35941 .28738 .34894 .27483 Metetra
.732 .753 .869 r
.34894 .27483 .35941 .28738 .37666 .27723 .36627 .2646 Metetra
.743 .755 .862 r
.36627 .2646 .37666 .27723 .39401 .26633 .38369 .25362 Metetra
.756 .758 .855 r
.38369 .25362 .39401 .26633 .41145 .25453 .40121 .24173 Metetra
.756 .758 .855 r
.40121 .24173 .41145 .25453 .42893 .24269 .41878 .2298 Metetra
.756 .758 .855 r
.41878 .2298 .42893 .24269 .44647 .23081 .4364 .21784 Metetra
.756 .758 .855 r
.4364 .21784 .44647 .23081 .46406 .2189 .45407 .20585 Metetra
.823 .772 .804 r
.45407 .20585 .46406 .2189 .48178 .20094 .4719 .18779 Metetra
.827 .772 .8 r
.4719 .18779 .48178 .20094 .49948 .18249 .48971 .16926 Metetra
.828 .772 .8 r
.48971 .16926 .49948 .18249 .51716 .16408 .5075 .15075 Metetra
.828 .773 .8 r
.5075 .15075 .51716 .16408 .53481 .14569 .52526 .13228 Metetra
.828 .773 .8 r
.52526 .13228 .53481 .14569 .55244 .12733 .54299 .11383 Metetra
.707 .74 .877 r
.54299 .11383 .55244 .12733 .57018 .11828 .56081 .1047 Metetra
.564 .68 .917 r
.56081 .1047 .57018 .11828 .58815 .11534 .57883 .10168 Metetra
.564 .68 .917 r
.57883 .10168 .58815 .11534 .60627 .11237 .59701 .09863 Metetra
.564 .68 .917 r
.59701 .09863 .60627 .11237 .62456 .10937 .61537 .09555 Metetra
.564 .68 .917 r
.61537 .09555 .62456 .10937 .64302 .10634 .63389 .09245 Metetra
.564 .68 .917 r
.63389 .09245 .64302 .10634 .66165 .10329 .65258 .08932 Metetra
.641 .716 .902 r
.65258 .08932 .66165 .10329 .68029 .09713 .6713 .08307 Metetra
.7 .741 .883 r
.6713 .08307 .68029 .09713 .69889 .08809 .68999 .07395 Metetra
.7 .741 .883 r
.68999 .07395 .69889 .08809 .71759 .07901 .70877 .06477 Metetra
.699 .747 .889 r
.0136 .49234 .02567 .50369 .04171 .49606 .02971 .48454 Metetra
.752 .754 .854 r
.02971 .48454 .04171 .49606 .05829 .48516 .04638 .47335 Metetra
.774 .753 .834 r
.04638 .47335 .05829 .48516 .07517 .47231 .06338 .46021 Metetra
.782 .751 .825 r
.06338 .46021 .07517 .47231 .09221 .45853 .08052 .44619 Metetra
.785 .748 .819 r
.08052 .44619 .09221 .45853 .10933 .44421 .09774 .43166 Metetra
.787 .747 .816 r
.09774 .43166 .10933 .44421 .12651 .42954 .11502 .4168 Metetra
.789 .745 .813 r
.11502 .4168 .12651 .42954 .14374 .41461 .13234 .40171 Metetra
.791 .745 .81 r
.13234 .40171 .14374 .41461 .161 .39939 .1497 .38635 Metetra
.79 .744 .81 r
.1497 .38635 .161 .39939 .17827 .38419 .16706 .37102 Metetra
.784 .742 .814 r
.16706 .37102 .17827 .38419 .19549 .36954 .18437 .35624 Metetra
.784 .741 .814 r
.18437 .35624 .19549 .36954 .21272 .35488 .20169 .34145 Metetra
.741 .732 .843 r
.20169 .34145 .21272 .35488 .22963 .34384 .21867 .33032 Metetra
.739 .732 .844 r
.21867 .33032 .22963 .34384 .24658 .33292 .23569 .3193 Metetra
.729 .729 .85 r
.23569 .3193 .24658 .33292 .26352 .32267 .2527 .30897 Metetra
.709 .723 .861 r
.2527 .30897 .26352 .32267 .28043 .31362 .26966 .29984 Metetra
.709 .723 .861 r
.26966 .29984 .28043 .31362 .29741 .30452 .28671 .29067 Metetra
.713 .724 .859 r
.28671 .29067 .29741 .30452 .31449 .29517 .30385 .28125 Metetra
.725 .728 .853 r
.30385 .28125 .31449 .29517 .33168 .28502 .32111 .27102 Metetra
.725 .728 .853 r
.32111 .27102 .33168 .28502 .34894 .27483 .33844 .26075 Metetra
.725 .728 .853 r
.33844 .26075 .34894 .27483 .36627 .2646 .35583 .25044 Metetra
.735 .731 .847 r
.35583 .25044 .36627 .2646 .38369 .25362 .37333 .23938 Metetra
.748 .735 .84 r
.37333 .23938 .38369 .25362 .40121 .24173 .39093 .22741 Metetra
.748 .735 .84 r
.39093 .22741 .40121 .24173 .41878 .2298 .40857 .2154 Metetra
.748 .735 .84 r
.40857 .2154 .41878 .2298 .4364 .21784 .42627 .20336 Metetra
.748 .735 .84 r
.42627 .20336 .4364 .21784 .45407 .20585 .44402 .19128 Metetra
.813 .751 .794 r
.44402 .19128 .45407 .20585 .4719 .18779 .46194 .17314 Metetra
.817 .752 .791 r
.46194 .17314 .4719 .18779 .48971 .16926 .47985 .15453 Metetra
.817 .752 .791 r
.47985 .15453 .48971 .16926 .5075 .15075 .49774 .13595 Metetra
.818 .752 .791 r
.49774 .13595 .5075 .15075 .52526 .13228 .5156 .11739 Metetra
.818 .752 .791 r
.5156 .11739 .52526 .13228 .54299 .11383 .53343 .09886 Metetra
.701 .716 .86 r
.53343 .09886 .54299 .11383 .56081 .1047 .55132 .08965 Metetra
.568 .657 .897 r
.55132 .08965 .56081 .1047 .57883 .10168 .56939 .08655 Metetra
.568 .657 .897 r
.56939 .08655 .57883 .10168 .59701 .09863 .58762 .08341 Metetra
.568 .657 .897 r
.58762 .08341 .59701 .09863 .61537 .09555 .60603 .08025 Metetra
.568 .657 .897 r
.60603 .08025 .61537 .09555 .63389 .09245 .62461 .07706 Metetra
.568 .657 .897 r
.62461 .07706 .63389 .09245 .65258 .08932 .64336 .07384 Metetra
.64 .692 .883 r
.64336 .07384 .65258 .08932 .6713 .08307 .66214 .06751 Metetra
.694 .716 .866 r
.66214 .06751 .6713 .08307 .68999 .07395 .6809 .05829 Metetra
.694 .716 .866 r
.6809 .05829 .68999 .07395 .70877 .06477 .69976 .04902 Metetra
.65 .578 .76 r
.0034 .46819 .0136 .49234 .02971 .48454 .01952 .46022 Metetra
.689 .597 .747 r
.01952 .46022 .02971 .48454 .04638 .47335 .03624 .44876 Metetra
.707 .604 .739 r
.03624 .44876 .04638 .47335 .06338 .46021 .05329 .43537 Metetra
.713 .605 .735 r
.05329 .43537 .06338 .46021 .08052 .44619 .07047 .42113 Metetra
.716 .606 .732 r
.07047 .42113 .08052 .44619 .09774 .43166 .08773 .40644 Metetra
.718 .606 .731 r
.08773 .40644 .09774 .43166 .11502 .4168 .10504 .39146 Metetra
.719 .606 .73 r
.10504 .39146 .11502 .4168 .13234 .40171 .12239 .37626 Metetra
.72 .606 .728 r
.12239 .37626 .13234 .40171 .1497 .38635 .13978 .36082 Metetra
.72 .605 .728 r
.13978 .36082 .1497 .38635 .16706 .37102 .15716 .3454 Metetra
.715 .603 .73 r
.15716 .3454 .16706 .37102 .18437 .35624 .1745 .33054 Metetra
.715 .602 .729 r
.1745 .33054 .18437 .35624 .20169 .34145 .19184 .31567 Metetra
.68 .584 .741 r
.19184 .31567 .20169 .34145 .21867 .33032 .20883 .30447 Metetra
.678 .583 .741 r
.20883 .30447 .21867 .33032 .23569 .3193 .22585 .29338 Metetra
.67 .578 .744 r
.22585 .29338 .23569 .3193 .2527 .30897 .24286 .28298 Metetra
.655 .571 .748 r
.24286 .28298 .2527 .30897 .26966 .29984 .25983 .27379 Metetra
.655 .571 .748 r
.25983 .27379 .26966 .29984 .28671 .29067 .27687 .26456 Metetra
.658 .572 .747 r
.27687 .26456 .28671 .29067 .30385 .28125 .29401 .25507 Metetra
.667 .577 .745 r
.29401 .25507 .30385 .28125 .32111 .27102 .31127 .24478 Metetra
.667 .577 .745 r
.31127 .24478 .32111 .27102 .33844 .26075 .3286 .23445 Metetra
.667 .577 .745 r
.3286 .23445 .33844 .26075 .35583 .25044 .346 .22408 Metetra
.675 .581 .742 r
.346 .22408 .35583 .25044 .37333 .23938 .3635 .21296 Metetra
.684 .586 .74 r
.3635 .21296 .37333 .23938 .39093 .22741 .38111 .20093 Metetra
.684 .586 .74 r
.38111 .20093 .39093 .22741 .40857 .2154 .39876 .18887 Metetra
.684 .586 .74 r
.39876 .18887 .40857 .2154 .42627 .20336 .41646 .17678 Metetra
.684 .586 .74 r
.41646 .17678 .42627 .20336 .44402 .19128 .43422 .16464 Metetra
.738 .614 .72 r
.43422 .16464 .44402 .19128 .46194 .17314 .45217 .14651 Metetra
.742 .616 .718 r
.45217 .14651 .46194 .17314 .47985 .15453 .47011 .1279 Metetra
.742 .616 .718 r
.47011 .1279 .47985 .15453 .49774 .13595 .48802 .10932 Metetra
.742 .616 .718 r
.48802 .10932 .49774 .13595 .5156 .11739 .50591 .09077 Metetra
.742 .616 .719 r
.50591 .09077 .5156 .11739 .53343 .09886 .52377 .07224 Metetra
.65 .568 .749 r
.52377 .07224 .53343 .09886 .55132 .08965 .54166 .06296 Metetra
.565 .52 .763 r
.54166 .06296 .55132 .08965 .56939 .08655 .55971 .05973 Metetra
.565 .519 .763 r
.55971 .05973 .56939 .08655 .58762 .08341 .57792 .05647 Metetra
.565 .519 .763 r
.57792 .05647 .58762 .08341 .60603 .08025 .59631 .05317 Metetra
.565 .519 .763 r
.59631 .05317 .60603 .08025 .62461 .07706 .61486 .04985 Metetra
.565 .519 .763 r
.61486 .04985 .62461 .07706 .64336 .07384 .63359 .0465 Metetra
.609 .545 .757 r
.63359 .0465 .64336 .07384 .66214 .06751 .65236 .04006 Metetra
.646 .565 .75 r
.65236 .04006 .66214 .06751 .6809 .05829 .67112 .03075 Metetra
.646 .565 .75 r
.67112 .03075 .6809 .05829 .69976 .04902 .68998 .0214 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.22085 .18321 m
.22535 .18799 L
s
[(2)] .21185 .17366 .94259 1 Mshowa
.41889 .10566 m
.42303 .11075 L
s
[(4)] .41061 .09549 .81421 1 Mshowa
.63263 .02197 m
.63634 .02738 L
s
[(6)] .62521 .01115 .68584 1 Mshowa
.125 Mabswid
.0816 .23773 m
.08444 .24046 L
s
.12718 .21989 m
.12997 .22266 L
s
.17359 .20172 m
.17634 .20454 L
s
.26898 .16436 m
.27163 .16727 L
s
.31802 .14516 m
.32061 .14812 L
s
.36798 .1256 m
.37052 .1286 L
s
.47078 .08534 m
.47321 .08844 L
s
.52368 .06463 m
.52605 .06778 L
s
.57762 .04351 m
.57992 .04671 L
s
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576.75, 467.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001da000`40O003h00Oogomogom@Wom003o
OogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom
@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00
ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmo
oD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood0
0?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogo
Ooe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom
003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooHQoo@<00;Ioo@00
ogomR7om00@007omOod00;Eoo@00ogomR7om00@007omOod001ioo@8009Eoo@00ogomR7om0`007Gom
0P0000=oo@000000U7om003oOof9Ood00`00Ooeoo@0IOod30003Ood2002DOod00?mooHUoo@<001Mo
o@8000Ioo@03001oo@0009=oo@00ogomX7om0`0027om00@007omOod0099oo@00ogomWWom0P002gom
00@007omOod0099oo@00ogomVgom0`003Gom00D007omOoeoo@00095oo@00ogomV7om0`0047om00<0
07omOod00Wom00<007omOod0SWom003oOofFOod2000COod00`00Ooeoo@02Ood00`00Ooeoo@2>Ood0
0?mooI=oo@<001Ioo@03001ooGom009oo@03001ooGom08eoo@00ogomTGom0P006Gom00<007omOod0
0gom00<007omOod0S7om003oOof>Ood3000JOod20005Ood00`00Ooeoo@2<Ood00?mooHaoo@8000=o
o@03001ooGom01Eoo@800003DSL007om00Eoo@03001ooGom08]oo@00ogomRGom0`001Gom00<007om
Ood04gom0P000U8g00=>=`0000001Gom0P00S7om003oOof7Ood20009Ood00`00Ooeoo@0@Ood20000
1E8gCSIB=dhgDSL00P0017om00<007om0000S7om003oOof4Ood3000LOod200001DhgDSMB=e8gCSL0
0U8g0P001gom00<007omOod0RGom003oOof2Ood2000MOod300002dhgDSM>=U8gCSMB=dhfDSL0058g
00001Wom00<007omOod0RGom003oOoeoOod3000MOod20002DSL01Dhg001B=e8gCSL00e8g00A>=`00
DSL000Moo@03001ooGom08Qoo@00ogomO7om0`007Wom0P00011B=dhfDSM>=e8g001B=dhgDSM>=U8g
CSMB=`00DSL000Qoo@03001ooGom08Moo@00ogomNWom0P007gom0P0000E>=e8gDSMB=dhg009B=`03
001>=e8g009B=`06CSMB=e8g001>=`0027om00<007omOod0Qgom003oOoegOod3000OOod200005E8g
CSMB=dhfDSM>=e8gCSIB=dhg001>=U8gCSMB=dhfDSL0058gCSH00008Ood00`00Ooeoo@26Ood00?mo
oGEoo@8001moo@<00003BSL004hg00=B=`09CSMB=e8gDSM>=e8g001B=dhg00=B=`05CSL0058gDSL0
0009Ood00`00Ooeoo@25Ood00?mooG9oo@<0009oo@03001ooGom01Uoo@<0000JBQM>=dXGCSQ:5`00
CSIB=dhgDSM>=U8gCSMB=dhf001>=e8gCSIB=dhgDSL0058gCSL000Uoo@03001ooGom08Eoo@00ogom
L7om0P001Gom00<007omOod04gom1P0000=:=dhgBSL00TXg00I>=dXgBSL0058gCSL3DSL01DhgDSMB
=e8g00000e8g00E>=e8gDSL004hg009B=`03001ooGom00Moo@03001ooGom08Aoo@00ogomKGom0`00
5Wom1`00029664HGAQQ65`00BQM>>4XGCSM:5dhhBQM>=dXG001>=e8gCSIB=dhgDSM>=U8gCSMB=`00
DSM>=e8gCSIB=`00DSM>=P8000Yoo@03001ooGom08=oo@00ogomJgom0P005Gom100000E664HG0016
5dHH00=65`05AQQ65dHGAQL00003BSL01dhgBSM:=dXgCSM:=`00009B=`05CSMB=e8gDSM>=`02DSL0
0`00CSMB=`02DSL01dhg00000000E]YFf`0000Uoo@03001ooGom08=oo@00ogomJ7om0`0047om1`00
02U65dHHAQM664HGAQQ65`00AQM664HGAQQ65dHHAQM66000CSM:5dhhBQM>=dXGCSQ:5dhg001B=dhg
DSM>=U8gCSMB=dhfDSL0058gCSIB=dhg00<00004E]YFfeKJ000:Ood00`00Ooeoo@22Ood00>Aoo@<0
07ioo@8000aoo@L00006AQM664HGAQL004HH0dHG00I664HGAQM65dHH0002AQL02DHHAQM65dHGAQQ6
5`00BSM>=`03BSL01ThgBSM:=dXg001>=`=B=`08CSMB=e8gDSM>=e8g001B=`80009Ff`06001FfeKK
E]]FfP001gom0P0000=oo@00Ood0PWom003UOod00`00Ooeoo@1jOod3000:Ood40000<dHGAQP004HH
AQM664HGAQQ65dHHAQM66000AQQ65dHHAQM664HGAQQ65`00AQM664HGAQQ65dHHAQM664HG001:5dhg
BQM>>4XGCSM:5dhh001B=dhfDSM>=e8gCSIB=dhgDSM>=P0200002eKKE]YJfeKJ001FfU[KE]YFfeKJ
00002Gom00<007omOod0PGom003UOod3001gOod30008Ood50002AQL01THHAQM65dHGAQP000965`09
AQQ65dHGAQM664HG00165dHH00=65`05AQQ65dHGAQL00003AQL01THHAQM65dHGAQP0009:=`05CSM:
=dXgBSM>=`02BSL00`00DSM>=`03DSL01ThgDSL00000E]X0009Ff`05E]YFf`00E]]FfP03E]/00eKJ
001oo@08Ood00`00Ooeoo@20Ood00>Eoo@04001ooGom001dOod20007Ood40000>4HHAQL004HGAQQ6
5dHHAQM664HGAQQ65`00AQM664HGAQQ65dHHAQM66000AQQ65dHHAQM664HGAQQ65dHH001664HGAQQ6
5dHHAQM664HG001:5dhhBQM>=dXGCSQ:5dhgBQL004hgDSM>=U8gCSL2000045[KE]YFf`00F]]FfUKK
E]X005KJE]]FfU[KE]YFf`002Wom00<007omOod0Ogom003UOod01000Ooeoo@00LGom0`001Gom1000
00=65dHHAQL00THG00E664HG00165dHH00=65`05AQQ65dHG00166003AQL01THHAQM65dHGAQP00096
5`09AQQ65dHGAQM664HG00165dHH00=65`05AQQ65dHG001>=`03BSL01ThgBSM:=dXgCSL000=B=`80
009Ff`05E]YFfeKKE]/00003E]/01@00E]]FfeKKE]X00eKK00<007omOod01gom00<007omOod0Ogom
003TOod4001`Ood20002Ood01000OoeooGom0P0003]BE`00AQQ65dHHAQM664HGAQQ65dHH001664HG
AQQ65dHHAQM664HGAQP004HHAQM664HGAQQ65dHHAQL004HGAQQ65dHHAQM664HGAQP004HHAQM664HG
AQQ65dHHAQM66000CSM:5dhhBQM>=dXGCSQ:5dhg00<0000BE]]FfU[KE]YFfeKJF]]FfP00E]YJfeKJ
001FfU[KE]YFfeKJ0P0000=Jo000Ood027om00<007omOod0OWom003oOoeFOod30004Ood01000Ood0
0000158g00<004HHAQL00THG00I664HGAQM65dHH0002AQL02DHHAQM65dHGAQQ65`00AQM66003AQL0
1DHHAQM65`00AQP00dHG00I664HGAQM65dHH0002AQL02DHHAQM65dHGAQQ65`00BSM>=`03BSL00dhg
BSM:=`0200001EKJE]]FfeKKE]X00eKK00YFfUKKE]/005KJE]/005KKE]YFf`8000=Fn`03001ooGom
00Qoo@03001ooGom07eoo@00ogomE7om0P001gom0P0003]BEdhfDUM>=e9GCSH004HGAQQ65dHHAQM6
64HGAQQ65`00AQM664HGAQQ65dHHAQM66000AQQ65dHHAQM664HGAQQ65`00AQM664HGAQQ65dHHAQM6
64HG00165dHHAQM664HGAQQ65dHH001>>4XGCSM:5dhh00<0000BD]a>^`00E]YJfeKJE]]FfU[KE]YF
feKJF]]FfP00E]X005KJ0P0000MJo5KkF_aFne[lE_/00009Ood00`00Ooeoo@1mOod00?mooE5oo@<0
00Qoo@03001B=e8g00MB=`0300165dHH00=65`05AQQ65dHG00166003AQL01DHHAQM65dHG00000dHG
00U664HGAQM65dHHAQL004HGAQP00dHG00E664HGAQL004HH00=65`07AQQ65dHGAQM66000BSL00`00
0Tjk00IB^djkC[/005KKE]X3E]/025KJE]]FfeKKE]YFf`00E]/200000eKkF_]Fn`02E_/015[kE_]F
n`002Wom00<007omOod0O7om003oOoe?Ood2000:Ood20000=59GCSIBEdhgDUM>=U9GCSMBE`00AQQ6
5dHHAQM664HGAQQ65dHH001664HGAQQ65dHHAQM664HG00165dHHAQM664HGAQQ65dHH001664HGAQQ6
5dHHAQM664HGAQP004HHAQM664HG1P0001ABg4jkD]a>^e;LC[]Bg4jkD]`005KKE]YJfeKJE]]FfU[K
E]YFfeKJ0`0000]Fne[lE_]Jo5KkF_aFne[lE_]Jo00000Yoo@03001ooGom07]oo@00ogomC7om0`00
2gom00@005YfGWH000QB=`0500165dHGAQM66003AQL01DHHAQL004HGAQP00dHG00E664HGAQL004HH
00=65`05AQQ65dHGAQL00003AQL014HHAQM65dHG1`000TJL00A6VdJLAY`000=>^`05D[]>^djkC[]B
^`02C[/00`00E]]FfP03E]/015KJE]/000000UKk00<005[kE_/00UKk00MJneKkE_]Fne[kE_/0000:
Ood00`00Ooeoo@1kOod00?mooB=oo@<002Aoo@8000eoo@0]001JMUifFWH004hgDUM>=U9GCSMBEdhf
DUM>=`00AQM664HGAQQ65dHHAQM66000AQQ65dHHAQM664HGAQQ65`00AQM664HGAQQ65dHHAQM664HG
00165dHH00@0000MAY]6W4JK0016VdJLAY]:W4JKAYa6VdZL001Bg4jkD]a>^e;LC[]Bg4jkD]a>^e;L
001FfeKJF]]FfP0200004E[lE_]Jo5Kk001Fne[lE_]Jo5KkF_aFne[lE_]Jo5Kk00002Wom00<007om
Ood0NWom003oOodTOod00`00Ooeoo@0POod3000>Ood00`00FWINMP02GWH00`00DSMB=`07DSL00`00
AQQ65`02AQL01THHAQM65dHGAQP000965`09AQQ65dHGAQM664HG00165dHH00965`L000=6W005AY]6
W4JLAY`00003AY`024JKAYa6W4JLAY]6W000D[/3C[/01e:kC[]>^djkD[]>^`00009Ff`800003E_]J
neKk009Fn`05F_/00000E_]Jn`03E_/00e[kE_]Fn`0200000eKk001oo@08Ood2001kOod00?mooB5o
o@D001ioo@<0011oo@0R001JMUifFWINMUYfGWH0059GCSMBEdhfDUM>=e9GCSIBE`00AQQ65dHHAQM6
64HGAQQ65`00AQM664HGAQQ65dHHAQL600008dZLAY]6W4JKBY`004JLAY]:W4JKAYa6VdZLAY]6W000
BYa6VdJLAY]:W4JKAYa6VdZL001Bg4jkD]a>^e;LC[]Bg4jkD]`00`0000QJo5KkF_aFne[lE_]Jo5Kk
0P0000IJo5KkF_aFne[lE_/2000015[lE_]Jo0001gom0P0000=oo@00Ood0NWom003oOodQOod01000
Ooeoo@007Gom0P004Wom00<005YfGWH00Uif00AJMUifGWH000UB=`0300165dHH00=65`05AQQ65dHG
AQL00002AQL40002AY`01@00AYa6W4JLAY/00dJL00E6V`00AYa6W4JK00=6W005AY]6W4JL0016V`03
AY`024JKAYa6W4JLAY]6W000D[/3C[/02E:k00000000D]a>g000E_]Jn`03E_/01U[kE_]Fn`00F_/0
009Fn`05F_/00000E_]Jo003E_/00e[l001oo@09Ood00`00Ooeoo@1hOod00?mooB9oo@03001oo@00
01Yoo@<00003Ood007om011oo@0I001JMUifFWINMUYfGWIJMUif001BEdhfDUM>=e9GCSIBEdhgDUM>
=P00AQM664HGAQP01`0002M:W4JKAYa6VdZLAY/004JKBYa6VdJLAY]:W4JKAYa6V`00AY]6W4JKBYa6
VdJLAY]:W4JK0016VdZLAY]6W4JKBYa6VdJLAY/004jkD]`00`00019Bg4kKD]a>fe;L001Jo5KkF_aF
ne[lE_]Jo5Kk001Fn`00E_/200002E[lE_]Jo5KkF_aFne[lE_/0000;Ood00`00Ooeoo@1gOod00?mo
oB=oo@8001Qoo@8000Eoo@03001ooGom00eoo@03001JMUif009NMP06FWINMUifGWIJMP002U8g1@00
0dJL00E6VdJL0016W4JK00=6W005AY]6W4JL0016V`03AY`01TJKAYa6W4JLAY/00096W005AY]6W4JL
AYa6V`02AY`00`00AY]6W002AY`00dJKAYa6W00400002U;LC]aBg4kLD]a>g5;LC]aBg0000UKk00IJ
neKkE_]Fne[kE_/30003E_/01E[lE_]FneKkF_`00eKk00<007omOod027om00<007omOod0Mgom003o
OodjOod3000FOod05000FWINMUYfGWIJMUifFWINMUYfGWIJMP00CSMBEdhfDUM>=e9GCSH20000:e[K
001:W4JKAYa6VdZLAY]6W4JK0016VdJLAY]:W4JKAYa6VdZL0016W4JKBYa6VdJLAY]:W4JKAYa6V`00
AY]6W4JKBYa6VdJLAY]:W000AYa6VdZL00@0000EA[a6_DJl001>fe;LC]]Bg4kKD]a>fe;LC]/005Kk
F_aFne[lE_]Jo5Kk0080000>F_aFn`00E_]Jo5KkF_aFne[lE_]Jo5KkF_`000]oo@03001ooGom07Io
o@00ogom>7om0P0067om0P000eif00EJMUifGWINMUYf00=NMP03001B=e8g00=B=`800005E]YFfeKJ
0016V`03AY`01TJKAYa6W4JLAY/00096W009AY]6W4JLAYa6VdJL0016W4JK00=6W005AY]6W4JLAY`0
0003AY`00dJKAY`000060007A[`03000D]a>g5;LC]aBg4kLD]a>g5;LC]`000=Fn`05F_/00000E_/0
0002E_/00`00F_aFn`02E_/01U[lE_]FneKkF_aFn`8000Yoo@03001ooGom00Qoo@@006Yoo@00ogom
=Gom0`006Gom018005YfGWH005ifFWINMUYfGWIJMUifFWINMUYf001>=U9GCSL200008E[KE]YJfeKJ
F]]FfP00AY]:W4JKAYa6VdZLAY]6W000BYa6VdJLAY]:W4JKAYa6VdZL0016W4JKBYa6VdJLAY]:W007
000074JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4JmA[a6_@00D]a>fe;LC]]Bg4kKD]a>fe;L001Jo5Kk
0P0000mJo5KkF_`005[lE_]Jo000F_aFne[lE_]Jo5KkF_`00P0000=Fne/L00002Wom00<007omOod0
1gom00<007omOod0Jgom003oOodcOod2000KOod01P00FWINMUif001JMP=NMP05FWINMUifGWIJMP02
GWH300002eKJF]]FfUKKE]YJfeKJE]/004JLAY/00dJL00E6VdJLAYa6W00000=6W006AY]6W4JLAYa6
V`000TJL00=6V`0000000P000dJl00<004JlA[`01TJl00<004JlA[`01dJl00X004kLD]a>g5;LC]aB
g4kLD]a>g0<000=Fn`05F_aFn`00E_]Jo002E_/00`00F_aFn`02E_/200001EKlE_]Jo5Kk00002gom
00<007omOod01gom00<007omOod0JWom003oOod`Ood3000LOod0;000FWINMUYeGWIJMP00FWINMUYf
GWIJMUifFWINMUYfGWH005[KE]YJfeKJF]]FfU[KE]YJfeKJF]/004JLAY]:W4JKAYa6VdZLAY/004JK
BYa6VdJLAY/700008DJlA[e6_4JmA[a6_DJl0016_4JmA[a6_DJlA[e6_4JmA[`004JlA[e6_4JmA[a6
_DJlA[e6_000C]]Bg4kKD]a>f`03000044kLD_`005[lE_]Jo5KkF_`005[lE_]Jo5Kk001Fne[l0P00
00QFne/LE_]K75KkFaaFn`002Wom00<007omOod027om00<007omOod0JGom003oOod^Ood2000OOod0
2@00GWINMUifFWINMP00GWIJMP03GWH05EYfGWINMUif001Vn000F]]FfUKKE]YJfeKJE]]FfU[KE]YF
f`00AYa6V`03AY`00dJKAY`000050005A[`00`00A[a6_007A[`00`00A[a6_007A[`00`00A[a6_006
A[`00`00D]a>g003000024kLD]a>g5;LC]`005KkF_`3E_/01@00E_]FneKkF_`00`0000]Jo5KkE_aF
ne[lE_]Fo5KkF_aFn`0000Yoo@03001ooGom00Eoo@04001ooGom001ZOod00?mooB]oo@<0021oo@0S
001NMUYeGWIJMUifFWD005YfGWIJMUifFWINMUYfGWH006KiI_P005KJF]]FfU[KE]YJfeKJF]]FfU[K
E]X004JKAYa6V`0400009DJmA[`004JlA[e6_4JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4JmA[a6_@00
A[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4Jm00H0000AC]aBo4kLD_a>g5;lC]aBo4kL001Fne[l
E_]Jo000F_aFn`0200003U/LE_/005KkFaaFne/LE_]K75KkFaaFne/L000;Ood00`00Ooeoo@05Ood2
001[Ood00?mooBQoo@<0029oo@05001NMUifGWIJMP03GWH01EYf001NMUifFWH00eif00<006KhI_P0
0VKh00/005KJF]]FfUKKE]YJfeKJE]]FfU[K00@000I6_0030016_4Jl00M6_0030016_4Jl00M6_003
0016_4Jl00E6_0L0000DA[e6_4JmA[a6_@00D]a>g5;LC]aBg4kLD]a>g5;LC]`005KkF_aFn`<0000?
E_]Fo5KkF_`005KlE_]Jo5KkE_aFne[lE_]Fo5Kk008000Uoo@8007Aoo@00ogom9Wom0P000gom00<0
07omOod07Wom01l005ifFWENMUYfGWIJMEifFWINMP00GWIJMUifFWINMP00I_UVn6[iI_QVnFKh001F
fU[KE]YJfeKJF]]FfP0200008U[kE_/004JlA[e6_4JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4JmA[a6
_@00A[e6_4JmA[a6_DJlA[e6_000A[a6_DJl100001Y6_DJlA[d004JmA[a6_DJlA[e6_4JmA[`004kL
D_a>g5;lC]aBo4kLD_a>g5;l001Jo5Kk0P0000mK75KkFaaFne/LE_]K7000FaaFne/LE_]K75KkFa`0
0P0000=Fne/L00001Wom0P000Wom00<007omOod0LGom003oOodSOod30006Ood00`00Ooeoo@0LOod0
1@00GWINMUifFWH00eif00EJMUifGWH005Yf00=NMP03FWH006Kh00IVn005001FfU[KE]YFf`020000
1EKkF_]Fne[k00002DJl00<004JlA[`01TJl00<004JlA[`00dJl1`0001]6_4JmA[a6_DJlA[e6_000
A[a6_DJlA[e6_4JmA[a6_DJl001>g5;LC]aBg4kLD]a>g5;LC]`00`0000mFn`00E_]Fo5KkF_aFneKl
E_]Jo000E_aFne[lE_/00P0000EJo5KkE_aFn`0000]oo@03001ooGom071oo@00ogom8Gom0P009gom
0P0001]JMEifFWINMUYeGWIJMUifFWENMUYf001JMUifFWH006KhJ_UVn6KiI_QZnFKhI_T005[KE]X0
0P0001UJneKkF_]Fne[kE_]Jn`00A[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4JmA[a6_@060000
7dJlA[e6_4JmA[`004JlA[e6_4JmA[a6_DJlA[e6_000A[a6_DJlA[e6_4JmA[a6_DJl001>g5;lC]aB
o4kL00<0000@C]aBo000Fa`005/LE_]K75KkFaaFne/LE_/005KkFa`2000025KkFaaFne/LE_]K75Kk
000:Ood00`00Ooeoo@1`Ood00?mooAioo@<002Qoo@05001NMUif001JMP03GWH02UYfGWINMUifFWIN
MP00GWIJMP002VKh0P0000]Fne[kE_]JneKkF_]Fne[kE_]Jn`0000Q6_0040016_4JlA[`400008TJm
A[`004JlA[e6_4JmA[a6_DJlA[e6_000A[a6_DJlA[e6_4JmA[a6_@00A[e6_4JmA[a6_DJlA[e6_4Jm
001Bg4kL0`00015>g5;lC]aBo4kL001Fn`00E_]Jo5KkE_aFne[lE_]Fo5Kk0080000;E_aFne[lE_]F
o5KkF_aFneKlE_/0000:Ood00`00Ooeoo@1_Ood00?mooAaoo@8002Yoo@0@001NMUYeGWH005ifFWEN
MUYfGWIJMEifFWINMUYeGWH200007FKhJ_UVn6KiI_QZnFKhI_UVn6[i001[6@00F_]Fne[kE_]JneKk
F_]Fne[kE_/004JlA[e6_4JmA[`01`000296_4JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4JmA[a6_@00
A[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4JmA[a6_@@00009C]aBo4kLD_e>g5;lC]aBoDkL0080
0007FaaFne/LE_]K75KkFa`00P0000eFn`00E_]K75KkFaaFne/LE_]K75KkFa`0000;Ood00`00Ooeo
o@1^Ood00?mooAUoo@<002]oo@06001NMUifGWIJMP000Uif00EJMUifGWINMUYf00=NMP03FWH006Kh
00UVn00?001W6FLHJaT005[kE_]JneKkF_]Fne[kE_]JneKk00D0000UA[a6_DJlA[e6_000A[a6_DJl
A[e6_4JmA[a6_@00A[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4JmA[a6_DJl0016_4JmA[`01000
0dJm00X005;lC]aBo4kLD_a>g5;lC]aBo0800005E_]Fo5KkF_aFn`02000045[lE_]Fo000F_aFneKl
E_]Jo5KkE_aFne[lE_]Fo0002Wom00<007omOod0KWom003oOodGOod2000]Ood0:P00GWIJMEifFWIN
MUYe001JMUifFWENMUYfGWIJMEifFWH006Kh001Vn6KiI_QZnFKhI_UVn6[i001[6FLHJaUW6000E_]J
neKkF_]Fne[kE_]Jn`80000TE_/004JlA[e6_4JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4JmA[a6_@00
A[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4Jm1P0001I2_4KMA[a6gD:lA]e6_000C]aBoDkLD_a>
g5;mC]aBo4kLD_d005/LE_]K7080000?E_]K75KkFaaFne/L001K75KkFaaFne/LE_]K75Kk00800003
Fa`007om00Uoo@03001ooGom06eoo@00ogom57om0`00;Wom00D005ifGWINMUYf00=NMP05001NMUif
GWIJMP03GWH01EYf001Vn6Kh00001fKh00d006LIIaQ[6FLHIaUW6000E_]JneKkF_]Fn`0200007e[k
E_]Jne[k0016_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_4JmA[a6_DJlA[d004JmA[a6_DJlA[e6_4Jm
00L000=6_@05A[`004JmA[e6_003A[d03dJlA[e6_@00C]aBo4kLD_a>g5;lC]aBo4kL001Fn`020000
3eKlE_]Jo5KkE_aFne[lE_/005KkF_aFneKlE_]Jo002000015KlFaaFn`002gom00<007omOod0K7om
003oOodBOod2000`Ood0:000GWIJMEifFWINMUYeGWIJMP00FWENMUYfGWIJMEifFWH006KhJ_UVn6Ki
001ZnFKhI_UVn6[iI_P006LHJaUW66/IIaQ[6FLH001Fne[k0P0001eFne[lE_]Jo5KkF_`004JmA[a6
_DJlA[e6_4JmA[a6_@00A[e6_4JmA[a6_DJlA[e6_000A[a6_DJl00@0000OA]e6_4KM0016gDJlA]e2
_4KMA[a6gD:l0016_4KM@[a6gDJlA]e2_4KMA[`004kLD_e>g5;lC]aBoDkLD_`00P0000mFne/LE_]K
75KkFaaFne/LE_]K75Kk001Fne/LE_/00P0000MK75KkFaaFne/LE_/0000:Ood00`00Ooeoo@1/Ood0
0?moo@moo@<0035oo@05001NMUifGWIJMP03GWH01EYfGWH005ifFWH00eif00=JMP00I_P01FKh00<0
06KhI_P00VKh00X006LHJaUW66LIIaQ[6FLHIaUW608000=Jn`0EE_]Jne[kF_]Fne[k0016_DJlA[e6
_4JmA[a6_DJl0016_4JmA[a6_DJl00L00005A[a6_DJmA[e6_002A[d00`00A[a6_@02A[d01DJlA[e6
_DJm00000dJm00E6_4JmA[e6_DJl0096_@06001>g5;lC]aBo4kL0P0000mBo000001Fne[lE_]Fo5Kk
F_aFneKlE_]Jo000E_`00P0000YFneLLE_aK75KkEaaFo5/LE_/000Yoo@03001ooGom06]oo@00ogom
37om0`000gom00<007omOod0;Gom03X005ifFWENMUYfGWIJMEifFWINMUYeGWH005ifFWENMUYf001V
n6[iI_QVnFKhJ_UVn6Ki001ZnFKh001W66/IIaQ[6FLHJaUW66/IIaP006LH001Fne[lE_]Jo5KkF_aF
ne[lE_]Jo000A[e6_4JmA[a6_@P0000U@[a6gDJlA]e2_000A[a6gD:lA]e6_4KM@[a6gDJl0012_4KM
A[a6gD:lA]e6_4KM0016gDJlA]e2_4KMA[a6gD:lA]d005;lC]`00`0001e>g5;mC]`004kL001Fne/L
E_]K75KkFaaFne/LE_]K7000FaaFne/LE_]K75KkFaaFne/LE_]K700000]oo@03001ooGom06Yoo@00
ogom2Wom0P00=Gom0P000Uif00EJMUifGWINMUYf00=NMP06FWH005ifGWIJMP002FKh018006Kh001W
66/IIaQW6FLHJaUW66LIIaP006LHJaT005[kE_/3F_/01UKkF_]Jne[kE_]Jn`D00006A[e6_4JmA[d0
04Jl0dJm00E6_4JmA[e6_@0000=6_@05A[a6_DJmA[e6_002A[d00`00A[a6_@02A[d01DJlA[e6_DJm
00000dJm00=6_4Jm00001@00015>o5;lC_aBo4klD_`005;l001Fo5KkF_aFneKlE_]Jo5Kk0080000>
Fa`005LLE_aK75KkEaaFo5/LE_]G75KlFa`000Yoo@03001ooGom06Yoo@00ogom1gom0`00=Wom03D0
05ifFWD005YfGWIJMEifFWINMUYeGWIJMUif001NMUYf001Vn6[iI_QVnFKhJ_UVn6KiI_QZnFKh001W
66/IIaQ[6FLHJaUW66/IIaP006LHJaUW66/I001Jo5KkF_aFne[lE_]Jo5Kk0080000SF_`004KM@[a6
gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]d004KMA[a6gD:lA]e6_4KM@[a6g@00A]e2_4KMA[a6
g@0900005DKMA[a6gD:lA]d005;lC]aBoDkLD_a>g000C]aBo000FaaFne/LE_]K700200003EKkFaaF
n`00E_]K75KkFaaFne/LE_]K75Kk00800003Fa`007om00Ioo@800003Ood007om06Yoo@00ogom1Gom
0P00>7om00D005ifGWINMP0000=NMP05FWINMUifGWIJMP03GWH2000;I_P04@00IaP006LHIaUW66/I
IaQW6FLH001W66/IIaU[6FLH00000U[k00AFne[kF_]Jn`80009Jn`05E_/004JmA[e6_003A[d01DJl
A[d004JmA[`00dJm00E6_4JmA[e6_@0000=6_@04A[a6_DJmA[d700000dJmA[a6_@02A[d01@00A[e6
_DJmA[`00dJm00m6_000C_aBo4klD_a>o5;l001Bo4klD_`005KlE_/00P0000eG75KlFaaFneLLE_`0
05KkEaaFo5/LE_]G7002000015KkEaaFo0002gom00<007omOod0J7om003oOod2Ood3000iOod0<`00
GWIJMEifFWINMP00GWIJMUifFWENMUYfGWIJMEifFWH006KhJ_UVn6KiI_QZnFKhI_UVn6[iI_P006LH
JaT006/IIaQ[6FLHJaUW6000IaQ[6FLHJaUW66/IIaP005KkF_aFn`02000075[lE_]Jo5KkF_aFn`00
A[a6gD:lA]e6_4KM@[a6g@00A]e2_4KMA[a6gD:lA]e6_000@[a6gDJl10000216gD:lA]d004KM@[a6
gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]e2_000C]aBo4kLD_e>g000C]aBoDkL0`0000eFne/L
E_]K75KkFaaFne/LE_/005KkFaaFn`0200001e/LE_]K75KkFaaFn`0000Yoo@03001ooGom06Qoo@00
ogom0P00?7om00@005ifGWIJMP9NMP03001JMUif009NMP08FWINMUifGWIJMP00I_P000UVn00E001W
66/IIaQW6@00JaUW66LIIaP006LHJaUW6F/IIaQ[6FLIJaT005[k00800005E_]Jne[kF_]Fn`03F_/0
1EKk0016_DJmA[`00dJm00E6_4Jm0016_DJl00=6_@H00096_@06A[a6_DJmA[e6_0000TJm00E6_4Jm
A[e6_DJl0096_@030016_4Jm0096_@0:A[a6_DJmA[e6_000C_aBo4klD_`400003TklD_`005LLE_aK
75KkEaaFo5/LE_]G7000Fa`200002UKlFaaFneLLE_aK75KkEaaFo0002Wom00<007omOod0Igom003l
Ood3000mOod0@`00FWENMUYfGWIJMEif001NMUYeGWIJMUifFWENMUYf001Vn6[i001VnFKhJ_UVn6Ki
I_QZnFKh001W66/IIaQ[6FLHJaT006/IIaP006LHJaUW66/IIaQ[6FLHJaUW66/I001Jo5KkF_aFne[l
E_]Jo5KkF_aFne[l0016gDJlA]e2_4KM00T0000TA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]e2_000
A[a6gD:lA]e6_4KM@[a6gDJl0012_4KMA[a6gD:lA]e6_4KM001BoDkL0`0001e>g5;mC]aBoDkL001F
ne/LE_]K75KkFaaFne/LE_]K7000FaaFne/LE_]K75KkFaaFne/LE_]K700000]oo@03001ooGom06Io
o@00nWom0P00?gom00@005ifGWIJMP=NMP05FWINMP00GWIJMP03GWH00eYf001Vn003I_P00`00I_QV
n004I_P06000IaQ[6FLHIaUW66/IIaP006LH001W66/IIaU[6FLHJaUW6F/IIaQ[6@00JaT000=Jn`05
E_]Jne[kF_]Fn`03F_/50003A[d01DJlA[d004JmA[`00dJm00E6_4Jm0016_DJl00=6_@06A[a6_DJm
A[e6_0000TJm00U6_4JmA[e6_DJlA[d004JmA[`00dJm1P00015>o5;l001Bo4klD_a>o5;lC_`005Kk
EaaFo5/LE_]G75Kl0080000>Ea`005/LE_]G75KlFaaFneLLE_aK75KkEa`000Yoo@03001ooGom06Io
o@00mgom0`00@7om03h005YeGWIJMUifFWENMUYfGWIJM@00FWINMUYeGWIJMP00I_QZnFKhI_UVn6[i
001VnFKhJ_UVn000IaQ[6FLHJaUW66/IIaQ[6FLH001W66/IIaQ[6FLHJaUW66/IIaQ[6@00JaUW66/I
001Jo5KkF_aFne[lE_]Jo5Kk0P0002=K7000A]e6_4KM@[a6gDJlA]e2_000A[a6gD:lA]e6_4KM@[a6
g@00A]e2_4KMA[a6gD:lA]e6_4KM0016gDJlA]e2_4KM00T0000EA]e2_4KMA[a6g@00D_e>g000C]aB
oDkLD_e>g5;mC]`005KkFaaFne/L0080000=E_]K75Kk001Fne/LE_]K75KkFaaFne/LE_/00P0000=K
7000Ood02Gom00<007omOod0IGom003eOod20002Ood00`00Ooeoo@0mOod01000GWINMUYf0eif00IJ
MUifGWINMUYf0002GWH00eYf001Vn007I_P06`00I_QVn000IaQ[6FLHIaUW66/IIaQW6FLH001W6000
IaU[6FLHJaUW6F/IIaQ[6@00JaUW6@02JaT00`00E_]Jn`02F_/01EKkF_]Jn`00E_/00U[k00<004Jl
A[d00TJm00I6_4JmA[e6_DJl0002A[d02DJlA[e6_DJmA[a6_@00A[e6_003A[d00dJlA[d000060000
74KMA[e6gDJmA]d004KMA[e6gDJmA]e6_DKMA[d004klD_`005;lC_aBo4klD_a>o5;l001K75Kk0P00
00eK75KkEaaFo5/LE_/005KlFaaFneLLE_aK7002000015KlFaaFn`002gom00<007omOod0I7om003b
Ood30013Ood20000>eifFWINMUYeGWIJMUifFWENMUYfGWH005ifFWH006KhJ_UVn6KiI_QZnFKhI_UV
n000I_P006LHJaUW66/IIaQ[6FLHJaUW6000IaQ[6FLH001W66/IIaQ[6FLHJaT006/IIaQ[6FLHJaUW
6000E_]Jo5KkF_`00P0001]Fne/LE_]K75Kk0012_4KMA[a6gD:lA]e6_4KM@[`004JlA]e2_4KMA[a6
gD:l0016_4KM@[`010000216gDJlA]d004KMA[a6gD:lA]e6_4KM@[`004JlA]e2_4KMA[a6gD:lA]e6
_000C]`004kLD_e>g5;mC]aBoDkL0`0000eFne/LE_]K75KkFaaFne/LE_/005KkFaaFn`0200001e/L
E_]K75KkFaaFn`0000Yoo@03001ooGom06Aoo@00kgom0`00AGom00@005YfGWH000=NMP05FWINMUif
GWIJMP03GWH2000;I_P06000IaQ[6FLHIaUW66/IIaQW6FLH001W66/IIaU[6@00JaUW6F/IIaQ[6@00
JaUW6@=[6@05IaU[6F/I001Fn`0200001U[lE_]Jne[kF_aFn`9Jn`030016_4Jm0096_@05A[a6_DJm
A[d00003A[d00dJlA[d0000500006dJmA]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKMA[d004Jm
A]e6_DKMA[e6gDJmA]e6_@02000015;lC_aBo4kl0`0000i>o5;l001K75KkEaaFo5/LE_]G75KlFa`0
05LL0P0000YFne/LE_aK75KkFaaFo5/LE_/000Yoo@03001ooGom06=oo@00kGom0P00Agom04d005Yf
GWIJMP00FWENMUYfGWIJMEifFWINMUYeGWIJMP00I_QZnFKhI_UVn6[iI_QVnFKhJ_UVn000IaP006LH
JaUW66/IIaQ[6FLH001W66/IIaQ[6FLHJaT006/IIaQ[6@00JaUW66/IIaQ[6FLHJaUW66/IIaP005Kk
FaaFne/LE_]K75KkFaaFne/L0016gD:lA]e6_4KM00T0000QA]e6_4KM@[`004JlA]e2_4KMA[a6gD:l
A]e6_000@[a6gDJlA]e2_4KMA[a6gD:l0016_4KM@[a6gDJlA]e2_4KM0080000QC]`00000001>o5;m
C_aBoDkl001Fne/LE_]K75KkFaaFne/LE_]K7000FaaFne/LE_]K75KkFaaFne/LE_]K700000Yoo@03
001ooGom06=oo@00jWom0`00Agom0P0000MJMUifFWINMP00GWIJMP03GWH025YfGWINMUifFWH006Kh
0009I_P06000IaQ[6FLH001W66/IIaQW6FLHJaT006/IIaU[6FLHJaUW6F/I001[6@00JaUW6@=[6@09
IaU[6F/IJaUW6@00JaT005Kk009Jn`07F_aFne[kF_]Jo5KkF_/01@0002M6gDJmA]e6_DKM0016gDJm
A]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJmA]d004KMA[e6gDJm
A]d01P00015>o5;lC_aBo4klD_a>o5;lC_`005KlFaaFneLLE_aK75Kk0080000<Fa`005/LE_aK75Kk
FaaFo5/LE_]K75Kl0P002Wom00<007omOod0HWom0030Ood4000TOod20019Ood0B@00GWIJMUifFWIN
MUYfGWH005ifFWENMUYfGWIJMEifFWH006KhJ_T006KiI_QZnFKhI_UVn6[iI_P006LHJaUW66/I001[
6FLHJaUW66/I001[6FLHJaUW66/IIaQ[6FLHJaT006/IIaQ[6FLHJaUW66/IIaQ[6FLH001W66/I001K
75KkFaaFne/LE_]K75Kk0080000SFa`004KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]d0
04KMA[a6gD:lA]e6_4KM@[a6g@00A]e2_4KMA[a6g@0900005DKMA[a6gD:lA]d005;mC_aBoDklD_e>
o5;mC_aBoDkl001Fne/LE_]K7002000035KkFaaFne/L001K75KkFaaFne/LE_]K70800003E_]K7000
00Moo@800003Ood007om069oo@00`7om00<007omOod08Wom0`00BWom00X005ifFWINMUYfGWIJMUif
FWH0009NMP06FWINMUifGWIJMP0016Kh00<006KhI_P016Kh01P006LHJaUW66LIIaQ[6@00IaUW66/I
001[6FLIJaUW66/IIaU[6FLHJaT006/I0003JaT01VLIJaU[6F/IIaT0009[6@05IaU[6@00F_aFn`02
F_/01E[lE_/005[kF_`00U[k01/004KMA[e6gDJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJmA]d004KM
A[e6gDJmA]e6_DKMA[d01P0000i6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJm0P0000aBo4klD_a>
o5;lC_aBo4klD_`005LLE_`2000035/LE_aK75KkFaaFo000E_]K75KlFaaFn`800005FaaG6e/LEa`0
000:Ood00`00Ooeoo@1QOod00<5oo@03001ooGom01moo@8004aoo@0l001NMUYfGWIJMUifFWINMUYf
GWH005ifFWINMUYeGWIJMP00I_QZnFKhI_UVn000I_QVnFKhJ_UVn6Ki001[6FLHJaUW66/IIaQ[6@00
JaT006/IIaQ[6FLHJaUW66/IIaQ[6@00JaUW6000IaQ[6FLHJaUW66/I0P0000YW66/IIaQ[6FLHJaT0
05/LE_]K7080000LE_]K75KkFaaFn`00A[a6gD:lA]e6_4KM@[a6gDJl0012_4KMA[a6gD:lA]e6_4KM
0016gDJlA]d4000054:lA]d004KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]d2000024kl
D_e>o5;mC_aBoDklD_d4000035KkFaaFne/LE_]K75KkFaaFn`00E_]K70800008E_]K75KkFaaFne/L
E_/000Yoo@03001ooGom061oo@00`Wom00<007omOod06gom0`00CGom00d005ifFWINMUYfGWIJMUif
FWINMUYfGWH00003GWH00eYf001Vn006I_P00`00I_QVn002I_P05`00JaUW66LIIaQ[6FLHIaUW66/I
001[6FLIJaUW66/IIaU[6FLHJaT006/IIaT00V/I00<006LIJaT00V/I00D006/IJaU[6FLI00=[6@03
IaT005[k0080009Jn`0EF_aJne[kF_]Jo5[k0016_DKMA[e6gDJmA]e6_DKM0016gDJmA]e6_DKM00L0
000NA]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJm0016_@00C_aB
o4kl100000iBo4klD_`005/LE_aK75KkFaaFo5/LE_]K75Kl0P0000]K75LLFaaG6e/LEaaK75LKFaaG
700000Yoo@03001ooGom05moo@00`7om00@007omOod001Yoo@80009oo@03001ooGom04Uoo@<0001G
FWINMUYfGWIJMUifFWINMUYfGWIJMP00FWENMUYf001Vn6[iI_QVnFKhJ_UVn6KiI_P006KhI_T006/I
IaQ[6FLHJaUW66/IIaQ[6@00JaT006/IIaQ[6FLHJaUW66/I001[6FLHJaUW66/IIaP006LHJaT006/I
IaQ[6FLHJaUW66/IIaQ[6FLH001Fne/LE_]K75KkFaaFne/LE_]K75Kk0016_4KM@[a6gDJl00P0000O
A]e2_4KMA[a6g@00A]e6_4KM@[a6gDJlA]e2_000A[a6gD:lA]e6_4KM@[a6gDJl0012_4KMA[a6gD:l
A]d01P00011>o5;mC_aBoDklD_e>o000E_]K75KkFaaFne/LE_]K7080000=E_/005KkFaaFne/LE_]K
75KkFaaFne/L00002Wom00<007omOod0Ggom0031Ood2000HOod30004Ood00`00Ooeoo@18Ood04`00
EUIFEeIG001JMUifFWINMUYfGWIJMUifFWINMP00GWIJMP0000YVn00I001Vn000JaUW66LIIaQ[6FLH
IaUW66/I001[6FLI001W66/IIaU[6FLHJaT006/IIaT00f/I00EW6F/I001[6@0000=[6@05IaU[6F/I
JaUW6@02JaT01@00IaT005[kF_`00e[k00EJo5[kF_]Jne[l00H0000TA[e6gDJmA]d004KMA[e6gDJm
A]e6_DKMA[e6g@00A]e6_DKMA[e6gDJmA]e6_@00A[e6gDJmA]e6_DKMA[e6g@00A]e6_DKM100002=6
_DKMA[d004klD_a>o5;lC_aBo4klD_a>o000E_]K75KlFaaFne/L001K75LKFa`005/LEa]K75LLFaaG
6e/LEaaK75LK008000Yoo@03001ooGom05ioo@00fGom0P00D7om0P00011FEUIGDUIFE`00GWIJMUif
FWINMUYfGWIJMUifFWINMP800011I_QZnFKhI_UVn6[iI_QVnFKhJ_UVn6Ki001[6FLHJaUW66/IIaQ[
6FLHJaT006/IIaQ[6FLH001W66/IIaQ[6@00JaUW66/IIaQ[6FLHJaUW66/I001[6FLHJaUW66/IIaQ[
6FLHJaUW6000IaQ[>FLH001Fne/LE_]K75KkFaaFn`0200008e/LE_/004JlA]e2_4KMA[a6gD:l0016
_4KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]d004KMA[a6gD:lA]d01`0001I6gDJlA]d0
04KMA[a6g@00D_e>o5;mC_aBoDklD_e>o5;mC_`005KkFaaFn`80000=FaaFne/LE_]K7000FaaFne/L
E_]K75KkFa`00P0000=Fne/L00002Wom00<007omOod0GGom003FOod3001AOod00`00EUMFEP03EUL0
3UIFEUL005ifFWINMUYfGWIJMUifFWINMUYf000<I_P05`00JaT006LIIaQ[6FLHIaUW66/I001[6FLI
JaUW66/IIaT006LHJaT006/IIaT00f/I00UW6F/IJaU[6@00JaT006/IIaT00f/I00EW6F/IJaT006LI
00=[6@04001Jne[kF_`2F_/200007E[kFa]Jne/L0016gDJmA]e6_DKMA[e6gDJm0016_DKMA[e6gDJm
A]e6_DKMA[d004JmA]e6_DKMA[d0200001]6gDJmA]e6_DKM0016gDJmA]e6_@00A[e6gDJmA]d005;l
C_aBo4klD_a>o5;lC_aBo000Fa`00P0000eG75/LEa]K75LLFaaG6e/L001K75LKFaaG700200001E/L
EaaK75LK00002Wom00<007omOod0GGom003COod3001BOod20000DUIGEUIFEe9FEUMFEUIGDUH005Yf
GWIJMUifFWINMUYfGWIJMP00I_P006KhI_UVn6[iI_QVnFKhJ_UVn6Ki001[6FLH001W66/IIaQ[6FLH
JaT006/IIaQ[6FLHJaUW66/I001[6@00JaUW66/IIaQ[6FLHJaUW66/I001[6FLHJaT006/IIaQ[6FLH
JaUW6000IaQ[>FLHJcUW66/i001K75Kk0P0001QK75KkFaaFne/LE_]K7000A]e6_4KM@[a6gDJlA]e2
_000A[a6gD:lA]e6_4KM@[`7000084:lA]e6_4KM0016gDJlA]e2_4KMA[a6gD:l0016_4KM@[a6g@00
A]e2_4KMA[a6g@00D_e>o5;mC_aBoDklD_d300003E/LE_]K75KkFaaFne/LE_]K75Kk001Fne/L0080
0008E_]K75KkFaaFne/LE_/000Yoo@03001ooGom05aoo@00dGom0P00E7om00@005IGEUMFEP=FE`0A
EUIFEeIGEUL005ifFWINMUYfGWIJMUifFWH006KhI_T00009I_P05`00JaUW66LIIaP006LHIaUW66/I
001[6FLIJaUW66/IIaU[6FLHJaT006/IIaT00f/I00EW6F/IJaU[6@0000=[6@05IaT006/IJaUW6@02
JaT00`00IaU[6@02JaT016LIJaU[6F/I0P0001IJne/LF_]K6e[kFaaJne/KF_]K7000A]e6_DKMA[e6
gDJmA]d004KMA[e6g@@0000SA[e6gDJm0016_DKMA[e6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJm
0016_DKMA[d004JmA]e6_DKMA[d004klD_a>o00400003U;lC_aBo000FaaG6e/LEaaK75LKFaaG75/L
Ea/200002e/LEa]K75LLFaaG6e/LEaaK75LK00002Wom00<007omOod0Fgom003>Ood3001DOod30000
7UIGEUIFEe9FEUMFEUIGDUIFEeIFEUL005ifFWINMUYfGWIJMP00I_QVnFKhI_T006[iI_QVnFKhJ_UV
n0800014JaUW66/IIaQ[6FLH001W66/I001[6FLHJaUW66/IIaQ[6FLHJaT006/I001[6FLHJaUW66/I
IaQ[6@00JaUW66/IIaQ[6FLH001W66/IIaP006LHJcUW66/iIaQ[>FLHJcT006/i001K75KkFaaFne/L
E_]K75KkFaaFn`00@[a6gDJlA]e2_0H0000RA]e2_4KMA[a6gD:lA]d004KM@[a6gDJlA]e2_4KMA[`0
04:lA]e6_4KM@[a6gDJlA]e2_000A[a6g@00A]e6_4KM@[`5000044klD_e>o5;mC_aBoDklD_d005/L
E_]K75KkFaaFne/L0P0000eFn`00E_]K75KkFaaFne/LE_]K75KkFa`0000:Ood00`00Ooeoo@1KOod0
0<aoo@8005Ioo@05001FEeIGEUL00003EUL01EIFEUMFEeIGEUH00UIG00T005YfGWIJMUifFWH006Kh
I_T00fKh00=Vn@00I_P00fKh01`006LHJaUW66LIIaQ[6FLHIaT006/I001[6FLIJaUW66/IIaU[6FLH
JaT006/IIaU[6@00JaUW6@=[6@05IaT006/IJaUW6@03JaT01FLI001[6@00IaT00f/I00EW6F/IJaU[
6@00009[6@0;001Jne/KF_]K75[kFa]Jne/LF_]K6`0600008dJmA]e6_DKM0016gDJmA]e6_DKMA[e6
gDJmA]d004KMA[e6gDJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJmA]d004KMA[d01@0001=6_DKMA[d0
04klD_a>o5;lC_aBo4klD_a>o000EaaK75LKFaaG700200003U/LEaaK7000FaaG75/LEa]K75LLFaaG
6e/LEa`20008Ood3001LOod00<Uoo@<005Moo@1Q001FEe9FEUMFEP00DUIFEeIFEUMBEUIGEUIFEe9F
EUL005ifFWINMUYfGWH006KiI_QVnFKhI_UVn6Ki001ZnFKh001W66/IIaQ[6FLHJaUW66/IIaQ[6@00
JaUW66/IIaQ[6FLHJaUW66/I001[6FLHJaUW6000IaQ[6FLHJaUW6000IaQ[6FLHJaUW66/IIaQ[6FLH
001W66/iIaQ[>FLHJcUW66/i001[>FLHJcUW6000E_]K75KkFaaFne/LE_/00P0002AK75Kk0012_4KM
A[a6gD:lA]e6_4KM0016gDJlA]e2_4KMA[a6gD:lA]d004KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM
@[`600005DKM@[a6gDJlA]e2_4KM001BoDklD_e>o5;mC_aBoDklD_e>o000E_]K700200003UKkFaaF
ne/LE_]K7000FaaFne/LE_]K75KkFa`200000eKkFa`0000:Ood00`00Ooeoo@1IOod00<Moo@80009o
o@03001ooGom05=oo@8000=FE`05EUIFEeIG001FEP03EUL035IFEUMFEeIGEUIFE`00GWIJMUif001V
n@=Vn00NI_UVn6KhI_P006Kh001W66/IIaQW6FLHJaUW66LIIaQ[6@00JaT006/IIaQ[6FLIJaUW66/I
001[6FLI0f/I00IW6@00JaU[6FLI0002JaT01FLIJaU[6F/IIaT00V/I00<006LI00000V/I00EW6F/I
JaU[6@0000=[6@08IaU[6F/I001Jne/KF_]K7080000MF_]K75[kFa/004KMA[e6gDJmA]e6_DKMA[d0
04JmA]e6_DKMA[e6gDJmA]e6_@00A[e6gDJmA]e6_@09000014JmA]e6_DKM0P000196_DKMA[e6gDJm
A]e6_DKM001Bo4klD_a>o5;lC_aBo4klD_`300003U/LEa]K75LLFaaG6e/LEaaK7000FaaG75/LEa/2
00001E/LEa]K75LL00002Wom00<007omOod0FGom0034Ood30004Ood00`00Ooeoo@1BOod0H000EUIF
Ee9FEUMFEUIGDUIFE`00EUMBEUIGEUIFEe9FEUMFEUIGDUH005YfGWH006KiI_QVnFKhI_UVn6KiI_QV
nFKh001W66/IIaQ[6FLHJaUW66/IIaQ[6@00JaUW66/I001[6FLHJaUW66/IIaP006LHJaUW66/IIaQ[
6FLH001W6000IaQ[6FLHJaUW66/IIaQ[6FLH001W66/i001[>FLHJcUW66/iIaP006LHJcUW66/iIaQ[
>@00FaaFn`80000FFaaFne/LE_]K75KkFa`004KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM@[`90000
7TJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]d004KMA[a6gD:lA]e6_4KM@[a6g@00D_e>o5;mC_aB
o@<0000?D_d005/LE_]K75KkFaaFne/LE_]K75Kk001Fne/L00800008E_]K75KkFaaFne/LE_/000Yo
o@03001ooGom05Qoo@00`Wom0P0027om00<007omOod0D7om00<005IFEUL00UIG00IFEUIGEUMFEeIF
0002EUL01EIFEUMFEeIGEUH00eIG00AFEP00001Vn@=Vn00NI_UVn6KhI_QVnFKh001W6@00IaQW6FLH
JaUW66LIIaQ[6@00JaUW6F/IIaP006LIJaUW66/IIaT006LI0f/I00IW6F/IJaU[6FLI0002JaT01FLI
JaU[6F/IIaT00V/I00<006LIJaT00V/I00H006/IJaU[6FLI0002JaT01VLIJaU[6F/IIaU[6@80000B
F_]K6e[kFaaJne/KF_]K75[kFa/004KMA[e6gDJmA]e6_DKM1P0002A6_DKMA[e6gDJm0016_DKMA[e6
gDJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKMA[d004klD_`300003e;l
C_aBo4klD_`005/LEaaK75LKFaaG75/LEa]K700300002U/LEaaK75LKFaaG75/LEa]K70002gom00<0
07omOod0Egom002oOod3001KOod30000KUIGDUIFEeIFEUMBEUIGEUIFEe9F001FEUIGDUIFEeIFEUMB
EUIGEUIFE`00I_UVn6KiI_QVnFKhI_UVn6KiI_P006LHJaT006/IIaQ[6FLHJaUW66/I001[6FLHJaUW
66/IIaP006LHJaUW6000IaQ[6FLHJaUW66/IIaQ[6FLH001W6000IaQ[6FLHJaUW66/IIaP006LHJcUW
66/iIaQ[>@00JcUW6000IaQ[>FLHJcUW66/iIaQ[>@00JcT005/LE_]K75KkFaaFne/LE_]K75Kk0016
_4KM@[`400007DKMA[`004:lA]e6_4KM@[a6gDJlA]d004KMA[a6gD:lA]e6_4KM@[a6g@00A]e2_4KM
A[a6gD:lA]d00P0000E2_4KMA[a6gD:l00H0000@D_e>o5;mC_aBoDklD_e>o000E_]K75KkFaaFne/L
E_/200003U/LE_/005KkFaaFne/LE_]K75KkFaaFne/L000:Ood00`00Ooeoo@0:Ood3001:Ood00;eo
o@8005eoo@07001FEeIFEUL005IGEUH00eIG00EFEUIGEUMFE`0000=FE`05EUIFEeIGEUMFEP020000
1Ekj001Vn6KhI_T00fKh00=VnFKh00000VLI01EW66LI001[6FLHIaUW66/IIaP006LIJaUW66/IIaU[
6FLH001W6@00IaT00f/I00IW6F/IJaU[6FLI0002JaT01@00JaU[6F/IIaT00V/I00<006LIJaT00V/I
00IW6F/IJaT006LI0002JaT05FLIJaU[6F/IIaU[6@00JaUW6F/I001K75[kFa]Jne/LF_]K6e[kFaaJ
n`03000084JmA]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJmA]d0
04KMA[e6gDJmA]d8000054JmA]e6_DKMA[d004klD_a>o5;lC_aBo4klD_a>o000Ea]K75LLFa`20000
45LLFaaG6e/L001K75LKFaaG75/LEa]K75LLFaaG6`002gom00<007omOod02Wom00<007omOod0BGom
002jOod3001MOod2000065IGEUIFEe9F001FEUIGDUIFEeIFEUMBEUIGEUH0059FEUMFEUIGDUIFEeIF
001Jn@9NnP1C001Vn6KiI_QVnFKhI_UVn000IaQ[6FLHJaUW66/I001[6FLHJaUW6000IaQ[6FLHJaUW
66/IIaQ[6FLH001W66/IIaQ[6FLHJaUW66/IIaP006LHJaUW66/I001[6FLHJaUW6000IaQ[>FLHJcUW
66/iIaQ[>FLH001W66/iIaQ[>FLHJcUW66/i001[>FLHJcUW6000E_]K75KkFaaFne/LE_]K70020000
75Kk0016_4KM@[a6gDJlA]e2_4KM0016gD:lA]e6_4KM@[a6gDJlA]d004KMA[a6gD:lA]e6_4KM1`00
01Y6gD:l0016_000@[a6gDJlA]e2_4KMA[a6g@00D_e>o5;mC_aBoDklD_e>o5;m001K75Kk0P0000mK
75KkFaaFne/LE_]K7000FaaFne/LE_]K75KkFa`00P0000=Fn`00Ood02Wom00<007omOod01Wom1@00
BWom002gOod3001OOod01000EUMFEeIF0eIG00EFEP00EUMFEeIF00=FE`05EUIFEeIG001FEP03EUL2
0005G_X01`00I_QVn6KhI_UVn000009W6@0FIaQW6FLIIaUW66LI001[6FLH001W6F/IIaQ[6FLIJaUW
66/IIaT006LI0002JaT01VLIJaU[6F/IIaT0009[6@05IaU[6F/IJaT00002JaT00`00IaU[6@02JaT0
2FLIJaU[6F/IIaT006/I001W6@03JaT01FLIJaT006/IIaT00f/I00MW6@00F_]K75[kFa]Jn`020000
6U/KF_]K75[k0016_DKMA[e6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJm0016_DKMA[d400007TKM
A[e6g@00A]e6_DKMA[e6g@00A]d004KMA[e6gDJmA]e6_DKMA[e6g@00D_a>o5;lC_aBo4klD_a>o0<0
000?Ea]K75LLFaaG6e/LEaaK75LKFa`005/LEa]K75LL00800005FaaG75/LEa/0000:Ood00`00Ooeo
o@06Ood01000Ooeoo@00Bgom002eOod2001POod200006E9FEUMFEUIGDUIFEeIFEUL005IGEUIFEe9F
EUMFEUIGDUIFE`00EUMBEUIG001NnU[i00=NnP1@F_UNnP00I_UVn6KiI_P006LHJaUW66/IIaQ[6FLH
JaUW6000IaP006LHJaUW66/IIaQ[6FLHJaUW6000IaQ[6@00JaUW66/IIaQ[6FLH001W66/IIaQ[6FLH
JaUW6000IaP006LHJcUW66/iIaQ[>FLHJcUW6000IaQ[>@00JcUW66/iIaQ[>FLH001W66/iIaQ[>FLH
JcUW6000E_]K7080000FE_]K75KkFaaFne/L0016gDJlA]e2_4KMA[a6gD:lA]d004KM@[a6gDJlA]d6
000084JlA]e2_4KMA[a6gD:l0016_4KM@[a6gDJl0012_4KM0016gD:lA]e6_4KM@[a6gDJlA]d005;m
C_aBoDklD_d2000044klD_d005/LE_]K75KkFaaFne/LE_]K75Kk001Fne/L0P0000MFne/LE_]K75Kk
Fa`0000;Ood00`00Ooeoo@06Ood00`00Ood0001;Ood00;9oo@<0065oo@05001FEeIGEUMFEP03EUL0
1EIFEUMFE`00EUH00eIG00IFEUIGEUMFEeIFEUL30009G_X01000I_UVn0000VLI00EW66LIIaUW6FLH
00=W6@0=IaP006LIJaUW66/IIaU[6FLHJaUW6@00IaT00f/I00H006/IJaU[6FLI0002JaT01FLIJaU[
6F/IIaT00V/I00<006LIJaT00V/I00IW6F/IJaU[6FLI0002JaT01FLIJaT006/IIaT00V/I00<006LI
JaT00V/I00EW6F/IJaU[6FLI0080000?FaaJne/KF_]K75[kFa]Jne/L0016gDJmA]e6_DKM00T0000S
A]e6_DKMA[d004JmA]e6_DKMA[e6gDJmA]e6_@00A[e6gDJmA]d004KMA[e6g@00A]e6_DKMA[e6gDJm
A]e6_@00C_aBo00300003e;lC_aBoDkl001G75/LEa]K75LLFaaG6e/LEaaK700300002U/LEa]K75LL
FaaG6e/LEaaK70002gom00<007omOod01Wom0P00Bgom002`Ood20002Ood00`00Ooeoo@1MOod30000
5U9FEUMFEUIGDUIFEeIFEUMBEUIGEUH0059FEUMFEUIGDUIFEeIFEUMBEP000Ukj00EJnEkjG_YNnU[i
00=NnP1HF_T006Kh001W66/IIaQ[6FLHJaUW66/IIaQ[6FLH001W6000IaQ[6FLHJaUW66/IIaP006LH
JaUW66/IIaQ[6@00JaUW6000IaQ[6FLHJaUW66/IIaQ[6FLH001W6000IaQ[>FLHJcUW66/iIaP006LH
JcUW66/iIaQ[>@00JcUW6000IaQ[>FLHJcUW66/iIaQ[>FLH001W6000E_]K75KkFaaFne/LE_]K75Kk
Fa`500009TKMA[a6gD:lA]d004KM@[a6gDJlA]e2_4KMA[`004:lA]e6_4KM@[a6gDJlA]e2_000A[a6
gD:l0016_4KM@[`004JlA]e2_4KMA[`6000045;mC_aBoDklD_e>o5;mC_`005KkFaaFne/LE_]K75Kk
0P0000iK75Kk001Fne/LE_]K75KkFaaFne/LE_]K70002Gom0P00EGom002]Ood3001SOod01P00EUIF
EeIG001FEP=FE`09EUIFEeIGEUMFEUIG001FEeIF00=FE`06EUIFEeIG001NnP002ekj00@006LIIaUW
60=W6@0AIaQW6FLIIaUW6000IaU[6@00JaUW6F/IIaQ[6FLI001W6@03JaT01VLIJaU[6@00IaT0009[
6@05IaU[6F/IJaUW6@02JaT01P00IaU[6F/I001W6@=[6@05IaU[6@00JaUW6@03JaT01FLI001[6@00
IaT00f/I00IW6F/IJaU[6FLI0002JaT02FLI001Jne/LF_]K6e[kFaaJn`0200008e/L0016gDJmA]e6
_DKMA[e6gDJmA]d004KMA[e6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJmA]d004KMA[e6g@00A]d0
20001DKM00l004klD_a>o5;mC_aBo4klD_e>o000EaaK75LKFa`00P0000eG6e/LEaaK75LK001G75/L
Ea]K75LLFaaG6`0200000e/L001oo@05Ood20002Ood00`00Ooeoo@0/Ood5000QOod00:]oo@8006Eo
o@0G001FEUIGDUIFE`00EUMBEUIGEUIFEe9FEUMFEUIGDUH005IFEUMBEUIGEUIFE`020002G_X01@00
G_YNnUkjF_T00ekj05IJnEkjG_X005kj001W66/IIaQ[6FLHJaUW66/IIaP006LHJaUW66/I001[6FLH
JaUW6000IaQ[6FLHJaUW66/IIaQ[6FLH001W66/IIaQ[6FLHJaUW66/IIaP006LHJcUW66/i001[>FLH
JcUW66/i001[>FLHJcUW66/iIaQ[>FLH001W66/iIaQ[>FLHJcUW66/iIaP006LHJcUW66/i001K75Kk
FaaFne/L0P0001aFne/LE_/004:lA]e6_4KM@[a6gDJlA]e2_000A[a6gD:lA]e6_4KM@[a6g@00A]e2
_4KMA[a6g@T0000JA]e6_4KM@[`004JmA]e2_4KMA[e6gD:lA]e6_@00C_aBoDklD_e>o5;mC_aBo@00
FaaFn`80000=FaaFne/LE_]K75KkFa`005/LE_]K75KkFa`00P0000AFne/LE_/000]oo@03001ooGom
02aoo@04001ooGom000QOod00:Qoo@<006Eoo@800009EUIFEeIGEUMFEUIG001FEeIF00=FE`06EUIF
EeIGEUMFEP000UIG00=FEUIG00001Ekj00<005kjG_X01Ekj0P0000ANnUlJG_X0009W6@04IaQW6FLI
IaT200000fLIJaUW6@02IaT01V/I001[6FLI001W6@=[6@09IaU[6F/IJaUW6@00JaT006LI00=[6@05
IaU[6F/I001W6@03JaT02FLIJaT006/IIaU[6@00JaUW6@03JaT01VLIJaU[6@00IaT0009[6@06IaU[
6F/IJaUW6@000V/I00MW6F/IJaU[6@00Fa]Jn`0200005U/KF_]K75[kFa]Jn`00A[e6gDJmA]e6_DKM
A[e6gDJm0016_DKMA[e6gDJm200000Q6gDJmA]e6_DKM0016g@001TKM00<004KMA]d01TKM00T005;m
C_aBo4klD_e>o5;lC_`00`0000eG75/LEa]K75LLFaaG6e/LEaaK7000FaaG700200001e/LEaaK75LK
FaaG700000Yoo@03001ooGom02aoo@03001ooGom029oo@00YWom0P00Igom01T005IGEUIFEe9FEUMF
EUIGDUH005IFEUMBEUIGEUIFEe9FEUMFEUIG001FEeIFEUL00003G_X01E[iG_YNnUkj00000ekj05AJ
nEkj001O6ekjHa]NnUlK001[6FLHJaUW66/I001[6FLHJaUW66/IIaQ[6FLH001W6000IaQ[6FLHJaUW
66/IIaQ[6FLH001W66/IIaP006LHJaUW66/IIaQ[6@00JcUW66/iIaQ[>FLHJcT006/i001[>FLHJcUW
66/iIaQ[>FLH001W66/iIaP006LHJcUW66/iIaP006LHJcUW66/iIaQ[>FLHJcT200004EKkFaaFne/L
E_]K75KkFaaFn`00@[a6gDJlA]e2_4KMA[`01`0002A6_4KM@[a6g@00A]e2_4KMA[a6gD:lA]e6_000
@[`004JlA]e2_4KMA[a6g@00A]e6_DKM@[a6gDJmA]e2_4KM001BoDklD_d400003DklD_d005/LE_]K
75KkFaaFne/LE_]K75Kk00<0000:E_]K75KkFaaFne/LE_]K75Kk000:Ood00`00Ooeoo@0[Ood2000S
Ood00:=oo@<006Qoo@03001FEeIF00=FE`05EUIFEeIGEUL00003EUL01EIFEUMFEeIGEUH00eIG0`00
2Ekj00d005kjG_YNnP00GaYNnUlJG_YO6UkjGaX00003IaT01000IaUW6F/I0fLI00I[6FLIIaUW6@00
IaT3JaT01VLIJaU[6F/IIaT0009[6@05IaU[6@00JaUW6@03JaT01@00JaU[6F/IIaT00f/I00EW6F/I
001[6FLI00=[6@05IaU[6F/I001W6@03JaT01VLI001[6F/IIaT0009[6@0FIaU[6F/IJaUW6F/I001[
6@00Fa]Jne/LF_]K6e[kFaaJne/K0016gDJmA]d400005DJmA]e6_@00A[e6gDJmA]e6_DKMA[d004Jm
A]e6_DKMA[e6gDJmA]e6_@020007A]d00`00A]e6g@03A]d700003e;lC_aBoDklD_a>o5;m001K75LL
FaaG6e/LEaaK700200003ELL001G6e/LEaaK75LKFaaG75/LEa]K700000]oo@03001ooGom02Yoo@04
001ooGom000QOod00:5oo@8006Uoo@<0000GEUIFEe9FEUMFEUIGDUIFEeIFEUL005IGEUIFEe9FEUMF
EUIGDUIFEeIF001Jn@03G_X01E[iG_YNnUkjF_T00Ukj06<005[i000005lKG_YS6ekjGa]NnV<KG_YO
6`00JaT006/IIaQ[6FLHJaUW66/IIaQ[6FLH001W6@00IaQ[6FLHJaUW66/IIaP006LHJaUW66/IIaQ[
6@00JaUW66/I001[>FLHJcUW66/iIaQ[>FLHJcT006/i001[>FLHJcUW66/iIaP006LHJcUW66/iIaQ[
>FLH001W6000IaQ[>FLHJcUW66/iIaQ[>@00JcUW6000E_]K75KkFaaFne/LE_]K75KkFa`00`000296
gDJlA]e2_4KMA[a6g@00A]e6_4KM@[a6gDJlA]e2_000A[a6gD:lA]e6_4KM@[a6gDJl0012_4KMA[a6
gD:lA]e6_0H0000DA]e6_DKM@[a6g@00D_e>o5;mC_aBoDklD_e>o000E_]K75KkFaaFn`80000>FaaF
ne/LE_/005KkFaaFne/LE_]K75KkFaaFn`8000Yoo@03001ooGom02Uoo@D0025oo@00WWom0`00JGom
0P0000ABEeIGDUH0009FE`05EUIFEeIGEUMFEP02EUL00`00EUIFE`02EUL015IFEUMFEeIG0P0000=N
nP00G_X02Ukj00h005kjGaYNnUlJG_YO6UkjGaYNnUlJG_YO6P000VLI00E[6FLIIaUW6F/I00=W6@06
001W6FLIIaT006LI0f/I00EW6F/I001[6FLI00=[6@05IaU[6@00JaT00003JaT03FLIJaU[6F/IIaU[
6@00JaUW6F/I001[6FLI009[6@03001W6F/I009[6@06IaU[6F/IJaUW6@000V/I00UW6F/IJaU[6FLI
JaT006/IIaT00V/I00P005[kFa]Jne/LF_]K6e[k0P0001iK6`00A]e6_DKMA[e6gDJmA]e6_DKM0016
gDJmA]e6_DKMA[e6gDJm0016_DKMA[e6gDJmA]e6_DKM0003A]d40002A]d00`00A]e6g@06A]d03@00
C_aBoDklD_a>o5;mC_aBo4kl001G6e/L0080000>Ea]K75LLFaaG6e/L001K75LKFaaG75/LEa]K7080
0003Ea]K700000Yoo@03001ooGom04ioo@00Vgom0`00Jgom01L005IGDUIFEe9FEUL005IGEUIFEe9F
EUMFEUIGDUIFEeIF001BEUIGEUIFEe9F00800006G_YJnEkj001NnU[i0ekj06AJnEkjG_YNnU[i001N
nP00G_YS6ekjGa]NnV<KG_YO6ekjHa/006<K001[6FLHJaUW66/IIaQ[6FLH001W6F/IIaQ[6@00JaUW
66/IIaQ[6@00JaUW66/IIaQ[6FLHJaUW66/I001[>FLHJcUW66/iIaQ[>FLHJcT006/iIaQ[>FLH001W
66/iIaP006LHJcUW66/iIaQ[>FLHJcUW6000IaP006LHJcUW66/iIaQ[>@00JcUW66/iIaQ[>FLH001F
ne/LE_]K7080000LE_]K75KkFa`004KM@[a6gDJlA]e2_4KMA[a6g@00A]e6_4KM@[a6gDJlA]d004KM
A[a6gD:lA]d700006DKMA[a6gD:lA]e6_000@[a6gDJmA]e2_4KMA[e6gD:l001>o5;mC_aBoDklD_e>
o5;m00<0000>FaaFne/LE_]K75KkFaaFne/L001K75KkFaaFn`800006FaaFne/LE_]K70002Gom00<0
07omOod0CWom002IOod20003Ood00`00Ooeoo@1VOod2000025IGDUMFEe9FEUMBEeIG0003EUL02UIF
EUMFEeIGEUIFE`00EUMFEUIG0P001Ukj00<005kjG_X01Ekj0P0000]NnUlJG_X005kjGaYNnUlJG_YO
6Ukj00800004Ga]O6UlK0002IaT01F/IIaUW6FLI00000fLI00Y[6FLIIaT006/IIaU[6@00JaUW6@=[
6@09IaU[6F/IJaT006/I001[6FLI00=[6@05IaT00000JaUW6@03JaT01FLI001[6@00IaT00f/I00IW
6F/IJaU[6FLI0002JaT01@00JaU[6F/IIaT00V/I00<006LIJaT00V/I00EW6F/I001K75[k0080000F
FaaJne/KF_]K75[k0016_DKMA[e6gDJmA]e6_DKMA[d004JmA]e6_DKMA[d80003A]d00`00A]d00008
A]d00`00A]e6g@07A]d01P00C_aBoDklD_a>o080000?D_a>o000Ea]K75LLFaaG6e/LEaaK75LK001G
75/L00800008EaaK75LKFaaG75/LEa/000Yoo@03001ooGom04eoo@00UWom0`00KGom01D0059FEUMB
EUIGDUIFEe9FEUMBEP00DUIFEeIFEUMBEUIGEUIFEe9FEUL00`000ekj00UJnEkjG_YNnU[iG_X005kj
F_T00ekj05h006<KG_YO6ekjHa/005lKG_YS6ekjGa]NnP00GaYS6elJHa]O6P00IaQ[6FLHJaUW6000
IaU[6FLHJaUW6F/IIaQ[6@00JaT006/IIaQ[6FLHJaUW66/IIaQ[6@00JcUW66/i001[>FLHJcUW6000
IaQ[>FLHJcUW66/iIaQ[>FLH001W66/iIaQ[>FLHJcUW66/iIaP006LHJcUW66/i001[>FLHJcUW6000
IaQ[>FLHJcUW66/iIaQ[>@80000?E_]K75KkFaaFne/LE_]K75Kk0016_4KM@[a6gDJl00T0000SA[a6
gDJlA]d004KMA[a6gDJlA]e6_000A[`004JlA]e2_4KMA[a6gD:lA]e6_000@[a6gDJmA]e2_4KMA[e6
g@00D_e>o00300003TklD_e>o5;mC_`005KkFaaFne/LE_]K75KkFa`300002e/LE_]K75KkFaaFne/L
E_]K75Kk00002Wom00<007omOod0C7om002DOod2001^Ood3000035IGDUMFEe9FEUMBEeIGDUIFE`00
EUMFEP=FE`06EUIFEeIGEUMFEP0035kj01X005kjG_YNnP00GaYNnUlJG_YO6UkjGaX005lJG_YO6Ukj
001O6UlKGaYO6elJGa]O6P000fLI00D006LIIaUW6F/I00=W6@06JaUW6FLI001[6FLI0f/I00EW6F/I
JaU[6@0000=[6@06IaT006/IJaUW6@000V/I00EW6F/IJaU[6FLI009[6@03001W6@00009[6@06IaU[
6F/IJaUW6@000V/I00EW6F/IJaU[6@00009[6@03001W6F/I009[6@0AIaU[6F/IJaT006/I001K75[k
Fa]Jne/LF_]K6e[kFaaJn`0500003dJmA]e6_DKMA[d004JmA]e6_DKMA[e6gDJmA]d00005A]d01000
A]e6g@0024KM00<004KMA]d00dKM1P0000m>o5;mC_aBo4klD_e>o5;l001K75LKFaaG75/LEa/00P00
00eK75LK001G75/LEa]K75LLFaaG6e/LEaaK70020007Ood3001>Ood0095oo@<006ioo@80000IEUMB
=UIG001FEe9FEUMBEUIGDUIFEe9FEUL005IGDUIFEeIFEUMBEUIGEUH005[i00000Ukj00EJnEkjG_YN
nU[i00=NnP03F_T005kj0080000;Ha]NnUlKG_YS6ekjGa]NnV<K001O6`020000G5lJHa]O6V<KGaYS
6elJHa]O6P00IaP006LIJaUW66/IIaU[6FLHJaUW6F/I001[6@00JaUW66/IIaQ[6FLHJaT006/iIaQ[
>FLHJcUW6000IaP006LHJcUW66/iIaQ[>FLHJcUW6000IaQ[>@00JcUW66/iIaQ[>FLH001W66/iIaQ[
>FLHJcUW6000IaP006LHJcUW66/iIaQ[>FLHJcT006/iIaQ[>@00FaaFne/LE_]K75KkFa`200008UKk
0016_4KMA[a6gDJlA]e6_4KMA[`004JlA]e6_4KMA[a6gDJl0016_4KMA[a6gDJlA]d004KM0016gDJl
A]e2_4KM2@000196gDJlA]e6_4KM001BoDklD_e>o5;mC_aBoDklD_d005/LE_/300003EKkFaaFne/L
E_/005KkFaaFne/LE_]K75Kk00800003FaaFn`0000Uoo@03001ooGom04]oo@00Sgom0P00Kgom0P00
1E9G00/0059FEUMBEeIGDUIFEe9GEUMBEP00009FE`04EUIFEeIGEUL20002G_X00`00G_YNnP0:G_X0
6`00G_YO6UkjGaYNnUlJG_YO6UkjGaYNnUlJ001O6elJGa]O6UlKGaYO6elJGa]O6UlKGaX00003IaT0
1F/IIaUW6FLIJaT00VLI00L006/IIaU[6@00JaUW6@03JaT01@00JaU[6F/IIaT00f/I00EW6@00JaU[
6FLI00=[6@05IaU[6F/I001W6@03JaT01P00JaU[6F/IIaT0009[6@05IaU[6F/IJaUW6@02JaT00`00
IaU[6@02JaT01FLIJaU[6F/I00000f/I00MW6@00F_]K75[kFa]Jn`0200005e/KF_]K75[k0016_DKM
A[e6gDJmA]e6_DKM0016gDJmA]e6_DKMA[e6gDJm00001DKM20001DKM00<004KMA]d01TKM00X004kl
D_a>o5;mC_aBo4klD_e>o0<0000>Ea]K75LLFaaG6e/LEaaK7000FaaG75/LEa]K70800005Ea]K75LL
Fa`0000:Ood00`00Ooeoo@1:Ood008aoo@<006moo@80000JEUMB=UIGDSIFEe8fEUL005IGDUIFEe9F
EUMBEUIGDUIFEe9F001FEUIGDUIFE`00G_YJn@=NnP05001NnUkjG_YJn@03G_X03e[iG_X00000G_X0
05kjGa]NnV<KG_YO6ekjHa]NnP020000Ff<K001S6elJHa]O6V<KGaYS6elJHa]O6P00GaX006LHJaUW
6F/IIaQ[6FLIJaT006/IIaU[6FLHJaT006/IIaQ[6@00JcUW66/iIaQ[>FLHJcUW6000IaP006LHJcUW
66/iIaQ[>FLH001W66/iIaQ[>FLHJcT006/iIaP006LHJcUW66/iIaQ[>FLHJcUW6000IaP006LHJcUW
66/iIaQ[>@00JcUW66/iIaQ[>FLH001Fne/L0080000FE_]K75KkFaaFne/L0016gDJlA]e6_4KMA[a6
gDJlA]d004KMA[a6gDJlA]d9000074KMA[a6g@00A]e6_4KMA[a6gDJlA]e6_4KM0016gDJlA]e6_4KM
A[a6gDJl001>o5;mC_aBoDkl0`0000m>o5;m001K75KkFaaFne/LE_]K75KkFa`005/LE_/00P0000QK
75KkFaaFne/LE_]K70002Gom00<007omOod0BWom002:Ood2001aOod00`00DUMBE`08DUL02`00EUMB
EUIGDUMFEe9FEUMBEeIG00000eIG00<005kjG_X01Ekj00<005kjG_X015kj0P0001UO6UkjGaX005lJ
G_YO6UkjGaYNnUlJG_X005lJGa]O6UlK001O6elJGa]O6UlKGaYO6`02000015lJGa]O6P000fLI00i[
6FLIIaT006/IIaU[6FLIJaUW6F/I001[6@000f/I00IW6F/IJaU[6FLI0002JaT01FLI001[6F/IIaT0
0f/I00D006/IJaU[6FLI009[6@03001W6@00009[6@05IaU[6F/IJaUW6@02JaT01P00IaU[6F/I001W
6@=[6@05001[6F/IJaUW6@03JaT04VLI000005/LF_]K6e[kFaaJne/KF_]K7000A]e6_DKMA[e6g@T0
00A6g@050016gDKMA]d00004A]d00`00A]e6g@06A]d00`00A]e6g@06A]d00`00D_e>o003000044kl
D_a>o5;mC_`005LLFaaG6e/LEaaK75LKFaaG75/L0P0000YG75/LEa]K75LLFaaG6e/LEa`000Yoo@03
001ooGom04Uoo@00Qgom0`00LGom0`0001EFEe8fEUMB=UIGDSIFEe8fEUMB=P00DUIFEe9FEUMBEUIG
DUIFEe9FEUL00`0000=NnU[iG_X00Ukj00EJnEkjG_YNnP0000=NnP80000<G_YO6ekjHa]NnUlK001S
6ekjGa]NnV<K0P0006QO6V<KGaYS6elJ001O6V<KGaYS6elJHa/006<KGaYS6elJHa/006/IIaQ[6FLI
JaT006/IIaU[6FLHJaUW6F/IIaQ[6@00JcUW66/iIaQ[>FLHJcUW6000IaQ[>FLHJcT006/iIaQ[>FLH
JcT006/iIaQ[>FLHJcUW66/iIaP006LHJcUW66/iIaQ[>FLHJcUW6000IaQ[>FLHJcT006/iIaQ[>@00
JcUW66/iIaQ[>FLHJcUW6000IaP005KkFaaFne/LE_]K75KkFaaFne/L1@0002I6gDJlA]e6_4KM0016
gDJlA]e6_4KMA[a6g@00A]e6_4KM0016gDJlA]e6_000A[a6gDJlA]e6_4KMA[a6gDJl0016_4KMA[a6
gDJl1@00015>o5;mC_aBoDklD_e>o5;mC_`005KkFaaFne/LE_]K75Kk0080000=Fa`005/LE_]K75Kk
FaaFne/LE_]K75Kk00002Wom00<007omOod0B7om0025Ood200000gom001oo@1_Ood20003DUL00`00
DUMBE`07DUL03000EUMBEeIGDUIFEe9GEUMBEUIGDUL000]NnP0Y001NnP00001O6UkjGaYNnUlJG_YO
6UkjGaX005lJG_YO6P00Ga]O6UlKGaYO6elJGa]O6P00GaYO6elJGa/005lKGaYO6elJGa]O6UlK001[
6@02IaT03`00JaUW6F/IIaU[6FLIJaUW6F/I001[6@00JaUW6@03JaT01FLI001[6F/IIaT00f/I00D0
06/IJaU[6@0000=[6@09IaU[6F/IJaUW6@00JaT006LI00=[6@05IaU[6F/I001W6@03JaT01FLIJaT0
06/I00000f/I00IW6F/IJaU[6FLI0002JaT02FLI001Jne/LF_]K6e[kFaaJn`0200002e/L0016gDJm
A]e6_DKMA[e6gDJm000024KM00@004KMA]d000E6g@030016gDKM00=6g@T000A6g@0@001BoDklD_a>
o5;mC_aBo4klD_e>o000EaaK75LKFa`200003ELKFaaG75/L001K75LLFaaG6e/LEaaK75LK008000Yo
o@03001ooGom04Qoo@00PWom0`000gom00<007omOod0KGom01T0058fEUMB=UIGDSH0058fEUMB=UIG
DSIFEe8fEUMB=UIG001FEe9FEUMBEUIGDUIFE`0200000e[J001Jn@03G_X01E[iG_YNnUkjF_T00Ukj
00h005kjHa]NnUlKG_YS6ekjGa]NnV<KG_X005kj0P0000aS6elJHa]O6V<KGaYS6elJHa]O6P00GaX2
0000FF<KGaYS6elJHa]O6V<KGaYS6`00JaT006/IIaU[6FLHJaUW6F/IIaQ[6@00JcUW6000IaQ[>FLH
JcUW66/i001[>FLHJcUW66/iIaQ[>@00JcT006/iIaQ[>FLHJcUW66/iIaP006LHJcUW6000IaQ[>FLH
JcUW6000IaQ[>FLHJcUW66/iIaQ[>@00JcUW66/iIaQ[>FLHJcUW6000IaQ[>FLHJcT005/LE_]K75Kk
Fa`00P0001iFne/LE_/004JlA]e6_4KMA[a6gDJlA]e6_000A[a6gDJlA]e6_4KMA[a6g@00A]d004KM
A[a6gDJlA]d600006dJlA]e6_4KMA[`004JlA]e6_4KMA[a6gDJlA]d005;mC_aBoDklD_e>o5;mC_aB
o@00FaaFn`0200003E/LE_]K75KkFaaFn`00E_]K75KkFaaFne/L00800003E_]K700000Yoo@03001o
oGom04Moo@00Ogom0`00M7om0P001e9G00<0059GDUL01e9G00H0059FEUMBEeIGDUH2000015kjF_YN
nP002Ukj03T005kj001NnUlJG_YO6UkjGaYNnUlJG_YO6Ukj001O6UlKGaYO6elJGa]O6UlKGaYO6elJ
Ga]O6P00GaYO6elJGa]O6UlKGaYO6elJGa]O6UlK001[6FLIJaUW6F/IIaU[6FLIJaT006/IIaU[6FLI
00000V/I00EW6F/I001[6FLI00=[6@05IaU[6F/IJaT00003JaT01VLIJaU[6F/IIaT0009[6@05IaU[
6F/I001W6@02JaT00`00IaU[6@02JaT02FLIJaU[6F/I001[6@00JaUW6@03JaT01FLI001[6F/IIaT0
0f/I00<005/KF_/00P00015K6e[kFaaJne/KF_/004JmA]e6_DKMA[e6gDJmA]e6_@0000M6g@040016
g@00A]d40002A]d00`00A]e6g@06A]d00`00A]e6g@06A]d02@00C_aBoDklD_a>o5;mC_aBo0040000
35LLFaaG6e/LEaaK75LKFaaG7000Ea]K70<00006FaaG75/LEa]K70002Wom00<007omOod0AWom001m
Ood2001fOod06000EUMB=UIGDSIFEe8fEUMB=UIG001FEe8fEUMB=UIGDSIFEe8fEUL005IGDUIFE`80
0009F]YNnU[JG_YJfUkj001NnU[i00=NnP0@F_UNnP00001NnV<KG_X005kjHa]NnUlKG_YS6ekjGa/2
000035lJ001O6V<KGaYS6elJHa]O6V<KGaYS6`80000;GaX005lJHa]O6V<KGaYS6elJHa]O6P020000
Bf<K001[6FLHJaUW6F/IIaQ[6@00JcUW66/iIaU[>FLH001W66/i001[>FLHJcUW66/iIaQ[>FLHJcT0
06/i001[>FLHJcUW66/iIaP006LHJcUW66/iIaQ[>FLH001W6000IaQ[>FLHJcUW66/iIaQ[>@00JcUW
66/i001[>FLHJcUW6000IaQ[>FLHJcUW66/iIaQ[>@02000065KkFaaFne/LE_]K75KkFaaFn`00A[a6
gDJlA]e6_4KMA[a6g@00A]e6_4KMA[a6g@H0000MA[a6gDJlA]e6_4KM0016gDJlA]e6_4KMA[a6gDJl
A]d004KMA[a6gDJlA]e6_4KMA[`004klD_e>o00400003E;mC_aBo@00FaaFne/LE_]K75KkFaaFne/L
00<00009FaaFne/LE_]K75KkFaaFn`0000Yoo@03001ooGom04Ioo@00NWom0`00MWom0`002E9G00<0
059GDUL0259G0`0000YNnU[jG_YJnUkjF_YNnU[jG_X000ENnP11001O6UkjGaYNnUlJ001O6UkjGaYN
nUlJG_YO6P00Ga]O6UlKGaX005lJGa]O6UlKGaYO6elJGa/005lKGaYO6`00Ga]O6UlKGaYO6elJGa]O
6P00GaYO6elJ001W6F/IIaU[6FLIJaT006/IIaU[6FLIJaUW6F/I001[6@00JaUW6@03JaT01FLIJaU[
6F/I00000f/I00H006/IJaU[6FLI0002JaT01FLIJaU[6F/IIaT00V/I00<006LIJaT00V/I00EW6F/I
JaU[6@0000=[6@06IaT006/IJaUW6@000V/I01QW6F/IJaU[6FLIJaT006/I001K6e[kFaaJne/KF_]K
75[kFa/004KMA[e6gDJmA]d<00000dKM00000007A]d00`00A]e6g@07A]d00`00A]e6g@05A]d40000
3dklD_a>o5;mC_aBo4kl001G6e/LEaaK75LKFaaG700200003E/L001K75LKFaaG75/LEa]K75LLFaaG
6`0000Yoo@03001ooGom04Eoo@00N7om0P00Mgom0P0003EB=UIGDSH0058fEUMB=UIGDSIFEe8fEUMB
=P00DSIFEe8fEUMB=UIGDSIFEe8f001JfUkjF]YNnU[JG_YJfUkjF]YNnU[JG_X005kjF_UNnP00Ga]N
nV<KG_YO6ekjHa/005lKG_YS6ekj0080000<Ha]O6V<KGaYS6`00Ha]O6V<KGaYS6elJ0P0000]S6elJ
Ha]O6V<K001S6elJHa]O6V<K0080001JGaYS6elJHa]O6P00IaU[6FLHJaT006/iIaQ[>FLIJcUW66/i
IaU[>@00JcUW66/iIaQ[>FLHJcUW66/i001[>FLHJcUW6000IaQ[>FLH001W66/iIaQ[>FLHJcUW66/i
IaP006LH001W66/iIaQ[>FLHJcT006/iIaQ[>FLHJcUW6000IaP006LHJcUW66/iIaQ[>FLHJcT006/i
IaP005KkFaaFne/LE_]K75KkFaaFne/L1@0000E6gDJlA]e6_4KM00@0000KA[a6gDJlA]e6_000A[a6
gDJlA]e6_4KMA[a6g@00A]e6_4KMA[a6gDJlA]e6_000A[a6gDJl00@0000AA]e6_000C_aBoDklD_e>
o5;mC_aBoDkl001Fne/LE_]K700200003UKkFaaFne/L001K75KkFaaFne/LE_]K75KkFa`20007Ood4
0016Ood007Eoo@<007Qoo@03001BEe9G00=BE`03001BEe9G00MBE`03001BEe9G00EBE`80000?F]X0
05[jG_YJnUkjF_YNnU[jG_YJnUkjF_X005kj0080000;GaYNnUlJG_YO6UkjGaYNnUlJ001O6P020000
<elJGa]O6UlKGaYO6elJGa/005lKGaYO6elJ001O6UlKGaYO6elJGa]O6UlK001O6elJGa/005lKGaYO
6elJGa]O6UlKGaX006LIJaT006/IIaU[6FLIJaUW6F/IIaU[6@00JaT00003JaT01FLIJaU[6F/I0000
0f/I00IW6F/IJaT006LI0002JaT01FLIJaU[6F/IIaT00V/I00H006LIJaT006/IIaT3JaT01FLI001[
6F/IIaT00f/I00EW6@00JaU[6FLI00=[6@05IaU[6@00JaUW6@02JaT02000F_]K6e[kFaaJne/KF_/2
00000e/K0016g@05A]d30008A]d20007A]d00`00A]e6g@03A]d70006A]d03@00D_a>o5;mC_aBo4kl
D_e>o5;l001K75LK0080000>FaaG6e/LEaaK75LK001G75/LEa]K75LLFaaG6`800003FaaG6`0000Uo
o@03001ooGom04Aoo@00Lgom0P00NGom0P0004=FEe8fEUMB=UIGDSIFE`00EUMB=UIGDSIFEe8fEUMB
=UIG001FEe8fEUMB=UIG001Nne[JF_/005kjF]YNnU[JG_YJfUkjF]YNnU[JG_YJfP00G_YO6ekjHa]N
nUlKG_YS6ekjGa]NnV<K001S6elJHa]O6V<KGaYS6elJHa]O6V<K001S6`0200002elJHa]O6V<KGaYS
6elJHa]O6P00GaX00P0005US6elJHa]O6V<KGaYS6elJHa/006/I001[>FLHJcUW6F/iIaQ[>FLIJcT0
06/iIaU[>@00JcUW66/iIaQ[>@00JcUW66/iIaQ[>FLHJcUW6000IaQ[>FLHJcUW66/iIaQ[>FLH001W
66/iIaQ[>@00JcUW66/iIaP006LHJcUW66/iIaQ[>FLH001W6000IaQ[>FLHJcUW66/i001[>FLHJcUW
66/iIaP005KkFaaFne/L00800008E_]K75KkFa`004KMA[a6g@80000<A[a6gDJl0016_4KMA[a6gDJl
A]e6_4KM0P0000A6_4KMA[a6g@P0000GA[a6gDJlA]e6_000A[a6gDJlA]e6_4KMA[a6g@00D_e>o5;m
C_aBoDklD_e>o00300003UKkFaaFne/LE_]K75KkFaaFn`00E_]K75KkFa`200001EKkFaaFne/L0000
2Wom00<007omOod0@gom001aOod2001iOod20009DUL00`00DUMBE`07DUL01000DUMBEe9G0P0000mJ
nU[JF_YJfU[j001NnU[jG_YJnUkjF_YNnU[jG_X00P0004ENnP00G_YO6UkjGaYNnUlJG_YO6UkjGaX0
05lK001O6elJGa]O6UlKGaYO6elJGa]O6UlK001O6elJGa]O6UlKGaYO6elJGa]O6UlKGaX005lJGa]O
6UlKGaYO6elJGa]O6UlKGaYO6`00JaUW6F/IIaU[6FLIJaUW6F/I001[6FLIJaUW6F/I00000f/I00D0
06/IJaU[6FLI00=[6@05IaT006/I001W6@03JaT01FLIJaU[6@00IaT00f/I00IW6F/I001[6FLI0002
JaT01VLIJaU[6F/IIaT0009[6@05001[6F/IJaUW6@02JaT00`00IaU[6@02JaT01FLIJaT005/LF_/0
0P0000IK75[kFa]Jne/LF_/40005A]d00`00A]e6g@03A]d90004A]d00`00A]e6g@06A]d00`00A]e6
g@07A]d01P00D_a>o5;mC_aBo080000?C_aBo000FaaG6e/LEaaK75LKFaaG75/L001K75LL00800008
FaaG75/LEa]K75LLFa`000Yoo@03001ooGom049oo@00LGom0`00MWom0P0001IBE`00EUMB=UIGDSIF
Ee8fEUMB=UIG001FEe8fEUMB=UIGDSIFEe8fEUMB=P<0000?F]YNne[JF_]JfUkkF]YJn`00G_YJfUkj
F]YNnU[J0080000<Ga]JnUlKF_X005kjGa]NnV<KG_YO6ekj0P0000aS6elJHa/006<KGaYS6elJHa]O
6V<KGaX200002f<K001S6elJHa]O6V<KGaYS6elJHa/00P0000]O6P00GaYS6elJHa]O6V<KGaYS6elJ
0080001;Ha/006/iIaU[>FLHJcUW6F/i001[>FLIJcUW66/iIaU[>@00JcT006/iIaQ[>FLHJcUW66/i
IaP006LHJcUW6000IaQ[>FLHJcUW66/i001[>FLHJcUW66/iIaP006LH001W66/iIaQ[>FLHJcUW6000
IaQ[>FLHJcT006/iIaQ[>FLH001W66/iIaQ[>FLHJcUW66/i00800006E_]K75KkFaaFne/L100000E6
_4KMA[a6gDJl00P0000SA]e6_4KMA[a6g@00A]e6_4KMA[a6gDJlA]e6_000A[a6gDJlA]e6_4KMA[a6
g@00A]e6_4KMA[a6gDJlA]e6_000C_aBo@0300003U;mC_aBoDklD_d005/LE_]K75KkFaaFne/LE_/3
00002UKkFaaFne/LE_]K75KkFaaFn`002Wom00<007omOod0@Wom001aOod00`00Ood0001dOod20000
1E8gDUMB=e9G00002E9G00<0059GDUL01e9G010005[jF]YJnU[JF_YJfU[jF]YJnU[JF_X005kjF_YN
nP80000gG_YNnekjG_]NnUkk001O6UkjGaYNnUlJG_X005lJGa]O6UlKGaX005lJGa]O6UlKGaYO6elJ
001O6UlKGaYO6`00Ga]O6UlKGaYO6elJGa/005lKGaYO6elJ001O6UlKGaYO6elJGa]O6P00GaX00elK
014006/IIaU[6FLIJaT006/IIaU[6FLIJaUW6F/IIaU[6@0000=[6@06IaU[6F/IJaUW6@000V/I00EW
6F/I001[6FLI00=[6@05001[6F/IJaUW6@03JaT01FLI001[6F/IIaT00f/I00EW6@00JaU[6FLI00=[
6@05001[6F/I001W6@03JaT02VLIJaU[6F/I001[6@00FaaJne/K0`0000AK6e[kFaaJn`D000A6g@03
0016gDKM00M6g@030016gDKM00E6g@030016gDKM00I6g@030016gDKM00=6g@H0000?D_a>o5;mC_aB
o4klD_e>o000EaaK75LKFaaG75/L0080000>EaaK7000FaaG75/LEa]K75LLFaaG6e/LEa`000Yoo@03
001ooGom045oo@00LGom00@007omOod0075oo@80000HDUMB=e9GDSIBEe8g001B=UIGDSIFEe8fEUMB
=UIGDSH0058fEUMB=UIGDSIFEe8f0P0000iJn`00G_]JfU[kF]YNne[JF_]JfUkkF]X005[J0P0001]O
6e[jGa]JnUlKF_YO6e[jGa/006<KG_YO6ekj001O6V<KGaYS6elJHa]O6P00GaYS6elJHa/00P0000]O
6V<KGaYS6elJHa/006<KGaYS6elJ0080000;Ha]O6V<KGaYS6elJ001O6V<KGaYS6`020000D5lJHa]O
6V<KGaYS6`00JcUW6F/i001[>FLIJcUW66/iIaU[>FLHJcT006/i001[>FLHJcUW66/iIaP006LHJcUW
66/iIaQ[>@00JcUW66/i001[>FLHJcUW66/iIaQ[>FLH001W6000IaQ[>FLHJcUW66/i001[>FLHJcUW
66/iIaP006LH001W66/iIaQ[>FLHJcUW66/i001[>FLHJcT300001E/LE_]K75KkFa`00P0001=Fn`00
A[a6gDJlA]e6_4KMA[a6g@00A]e6_4KMA[a6gDJlA]e6_00200003DKMA[a6gDJlA]e6_4KM0016gDJl
A]e6_4KM00P0000BA[a6gDJlA]e6_000C_aBoDklD_e>o5;mC_aBoDkl001Fne/L0`0000eK75KkFaaF
ne/L001K75KkFaaFne/LE_]K700200000eKk001oo@09Ood00`00Ooeoo@10Ood0071oo@03001ooGom
009oo@03001ooGom06aoo@800009DSMBEe8gDUMB=e9GDSMBE`0000YBE`03001BEe9G00=BE`0O001J
fU[jF]X005[JF_YJfU[jF]YJnU[JF_YJfU[jF]X005kjG_]NnUkkG_YNnekjG_]NnUkkG_YNn`00GaX0
0P0000]O6UlKGaYO6elJGa]O6UlKGaX005lJ0080000;Ga]O6UlKGaYO6elJGa]O6UlK001O6`020000
2elJGa]O6UlKGaYO6elJGa]O6P00GaX00P0000=O6elJGa/00UlK01EO6UlKGa]O6`00JaT006/IIaU[
6FLIJaUW6F/IIaU[6@00JaUW6@00IaT00f/I00EW6F/I001[6FLI00=[6@05IaU[6@00JaT00003JaT0
2VLIJaU[6F/IIaT006/IJcUW6@000V/I00EW6F/I001[6FLI00=[6@05IaU[6F/I001W6@03JaT01VLI
JaU[6F/I001[6@@00005F_]K75[kFa]Jn`0200001E/KF_]K75[k00001dKM00<004KMA]d01dKM0P00
14KM200014KM00<004KMA]d01dKM00T004klD_a>o5;mC_aBo4klD_d00`0000iK75LKFaaG75/LEa]K
75LL001G6e/LEaaK75LK0P0000EK75LKFaaG700000Uoo@03001ooGom041oo@00L7om00<007om0000
0gom00<007omOod0JGom0`0001QB=U9GDSMBEe8fDUMB=e9GDSIBE`00EUMB=UIGDSIFEe8fEUMB=UIG
001FEe8fEUL200003U[JF_]JfUkkF]X005[JG_]JfU[kF]YNne[JF_/20000Q5[j001JnUlKF_YO6e[j
Ga]JnUlKF_YO6e[jGa/006<KGaYS6elJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJ
Ha]O6V<K001S6elJHa]O6V<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa]O6V<KGaYS6`00
JcUW6F/iIaQ[>FLIJcUW66/i001[>FLHJcUW6@00IaQ[>FLHJcT006/iIaQ[>FLHJcUW66/iIaQ[>@00
JcUW66/iIaQ[>FLHJcUW6000IaQ[>FLHJcT006/iIaQ[>@00JcUW66/iIaQ[>FLHJcUW6000IaP006LH
JcUW66/iIaQ[>@<00007JcUW66/iIaP005KkFa`00P0001EFne/LE_]K75KkFa`004KMA[a6gDJlA]e6
_4KMA[`004JlA]e6_4KMA[`02@0001e6_4KMA[a6g@00A]e6_4KMA[a6gDJlA]e6_000A[a6gDJlA]e6
_4KMA[a6g@00D_e>o5;mC_aBoDkl0080000?D_e>o000E_]K75KkFaaFne/LE_]K75Kk001Fne/L0080
0007E_]K75KkFaaFne/L00002Wom00<007omOod0?gom001`Ood20005Ood00`00Ooeoo@1VOod20000
3U8gDUMB=`00DSMBEe8gDUMB=e9GDSMBEe8g000:DUL300004E[jF]YJnU[JF_YJfU[jF]X005[JF_YJ
fU[jF]YJnP00G_/00e[k00X005kjG_]NnUkkG_YNnekjG_]NnP80000ZGa/005lKGaYO6elJGa]O6UlK
GaYO6elJ001O6P00GaYO6elJGa]O6UlKGaYO6elJGa/005lK001O6elJGa]O6UlKGaYO6elJGa]O6P00
Ga/005lJ0elK01eO6UlKGa]O6elJGa/006<K001[6FLIJaUW6F/IIaU[6@00JaUW6F/IIaU[6FLI001W
6F/I001[6FLI00=[6@09IaU[6F/IJaT006/I001[6FLI00=[6@0=IaT006/IJcUW6F/iJaU[>@00JaT0
06/IIaT00f/I00EW6F/IJaT006LI009[6@03001W6F/I00<000=[6@05IaU[6F/IJaUW6@0200002U/L
F_]K6e[kFaaJne/KF_]K70001DKM20001DKM00<004KMA]d01TKM00<004KMA]d01DKM00<004KMA]d0
1dKM00<005;mC_`00`0000m>o5;lC_aBo@00FaaG75/LEa]K75LLFaaG6e/LEa`00P0000YK75LLFaaG
6e/LEaaK75LKFa`000Yoo@03001ooGom03ioo@00L7om00<007omOod01Gom0P00IGom02/0059GDSMB
EdhfDUL0059GDSIBEe8gDUMB=U9GDSMBE`00EUMB=UIGDSIFEe8fEUMB=UIGDSH005[JG_]JfU[kF]YN
ne[JF_]JfUkkF]X005[JG_]JfP0200003EkkF_YNne[jG_/005lKF_YO6e[jGa]JnUlK0080000<F_YO
6e[jGa/006<KGaYS6elJHa]O6V<K0P0000]O6V<KGaX005lJHa]O6V<KGaYS6elJ0080000;Ha]O6V<K
001S6elJHa]O6V<KGaYS6`0200002elJHa]O6P00GaYS6elJHa]O6V<KGaX00P0003eS6elJ001W66/i
IaU[>FLHJcT006/iIaQ[>FLIJcUW66/i001[>@00JcUW66/iIaQ[>FLHJcUW66/i001[>FLHJcT006/i
IaQ[>FLH001W66/iIaQ[>FLHJcUW66/i001[>FLHJcUW66/iIaQ[>FLH001W66/iIaQ[>@0300005f/i
001[>FLHJcUW66/iIaQ[>FLH001W6000E_]K75KkFaaFne/LE_]K75KkFa`01@0000e6gDJlA]e6_000
A[a6gDJlA]e6_4KMA[a6g@0200005TJlA]e6_4KMA[a6gDJl0016_4KMA[a6gDJlA]e6_4KM0016gDJl
A]e6_4KM1P00011>o5;mC_aBoDklD_e>o5;m001K75KkFaaFne/LE_]K7080000;E_/005KkFaaFne/L
E_]K75KkFaaFn`020009Ood00`00Ooeoo@0nOod0071oo@03001ooGom00Moo@03001ooGom061oo@80
000BDUMB=e9GDSMBEe8gDUL0059GDSMBEe8gDUMB=e9GDSMBE`001e9G0P0000iJfP00F]YJnU[JF_YJ
fU[jF]YJnU[JF_X005[j0P0000=JnekkF_/00U[k00QNne[kF_/005kkG_YNnekj0P001UlK028005lJ
Ga]O6UlKGaYO6`00Ga]O6UlKGaYO6`00Ga]O6UlKGaYO6elJ001O6UlKGaYO6elJ001O6UlKGaYO6elJ
Ga/000=O6`05GaYO6`00Ga]O6P03Ga/01ElJ001O6f<KGaX00UlK018006LIJaUW6F/I001[6FLIJaUW
6F/IIaU[6FLIJaT006/IIaT3JaT01FLIJaU[6F/I00000f/I015W6@00JaU[6FLI001[6F/iIaU[>F/I
JcUW6F/i001[>@0000=[6@05IaU[6F/I001W6@02JaT2000016/I001[6@000f/I00IW6F/IJaU[6FLI
0002JaT02FLI001Jne/LF_]K6e[kFaaJn`0200000e/L0016g@07A]d00`00A]e6g@06A]d00`00A]e6
g@06A]d00`00A]e6g@03A]d80005A]d03`00D_e>o5;lC_aBoDklD_a>o5;m001K75LLFaaG6`020000
2e/LEa]K7000FaaG6e/LEaaK75LKFa`00P0000=G6e/L00001Wom0P0000=oo@00Ood0?Wom001`Ood0
1000Ood000001gom00<007omOod0GGom0P0001U>=U9GDSMBEdhfDUMB=e9GCSH0058gDUMB=U9GDSMB
Ee8fDUMB=`00DSIFEe8fEUMB=P0200007E[kF]YNn`00F_]JfUkkF]YJne[JG_]JfU[kF]YNn`00G_]J
nUkkF_YNne[jG_]JnUkkF_YNn`00Ga/00P0005=JnUlKF_YO6e[jGa]JnUlKF_X005lJHa]O6V<K001S
6elJHa]O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS
6elJHa/006<KGaYS6elJ001O6V<KGaYS6elJHa]O6P00IaQ[>@00JcUW66/iIaU[>FLHJcUW6F/i001[
>@00JcUW66/iIaQ[>FLH0080000LJcUW66/iIaQ[>FLH001W6000IaQ[>FLHJcUW66/iIaQ[>@00JcUW
66/i001[>FLHJcUW6000IaP3000066LHJcUW66/i001[>FLHJcUW66/iIaQ[>FLH001W66/iIaU[>@00
FaaFne/LE_]K7080000EE_]K75KkFa`004KMA[a6gDJlA]e6_4KM0016gDJlA]e6_4KMA[a6gDJl0080
0004A]e6_4KMA[`900006TJlA]e6_4KM0016gDJlA]e6_4KMA[a6gDJl001>o5;mC_aBoDklD_e>o5;m
C_`005KkFa`200002eKkFaaFne/LE_]K7000FaaFne/LE_/00P0000EK75KkFaaFn`0000Yoo@03001o
oGom03aoo@00Kgom0`002Wom00<007omOod0FWom0P0001IBE`00DUMB=e9GDSMBEe8gDUMB=e9G001B
Ee8gDUMB=e9GDSMBEe8gDUL000=BE`80000?F]YJnU[JF_YJfU[j001JnU[JF_YJfU[jF]YJnU[J0080
0003F_/005kk00=Jn`05G_]Jne[kF_]Nn`02F_/00`00Ga]O6`0:Ga/03`00GaX00000Ga]O6UlKGaYO
6elJGa]O6UlK001O6`0200002elJGa]O6UlKGaYO6elJGa]O6P00GaX00P000elK00QO6UlKGa]O6elJ
Ga/005lK0P0000=O6f<KGaX00UlK01IS6elJGa/006/I001[6FLIJaUW6F/IIaU[6FLIJaT006/IIaU[
6@00JaUW6@9[6@03001W6F/I009[6@0EIaU[6F/IJaUW6@00JaU[>FLIJcU[6F/iIaU[>@00JcUW6F/i
JaT006LI009[6@<0009[6@09IaU[6F/IJaT006/I001[6FLI00=[6@05IaT006/IJaUW6@03JaT00`00
Fa]Jn`0200001e/KF_]K75[kFa]Jn`0000Q6g@030016gDKM00=6g@P000E6g@030016gDKM00I6g@03
0016gDKM00I6g@08001>o5;mC_aBo4klD_e>o0@0000;FaaG75/LEa]K75LLFaaG6`00EaaK70020000
25LLFaaG6e/LEaaK75LK0009Ood00`00Ooeoo@0lOod006moo@03001ooGom00]oo@03001ooGom05Mo
o@80000HDSMBEdhfDUL0059GCSIBEe8gDUM>=U9GDSMBE`00DUMB=e9GDSIBEe8gDUMB=U9G0`0001iN
ne[JF_]JfUkkF]YJne[JG_/005[kF]YNne[JF_]JfP00F_YNne[jG_/005kkF_YNne[jG_]JnUkkF_X2
0000KUlK001O6e[jGa]JnUlKF_YO6e[jGa]JnUlKF_X005lJHa]O6V<KGaYS6elJHa]O6V<KGaYS6`00
Ha]O6V<KGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaYS6elJHa/006<KGaYS6elJ
Ha]O6V<KGaYS6elJHa/006/iIaQ[>FLIJcUW66/iIaU[>@00JcUW6F/iIaP006LHJcUW6000IaQ[>FLH
JcUW66/iIaQ[>FLH001W6000IaQ[>FLHJcUW66/i001[>FLHJcUW66/iIaP300006VLHJcUW66/iIaQ[
>FLHJcT006/iIaQ[>@00JcUW66/iIaP006LHJcUW6F/iIaQ[>FLIJcT200003eKkFaaFne/LE_]K75Kk
FaaFn`00A[a6gDJlA]e6_008000014KMA[a6gDJl0P0001e6gDJlA]e6_4KMA[a6g@00A]e6_4KMA[a6
gDJlA]e6_000A[a6gDJlA]e6_4KMA[a6g@00D_e>o5;m00@0000=C_aBoDkl001Fne/LE_]K75KkFaaF
ne/LE_/00P0000YK75KkFaaFne/LE_]K75KkFa`000Yoo@03001ooGom00Moo@<0035oo@00Kgom00<0
07omOod037om00<007omOod0E7om0P0002]BEe8gDUMB=e9GDSL0058gDUMB=e9GDSMBEe8gDUMB=`00
DSMBEe8gDUMB=e9GDSMBEe8g001JfU[jF]YJnU[JF_YJfU[jF]YJnU[JF_X005[jF]YJnP020003F_/0
1EkkF_/005[kG_/00e[k00QNne[k001JnelKF_]K6`002ElK0P0000]O6`00GaYO6elJGa]O6UlKGaYO
6elJ0080000;Ga/005lKGaYO6elJGa]O6UlKGaYO6`0200001ElJ001O6elKGaX00elK00=O6UlKGa/0
0P0000AO6`00Ha]O6P9O6`04Ha]O6UlKGa/2000055lK001[6FLIJaUW6F/IIaU[6@00JaUW6F/IIaU[
6FLI001[6@00IaT3JaT04fLIJaU[6F/IIaT006/IJcUW6@00JaU[>FLIJcT006/iIaU[>F/I00<00003
JaT006LI00=[6@05IaU[6F/IJaT00003JaT01VLI001[6F/IIaT0009[6@0CIaU[6F/IJaUW6F/I001[
6@00Fa]Jne/LF_]K6e[kFaaJne/KF_/01@0014KM00<004KMA]d01TKM00<004KMA]d01TKM00<004KM
A]d01TKM00<004KMA]d00dKM1P0000mBoDklD_aBo5;mC_aBo000FaaG6e/LEaaK75LKFa`00P0000eG
6`00EaaK75LKFaaG75/LEa]K75LLFa`00009Ood00`00Ooeoo@07Ood01000Ooeoo@00<7om001OOod4
0003Ood20007Ood00`00Ooeoo@0=Ood00`00Ooeoo@1BOod06`00CSIBEe8gDUM>=U9GDSMBEdhf001B
=e9GCSIBEe8gDUM>=U9G001BEe8fDUMB=e9GDSIBE`0200003eKJ001JfU[kF]YNne[JF_]JfUkkF]YJ
ne[J001JfP0200003EkkF_YNne[jG_]JnUkkF_X005[jG_]JnUkk0080000=F_YO6e[kGa]JnP00F_YO
6e[jGa]JnUlKF_X00P0002EO6e/JGa/006<KGaYS6elJHa]O6V<KGaX005lJHa]O6P00GaYS6elJHa]O
6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<KGaYS6`020000=ElJHa]O6V<K001S6elJHa]O6V<KGaX0
05lJHa]O6V<K001[>FLHJcUW6F/i001[>FLIJcUW66/iIaU[>FLH001W66/iIaQ[>FLHJcUW66/iIaP0
06LHJcUW66/i001[>FLHJcT006/iIaP00`0002YW66/iIaP006LI001W66/iIaQ[>FLHJcT006/iIaQ[
>FLIJcUW6000IaP006LHJcUW6F/iIaQ[>FLIJcT006/iIaU[>@00FaaFne/LE_]K75KkFa`200004UKk
0016_4[MA[a6gDJlB]e6_4KM0016gDJlA]e6_4KMA[a6g@80000=A[a6gDJlA]e6_4KMA[`004JlA]e6
_4KMA[`02@0001=6_4[MA[a6g@00D_e>o5;mC_aBoDklD_e>o5;m001K75KkFaaFn`02000035/LE_]K
75Kk001Fne/LE_]K75KkFaaFn`800003Fa`007om00Qoo@03001ooGom00Ioo@04001ooGom000`Ood0
05moo@03001ooGom00=oo@04001ooGom0006Ood3000>Ood00`00Ooeoo@1?Ood300006U9GDSMBEe8g
DUMB=e9GDSMBE`00DUMB=e9GDSMBEe8gDUMB=e9G001BEe8gDUMB=e9G0002F]X04E[K001JnU[JF_YJ
fU[jF]YJnU[JF_YJfU[jF]X005[kG_/00e[k00QNne[kF_]JnekkF_/005[k0P0000UK6e[kGa]Jne/K
F_]O6e[k000015lK0P001UlK00H005lKGaYO6elJGa/200002elJGa]O6UlKGaX005lJGa]O6UlKGaX0
0P0000=O6elJGa/00UlK00D005lKGa]O6elJ0080000;Ha]O6UlKGa]S6elJ001O6f<KGaYO6`020000
5UlJGa]O6f<KGaYO6`00JaUW6F/I001[6FLIJaUW6F/IIaU[6FLI001W6@000V/I00iW6F/IJaU[6FLI
001[6F/iIaU[>F/IJcT006/i100000][6F/iIaU[>F/I001W6F/iJaT006LI00=[6@05001[6F/IJaUW
6@03JaT01FLI001[6F/IIaT00f/I00EW6F/I001[6FLI009[6@06001Jne/KF_]K75[k0P0000AK75[k
Fa/000Q6g@030016gDKM00I6g@8000A6g@P000E6g@030016gDKM00I6g@05001Bo5;lD_e>o002D_`0
1E;mC_`005LLFa`00P0000aG75/LEa]K75LLFa`005/LEaaK75LKFa`2000015LKFaaG70002Wom00<0
07omOod01Gom0`00<Gom001POod00`00Ooeoo@05Ood00`00Ooeoo@04Ood00`00Ooeoo@0?Ood00`00
Ooeoo@1<Ood200006UIGDSIFE`00DUM>=U9GDSMBEdhfDUMB=`00CSIBEe8gDUM>=U9GDSMBEdhf001B
=e9GDSH200003e[kE]YJneKJF_/005kkF]YJne[JG_]JfU[kF]YNn`0200006e[j001JnUkkF_YNne[j
G_]JnUkkF_YNne[j001JnelKF_YO6e[kGa]JnUlKF_]O6e[j001JnP0200009ElKGaYO6e/JGa]O6UlK
FaYO6`00Ha]O6V<K001S6elJHa]O6V<KGaYS6elJ001O6V<KGaX005lJHa]O6V<KGaYS6elJHa/006<K
0080000;GaYS6elJHa]O6V<KGaYS6elJ001O6P0200009V<KGaYS6elJHa]O6V<KGaYS6`00JcT006/i
IaU[>FLHJcUW6F/iIaP006LIJcUW6000IaQ[>FLHJcUW6000IaQ[>FLHJcUW66/iIaP30000;6LHJcUW
66/iIaQ[>FLH001W6F/iIaQ[>@00JcUW66/i001[>FLHJcUW6F/iIaQ[>FLI001W6000IaU[>FLHJcUW
6F/i001[>FLIJcUW66/iIaT005KkFa`200005EKkFaaFne/LE_]K7000A]e6_4[MA[a6gDJlB]e6_000
A[a6gDJlA]e6_00800007d[MA[a6gDJl0016_4KMA[a:gDJlA]e6_4[M0016gDJlB]e6_4KMA[a:gDJl
001>o5;mC_aBoDklD_e>o5;m00<0000<FaaFne/LE_]K75KkFaaFne/L001K75Kk0P0000MK75KkFaaF
ne/LE_/00009Ood00`00Ooeoo@06Ood00`00Ooeoo@0`Ood005Uoo@@000Aoo@03001ooGom009oo@80
00Moo@03001ooGom011oo@03001ooGom04Yoo@0J001BEe9GDUMFEe9G001B=e9GDSMBEe8gDUMB=e9G
DSL0058gDUMB=e9GDSMBEe8gDUMB=`<000=JfP0<F]]JfU[JF]YJf`00F_YJfU[jF]YJnU[J0P000U[k
00ENne[k001Jnekk00=Jn`03G_]Jne[k0080000>F_/005[kGa]Jne/KF_]O6e[kFa]JnelKF_/000]O
6`0?001O6P00001O6elJGa]O6UlKGaYO6elJGa/005lK0080009O6`05GaYO6elKGa]O6P03Ga/01@00
Ga]O6f<KGaX00UlK00YS6elJGa]O6f<KGaX005lKHa]O6P9O6`0GHa]O6UlKGa]S6elJGa/006/IIaU[
6FLIJaUW6F/IIaT006LIJaUW6F/IIaT00002JaT026LI001[6F/iIaU[>F/IJcT300004V/i001[>F/I
JcUW6F/iJaT006LIJcU[6F/iIaU[>@00JaT000=[6@06IaU[6F/IJaUW6@000V/I00UW6@00JaU[6FLI
JaT006/IIaT00f/I00=W6F/IJaT00P0000YK6e[kFaaJne/KF_]K75[kFa/000M6g@H000A6g@030016
gDKM00I6g@030016gDKM00I6g@030016gDKM00I6g@04001>o5;lD_`400003E;mC_`005LLFaaG6e/L
EaaK75LKFaaG75/L0080000:EaaK75LKFaaG75/LEa]K75LL0009Ood00`00Ooeoo@05Ood3000`Ood0
05moo@04001ooGom0003Ood00`00Ooeoo@05Ood00`00Ooeoo@0BOod00`00Ooeoo@17Ood20000:U8f
EUMB=UIGDSIFEe8f001B=e9GCSIBEe8gDUM>=U9G001BEdhfDUMB=e9GCSIBEe8gDUL005[kE]YJneKJ
F_]FfU[kE]YJneKJF_/005kkF]YJn`80000LF_YNne[jG_]JnUkk001Nne[jG_]JnUkkF_YNn`00Ga]J
nelKF_X005[kGa]JnUlKF_]O6e[jGa/20000F5/K001O6UlKFaYO6elJGa]K6UlKGaYO6e/J001O6V<K
GaYS6elJHa]O6V<KGaYS6elJHa/006<KGaYS6elJHa]O6V<KGaYS6elJHa/006<K001S6elJHa]O6V<K
GaYS6elJHa]O6P00GaX005lJHa]O6V<KGaYS6elJHa]O6V<K001S6`00JcUW66/iIaU[>FLH001W6F/i
IaQ[>FLIJcUW6000IaP006LHJcUW66/i0`0003i[>@00JcUW66/i001[>FLHJcUW6000IaU[>FLHJcUW
6F/iIaQ[>@00JcUW66/iIaU[>FLHJcUW6@00IaQ[>FLIJcT006/iIaU[>@00JcUW6F/iIaQ[>FLIJcUW
6000IaT005KkFaaFne/LE_]K75KkFaaFn`00A[a6gDJl1000029:gDJl0016_4[MA[a6gDJlB]e6_4KM
001:gDJlA]e6_4[MA[a6g@00B]e6_4KMA[a:gDJlA]e6_000A[a6gDJlB]e6_0L0000?C_aBoDklD_e>
o5;mC_`005KkFaaFne/LE_]K75Kk0080000<Fa`005/LE_]K75KkFaaFne/LE_]K700027om0`00>Gom
001POod20004Ood30005Ood3000COod00`00Ooeoo@15Ood00`00EUMBE`02DUL05UIGDUMBEe9GEUL0
059GDSMBEe8gDUMB=e9GDSMBE`00DUMB=e9GDSMBEe8g0P0000EJf`00F]YJfU[K00=JfP06F]]JfU[J
F]X005[J0P0000ENne[kF_]Jnekk00=Jn`06G_/005[kF_]Nne[k0P0001=O6e[kFa]JnelK001K6e[k
Ga]Jne/KF_]O6`00Ga]K6elKFa/00008Ga/200002elK001O6UlKGaYO6elJGa]O6UlKGaX00P0000AO
6`00Ga]O6P=O6`03GaYO6elK0080009O6`06Ha/005lKGa]S6elJ0UlK00YS6`00001O6f<KGaX005lK
Ha]O6P9O6`0IHa]O6P00001S6elJGa/006/IIaU[6FLI001W6F/IIaU[6FLIJaUW6F/IIaT006/IJcT0
0`0001Y[>FLIJcT006/iIaU[>F/I001W6F/iJaT006LIJcU[6F/iIaU[>F/IJcT006/i001[6FLI0f/I
00EW6@00JaU[6FLI00=[6@05001[6@00JaUW6@03JaT01FLIJaU[6@00IaT00V/I00T005[kFa]Jne/L
F_]K6e[kFa`010001TKM00<004KMA]d01TKM0P001dKM00<004KMA]d00dKM20001DKM00H004klD_aB
o5;mC_`2D_`01e;m001K75LLFaaG6e/L0080000=Ea]K75LL001G6e/LEaaK75LKFaaG75/LEa/00P00
1Gom0P000Wom00<007omOod0=gom001^Ood00`00Ooeoo@0DOod00`00Ooeoo@12Ood30000658fEUMB
=UIGDSIFEe8fEUMB=P00CSIBEe8gDUM>=U9GDSMBEdhf001B=e9GCSIBE`80000NE]YJneKJF_/005[k
E]YJneKJF_]FfU[kE]YJneKJ001JnUkkF_YNne[jG_]JnUkkF_YNne[jG_/005kk0P0000eJnUlKF_]O
6e[jGa]JnelK001O6e[kGa]JnP0200003UlKFa]O6e/KGa/005lKGaYO6e/JGa]O6UlK0003Ga/0@e/J
001O6V<KGaYS6elJHa]O6P00GaYS6elJHa/006<KGaYS6elJHa]O6P00GaYS6elJHa]O6P00GaYS6elJ
Ha]O6V<K001S6elJHa]O6V<K001S6elJHa]O6V<KGaX005lJHa]O6V<KGaX006LIJcUW6000IaU[>FLH
JcUW6F/iIaQ[>FLI00@0000nJcUW66/iIaQ[>@00JcUW66/iIaQ[>FLH001W6000IaU[>FLHJcUW6F/i
IaQ[>@00JcUW66/i001[>FLHJcUW6@00IaQ[>FLIJcUW66/iIaU[>@00JcUW6F/iIaQ[>FLIJcUW6000
IaU[>FLHJcT005/LE_]K75KkFaaFn`80000JFaaFn`00A[a6gDJlB]e6_4KMA[a:g@00A]e6_4[MA[a6
gDJlB]e6_000A[a:gDJlA]e6_0P0000JB]e6_4KMA[`004JlA]e6_4[MA[a6gDJlB]d005;mC_aBoDkl
D_e>o5;mC_aBo@00FaaFn`80000<FaaFne/LE_]K75Kk001Fne/LE_]K75Kk0`0000=Fne/L00002Gom
00<007omOod0=Wom001^Ood00`00Ooeoo@0EOod00`00Ooeoo@0oOod20002EUL0159F001BEeIG0e9G
011FEe9GDUMBE`00DSMBEe8gDUMB=e9GDSMBEe8g001B=`800007F]]JfU[KE]YJfe[J00000e[J00EJ
fe[JF]YJfU[K00800003F_/005[k009Jn`05G_]Jne[kF_]Nn`03F_/03ekk001K6e[kGa]Jne/KF_]O
6e[kFa]JnelK001K6`0200002E/KGa]K6elKFa]O6e/KGa/00004Ga/20006Ga/01@00GaYO6elJGa/0
0P0000UO6UlKGa]O6elJGa/005lKGaX00UlK00H005lJGa]O6f<KGaX2Ga/01P00GaYO6elKHa/0009O
6`06Ha]O6UlKGa]S6`000UlK00IS6elJ001O6f<KGaX2Ga/03F<KGaX006LI001W6F/IIaU[6FLIJaUW
6F/I00<0000OJcT006/iJaU[>FLIJcU[6@00IaU[>F/IJcUW6F/iJaT006LIJcU[6F/iIaU[>F/IJcT0
06/iJaU[>FLI00000V/I00EW6@00JaU[6FLI00=[6@05IaU[6@00JaT00003JaT01FLIJaU[6@00IaT0
0f/I00EW6F/I001K75[k00<00005F_]K6e[kFa`00009A]d00`00A]e6g@05A]d60004A]d00`00A]e6
g@06A]d00`00A]e6g@06A]d00`00D_e>o002D_`00e;mC_aBo00400002eLLFaaG6e/LEaaK75LKFa`0
05/LEa/00`0000IG6e/LEaaK75LK000:Ood00`00Ooeoo@0eOod006ioo@03001ooGom01Ioo@8003io
o@0J001FEe9FEUMBEUIG001FEe8fEUMB=UIGDSIFEe8fEUL0059GCSIBEe8gDUM>=U9GDSMBE`80000?
E]YJneKJF_]FfU[kE]YJneKJ001FfU[kE]YJneKJ008000AJn`0:001JnUkkF_YNne[jG_]JnUkkF_X2
00006elK001O6e[kGa]JnUlKF_]O6e[jGa]JnelK001O6e/KGa]K6elKFa]O6e/KGa]K6elK001O6`02
00001E/JGa]O6elKFaX00elK00=K6P00GaX00P0000]S6elJHa]O6V<KGaYS6elJHa/006<K0080000;
GaYS6elJHa]O6V<KGaYS6elJ001O6P0200002f<KGaYS6elJHa]O6V<KGaYS6`00Ha/00P00011O6V<K
GaYS6elJHa]O6V<KGaX006LIJcUW66/iIaU[>@@0000nIaU[>FLIJcT006/iIaQ[>FLH001W66/iIaQ[
>FLHJcUW6000IaT006LHJcUW6F/iIaQ[>@00JcUW66/iIaU[>FLH001W6@00IaQ[>FLIJcUW66/iIaU[
>@00JcUW6F/i001[>FLIJcUW6000IaU[>FLHJcUW6F/iIaQ[>@80000EE_]K75KkFaaFne/LE_]K7000
B]e6_4KMA[a:gDJlA]e6_000A[a6gDJl00@0000PB]d00000A[a:gDJlA]e6_4[MA[a6g@00B]e6_4KM
A[a:gDJlA]d004[MA[a6gDJlB]e6_4KMA[`004klD_e>o0@0000=D_e>o5;m001K75KkFaaFne/LE_]K
75KkFa`00P0000YFne/LE_]K75KkFaaFne/LE_/000Uoo@03001ooGom03Eoo@00KWom00<007omOod0
67om00<007omOod0>Gom0P000eIG00EBEUIGEUMFE`00009BE`0>EUMBEe9GDUMFEe9G001B=e9GDSMB
Ee8gDUMB=`80000=F]/005[KF]YJfeKJF]]JfU[KE]YJfe[J00000U[J0P001e[k00D005[kF_]Jnekk
00=Jn`0>001Jne/KF_]O6`00Fa]JnelKF_]K6e[kGa]Jn`80000>Ga/005lKFa]O6e/KGa]K6elKFa]O
6e/KGa/000aO6`04001O6elKGaX3Ga/02ElJGa]O6elKGaYO6`00Ha]O6P02Ga/01V<KGaYO6elKHa]O
6P9O6`06001O6UlKGa]S6elJ0UlK00IS6elJGa]O6f<K0002Ga/01V<KGaYO6elKHa]O6P9O6`05001O
6P00IaU[6@0300009f/IIaT006LIJcUW6F/iIaU[>@00JcU[6@00IaU[>F/IJcUW6F/iJaT006LIJcT0
06/iIaU[>F/IJcUW6@00JaU[>FLIJcU[6F/iIaT00002JaT02FLIJaU[6F/IIaU[6@00JaUW6@02JaT0
1P00IaU[6F/I001W6@=[6@0@IaU[6F/IJaT006/I001K75[kFa]Jne/LF_]K6e[k0005A]d70006A]d2
0007A]d00`00A]e6g@06A]d00`00A]e6g@03A]d600001DklD_aBo5;mC_`00U;l00P005LKFaaG75/L
Ea]K75LL0P0000aK7000FaaG6e/LEaaK75LKFaaG75/L000:Ood00`00Ooeoo@0dOod006ioo@<001Uo
o@03001ooGom03Moo@0Z001BEUIGDUIFEe9FEUMBEUIGDUH0058fEUMB=UIGDSIFEe8fEUMB=P00DSMB
EdhfDUMB=`00E]YJneKJ001FfU[kE]YJneKJF_]FfU[kE]YJneKJ0P002U[k00D005[jG_]JnUkk0080
000KF_]O6e[jGa]Jn`00F_YO6e[kGa]JnUlKF_/005/KGa]K6elK001O6e/KGa]K6elKFa]O6e/K0080
0003Ga/005lK009O6`06FaYO6elKGa]K6UlK0P0000]K6P00GaYS6elJHa]O6V<KGaYS6elJ0080000;
Ha/006<KGaYS6elJHa]O6V<KGaYS6`0200002elJ001O6V<KGaYS6elJHa]O6V<KGaX00P0000US6`00
Ha]O6V<KGaYS6elJHa/00P0000=O6V<K00000P0004m[>FLHJcUW6F/i001[>FLIJcUW6F/iIaT006LH
001W66/iIaQ[>FLHJcUW6000IaU[>FLHJcT006/iIaQ[>FLI001W66/iIaU[>FLHJcUW6@00IaP006LI
JcUW66/iIaU[>@00JcUW6F/iIaQ[>FLI001W6000IaU[>FLHJcUW6F/iIaQ[>@00JcUW6000E_]K75Kk
FaaFne/LE_]K700600003DJlB]e6_4KMA[`004JlA]e6_4[MA[a6gDJl0080000>A]e6_4[MA[a6gDJl
B]e6_000A[a:gDJlA]e6_0P0000CB]e6g4KMA]`004klD_e>o5;mC_aBoDklD_e>o000E_]K75KkFa`0
0P0000eFne/LE_]K7000FaaFne/LE_]K75KkFaaFn`02000:Ood00`00Ooeoo@0cOod006eoo@03001o
oGom01]oo@03001ooGom03Aoo@<000=FE`08DUIFEeIGEUMBEUIG001FE`=BE`09EUMBEe9GDUMFE`00
DUMB=e9G0080000>F]YJfeKJF]]JfP00E]YJfe[JF]]FfU[KF]YJf`800003F_/005[k00YJn`0A001J
n`00001O6e[kFa]JnelKF_]K6e[k001Jne/KF_]O6`02000035/KGa]K6elKFa]O6`00Ga]K6elKFa]O
6`800005Fa]O6e/KGa/00007Ga/00`00Ga]O6`02Ga/01000Ga]O6elJ0elK00UO6P00Ga]S6elJGa/0
06<KGaX00UlK00IS6elJGa/006<KGaX2Ga/01P00GaYO6elKHa]O6P9O6`06001O6UlKGa]S6`000UlK
00IS6elJGa/006<KGaX20000;V<K001[6FLIJaUW6F/I001[>FLIJcUW6F/iIaU[>FLI001W6F/iJaU[
>FLIJcU[6@00IaU[>F/IJcUW6F/i001[>FLI001[6F/iIaU[>F/IJcUW6@00JaU[>@000f/I00EW6F/I
JaT006LI00=[6@05IaU[6F/I001W6@03JaT01FLIJaU[6F/I00000f/I00MW6@00F_]K75[kFa]Jn`02
00000e/KF_/00008A]d00`00A]e6g@06A]d20006A]d70004A]d00`00A]e6g@06A]d01000D_aBoDkl
0U;l00IBoDklD_`005/LEa/200003E/LEa]K75LLFaaG6`00EaaK75LKFaaG75/L00800003EaaK7000
00Uoo@03001ooGom03=oo@00KGom00<007omOod077om00<007omOod0<Wom01P005IGDUIFE`00EUMB
EUIGDUIFEe9FEUMBEUIG001FEe8fEUMB=UIGDSIFEe8fEUL300004U[kE]YJneKJF_]FfU[kE]X005KJ
F_]FfU[kE]YJn`00F_]Fn`9Jn`03001Jne[k00QJn`80000=F_YO6e[kGa]JnUlKF_]O6e[jGa]Jn`00
F_X00P0000aO6e/KGa]K6elKFa]O6e/KGa/005lKFa/2000025lKFa]O6e/KGa]K6elK0003Ga/01E/J
000005lKFaX00elK00IK6P00GaYS6elJHa/200002elJHa]O6V<KGaYS6`00Ha]O6V<KGaX00P0000]S
6elJHa]O6V<KGaX005lJHa]O6V<K0080000:GaYS6elJHa]O6P00GaYS6elJHa/40000CelJHa]O6V<K
001[>FLIJcT006/iIaU[>FLIJcUW6F/iIaT006LI001W66/iIaQ[>FLHJcT006/iIaQ[>FLIJcUW6000
IaT006LHJcUW6F/iIaQ[>FLI001W66/iIaU[>@00JcUW6F/iIaP006LIJcUW66/iIaU[>FLH001W6@00
IaQ[>FLIJcUW66/i001[>FLHJcUW6F/i001K75Kk00<0000JE_]K75KkFaaFn`00A[a:gDJlA]e6_4[M
A[a6g@00B]e6_4KMA[a:gDJlA]d004[M0016g@@0000MA[a:gDJl0016_4[MA[a6gDJlB]e6_000A]a:
gDKLA]e6g4[MA]a6g@00D_e>o5;mC_aBoDklD_e>o003000035KkFaaFne/LE_]K75KkFaaFn`00E_]K
70<00005FaaFne/LE_/0000:Ood00`00Ooeoo@0bOod006eoo@03001ooGom01eoo@03001ooGom031o
o@03001FEeIF009FE`03001BEUIG009FE`08DUIFEeIGEUMBEP00DUMFE`=BE`0DEUMBEe9GDUL005KJ
F]]JfU[KE]YJfe[JF]]FfU[KF]X005KJF]]JfP8000EJn`03001Jne[k00IJn`80000KFa]Jn`00F_]K
6e[kGa]Jne/KF_]O6e[kFa]Jn`00Fa]O6e/KGa]K6elKFa]O6e/KGa]K6elK0080000<Fa]O6e/KGa]K
6elKFa]O6e/KGa/005lK0P002ElK00@005lK0000009O6`09Ha]O6UlKGa]S6elJGa/006<K00800003
Ga]S6elJ009O6`06Ha]O6UlKGa/005lJ0P0000IS6elJGa]O6f<KGaX2Ga/00`00GaX0000200001ElJ
Ga]O6f<KGaX00UlK02iS6`00JaT006/iIaU[>FLIJcUW6F/iIaT006LIJcUW6@00IaU[>F/IJcT006/i
JaU[>FLIJcU[6F/iIaT006/IJcUW6F/iJaU[>FLI001[6F/iIaU[>F/IJcT0009[6@03001W6F/I009[
6@05IaU[6F/I001W6@02JaT00`00IaU[6@02JaT01@00JaU[6F/IIaT00f/I0P0000UJne/LF_]K6e[k
FaaJne/K000024KM00<004KMA]d00dKM1P001dKM00<004KMA]d01TKM00<004KMA]d01TKM00@005;l
D_aBo@@0000=C_aBo000FaaG6e/LEaaK75LKFaaG75/LEa/00P0000UK75LKFaaG75/LEa]K75LL0000
2Wom00<007omOod0<Gom001]Ood3000NOod00`00Ooeoo@0]Ood200005eIGDUIFEe9FEUMBEP00DUIF
Ee9FEUMBEUIGDUIFE`00EUMB=UIGDSIFEe8fEUL00P0000iJfP00E]YJneKJF_]FfU[kE]YJneKJF_/0
05[k0P000U[k00MFne[kF_]JneKkF_/00005F_/200003U[kFa]Jne/LF_/005[jGa]JnelKF_YO6e[k
Ga/200002e/K001K6elKFa]O6e/KGa]K6elKFa/00P0000iO6`00Ga]K6elKFa]O6e/KGa]K6elKFa]O
6`000elK00EK6UlKGa]O6e/J00=O6`0UFaX005lJHa]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<K
GaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaX00`0006AO6V<KGaYS6elJHa]O6V<K
GaYS6elJHa/006/iIaU[>FLIJcUW6F/iIaT006LIJcUW6F/i001[>FLHJcT006/iIaQ[>FLIJcUW66/i
IaT006LH001W6F/iIaQ[>FLIJcT006/iIaU[>FLHJcUW6@00IaP006LIJcUW66/iIaU[>FLH001W6F/i
IaQ[>@00JcUW66/i001[>FLHJcUW6F/iIaQ[>@00JcT005/LE_]K75KkFaaFne/LE_]K7000A]e6_4[M
A[a6g@P00004A[a:gDJlA]d200005TJlA]e6_4[MA[a6gDJlB]d004KMA[a:gDJlA]e6_4[M0016gDKL
B]e6g4KM1`0000mBoDklD_e>o5;mC_aBo@00FaaFne/LE_]K75KkFa`00P0000]Fn`00E_]K75KkFaaF
ne/LE_]K700000Yoo@03001ooGom035oo@00KGom00<007omOod07gom00<007omOod0:gom00@005IG
EUMFEP=FE`05EUIFE`00EUMBEP03EUL01E9FEUMFEeIG00000U9G01AFEe9GDUL005[jF]YJnU[J001F
fU[KF]YJfeKJF]]JfU[KE]YJf`002e[k00<005[kF_/00P0002YK6e[kFa]Jne/KF_]K6`00Ga]Jne/K
F_]O6e[kFa/005lKFa]O6e/K001K6elKFa]O6e/KGa]K6`00Fa]O6e/KGa/005lKFa]O6e/KGa]K6elK
Fa/200000elK001O6`09Ga/01P00Ga/005lKHa]O6P9O6`0:Ha]O6UlKGa]S6`00Ga/006<KGaX2Ga/0
1F<KGaYO6elKHa/00P0000=O6`00GaX00UlK00=S6elJ0000100000=O6`00GaX00UlK00IS6elJGa]O
6f<KGaX20000;V<K001[>FLIJcUW6F/iIaT006LIJcUW6F/iIaU[>@00JcT006/iJaU[>FLIJcU[6F/i
IaT006/IJcUW6@00JaU[>FLIJcT006/iIaU[>F/IJcUW6F/iJaT006LI0f/I00EW6F/IJaT006LI00=[
6@05IaU[6@00JaT00003JaT01FLIJaU[6F/I00000f/I00T005/KF_]K75[kFa]Jne/LF_/01P0014KM
00<004KMA]d01TKM0P001dKM00<004KMA]d00dKM20001DKM00D005;lD_aBo4kl00=Bo007C_`005LL
FaaG6e/LEa`00P0000aK75LLFa`005/LEaaK75LKFaaG75/LEa/20007Ood200000gom001oo@0aOod0
06eoo@03001ooGom021oo@03001ooGom02Uoo@0H001BEUIGDUIFEe9FEUMBEUIGDUH0059FEUMBEUIG
DUIFEe9FEUMBEP00DSIFEe8f0P0000iNne[JG_YJfUkk001JneKJF_]FfU[kE]YJneKJ0P0000AJn`00
F_]Fn`=Jn`06E_]Jne[kF_]Fne[k0P0000mJne/LF_]K6e[kFaaJne/KF_]K7000Ga]JnUlKF_/00P00
00]O6e/KGa]K6elKFa/005/KGa]K6elK0080000CFa]O6e/KGa]K6`00Fa]O6e/KGa]K6elKFa/005/K
GaaK6elK00000elK00AK6UlKGa]O6`80009O6`09FaX005lJHa]O6V<KGaYS6elJ0080000BHa]O6P00
GaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaX005lJ0`00069O6V<K001S6elJHa]O6P00GaYS6elJHa]O
6V<KGaX005lJHa]O6V<K001[>FLIJcUW6@00IaU[>FLIJcUW6F/iIaU[>@00JcUW66/iIaU[>FLHJcUW
6@00IaQ[>FLIJcT006/iIaU[>@00JcUW6F/iIaQ[>FLIJcUW6000IaT006LHJcUW6F/iIaQ[>@00JcUW
66/iIaU[>FLHJcT006/iIaQ[>FLIJcUW66/i001[>FLHJcUW6@00E_]K75KkFaaFne/L0P0001AFne/L
0016gDJlB]e6_4KMA[a:gDJl0016_4[MA[a6gDJlB]e6_4KM0P0000A6_4KMA[a:g@P0000JA]a6gDKL
B]d004KMA]a:gDKLA]e6g4[MA]`004klD_e>o5;mC_aBoDklD_e>o000E_]K7080000<E_]K75KkFaaF
ne/L001K75KkFaaFne/L0P0000=Fne/L00002Wom00<007omOod0;gom001/Ood00`00Ooeoo@0ROod0
0`00Ooeoo@0WOod200000eIGEUIFE`02EUL01UIFEUMFEeIGEUH0009FE`05DUIFEeIGEUMBEP02EUL3
00003U[JF_YJfU[jF]YJnU[JF_X005[KE]YJfe[JF]/20004F_/00`00F_]Jn`06F_/200003e[k001K
6e[kFa]Jne/KF_]K6e[kFa]Jne/K001O6`0200002e/KGa]K6elKFa]O6e/KGa]K6`00Fa/00P0000eO
6e/KGa]K6elKFa]O6e/K001K6elKFa]O6`0200001U/KGa]K6elKFa/000IO6`03001O6elK00=O6`05
001O6elKHa]O6P02Ga/02P00GaYO6elKHa]O6P00Ga]S6elJ0UlK0P000UlK00=S6elJ00000P0000=O
6UlKGa/00P000UlK00IS6elJGa]O6`00GaX2Ga/01V<K000005lKHa]O6P9O6`0^001W6F/iIaT006LI
JcUW6F/iIaU[>FLIJcT006/i001[>FLIJcU[6F/iIaT006/IJcUW6F/iJaU[>@00JcT006/iIaU[>F/I
JcUW6F/iJaT006LIJcU[6@00IaT3JaT01@00JaU[6F/IIaT00f/I00D006/I001[6FLI00=[6@80009[
6@06IaU[6F/I001Jne/K0`0000IK6e[kFaaJne/K0007A]d00`00A]e6g@06A]d60004A]d00`00A]e6
g@06A]d00`00A]e6g@06A]d00`00C_aBo002D_`00dklD_aBo00400002e/LEa]K75LLFaaG6e/LEa`0
05LKFa`00`0000IK75LLFaaG6e/L0009Ood00`00Ooeoo@0_Ood006aoo@04001oo@00000ROod00`00
Ooeoo@0TOod200009EIFFWL005IGDUIFEe9FEUMBEUIGDUIFE`00EUMBEUIGDUIFEe9FEUMBEUIG001N
nU[JG_]JfUkjF]YNne[JG_YJfUkk001JneKJ00800003F_]Fne[k009Jn`05E_/005[kF_]Fn`03F_/0
;EKk001Jne/LE_]K7000Fa]Jne/LF_]K6e[kFaaJne/KF_]K7000Ga]K6elKFa]O6e/KGa]K6elKFa]O
6e/K001K6elKFa]O6e/KGa]K6elKFa]O6e/K001K6`0200002UlKFa]O75/KGa]K6elLFa/005/J0elK
00D005lKGa]O6e/J00=O6`0E001S6elJHa]O6P00GaYS6elJHa]O6V<KGaX005lJHa]O6P00GaYS6elJ
00<00004GaYS6`00Ha/200002elJHa]O6V<KGaYS6elJHa]O6P00GaX00P00051S6elJHa]O6V<KGaYS
6elJ001W6@00IaU[>FLIJcUW6F/iIaU[>@00JcUW6F/i001[>FLHJcUW6@00IaQ[>FLIJcUW66/iIaU[
>@00JcUW6F/iIaQ[>FLIJcUW6000IaU[>FLHJcT006/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[
>@00JcUW66/iIaT006LHJcUW6F/iIaQ[>FLI0P0001EK75KkFaaFne/LE_]K75Kk0016_4KMA[a:gDJl
A]e6_4[M0016gDJlB]d010000216_4[M001:gDJlA]e6_4[MA[a6gDJl0016g4KMA]a:gDKLA]e6g000
A]a6gDKLB]e6g4KMA]a:g@00D_e>o5;m100000e>o5;mC_`005KkFaaFne/LE_]K75KkFaaFn`020000
2U/LE_]K75KkFaaFne/LE_]K70002Gom00<007omOod0;Wom001/Ood2000UOod00`00Ooeoo@0ROod0
1P00FWIJEUYfFUH0009FE`05EUIFEeIGEUMFEP02EUL00`00DUIFE`02EUL00e9FEUMFE`0200003Ekj
001JnU[JF_YJfU[jF]YJnU[JF_YJfU[j008000UJn`03001Jne[k009Jn`8000IJn`09001K6e[kFa]J
ne/KF_]K6e[k0080000;Fa/005lKFa]O6e/KGa]K6elKFa]O6`0200006e/K001K6elKFa]O6e/KGa]K
6elKFa]O6e/K001K6elKFa]O6e/KGa]K6elKFa]O6e/K001O6`020009Ga/01@00Ga/00000GaX00UlK
00MS6elJGa]O6f<K001O6`0200001ElJ00000000GaX00UlK00IS6elJGa/006<KGaX2Ga/01V<KGaYO
6elKHa]O6P9O6`06001O6UlKGa]S6elJ0UlK02QS6elJGa]O6`00IaU[>FLIJcUW6F/iIaU[>@00JcUW
6F/iIaT006/IJcUW6@00JaU[>FLIJcU[6F/iIaU[>@00JcT006/iJaU[>FLIJcU[6@800008JcU[6F/i
IaU[>@00JaT000=[6@05IaU[6F/IJaT00003JaT01VLI001[6F/IIaT0009[6@0BIaU[6F/IJaUW6@00
JaT005[kFa]Jne/LF_]K6e[kFaaJn`001DKM1P001dKM00<004KMA]d01DKM00<004KMA]d01TKM00<0
04KMA]d00dKM1P000e;l00a>o5;lD_aBo000FaaG75/LEa]K75LLFa`200002eLL001G6e/LEaaK75LK
FaaG75/LEa/00P002Gom00<007omOod0;Gom001/Ood00`00Ooeoo@0UOod00`00Ooeoo@0POod09@00
FWMFEUYgFUIJM`00EUMBEUIGDUIFEe9FEUMBEUIGDUH0059FEUMBEUIGDUH005[JG_YJfUkj001NnU[J
G_]JfUkjF]YNne[J00800004G_/005[kE_/3F_/01eKkF_]Jne[kE_/005[k0080000?FaaJne/LE_]K
75[kFaaFne/L001K6e[kFaaJne/K0080000JF_]K75[kGa`005lKFa]O6e/KGa]K6elK001O6e/KGa]K
6`00Fa]O6e/KGa]K6elKFa]O6`80000?Fa/005/KGaaK6elKFa]O75/KGa]K6elLFa/005/J00=O6`05
FaYO6elKGa]K6P03Ga/03P00Ha]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha/2000055lJHa]O6V<KGaYS
6elJHa/006<K001S6elJHa]O6V<KGaYS6elJHa/200002UlJ001O6V<KGaYS6elJHa]O6V<K0P00059O
6P00IaU[>FLIJcUW6F/i001[>FLIJcUW6F/iIaT006LI001W66/iIaU[>FLHJcUW6F/i001[>FLIJcT0
06/iIaU[>FLHJcT006/iIaQ[>FLIJcUW66/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaU[>FLH001W
6@00IaQ[>FLIJcUW66/iIaT006LHJcUW6@00E_]K75KkFaaFne/LE_]K70H0000=A[a:gDJlB]d004[M
A[a:gDJlB]e6_4[MA[`00P0000e:gDJlA]e6_4[MA[a6g@00B]e6g4KMA]a:g@0800004dKLB]e6g4[M
001BoDklD_e>o5;mC_aBoDklD_d005/LE_]K75Kk0080000;FaaFne/L001K75KkFaaFne/LE_]K7002
00000eKkFa`00008Ood00`00Ooeoo@0]Ood006aoo@03001ooGom02Ioo@8001ioo@800008FWIJEUYf
FUIJMUYFFWH000=FE`0:EUIFEeIGEUMFEUIG001FEe9FEUL200004e[jG_YNnUkjF_X005[JF_YJfU[j
F]YJnU[J001JnekkF_YNn`0000YJn`03001Jne[k00YJn`03001K6e[k008000MK6`05001O6e/KGa]K
6`0200006elKFa]O6e/KGa/005lKFa]O6e/KGa]K6elK001O6e/KGa]K6`00Fa]O6e/KGa]K6elKFa]O
6`0200000e/K001O6`08Ga/200001UlK001O6elKHa]O6P9O6`03Ha]O6P0000<0009O6`06Ha]O6UlK
Ga]S6elJ0P0000IS6elJGa/006<KGaX2Ga/01V<KGaX00000Ha]O6P9O6`0:001O6UlKGa]S6elJGa/0
06<KGaX2Ga/0;P00IaU[>FLIJcT006/iIaU[>FLIJcUW6F/iIaT006/IJcUW6F/iJaU[>FLIJcT006/i
IaU[>F/IJcT006/iJaU[>@00JcU[6F/iIaU[>F/IJcT006/i001[6FLI0f/I00EW6@00JaU[6FLI00=[
6@05IaT006/IJaUW6@03JaT03FLI001[6F/IIaU[6@00FaaJne/KF_]K75[k00800003FaaJn`0000M6
g@030016gDKM00M6g@030016gDKM00=6g@P000A6g@030016gDKM00I6g@03001Bo4kl00=Bo006C_aB
o5;l001G6e/L0P0000]G6e/LEaaK75LKFa`005/LEa]K75LL00800005FaaG75/LEa/00009Ood00`00
Ooeoo@0/Ood005]oo@@000=oo@8000Qoo@03001ooGom02Qoo@03001ooGom01Yoo@0E001JEUYgEUIJ
MeYFFWMFEUYgFUH0059FEUMBEUIGDUIFEe9FEUMBEUIG00<0000=G_YJfUkjF]YNnU[JG_YJfP00F]YN
nU[JG_/00P0000IJnUkkF_YNne[j0002F_/01UKkF_]Jne[kE_]Jn`80000=E_/005[kFaaFne/LF_]K
75KkFaaJne/LE_/00`0000aJnelLF_]K75[kGaaJne/LF_]O7000Ga/200003E/KGa]K6elKFa]O6e/K
Ga/005lKFa]O6e/K0080000<GaaK6elKFa]O75/K001K6elLFa]O6e/K0P0000IO6e/KGaaK6`00FaX3
Ga/01E/JGa/00000FaX00elK00H006<KGaYS6elJHa/300005F<KGaYS6`00Ha]O6V<KGaYS6elJ001O
6V<KGaYS6elJ001O6V<KGaYS6`0200002elJHa]O6V<KGaYS6`00Ha]O6V<KGaX00P0001]S6elJHa]O
6V<K001[>FLIJcT006/iIaU[>FLIJcUW6F/iIaT006LI001W6F/iIaQ[>FLIJcT00P0002UW6F/iIaQ[
>FLIJcT006/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/i001[>FLHJcUW6@00IaQ[>FLIJcUW66/iIaT0
06LH001W6F/iIaQ[>FLI00800008JcUW6F/iIaQ[>@00FaaFn`<0000CE_]K75KkFa`004[MA[a:gDJl
B]e6_4[MA[`004JlB]e6_4[MA[`02@0001i6_4[MA[a:g@00B]e6g4[MA]a:gDKLB]d004[MA]a:gDKL
B]e6g4[MA]`004klD_e>o5;mC_aBoDklD_d300002e/LE_]K75KkFaaFne/LE_/005KkFa`00P0000QF
ne/LE_]K75KkFaaFn`002Gom00<007omOod0:gom001KOod00`00Ooeoo@03Ood01000Ooeoo@001gom
0P00:Wom00<007omOod067om00h005YFFWIJEUYfFUIJMUYFFWIJEUYf001FEeIF0eIG00IFEUIGEUMF
EeIF0002G_X01E[jG_YNnUkjF_X00ekj00=JnP00F]X00P0000UNne[kG_]JnUkkF_]Nne[j00001E[k
0P0015[k00<005[kF_/01U[k0P000U/K00<005/KFa/02E/K00h005lKFa]O6e/KGa]K6elKFa]O6e/K
Ga/005lK0P0000aK6elKFa]O6e/KGa]K6elKFa/005/KGa/200001e/KGa]K6elKFa]O6`0000AO6`80
00IO6`03001O6UlK00@00003Ga]S6elJ009O6`0:Ha/005lKGa]S6elJ001O6f<KGaX2Ga/016<KGaX0
05lK0P000UlK00US6elJGa]O6f<KGaYO6`00Ha/00P0000=O6f<KGaX00UlK02mS6elJGa/006/i001[
>FLIJcUW6F/iIaU[>FLI001W6F/iIaT006/IJcUW6F/iJaT006LIJcU[6F/iIaU[>F/IJcT006/iJaU[
>FLIJcU[6F/i001[>F/IJcUW6@00009[6@05IaT006/IJaUW6@03JaT01VLI001[6F/IIaT0009[6@05
IaU[6@00JaUW6@03JaT03FLIJaT00000F_]K6e[kFaaJne/KF_]K700000E6g@P000E6g@030016gDKM
00E6g@030016gDKM00I6g@030016gDKM00I6g@04001Bo5;lC_`40002D_`02P00Ea]K75LLFaaG6e/L
EaaK75LK0P0000YK75LKFaaG75/LEa]K75LLFa`000Uoo@03001ooGom02]oo@00G7om00<007omOod0
0Wom00@007omOod000Ioo@8002aoo@03001ooGom01Ioo@80000CFWMFEUYgFUIJMeIFFWMJEUYgEUIJ
M`00EUMBEUIGDUIFEe9FEUL00P0001YJf@00F]YNnU[JG_YJfUkjF]YNnU[JG_YJfP00F_YNne[jG_]J
nUkkF_YNne[jG_]JnP000U[k0P0000eJne/LE_]K75[kFaaFn`00F_]K75KkFaaJn`0200003U/LF_]K
75[kFa`005/LF_]O75[kFaaJnelLF_/200006UlL001O6e/KGa]K6elKFa]O6e/KGa]K6elK001O6e/K
GaaK6elKFa]O75/KGa]K6elLFa/200002elLFa]O6e/KGaaK6elKFa]O7000Ga/00P000UlK00IK6UlK
Ga]O6e/JGa/500002f<KGaYS6elJHa]O6V<KGaYS6`00Ha/00P0004IO6V<KGaYS6elJHa]O6V<KGaX0
05lJHa]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa]O6V<KGaYS6`00JcUW6F/iIaU[
>FLIJcUW6@00IaU[>FLIJcUW6@00IaU[>FLH001W6F/iIaQ[>FLIJcUW66/i001[>@00JcUW6F/iIaQ[
>@80000/IaQ[>FLIJcUW6000IaT006LHJcUW6F/iIaQ[>FLI001W66/iIaU[>@00JcUW6F/i001[>FLI
JcUW66/iIaU[>@00JcT005/LE_]K75KkFaaFne/LE_]K70D0000TB]e6_4[MA[`004JlB]e6_4[MA[a:
gDJlB]d004[MA[a:gDJlB]e6_4[MA[`004KLB]e6g4[MA]a:gDKL0016g4[MA]a:gDKL1`0000i>o5;m
C_aBoDklD_d005/LE_]K75KkFaaFne/L0P0000eFn`00E_]K75KkFaaFne/LE_]K75KkFa`00008Ood2
000/Ood005Eoo@@000Aoo@05001ooGomOod00002Ood00`00Ooeoo@04Ood00`00Ooeoo@0/Ood00`00
Ooeoo@0DOod03`00FUIJMP00FWIJEUYfFUIJMUYFFWIJEUYfFUH00002EUL00eIFEUMFE`020003G_X0
1E[j001NnUkjF_X00ekj015JnUkj000005kj001JnekkF_YNne[kG_]JnUkkF_]Nne[j008000YJn`03
001Jne[k00800003Fa]K75/K009K6`04FaaK6e/K0005Fa/20004Fa/02@00Ga]K6elKFa]O6e/KGa]K
6`0200002elK001O6e/KGa]K6elKFa]O6e/KGa/00P0000eK6`00Fa]O6e/KGa]K6elKFa]O6e/KGa/0
0007Ga/30002Ga/01P00GaYO6elKHa]O6P9O6`06Ha]O6UlKGa]S6`000UlK00IS6elJGa]O6f<KGaX2
Ga/01P00GaX005lKHa]O6P9O6`0:Ha]O6UlKGa]S6`00Ga/006<KGaX2Ga/016<KGaYO6elK0P0002eO
6`00JcUW6F/iIaU[>FLI001W6F/iIaU[>FLIJcUW6@00JaT006LIJcU[6F/iIaU[>F/IJcT006/iJaU[
>@00JcU[6F/iIaT006/IJcUW6F/iJaU[>FLI00000V/I00IW6F/IJaU[6FLI0002JaT02FLIJaU[6F/I
001[6@00JaUW6@03JaT03FLIJaT006/IIaU[6@00FaaJne/KF_]K75[k00800003Fa`004KM00M6g@03
0016gDKM00I6g@030016gDKM00E6g@030016gDKM00=6g@P000E6g@04001Bo5;lC_`3D_`01dklD_`0
05/LEa]K75LL0080000<FaaG75/LEa/005LLFaaG6e/LEaaK75LK0P0000=K7000Ood01Gom00@007om
Ood002]oo@00Fgom00@007omOod0009oo@04001ooGom0006Ood00`00Ooeoo@0]Ood00`00Ooeoo@0A
Ood200004UYFFWMFEP00FUIJMeIFFWMJEUYgEUIJMeYFFWL005IGDUIFE`80000LF]YNnU[IG_YJfUkj
001NnU[JG_YJfUkjF]YNnP00Ga]NnUlKF_X005[jG_]JnUkkF_YNne[jG_/200003E[j001Jne/LE_]K
75[kFaaFne/LF_]K75Kk0080000>FaaJne/LF_]K75[kFaaJne/LF_]K7000FaaJn`80000=FaaJnelL
F_]K75[kGa`005lKFa]O6e/KGa/00P0001UK6elKFa]O7000Ga]K6elLFa]O6e/KGa`005lKFa]O75/K
001K6elLFa]O6e/KGaaK6`0200001ElL001O6e/JGa/00`000elK0P0000]O6`00GaYS6elJHa]O6V<K
GaYS6elJ00800009Ha/006<KGaYS6elJHa]O6V<K0080000;GaYS6elJ001O6V<KGaYS6elJHa]O6P02
0000Ff<KGaYS6`00Ha]O6V<KGaYS6elJ001O6V<KGaYS6`00JcUW6F/iIaT006LIJcUW6F/iIaU[>FLI
JcUW6@00IaU[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaT006LHJcUW6@00IaQ[>FLIJcUW66/iIaT006LH
001W6F/iIaQ[>FLI001W66/iIaU[>FLHJcUW6F/i001[>FLIJcUW66/iIaU[>@00JcUW6F/iIaP005Kk
FaaFne/L0080000EE_]K75KkFa`004[MA[a:gDJlB]e6_4[M001:gDJlB]e6_4[MA[a:gDJl00800004
B]e6_4[MA[`800006D[MA]a:gDKL0016g4[MA]a:gDKLB]e6g4[M001BoDklD_e>o5;mC_aBoDkl001F
ne/L0080000<E_]K75KkFaaFne/L001K75KkFaaFne/L0P0000AFne/LE_/000Uoo@03001ooGom02Uo
o@00G7om0P0017om0P001gom0`00;Wom00<007omOod03gom018005YfFUIJMUYFFWIJEP00FUIJMUYF
FWIJEUYfFUIJMUYFFWH300000ekjF_YNnP02G_X01E[jG_YNnUkj00000ekj01IJnP00001NnekjG_]N
nUkk001Nne[kG_]JnUkkF_]Nn`00Ga]K6elKFa/000QJn`800004Fa/005/KFa`3Fa/01E/LFa]K6e/K
Fa`00U/K0P002U/K00<005lKFa/00P0000aO6e/KGa]K6elKFa]O6`00Ga]K6elKFa/200002elKFa]O
6e/KGa/005lKFa]O6e/KGa/00P0000AK6elKFa]O6`<000EO6`03001O6elK009O6`06001O6UlKGa]S
6elJ0UlK00H005lJGa]O6f<K0002Ga/01V<KGaYO6`00Ha]O6P9O6`06Ha/005lKGa]S6elJ0UlK00/0
05lJGa]O6f<KGaX005lKHa]O6UlK0080000bGaYO6elKHa]O6P00IaU[>FLI001W6F/iIaU[>FLIJcUW
6F/iIaT006LI001[6F/iIaU[>F/IJcT006/iJaU[>FLIJcU[6@00IaT006/IJcUW6F/iJaU[>FLI001[
6F/iIaT0009[6@05IaT006/IJaUW6@03JaT01FLIJaT006/I00000f/I00EW6F/I001[6FLI00=[6@03
IaT005[k00800007Fa]Jne/LF_]K6e[k000024KM00<004KMA]d00dKM200014KM00<004KMA]d01TKM
00<004KMA]d01TKM00D005;lD_aBo4kl00=Bo0<0000<FaaG6e/LEaaK75LKFaaG75/L001K75LL0P00
00MK75LLFaaG6e/LEa`00009Ood00`00Ooeoo@0XOod006]oo@03001ooGom02moo@03001ooGom00eo
o@0R001JMeYFFWMFEUYgFUIJM`00FWMJEUYgEUIJMeYFFWMFEUYgFUH005[IG_YJfUkjF]UNnU[JG_YJ
fEkjF]YNnP00G_X200003E[jGa]NnUlKF_YO6ekjGa/005kkF_YNne[j0080000LGa]JnUlKF_]O6`00
FaaJne/LE_]K75[kFa`005/LF_]K75[k001Jne/LF_]K75[kFaaJne/LF_/200003E/L001K75[kGaaJ
ne/LF_]O75[kFaaJnelL0080000<Fa]O75/KGa]K6elLFa]O6e/KGa`005lK0P0000]K6elKFa]O75/K
Ga]K6elL001O6e/K00800004Ga]K6elLFa/2000015lL001O6e/J0UlK0P000elK00QK6UlKGa/005lJ
Ha]O6V<K0P00025O6V<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa/006<KGaYS6elJ001O
6V<KGaYS6elJHa]O6P00GaX00P00061S6elJHa]O6V<KGaYS6elJ001W6@00IaU[>FLIJcUW6F/iIaU[
>FLI001W6F/iIaT006LIJcUW66/i001[>FLHJcUW6F/iIaQ[>FLI001W66/iIaU[>FLHJcUW6@00IaQ[
>FLIJcUW6000IaT006LHJcUW6F/iIaQ[>FLIJcT006/iIaT006LHJcUW6F/i001[>FLIJcUW66/iIaU[
>FLH001Fne/LE_]K75KkFaaFne/LE_/004JlB]e6_4[MA[`800008T[MA[a:gDJl0016_4[MA[a:gDJl
B]e6_4[M001:gDKLB]e6g4[MA]a:g@00B]e6g4[MA]a:gDKLB]e6g000C_aBoDkl100000aBoDkl001F
ne/LE_]K75KkFaaFne/LE_/300002EKkFaaFne/LE_]K75KkFa`00009Ood00`00Ooeoo@0XOod006]o
o@03001ooGom031oo@03001ooGom00]oo@0G001JMUYFFWIJEUYfFUIJMUYF001JEUYfFUIJMUYFFWIJ
EUYfFUH006;i001JnP03G_X01E[jG_YNnUkjF_X00ekj00h005kkG_YNnekjG_]NnUkkG_YNnekjG_/0
05kk0P0000UK6elKFa]O6e/KGa]K6elK000015[k0P001U/K00<005/KFa`00e/K00EK75/K001K6e/L
009K6`03001K6e/K00IK6`80000IFa/005lKFa]O6e/KGa]K6elKFa]O6e/KGa/005lKFa]O6e/KGa]K
6elKFa]O6e/KGa/00P0000=K6elKFa/00`0000IK6elKFa]O6`00Ga/20009Ga/01P00GaX00000Ha]O
6P9O6`06Ha]O6UlKGa/005lJ0P0000IS6elJGa]O6f<KGaX2Ga/00f<K001O6`0200001ElJGa]O6f<K
GaX00UlK00IS6elJ001O6f<KGaX2Ga/0<f<KGaYO6elKHa]O6P00IaU[>FLIJcUW6F/iIaU[>FLI001W
6F/iIaU[>@00JcU[6F/i001[>F/IJcUW6F/iJaU[>FLI001[6@00IaU[>F/IJcUW6@00JaU[>FLIJcU[
6F/iIaT00002JaT02FLIJaU[6F/IIaU[6@00JaUW6@02JaT01P00IaU[6@00JaUW6@=[6@0?IaU[6F/I
001W6@00F_]K75[kFa]Jne/LF_]K6e[k00D00005A]a6gDKMA]d00003A]d01TKLA]e6gDKMA]`000M6
g@030016gDKM00I6g@030016gDKM00=6g@H0009Bo00<C_aBo5;lD_a>o000EaaK75LKFaaG75/L0P00
00eG75/L001K75LLFaaG6e/LEaaK75LKFa`00009Ood00`00Ooeoo@0WOod006Yoo@03001ooGom039o
o@03001ooGom00Uoo@0D001JMeYFFWMFEUYgFUIJMeIFFWMJEP00EUIJMeYFFWMFEUYgFUH000=Rn@0W
001JfEkjF]YNnU[IG_YJfUkjF]UNnP00Ga/005lKG_YO6e[jGa]NnUlKF_YO6ekjGa/005lKF_]O6e[j
Ga]JnelKF_YO6e[kGa/005/L0080000>F_]K75[kFaaJne/LF_]K75[k001Jne/LF_]K7080000KF_]K
75[kFaaJn`00F_]K75[kGaaJne/LF_/005/KFaaK6`00Fa]O6e/KGaaK6elKFa]O75/K0080000:Ga`0
05lKFa]O75/KGa]K6elLFa/200000elL0000000200002e/KGa]K6elLFa]O6e/KGa`005lKFaX00elK
00EK6UlKGa]O6e/J009O6`0_001O6V<KGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<K
GaYS6elJHa/006<KGaYS6elJHa]O6V<KGaYS6elJ001O6P00GaYS6elJHa]O6V<KGaYS6`020000D5lJ
001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcUW6F/i001[>@00JcUW66/iIaU[>FLHJcUW6@00IaQ[>@00
JcUW66/iIaT006LHJcUW6F/iIaQ[>FLI001W6000IaU[>FLHJcUW6F/i001[>FLIJcUW66/i001[>@00
JcUW6F/iIaQ[>FLIJcUW6000IaU[>@00FaaFne/LE_]K75KkFa`200004UKk0016_4[MA[a:gDJlB]e6
_4[M001:gDJlB]e6_4[MA[a:g@80000=A[a:gDJlB]e6_4[MA[`004KLB]e6g4[MA]`02000015:gDKL
B]e6g000C_aBoDklD_e>o5;mC_aBoDkl001Fne/L00<0000<FaaFne/LE_/005KkFaaFne/LE_]K75Kk
0P0000=K7000Ood027om00<007omOod09Wom001ZOod00`00Ooeoo@0cOod00`00Ooeoo@07Ood20000
4UYFFWIJEUYfFUIJMUYFFWIJEUYf001JMUYFFWIJEUYfFUH000ERn@03001JnUkj009NnP03F_YNnUkj
0080009NnP0:G_/005kkG_YNnekjG_]NnUkkG_X200003UlK001O6e/KGa]K6elKFa]O6e/KGa]K6elK
000<Fa/01000Fa/000000U/K00MK75/KFa]K6e/LFa/00004Fa/20003Fa/02E/LFa/005/KGa]K6elK
Fa]O6`0200003E/KGa]K6elK001O6e/KGa]K6elKFa/005/K00@00008Ga]K6elKFa]O6e/KGa]K6`80
0003Ga/005lK00QO6`800003Ga/005lJ009O6`05Ha]O6UlKGa]S6`0200000elK001O6P02Ga/01V<K
GaYO6elKHa]O6P800006Ha/005lKGa]S6elJ0UlK00YS6`00001O6f<KGaX005lKHa]O6P9O6`0cHa/0
05lKGa]S6elJ001W6F/iIaU[>FLI001W6F/iIaU[>FLIJcUW6F/i001[>F/IJcUW6F/iJaU[>FLI001[
6F/iIaU[>@00JcUW6@00JaU[>FLIJcU[6F/iIaT006/IJcUW6@00009[6@05IaU[6@00JaUW6@03JaT0
1FLIJaT006/IIaT00f/I00eW6F/IJaT006LIJaUW6F/I001K6e[kFaaJn`0200001U[lF_]Jne[k0016
g0=6g@05A]a6gDKM0016g003A]d01DKLA]e6gDKM00001DKM200014KM00<004KMA]d01DKM00<005;l
C_`00e;l00A>o5;lD_aBo0<0000=FaaG6e/LEaaK75LKFaaG7000Ea]K75LLFa`00P0000AG75/LEa/0
00Uoo@03001ooGom02Ioo@00JWom0`00=7om00<007omOod01Gom018005YgFUH005IFFWMJEUYgEUIJ
MeYFFWMFEUYg001JMeIFFWL20006H_T08`00G_YJfEkjF]YNnU[I001NnUlKF_YO6ekj001JnUlKG_YO
6e[jGa]NnP00F_YO6ekjGa/005lKF_]O6e[jGa]JnelKF_X00P0001aO6`00FaaJne/LF_]K75[kFaaJ
ne/LF_]K75[k001Jne/LF_]K75[kFaaJne/LF_]K75[k001Jn`80000<GaaK6e/LFa]O75/KFaaK6`00
Fa]O6e/K0P0000]O6e/KGaaK6elKFa/005/KGa]K6elL00@0000CFa]O6e/K001K6elKFa]O75/KGa]K
6`00Fa]O6e/KGa`005lKFaX00elK00EK6UlK001O6e/J009O6`1k001O6V<KGaYS6elJHa/006<KGaYS
6elJ001O6V<KGaYS6elJHa]O6P00GaYS6elJHa/006<KGaYS6elJHa/006<KGaYS6elJHa]O6P00GaYS
6elJHa/006<KGaYS6elJHa]O6P00IaU[>FLI001W6F/iIaU[>FLIJcUW6F/i001[>@00JcUW6F/iIaQ[
>FLI001W66/iIaU[>FLH001W6@00IaQ[>FLIJcUW66/iIaT006LHJcUW6F/i001[>FLIJcT006/iIaU[
>FLHJcUW6F/i001[>@00JcUW66/iIaU[>FLH001W6F/iIaQ[>FLI001Fne/L0080000EE_]K75KkFaaF
ne/L001:gDJlB]e6_4[MA[a:gDJl0016_4[MA[a:gDJl00P0000KB]e6g4[MA]`004KLB]e6g4[MA]a:
gDKL0016g4[MA]a:gDKLB]e6g4[M001BoDklD_e>o5;m00<0000>D_e>o000E_]K75KkFaaFne/LE_]K
7000FaaFn`800007FaaFne/LE_]K75Kk00002Gom00<007omOod09Gom001ZOod00`00Ooeoo@0eOod0
0`00Ooeoo@02Ood200004UYfFUIJMP00FWIJEUYfFUIJMUYFFWIJEUYfFUH005YFFWH000URn@03001N
nU[j009NnP05001NnUkjG_YNn`03G_X01@00G_YNnekjG_/00P000UlK00YO6UlKGa]O6`00Ga]K6elK
Fa]O6`800004Fa]O6elKGa/20008Fa/2000015/K001K6e/L0e/K00UK75/KFa]K6e/LFa/005/KFa`0
0e/K00MK75/KFa]K6e/L001O6`0200002e/KGa]K6elKFa]O6e/KGa]K6`00Fa/00`0000aK6elKFa]O
6e/KGa]K6`00Fa]O6e/KGa/200001e/KGa]K6elKFa]O6`0000AO6`8000EO6`03001S6elJ009O6`80
009O6`06Ha]O6UlKGa/005lJ0UlK00IS6`00001O6f<KGaX2Ga/01P00GaYO6elKHa/0009O6`08Ha]O
6UlKGa]S6elJ001O6`80009O6`0fHa]O6UlKGa]S6elJ001W6@00IaU[>FLIJcUW6F/iIaU[>@00JcUW
6F/i001[>F/IJcUW6@00JaU[>FLIJcU[6F/iIaT006/IJcUW6F/iJaU[>FLI001[6F/iIaU[>F/IJcT0
06/I001[6FLI0f/I00UW6F/I001[6FLIJaT006/IIaT00V/I00P006LIJaUW6F/IIaU[6FLI0P000U[k
00EJo5[kF_]Jne[l009Jn`030016gDKL00=6g@P00005A]a6gDKMA]d00007A]d00`00A]e6g@06A]d0
0`00A]e6g@05A]d00`00D_aBo00300000e;lC_aBo002D_`02@00FaaG75/LEa]K75LLFaaG6`030000
2ELKFaaG75/LEa]K75LLFa`0000:Ood00`00Ooeoo@0TOod006Yoo@03001ooGom03Ioo@0E001ooGom
001JEUYgFUIJMeYFFWL005YgEUIJMeYFFWMFEUYgFUIJMeIF008000]Rn@0?001NnP00001NnUlKF_YO
6ekjGa]JnUlKG_X005[j0080000<Ga]JnUlKG_YO6e[jGa]NnUlK001O6e[k0P0000MO6e/KGa]K6UlK
Fa]O6`0200001E[kFaaJne/LF_/00P0000eK75[kFaaJn`00F_]K75[kFaaJne/LF_]K700200005e/K
001K6e/LFa]O75/KFaaK6elLFa]K7000GaaK6elKFa]O75/KGa]K6elLFa/00`0000eK6elKFa]O75/K
Ga]K6elLFa]O6e/K001K6`0200002elLFa]O6e/KGaaK6elKFa]O7000Ga/00P000UlK00QK6UlKGa]O
6e/JGa/006<K0P0000]O6V<KGaYS6elJHa]O6V<KGaX005lJ0080000:Ha]O6V<KGaYS6elJHa]O6P00
GaX20000If<KGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaYS6elJ001W6F/iIaU[
>FLIJcUW6F/i001[>FLIJcUW6@00IaQ[>FLI001W66/iIaU[>FLHJcUW6@00IaP006LIJcUW66/iIaT0
06LHJcUW6F/iIaQ[>FLIJcT006/iIaU[>FLHJcUW6F/i001[>FLIJcUW6000IaU[>FLH001W6F/iIaQ[
>FLIJcUW6000IaT005KkFaaFne/LE_]K75KkFaaFne/L00D0000<B]e6_4[MA[`004JlB]e6_4[MA[a:
gDJl0P0001E:gDKLB]e6g4[MA]a:g@00B]e6g4[MA]a:gDKLB]d004[MA]a:gDKLB]d01@0000mBoDkl
D_e>o5;mC_aBoDklD_d005/LE_]K75KkFa`00P0000]Fne/L001K75KkFaaFne/LE_]K75Kk008000Mo
o@<002Ioo@00JWom00<007omOod0=gom0P0001=JEUYfFUIJMUYFFWIJEP00FUIJMUYFFWIJEUYfFUIJ
MUYFFWH0000=H_T00`00G_]NnP02G_X01EkkG_YNnUkjG_/00ekj00<005lJGa/00UlK00EO6UlKGa]O
6elJ00=O6`80009O6`05Fa]O6elKGa]K6`03Ga/015/K001K6e/K0P0000=K6e/LFa/00U/K00EK75/K
001K6e/L00=K6`80009K6`05FaaK6`00Fa]K7003Fa/035/LFa/00000Fa`005lKFa]O6e/KGa]K6`D0
000KFa/005/KGa]K6elKFa]O6e/KGa]K6elKFa/005/KGa]K6elKFa]O6e/KGa]K6elKFa]O6`0000]O
6`03001S6elJ009O6`06Ha]O6UlKGa]S6elJ0UlK00H005lJGa]O6f<KGaX2Ga/01V<KGaYO6elK001O
6P9O6`06Ha]O6UlKGa]S6elJ0UlK00H005lJ001O6f<KGaX2Ga/00f<KGaYO6`020000;ElJ001W6F/i
IaU[>FLIJcT006/iIaU[>FLIJcUW6@00IaT006/IJcUW6F/iJaU[>FLI001[6F/iIaT006/IJcUW6@00
JaU[>FLIJcU[6F/iIaU[>@00JcT00003JaT01FLIJaT00000IaT00f/I011W6@00JaT006LIJaUW6F/I
IaU[6FLI001W6F/IIaT000=Jn`04F_aJne[kF_/2000015[k001:gDKL0TKM00I:gDKLA]d004KMA]`3
A]d014KLA]e6g@001dKM00<004KMA]d00dKM20000TKM00=:gDKM00000U;l00E>o5;lD_aBo4kl009B
o003001G6e/L00<0000;FaaG75/LEa/005LLFaaG6e/LEaaK700200000eLLFa`00009Ood00`00Ooeo
o@0SOod006Yoo@8003Qoo@0F001JEUYgFUIJMeYFFWMJEUYg001JMeYFFWMFEUYgFUIJMeIFFWL006;i
000;H_T03000IaX005lKF_YO6ekjGa]JnUlKG_YO6`80000KG_X005[jGa]NnUlKF_YO6ekjGa]JnUlK
001O6`00Ga]K6elKFaYO6e/KGa]K6UlKFa]O6e/J0080000=FaaJne/LF_]K75[kFaaJne/LF_/005[k
Fa`00P0000aK6e/LFa]K75/KFa`005lLFa]K75/KGa`2000025/KGaaK6e/L001O75/KGa/2000045/K
Ga/005lLFa]O6e/K001K6elKFa]O75/KGa]K6elL0P0000]K6`00Fa]O6e/KGaaK6elKFa]O75/K0080
0004Ga`005lKFaX3Ga/00e/JGa]O6`0200002elK001S6elJHa]O6V<KGaYS6elJHa/00P0000YO6P00
GaYS6elJHa]O6V<KGaYS6`80000:GaX005lJHa]O6V<KGaYS6elJHa/20000FUlJHa]O6P00GaYS6elJ
Ha]O6V<K001S6elJHa]O6P00IaU[>FLIJcT006/iIaU[>FLIJcUW6F/iIaT006LHJcUW6F/iIaQ[>FLI
001W66/iIaU[>FLH001W6@00IaQ[>FLIJcUW66/iIaU[>@00JcUW6F/i001[>FLIJcUW6000IaU[>FLH
JcUW6F/iIaP006LIJcUW66/iIaU[>FLH001W6F/iIaQ[>@00FaaFne/LE_]K7080000DE_]K75Kk0016
_4[MA[a:gDJlB]e6_4[M001:gDJlB]e6_4[MA[a:g@800004A]a:gDKLB]d800005TKLB]e6g4[M001:
gDKLB]e6g4[MA]a:gDKL001>o5;mC_aBoDklD_e>o5;m0`0000]K75KkFaaFne/LE_]K75Kk001Fne/L
00<00005FaaFne/LE_/0000:Ood00`00Ooeoo@0ROod006Uoo@8003Qoo@0D001JEUYfFUIJMUYFFWIJ
EUYfFUIJMP00FWIJEUYfFUIJMUYFFWH0009Rn@03001RnF;i00MRn@800005IaYS6F<I001Nn`03G_X0
1UkkG_YNnP00Ga]O6P9O6`03001O6UlK009O6`03GaYO6elK008000=O6`05001O6elKGa]K6`03Ga/0
25/KGa/00000Fa/005/KFa`3Fa/01U/LFa]K6e/KFaaK6`800005FaaK6e/KFa]K7003Fa/015/L001K
6e/K0P000U/K00EK75/KFa]K6e/L00<0000@Ga]K6`00001O6e/KGa]K6elKFa/005/KGa]K6elKFa/2
00004UlKFa]O6e/K001K6elKFa]O6e/KGa]K6`00Fa]O6e/KGa/000IO6`03001O6elK009O6`03001S
6elJ009O6`06Ha]O6UlK001S6elJ0UlK00X005lJGa]O6f<KGaYO6`00Ha]O6P9O6`0:001O6UlKGa]S
6elJGa/006<KGaX2Ga/01V<K001O6elKHa]O6P80000JHa]O6UlKGa]S6`00JcUW6F/i001[>FLIJcUW
6F/iIaU[>FLI001W6@00IaU[>F/IJcUW6@80000FJcUW6F/iJaU[>FLI001[6F/iIaU[>F/IJcUW6F/i
001[>FLIJcU[6@00IaT2JaT00`00IaU[6@02JaT02fLIJaU[6@00IaT006LIJaUW6F/IIaT00P0000Q[
6FLIJaUW6F/I001Jo5[k0P0000YJo5[kF_]Jne[lF_/004KMB]e6g096g@03B]e6g0000096g@03A]a6
gDKM00P00005B]e6gDKMA]d00003A]d01T[MA]e6gDKMB]d00096g@06B]e6gDKMA]e:g@000e;l00=>
o5;lD_`00P000U;l00X005LKFaaG75/LEa]K75LLFaaG6`800009FaaG6e/LEaaK75LKFaaG700000Uo
o@03001ooGom00Uoo@8001Moo@00JGom00<007omOod0=Wom0P00019JMeYFFWMJEUYgFUIJMeYFFWMJ
EP00EUIJMeYFFWMFEUYg0004H_T00`00H_URn@05H_T03000H_UW6V;iIaYRnFLJ001O6e[jGa]NnP80
000JGa]NnUlKG_YO6`00Ga]JnUlKG_YO6e[j001O6UlKFaYO6elJ001K6UlKFa]O6e/JGa]K6`80000=
Ga]K6elKFa/005[kFaaJne/LF_]K75[kFa`00P0000aK6`00Fa]K75/KFaaK6e/LFa]K75/KFa`20000
1U/KFaaK6elLFa]K70<00003Fa`005lL0080000<Fa]O75/KGa]K6elLFa]O6e/K001K6elK0P0000aK
6elKFa]O75/KGa]K6`00Fa]O6e/KGa`200001U/KGaaK6elKFa/0009O6`05FaYO6`00001K6`03Ga/0
1e/KGa/006<KGaYS6elJ0080000:Ha]O6V<KGaYS6`00Ha]O6V<KGaX200005F<KGaYS6elJHa]O6P00
GaYS6elJHa/006<KGaYS6elJHa]O6V<K001S6`020000CUlJHa]O6V<KGaYS6elJHa/006/i001[>FLI
JcUW6F/iIaU[>FLI001W6F/iIaT006LHJcUW6F/i001[>FLIJcUW66/iIaT006LH001W6F/iIaQ[>FLI
JcT006/iIaU[>FLHJcUW6@00IaP006LIJcUW66/iIaU[>FLH001W6F/iIaP006LIJcUW66/i001[>FLH
JcUW6F/iIaQ[>@80000>E_]K75KkFaaFne/LE_]K7000B]e6_4[MA[a:g@P00004A[a:gDJlB]d20000
6dKLB]e6g4[MA]a:gDKL0016g4[MA]a:gDKLB]e6g000A]a:gDKLB]e6g4[MA]a:g@00D_e>o0030000
34klD_e>o5;m001K75KkFaaFne/LE_]K7080000;E_/005KkFaaFne/LE_]K75KkFa`0000:Ood00`00
Ooeoo@07Ood01000Ooeoo@005Wom001YOod00`00Ooeoo@0eOod04P00FWIJMP00FWIJEUYfFUIJMUYF
FWIJEUYfFUH005YFFWIJEP8000IRn@03001RnF;i00=Rn@03001S6FLJ00=S6@05IaYS6F<I001Nn`02
0002Ga/02ElJGa]O6elKGaYO6`00Ga]O6P02Ga/00`00Ga]O6`05Ga/00`00Fa]O6`02Ga/20002Ga/0
25/KGa]O6elKFa/005/KFa`3Fa/20002Fa/01E/LFa/005/KFa`00e/K00IK75/K000005/L0002Fa/0
1E/L00000000Fa`00e/K00iK7000Ga]K6elKFa]O6e/KGa]K6elKFa]O6e/K0P0000aO6e/KGa]K6elK
Fa]O6e/KGa]K6`00Fa/200002UlKFa]O6e/KGa]K6elKFa/005lK0P002ElK00L006<K000005lKHa]O
6P02Ga/01F<KGaYO6`00Ha/00P0000=O6f<KGaX00UlK00IS6elJGa]O6`00GaX200001V<KGaYO6elK
Ha]O6P9O6`06Ha/005lKGa]S6elJ0UlK039S6elJGa]O6f<K001[>FLIJcUW6F/iIaU[>FLI001W6F/i
IaU[>@00JcUW6F/i001[>FLIJcU[6F/iIaT006/IJcUW6@00JaU[>FLIJcT006/iIaU[>F/IJcUW6F/i
JaT006LI0f/I01QW6F/IJaT006LIJaUW6F/I001[6FLIJaT006/IIaU[6FLIJaUW6F/I001[6@00F_`3
F_/01E[lF_]Jne[kF_`01@000TKM00I:gDKL0016gD[MA]`2A]d01D[MA]`00000B]d00dKM00E:gDKM
A]d004[M00=6g@05B]e6gDKMA]d00003A]d00d[MA]d000040002D_`02dklD_aBo5;lC_aBo000FaaG
6e/LEa`00P0000aK75LLFa`005/LEaaK75LKFaaG75/LEa/2000:Ood00`00Ooeoo@06Ood01000Ooeo
o@005Wom001YOod00`00Ooeoo@0dOod04`00FUIJMeYF001JEUYgFUIJMeYFFWMJEUYgFUIJM`00FWMF
EP0000URn@03001RnF;i0080000HH_UW6V;iIaYRnFLJH_UW6V;iIaX005lKG_YO6ekjGa]NnUlKG_YO
6ekjGa/005lK0P0000]O6UlKFaYO6elJGa]K6UlKGaX005/J0080000=Ga]K6elKFa]O6e/KGa]K6elK
Fa/005[kFa`00P0000aK6e/LFa]K75/KFa`005/LFa]K75/KFa`2000015/KFaaK6e/L0`0000IK75/K
GaaK6e/LFa/200002e/L001O75/KGa]K6elLFa]O6e/KGa`00P0001YK6`00Fa]O6e/KGaaK6elKFa]O
75/KGa]K6`00Fa]O6e/KGaaK6elKFa]O75/KGa]K6`000UlK00EK6elKGa]O6e/K00=O6`0UFa]O6`00
Ha]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJ
Ha]O6V<KGaX00P0000YS6`00Ha]O6V<KGaYS6elJHa]O6P80001>Ha/006/iIaU[>FLIJcUW6@00IaU[
>FLIJcUW6F/i001[>@00JcUW6F/iIaQ[>FLI001W66/iIaU[>@00JcUW6F/i001[>FLIJcUW66/iIaU[
>FLH001W6@00IaQ[>FLIJcUW6000IaU[>FLHJcUW6F/i001[>@00JcUW66/iIaU[>FLHJcT006/iIaP0
05KkFaaFne/LE_]K75Kk0P00019K7000B]e6_4[MA[a:gDJlB]d004[MA[a:gDJlB]e6_4[MA[`20000
3D[MA]a:gDKLB]e6g4[M001:gDKLB]e6g4[M00P0000@A]a:gDKLB]d005;mC_aBoDklD_e>o5;mC_`0
05KkFa`2000035KkFaaFne/LE_]K7000FaaFne/LE_]K70800003E_]K700000Uoo@03001ooGom00Mo
o@8001Moo@00JGom00@007om0000035oo@8000AJMP0<001JMUYFFWIJEUYfFUIJMUYFFWIJEUYf0P00
2V;i00<006;i00000V<I00EW6V<IHaUS6FLJ00=S6@06IaX006<J001O6elJ0elK00MO6UlKGa]O6elJ
Ga/0000<Ga/00`00Fa]O6`02Ga/01E/KGa]O6elKFa/00elK00AK6`00001K70=K6`06FaaK6e/KFa]K
70000U/K0P000U/K00IK7000000005/L0002Fa/00e/LFa]K6`020003Fa/05e/L001O6e/KGa]K6elK
Fa]O6`00Ga]K6elKFa/005/KGa]K6elKFa]O6e/KGa/00P0000YK6`00Fa]O6e/KGa]K6elKFa]O6`80
0003Fa/005lK00QO6`800004Ga/006<KGaX2Ga/016<KGaYO6elK0P0000AO6`00Ha]O6P9O6`05Ha]O
6UlKGa]S6`0200000elK001O6P02Ga/01V<KGaYO6elK001O6P9O6`06Ha/005lKGa]S6elJ0UlK01X0
05lJGa]O6f<K001[>FLIJcUW6@00IaU[>FLIJcUW6F/iIaU[>@00JcUW6F/iJaU[>FLI0P0001I[>FLI
JcU[6F/i001[>@00JcUW6F/iJaU[>FLIJcU[6@00IaU[>@00JaUW6@9[6@0I001W6F/IIaU[6FLIJaUW
6F/I001[6FLIJaUW6F/IIaU[6@00JaUW6F/IIaT005[kF_`00U[k0P0000EJne/KF_]K70000096g@06
B]e6g4KMA]e:g@000TKM00U:gDKLA]e6gD[M0016g@00B]d00TKM2@0000E:gDKMA]e6g@0000=6g@06
B]e6gDKMA]d004kl0e;l00A>o5;lD_aBo0<0000;FaaG6e/LEaaK75LKFaaG7000Ea]K700300001U/L
EaaK75LKFa`000Uoo@03001ooGom00Eoo@04001ooGom000FOod006Uoo@80039oo@0D001JMeYFFWMJ
EUYgFUIJM`00FWMJEUYgFUIJMeYFFWMJEUYgFUH000aRn@0I001W6V;iIaYRnFLJH_UW6V;iIaYRnFLJ
001W6V<IIaX005lKG_YO6ekjGa]NnUlKG_X00P0000]O6`00Ga]K6UlKGaYO6e/JGa]O6UlK0080000<
GaX005/KGa]K6elKFa]O6e/KGa]K6elK0P0000aK6`00Fa]K75/KFaaK6e/LFa]K75/KFa`200000e/K
Fa`00002000025/LFa]K75/KFa`005lLFa/2000035lLFa]K75/KGaaK6e/L001O75/KGa]K6`80000<
Ga]K6elLFa]O6e/K001K6elKFa]O75/K0P00015O75/KGa]K6`00Fa]O6e/KGaaK6elK001O75/KGa]K
6`00009O6`06Fa]O6elKGa]K6`000UlK021K6elK001S6elJHa]O6V<KGaX005lJHa]O6V<K001S6elJ
Ha]O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<K0P0000YO6V<KGaYS6elJ001O6V<KGaYS6`80001=
GaYS6elJHa]O6P00IaU[>FLI001W6F/iIaU[>FLIJcUW6F/i001[>@00JcUW66/iIaU[>@00JcUW6F/i
IaQ[>FLIJcT006/iIaU[>FLHJcUW6F/iIaP006LIJcUW66/i001[>FLH001W6F/iIaQ[>FLIJcUW66/i
001[>@00JcUW6F/iIaQ[>@00JcUW66/iIaU[>@00FaaFn`02000055/LE_]K75KkFaaFn`00A[a:gDJl
B]e6_4[MA[`004JlB]e6_4[MA[`800006T[MA]a:gDKLB]d004[MA]a:gDKLB]e6g4[M001:gDKLB]e6
g4[MA]a:gDKL001>o5;mC_`4000035;mC_`005KkFaaFne/LE_]K75KkFaaFn`800009FaaFne/LE_]K
75KkFaaFn`0000Yoo@03001ooGom00Eoo@8001Moo@00J7om00<007omOod0<Gom00<005YfFWH01UYf
00d005YFFWIJEUYfFUIJMUYFFWIJEP00H_T0000:H_T01000HaT006LJ0f<I00]W6V<IHaUS6FLJ001S
6V<IIaYS6@00009O6`06GaYO6elKGa]O6P000UlK00=O6UlK00001elK00<005lKGa/00UlK0P000elK
00EK6elKGa]O6`0000=O6`04Fa/005/KFa`3Fa/01E/LFa/00000Fa`00`0000EK75/KFa]K6e/L00=K
6`05Fa`00000Fa]K7003Fa/01e/LFa]K6e/KFa`005lK0080000<Fa]O6e/KGa]K6elKFa]O6e/K001K
6elK0P0000]K6elKFa]O6e/KGa/005lKFa]O6e/K00800007Ga]K6elKFa]O6e/K000015lK0P001ElK
00D005lKHa]O6UlK00800009GaYO6elKHa]O6UlK001S6elJ009O6`80009O6`06Ha]O6UlKGa/005lJ
0P0000IS6elJGa]O6f<KGaX2Ga/01P00GaX00000Ha]O6P9O6`19Ha]O6UlKGa/006LI001W6F/iIaU[
>FLIJcUW6F/i001[>FLIJcT006/iIaU[>@00JcUW6F/iJaU[>FLIJcT006/i001[>F/IJcUW6F/iJaT0
06LIJcU[6F/iIaT006/I001W6F/IIaU[6FLIJaUW6F/I001[6FLI001W6F/IIaU[6@00JaUW6F/IIaU[
6FLIJaT00P0000]Jne/LF_]K6e[kFaaJne/KF_/004KL0096g@03B]d0000000H00004A]a6gDKMB]d2
00000dKMB]e6g@02A]d01D[MA]d004KMB]d00dKM00E:gDKMA]d004[M00=6g@03B]d0000000@000IB
o008001K75LLFaaG6e/LEaaK7080000<Ea`005LKFaaG75/LEa]K75LLFaaG6`0027om0P0087om001H
Ood50002Ood20007Ood00`00Ooeoo@0`Ood05`00FWMJEUYgFUIJMeYFFWMJEUYg001JMeYFFWMJEUYg
FUIJMeYF001RnFKi00002F;i00@006LJH_UW6P800005H_UW6V;iIaYRn@0200002fLJHaUW6V<IIaYS
6@00G_YO6ekjGa/00P0000]O6UlKGaYO6elJGa/005lKFaYO6elJ00800006Ga]O6UlKFaYO6elJ0P00
00AO6e/KGa]K6`80000;Ga]K6elKFa]O6e/K001K6e/LFa]K700500002U/L001K75/KFaaK6e/LFa]K
75/K0P0001YK7000GaaK6e/LFa]O75/KFaaK6elLFa]K7000GaaK6elKFa]O75/KGa]K6elLFa]O6e/K
0P0000]O6e/KGaaK6elKFa]O75/KGa/005lL0080000;Fa]O75/KGa]K6elLFa]O6e/K001O6`020003
Ga/01e/KGa]O6elKFa/005lJ0080000;Ha]O6V<KGaYS6elJHa]O6V<K001S6`020000L5lJHa]O6V<K
GaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJHa]O6P00
IaU[>FLIJcUW6F/iIaU[>@00JcUW6F/iIaU[>@00JcT006/iIaU[>FLHJcUW6F/i001[>FLIJcT006/i
IaU[>FLH001W6F/iIaQ[>FLIJcUW6000IaU[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaT006LHJcT006/i
IaQ[>FLIJcUW66/i001[>@00FaaFne/LE_]K75KkFaaFne/L1@0000e:gDJlB]e6_000A]a:gDKLB]e6
g4[MA]a:g@0200003DKLB]e6g4[MA]a:gDKL0016g4[MA]a:gDKL00P0000BB]e6g4[MA]`004klD_e>
o5;mC_aBoDklD_d005/LE_]K75Kk0P0000]K75KkFa`005/LE_]K75KkFaaFne/L00800003E_/007om
00Aoo@80009oo@03001ooGom01eoo@00FWom00D007omOoeoo@00009oo@03001ooGom00Aoo@03001o
oGom02moo@03001JMUYf00QJMP09001JEUYfFUIJMUYFFWIJEP0000ARn@03001RnF;i00ERn@04001S
6F<IIaX2HaT20003HaT03000HaUS6V<IIaYS6F<JHaUW6V<I001O6`8000=O6`08GaYO6elKGa]O6UlK
001O6`8000YO6`05001O6`00001K6`03Ga/01e/KGa]O6elKFa/005/K00@00006FaaK6e/KFa]K7000
0U/K00=K75/KFa/00P0000EK6e/LFa]K7000009K6`06FaaK6e/KFa]K75/K0P0000]K7000Ga]K6elK
Fa]O6e/KGa]K6elK0080000JFa/005/KGa]K6elKFa]O6e/KGa]K6elK001O6e/KGa]K6elKFa]O6e/K
Ga]K6elKFa/000]O6`04001O6f<KGaX2Ga/02V<KGaYO6elKHa]O6UlK001S6elJ0UlK00YS6elJGa]O
6f<KGaX005lK001O6P9O6`05Ha]O6UlKGa]S6`0200000elK001O6P02Ga/01F<KGaYO6elKHa/00P00
04eO6`00IaU[>FLIJcUW6F/i001[>FLIJcUW6F/iIaU[>@00JcUW6F/iJaU[>FLIJcT006/iIaU[>F/I
001W6F/iJaT006LIJcU[6F/iIaU[>F/I001W6@00IaU[6FLIJaUW6F/I001[6FLIJaUW6F/I001[6@00
JaUW6F/IIaU[6FLIJaT006/IIaU[6@00Fa]Jne/LF_]K6e[k00800004Fa]Jn`00A]`2A]d01T[MA]a6
gDKM0016g096g@05B]e6g4KMA]e:g@02000014KMB]e6gDKM200000I6gD[MA]e6g@00B]d3A]d014[M
A]e6g@0025;l00<005LKFa`00P0000]G6e/LEaaK75LKFa`005/LEa]K75LL00800005FaaG75/LEa/0
0009Ood00`00Ooeoo@0LOod005Yoo@03001ooGom00Aoo@03001ooGom00Aoo@<002ioo@80000@FUIJ
MeYFFWMJEUYgFUIJMeYFFWMJEP00FUIJMeYFFWL200001f;iI_URn6KiH_UVn@0000ARn@80000nIaYR
nFLJH_UW6V;iIaYRn@00H_T006<IIaYS6FLJHaUW6V<IIaYS6FLJHaT005lJGa]O6UlKGaYO6elJGa]O
6UlKGaYO6`00Ga]K6UlKGaYO6e/JGa]O6UlKFaYO6elJGa/005lKFa]O6e/KGa]K6elKFa]O6e/KGa]K
6`<0000;Fa]K75/KFaaK6e/LFa]K7000FaaK6`0200003E/LFa]K75/KFaaK6e/L001O75/KFaaK6elL
0080000IFa]O75/KFa`005lLFa]O6e/KGaaK6elK001O75/KGa]K6`00Fa]O6e/KGaaK6elKFa/00P00
00]O6`00GaaK6elKFa]O75/KGa]K6elL00800005Fa/005lKGa]K6`03Ga/03e/KGa/00000Fa/005lJ
Ha]O6V<KGaYS6elJHa]O6P0200002F<K001S6elJHa]O6V<KGaYS6`020000<5lJHa]O6P00GaYS6elJ
Ha]O6V<K001S6elJHa]O6P00GaYS6elJHa]O6V<K001S6elJHa]O6P00IaU[>FLIJcT006/iIaU[>FLI
JcUW6F/i001[>@00JcUW66/iIaU[>@80000aIaU[>FLHJcUW6@00IaP006LIJcUW66/iIaU[>FLH001W
6F/iIaP006LIJcUW66/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[>FLIJcT0
05/LE_/00`0001=Fne/LE_]K7000B]e6_4[MA[a:gDJlB]e6_000A]a:gDKLB]e6g00800007D[MA]a:
gDKL0016g4[MA]a:gDKLB]e6g000A]a:gDKLB]e6g4[MA]a:g@00D_e>o5;mC_aBoDklD_d00`0000]K
75KkFaaFne/LE_]K75Kk001Fne/L00800007E_]K75KkFaaFne/L00002Gom00<007omOod077om001B
Ood40004Ood00`00Ooeoo@02Ood20007Ood00`00Ooeoo@0]Ood01000FWIJMP002UYf00D005YfFUIJ
MP0000URn@04001RnF;i0003HaT01FLJHaUS6F<IIaX00f<I00l006<IHaYS6FLJHaUS6V<IIaYS6F<J
HaT006<I00000UlK00EO6UlKGa]O6elJ009O6`800003Ga/005lK00UO6`800003Ga/005lK009O6`05
Fa]O6elKGa]K6`03000015/K001K6e/L0e/K00EK75/KFa]K6e/L0080000;Fa]K75/KFaaK6e/LFa]K
75/KFa`00002Fa/20002Fa/02U/LFa]K6e/KFa`005lKFa]O6e/K0P0000]O6e/KGa]K6elK001O6e/K
Ga]K6elK0080000BFa]O6e/KGa/005lKFa]O6e/KGa]K6elK001O6e/KGa]K6`001UlK00<005lKGa/0
0UlK00@005lKHa]O6P9O6`0:Ha]O6P00Ga]S6elJGa/006<KGaX2Ga/02V<K001O6elKHa]O6UlK001S
6elJ0UlK0P000UlK00IS6elJGa/006<KGaX2Ga/20002Ga/0:V<KGa]O6`00JcUW6F/i001[>FLIJcUW
6F/iIaU[>@00JcUW6F/i001[>FLIJcU[6@00IaU[>F/IJcUW6F/iJaT006LIJcU[6F/iIaU[>F/I001W
6@=[6@0L001[6FLIJaT006/IIaU[6FLIJaUW6F/I001[6@00JaUW6F/IIaU[6@00JaUW6F/IIaU[6FLI
JaT200002e[kFaaJne/KF_]K75[kFa/004[MA]`00TKM00=:g@0000001P0000E6g4KMA]e:g@000096
g@06B]e6g4KMA]e:g@000TKM00U:gDKMA]e6gD[MA]d004KMB]d00dKM00=:gDKM00000e;l10000U;l
00T005LKFaaG75/LEa]K75LLFa`00`0000YK75LKFaaG75/LEa]K75LLFa`000Uoo@03001ooGom01]o
o@00FWom00<007omOod00Wom00<007omOod01Wom00<007omOod0:gom0P0004MJMeYFFWL005YgFUIJ
MeYFFWMJEUYgFUIJMeYF001JEUYg001VnF;iI_URn6KiH_UVnF;hI_URn@00H_T006;iIaYRnFLJH_UW
6V;iIaYRnFLJH_T006<I001S6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6@00GaYO6elJGa]O6UlKGaX0
05lJGa]O6UlK0080000AFaYO6elJGa]K6UlKGaX005lJGa]O6UlK001O6e/KGa]K6`04000035lKFa]O
6e/K001K6e/LFa]K75/KFaaK6`80000=Fa`005/LFa]K75/KFaaK6e/LFa]K75/KFa`00P0000aK6e/L
Fa]O75/KFaaK6elLFa]K7000Ga`200002e/KGaaK6elKFa]O75/KGa/005lLFa/00P0000aO75/KGa]K
6elLFa]O6`00GaaK6elKFa/200001UlKFa]O75/KGa/000=O6`05Fa/00000Ga]K6`03Ga/01U/K001O
6V<KGaYS6`80000DGaYS6elJHa]O6P00GaYS6elJHa/006<KGaYS6elJHa]O6V<K001S6`80000:GaYS
6elJHa]O6V<KGaYS6`00Ha/20000:elJHa]O6V<KGaYS6elJHa/006/i001[>FLIJcUW6F/iIaU[>@00
JcUW6F/iIaT006LIJcUW6000IaU[>FLHJcUW6F/iIaP006LI001W66/iIaU[>FLH0080000[JcUW66/i
IaU[>@00JcT006/iIaQ[>FLIJcUW66/i001[>FLHJcT006/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/i
001K75KkFaaFne/LE_]K75KkFa`01@0000a:gDKLB]e6g000A]a:gDKLB]e6g4[MA]`200005D[MA]a:
gDKLB]e6g4[M001:gDKLB]e6g4[MA]a:g@00B]e6g4[MA]a:g@0600003DklD_e>o5;mC_aBoDkl001F
ne/LE_]K75Kk0080000<FaaFn`00E_]K75KkFaaFne/LE_]K75Kk0P002Gom00<007omOod06Wom001I
Ood20004Ood30006Ood00`00Ooeoo@0ZOod00`00FWIJMP04FWH00`00FWIJMP08FWH2000<H_T01@00
HaUS6F<IIaX00f<I01MW6V<IHaUS6@00HaUS6V<I001S6F<JHaUW6V<IHaYS6@00HaUW6V<JIaYS6@00
009O6`04GaYO6`000006Ga/20004Ga/20006Ga/400001E/K000005lKFa/00elK00@005/KFa]K709K
6`80000=Fa]K75/KFa`005/LFa]K75/KFaaK6e/LFa/00P0000EK7000Fa]K6e/L00=K6`0AFaaK6e/K
Fa]K7000Ga]K6elKFa]O6e/KGa]K6elKFa]O6`02000035/KGa]K6elKFa]O6e/KGa]K6elK001O6`80
000:Fa]O6e/KGa]K6elKFa]O6`00Ga/20009Ga/01000Ga/000000UlK00QS6elJGa]O6f<KGaX005lK
0P000UlK00YS6elJGa]O6f<KGaYO6`00Ha]O6P9O6`09Ha]O6UlKGa]S6elJGa/006<K00=O6`05Ha]O
6elKGa]S6`02Ga/08`00JcUW6F/iIaU[>FLIJcT006/iIaU[>FLIJcUW6@00JaT006LIJcU[6F/iIaU[
>F/I001W6F/iJaT006LIJcU[6F/i00000f/I02MW6F/IJaU[6@00JaUW6F/IIaU[6FLIJaT006/IIaU[
6FLIJaT006/I001[6FLIJaUW6F/IIaU[6@00JaUW6@00F_]K6e[kFaaJne/KF_/00P0000aK6`00B]e6
g4[MA]e:gDKLB]d004[MA]`2A]d014[MA]a6gDKM0P000TKM00E:gDKLA]e6g@0000=6g@03B]e6g@00
00L00005B]e6gD[MA]d00009D_`00`00Ea]K7002000035LKFaaG75/LEa/005LLFaaG6e/LEaaK7080
0003EaaK700000Qoo@03001ooGom01Yoo@00Igom0`00:Wom03L005YFFWMJEUYgFUIJMeYF001JEUYg
FUIJMeYFFWMJEUYgFUIJM`00I_URnFKiH_QVnF;iI_URn6KiH_UVnF;h001Rn@00H_UW6V;iIaYRnFLJ
H_UW6V;i001S6FLJHaUW6P00IaYS6FLJHaUW6P0200002F<IIaYS6FLJHaUW6V<I001O6P02000035lK
GaYO6elJGa]O6UlKGaYO6elJ001K6P800006Ga]O6UlKGaYO6elJ100000iO6`00001K6elKFa]O6e/K
Ga]K6elK001K75/K0P0000eK75/KFaaK6e/LFa]K7000FaaK6e/LFa]K700200003E/KFaaK6e/L001O
75/KFaaK6elLFa]K75/K0080000:Fa`005lLFa]O6e/KGaaK6elKFa/200006UlK001O75/KGa]K6elL
Fa]O6e/KGaaK6elK001O75/KGa]K6elLFa]O6e/KGaaK6elK0003Ga/01E/KGa]O6elKFa/00elK01MK
6`00GaYS6elJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJ0080000:Ha/006<KGaYS
6elJHa]O6V<KGaX200002V<K001S6elJHa]O6V<KGaYS6elJ0P0004]S6`00JcUW6F/iIaU[>@00JcUW
6F/iIaU[>FLIJcUW6@00IaU[>FLHJcUW6F/iIaP006LIJcUW66/i001[>FLHJcT006/iIaQ[>FLIJcUW
66/i001[>@00JcUW6F/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[>FLIJcUW66/i001[>FLHJcUW
6@00E_]K75KkFa`00P0001AFne/LE_/004KLB]e6g4[MA]a:gDKLB]d004[MA]a:gDKLB]e6g4[M0P00
00A6g4[MA]a:g@P0000FA]a:gDKLB]d004[MA]a:gDKLB]e6g4[MA]`004klD_e>o5;mC_aBoDklD_d3
00002e/LE_]K75KkFaaFne/LE_/005KkFa`00`0000EK75KkFaaFn`0000Uoo@03001ooGom01Uoo@00
Igom00<007omOod0:Gom00<005YfFWH01UYf00<005YfFWH01eYf00<006;i00002V;i00@006<IIaUS
6@80009S6@03IaYS6F<I0080000FHaUS6V<IIaYS6F<J001W6V<IHaX006LJHaUW6V<JIaYS6FLJHaYW
6V<I000=Ga/00`00Ga]O6`03Ga/30004Ga/01@00Ga]O6elKFa/00elK00AK6elKGa]O6`80000=Fa]K
75/KFaaK6e/LFa]K75/KFa`005/LFa/00P0000QK75/KFaaK6e/LFa]K70000U/K00=K75/KFa/00P00
0e/K01IK7000Ga]K6elKFa]O6e/K001K6elKFa]O6`00Ga]K6elKFa]O6e/KGa]K6`80000:Ga/005lK
Fa]O6e/KGa]K6elKFa/200000elK001O6`08Ga/200001ElK001O6f<KGaX00UlK00=S6elJGa/00P00
00EO6P00Ga]S6elJ009O6`0:Ha]O6P00Ga]S6elJGa/006<KGaX2Ga/01F<KGaX005lKHa/00UlK00<0
06<KGa/00UlK00ES6elK001O6f<K009O6`0O001[>FLIJcT006/iIaU[>FLIJcUW6F/iIaT006LI001[
6F/iIaU[>F/I001W6F/iJaU[>FLIJcT006/i00000f/I02EW6F/IJaU[6@00JaUW6F/I001[6FLIJaT0
06/IIaU[6FLIJaUW6F/I001[6@00JaUW6F/IIaU[6@00JaUW6F/IIaU[6@00FaaJn`0200004U/LF_]K
6e[kFaaJn`00A]e:gDKLB]e6gD[MA]`004KMB]e6g096g@P0000GB]e6g4[MA]d004KMB]e6gD[MA]e:
gDKM0016gD[MA]e:gDKMB]e6gD[MA]d00003D_`40002D_`02P00Ea]K75LLFaaG6e/LEaaK75LK0P00
00UK75LKFaaG75/LEa]K75LL00002Gom00<007omOod067om001WOod00`00Ooeoo@0XOod09P00FUIJ
MeYFFWMJEUYgFUIJMeYFFWL005YgFUIJMeYFFWMJEUYg001VnF;iI_T006KiH_UVnF;hI_URnFKiH_P0
06;iIaYRnFLJH_T200009fLJH_UW6P00IaYS6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<I
IaYS6FLJHaT006<I001O6UlKGaYO6elJGa]O6UlKGaYO6`0200000elJ001O6P0300001ElJGa]O6UlK
GaX00P0000YO6`00Ga]K6elKFa]O6e/KGa]K6`80000=Ga/005/LFa]K75/KFaaK6e/LFa]K75/KFa`0
0P0000eK6e/LFa]K75/KFaaK6e/LFa]K7000GaaK6`0200006ElLFa]K75/KGaaK6e/L001O75/KGa]K
6`00Fa]O6e/KGaaK6elK001O75/KGa]K6elL0080000:Fa]O75/KGa/005lLFa]O6e/KGa`200001E/K
GaaK6elK00000elK00EK6elKGa]O6`0000=O6`0BFa/005lJHa]O6V<KGaYS6`00Ha]O6V<KGaX005lJ
Ha]O6V<K0P0000YO6V<KGaYS6elJ001O6V<KGaYS6`80000:GaYS6elJHa]O6P00GaYS6elJHa/20000
BUlJHa]O6V<KGaYS6`00JcT006/iIaU[>FLIJcUW6F/iIaT006LIJcT006/iIaU[>FLH001W6F/iIaQ[
>FLIJcUW66/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaU[>@00JcT006/iIaQ[>FLIJcUW66/i001[
>FLH001W6F/iIaQ[>@00JcUW66/iIaU[>FLHJcT200003UKkFaaFne/LE_]K75KkFa`004[MA]a:gDKL
B]d8000014KLB]e6g4[M0P0001E6g4[MA]a:gDKLB]d004[MA]a:gDKLB]e6g4[MA]`004KLB]e6g4[M
A]`01`0000i>o5;mC_aBoDklD_d005/LE_]K75KkFaaFne/L0P0000]Fn`00E_]K75KkFaaFne/LE_]K
700000Uoo@03001ooGom01Qoo@0037om00<007omOod02gom0`0017om00<007omOod06gom0`009Gom
00<007omOod09gom0P002UYf00<005YfFWH015Yf00<006;iH_T00f;i00<006;iH_T00f;i0P0002ES
6FLIHaUW6F<IIaUS6FLI001S6@00IaYS6F<JHaUW6V<IHaYS6FLJHaUS6P00IaYS6FLJHaYW6V<IIaYS
6VLJHaT006<JIaYS6@020007Ga/01000Ga]O6elK0P001elK00<005lKGa/00UlK00D005lKGa]O6e/K
009O6`03001K6elK009O6`09001K75/KFaaK6e/LFa]K75/K0080000=Fa`005/LFa]K75/KFaaK6e/L
Fa]K75/KFa`00P0000=K6e/LFa/00U/K00MK75/KFa]K6e/L001O6`0200002e/KGa]K6elKFa]O6e/K
Ga/005lKFa/00P0000YO6e/KGa]K6elKFa]O6`00Ga]K6`800008Ga]K6elKFa]O6e/KGa/000AO6`80
00EO6`05001O6elKHa]O6P02000026<KGaYO6elKHa]O6P00Ga/20002Ga/026<KGaYO6elKHa]O6P00
Ga/20002Ga/026<KGa]O6elKHa]O6`00Ga/20002Ga/01F<KGa]O6elKHa/00UlK01l006/iIaU[>FLI
JcUW6F/iIaT006LIJcUW6F/i001[>F/I001W6F/iJaU[>FLIJcU[6F/i001[>@00JaUW6@03JaT0;000
JaUW6F/IIaU[6FLIJaT006/IIaU[6FLIJaUW6F/I001[6FLIJaUW6@00IaU[6@00JaUW6F/IIaU[6FLI
JaT006/I001K75[kFa]Jne/LF_]K6e[kFa`500007D[MA]e:gDKL0016gD[MA]a:gDKMB]e6g4[M001:
gDKLB]e6gD[MA]a:g@00B]e6gD[MA]e:gDKMB]d01P0000I6gD[MA]e:gDKM0008D_`01@00FaaG6e/L
Ea`00P0000aK75LLFa`005/LEaaK75LKFaaG75/LEa/20006Ood200000gom001oo@0HOod000]oo@03
001ooGom00Qoo@03001ooGom009oo@03001ooGom00Aoo@03001ooGom009oo@03001ooGom00=oo@03
001ooGom019oo@03001ooGom029oo@03001ooGom02Ioo@0B001JEUYg001JMeYFFWMJEUYgFUIJMeYF
FWMJEP00FUIJMeYF0P0003AVnF;iI_URn6KiH_UVn@00I_URnFKi001W6V;iIaYRnFLJH_UW6V;iIaYR
nFLJ001W6V<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS
6@800004Ga]O6UlKGaX200002elK00000000Ga]O6P00GaYO6elJGa/00P000UlK01IO6UlKGa]O6`00
Ga]K6elKFa/005/KGa]K6elLFa]O6`00FaaK6e/LFa]K7080000=Fa]K75/KFa`005/LFa]K75/KFaaK
6e/LFa/00P0001UK7000GaaK6e/LFa]O75/KFaaK6elLFa]K7000GaaK6elKFa]O75/KGa]K6elLFa]O
6`0200002U/KGa]K6elLFa]O6e/KGaaK6elK0P0000aK6elKFa]O75/KGa]K6elLFa]O6`00Ga/20000
1E/KGa]O6elKFa/00elK02l006<K000005lJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS
6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJ0080001<Ha/0
06/iIaU[>FLIJcUW6@00IaU[>FLIJcUW6@00IaP006LIJcUW66/iIaU[>FLHJcT006/iIaQ[>@00JcUW
66/i001[>FLHJcUW6F/iIaQ[>@00JcT006/iIaU[>FLHJcT006/iIaQ[>FLIJcT006/i001[>FLHJcUW
6F/iIaQ[>@00JcUW66/i001K75KkFaaFne/LE_/200004U/L001:gDKLB]e6g4[MA]a:gDKL0016g4[M
A]a:gDKLB]e6g080000:B]e6g4[MA]a:gDKL0016g4[MA]`400005d[MA]`004KLB]e6g4[MA]a:gDKL
B]d005;mC_aBoDklD_e>o5;mC_`005KkFa`00P0000aFne/LE_]K75KkFa`005/LE_]K75KkFa`20000
0eKkFa`00009Ood00`00Ooeoo@0FOod000=oo@<000Aoo@04001ooGomOod50003Ood00`00Ooeoo@02
Ood30005Ood00`00Ooeoo@02Ood00`00Ooeoo@03Ood01000OoeooGom1@000gom0P0017om0`0097om
0P009Gom0P000eYf00<005YfFWH025Yf00@005YfFWH000YRn@0T001Rn@00IaUS6FLIHaUW6F<IIaUS
6FLIHaUW6@00IaX006<JHaUW6V<IHaYS6FLJHaUS6P00IaYS6FLJ001W6V<IIaYS6VLJ0P0000YS6VLJ
HaUW6V<JIaYS6FLJ001O6`D000IO6`04001O6`000009Ga/01@00Ga/00000Fa/00elK00MK6elKGa]O
6`00FaaK6`0200003E/LFa]K75/KFaaK6e/L001K75/KFaaK6e/L00800005Fa]K75/KFa`00002Fa/0
1U/LFa]K6e/KFaaK6`80000:Fa`005lKFa]O6e/KGa]K6elKFa/200002UlK001O6e/KGa]K6elKFa]O
6e/K0P0000iO6`00Ga]K6elKFa]O6e/KGa]K6elKFa]O6`002elK00D005lKGa]S6elJ009O6`0:Ha]O
6UlKGa/005lJ001O6f<KGaX2Ga/00f<KGaYO6`02000015lK001O6f<K0elK00=S6elKGa/00P0000AO
6`00Ga]S6`=O6`05Ha]O6`00Ga]S6`02Ga/0B000JcUW6F/iIaT006LIJcUW6F/iIaU[>FLI001W6F/i
JaU[>FLIJcU[6F/i001[>F/IJcUW6F/i001[6@00JaUW6F/IIaU[6FLIJaT006/IIaT006LIJaUW6F/I
001[6FLIJaUW6F/IIaU[6@00JaUW6F/IIaU[6FLIJaT006/IIaU[6FLI001Jne/LF_]K6`80000EF_]K
6e[kFa`004[MA]e:gDKLB]e6gD[M001:gDKMB]e6g4[MA]e:gDKL00800003B]e6g4[M00H0000AA]e:
gDKMB]e6gD[MA]d004KMB]e6gD[MA]e:gDKMB]d00007D_`300002e/LEa]K75LLFaaG6e/LEa`005LK
Fa`00`0000IK75LLFaaG6e/L0008Ood00`00Ooeoo@0FOod000=oo@04001ooGom0003Ood00`00Ooeo
o@02Ood01000Ooeoo@0017om00D007omOoeoo@00009oo@03001ooGom009oo@03001ooGom009oo@03
001ooGom00=oo@03001ooGom009oo@04001ooGom0002Ood01000Ooeoo@000Wom00@007omOod002Ao
o@03001ooGom02=oo@0B001JMeYFFWMFEUYgFUH005YFFWMJEUYgFUIJMeYFFWMJEUYg0P0001MRn6Ki
H_UVnF;hI_URnFKiH_QVnF;iI_T006LJH_UW6V;iIaYRnFLJH_UW6V;i0080000QIaYS6FLJ001W6V<I
IaYS6FLJHaUW6P00IaYS6FLJHaUW6P00IaYS6FLJ001W6V<IIaYS6FLJHaUW6V<IIaYS6FLJ00<0000<
Ga]O6UlKGaYO6elJGa]O6UlKGaX005lJ0elK00EO6UlKGa]O6elJ00=O6`0<001O75/KGa]K6elLFa]O
6e/KGaaK6elK0P0000eK6e/LFa]K75/KFaaK6e/LFa]K7000FaaK6`0200003E/LFa]K75/KFaaK6e/L
001O75/KFaaK6elL0080000UFa]O75/KFa`005lLFa]O6e/KGaaK6`00Fa]O75/KGa/005lLFa]O6e/K
GaaK6`00Fa]O75/KGa/005lLFa]O6e/KGaaK6elKFa/00P0000=O6`00Ga/00UlK00EK6elKGa]O6e/K
00800009Ga/006<KGaYS6elJHa]O6V<K0080000PGaYS6elJ001O6V<KGaYS6elJHa/006<KGaYS6elJ
001O6V<KGaYS6elJHa/006<KGaYS6elJ001O6V<KGaYS6`80001;GaYS6elJHa]O6P00IaU[>FLI001W
6F/iIaU[>FLIJcUW6@00IaT006LHJcUW6F/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[>FLIJcUW
66/i001[>FLHJcUW6@00IaQ[>@00JcUW66/iIaU[>FLHJcT006/i001[>FLIJcUW66/i001[>FLHJcUW
6F/iIaP005Kk0080000EFaaFne/LE_]K75Kk0016g4[MA]a:gDKLB]e6g4[M001:gDKLB]e6g4[M00L0
000JB]e6g4[MA]`004KLB]e6g4[MA]a:gDKLB]d004[MA]a:gDKLB]e6g4[MA]`004klD_e>o0@0000;
D_e>o000E_]K75KkFaaFne/LE_]K700300002E/LE_]K75KkFaaFne/LE_/00009Ood00`00Ooeoo@0E
Ood000Ioo@05001ooGomOod00004Ood00`00Ooeoo@09Ood01000Ooeoo@0017om00<007omOod00Wom
00<007omOod00gom00<007omOod00Wom00<007omOod00gom00@007omOod0009oo@04001ooGom000S
Ood00`00Ooeoo@0SOod00`00FWMJMP02FWH015YgFWIJMP002UYf00<006;iH_T02V;i00l006LI001W
6F<IIaUS6FLIHaUW6F<I001W6FLJHaT00VLI00H006<IHaYS6FLJHaT200004fLJHaUW6V<JIaYS6FLJ
001W6P00IaYS6VLJHaUW6V<JIaYS6FLJ00<00003IaX005lK00QO6`800003Ga/005lK00QO6`800003
Ga/005lK009O6`05Fa]O6elKGa]K6`0200003ElK001K75/KFaaK6e/LFa]K75/KFaaK6e/L0080000;
Fa]K75/KFaaK6e/LFa]K75/KFa`00002Fa/20002Fa/02E/LFa]K6e/K001K6elKFa]O6`02000065/K
Ga]K6elKFa]O6`00Ga]K6elKFa/005/KGa]K6elKFa]O6`00Ga]K6elKFa]O6`800005Fa]O6e/KGa/0
0006Ga/00`00Ga]O6`02Ga/02@00Ga]O6f<KGaYO6`00Ha]O6P02Ga/01V<K001O6elKHa]O6P800006
Ha]O6elKGa]S6`000UlK00ES6elK000006<K00=O6`04Ha]O6`00Ga/20002Ga/0FV<KGa]O6elKHa]O
6`00IaT006LIJcUW6F/iIaU[>FLI001W6F/iIaT006LIJcU[6F/i001[>F/IJcUW6F/iJaU[>@00JcT0
06/IIaU[6FLIJaT006/IIaU[6FLIJaT006/I001[6FLIJaUW6F/IIaU[6@00JaUW6F/I001[6FLIJaT0
06/IIaU[6FLIJaUW6F/IIaT005[kFaaJne/KF_]K75[kFa]Jn`00A]a:gDKMB]e6g0P0000KB]e6gD[M
A]`004KMB]e6g4[MA]e:gDKL0016gD[MA]e:gDKMB]e6gD[M001:gDKMB]e6gD[M00H000IBo007001K
75LLFaaG6e/LEa`00P0000]K75LL001G6e/LEaaK75LKFaaG75/L008000Qoo@03001ooGom01Eoo@00
17om0P0017om00<007omOod00Wom0P002Gom10001Gom00<007omOod00gom00<007omOod00gom00D0
07omOoeoo@0000Ioo@8000Aoo@@0029oo@03001ooGom029oo@1:001JMeYFFWMFEUYgFUIJMeIF001J
EUYgFUIJMeYFFWMJEUYgFUH006;i001RnFKiH_QVnF;iI_URn6KiH_UVn@00IaYS6FLJ001W6V;iIaYR
nFLJH_T006<IIaYS6FLJHaUW6V<I001S6FLJHaT006<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6V<IIaYS
6FLJHaUW6P<0000DIaX006LJHaUW6P00Ga]O6UlKGaYO6elJGa/005lKGaYO6elJ001O6P=O6`05GaYO
6elK001O6P03Ga/05@00GaaK6elKFa]O75/K001K6elLFa]O6`00FaaK6e/LFa]K75/KFaaK6`020000
3E/L001K75/KFaaK6e/LFa]K75/KFaaK6e/L0080000;Fa]K75/KGaaK6e/LFa]O75/K001K6`020000
2elKFa]O75/KGa]K6elLFa]O6`00Ga`00P0000]K6elLFa]O6e/KGaaK6elK001O75/K00800008GaaK
6elKFa]O75/K001K6`=O6`80009O6`0BFa]O6elK001O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa/006<K
0P0000YO6V<KGaYS6elJHa]O6V<K001S6`80001RGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJ
Ha]O6V<KGaYS6elJ001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/iIaQ[>@00JcUW66/iIaU[>FLH
JcT006/iIaP006LIJcUW66/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[>FLI
JcT006/i001[>FLHJcUW6F/iIaQ[>FLI001W6000E_]K75KkFaaFne/LE_]K70H0000<A]a:gDKLB]d0
04[MA]a:gDKLB]e6g4[M0P0000e6g4[MA]a:gDKLB]e6g000A]a:gDKLB]e6g008000044[MA]a:gDKL
001>o5;mC_aBoDklD_e>o5;m001K75Kk0`0000]Fne/LE_]K7000FaaFne/LE_]K75Kk00800003FaaF
n`0000Qoo@03001ooGom01Aoo@000gom00@007omOod000Aoo@05001ooGomOod00002Ood00`00Ooeo
o@0=Ood00`00Ooeoo@04Ood00`00Ooeoo@03Ood01@00OoeooGom0000<Wom00<007omOod08Gom00<0
05YgFWH00UYf00MJMeYfFWIJMUYgFWH00007FWH01@00H_URnF;i000026;i00X006LIHaUW6F<IIaT0
06LIHaUW6@800003IaUW6V<I009W6@0GIaYS6FLIIaT006<I001S6VLJHaUW6V<JIaYS6FLJHaYW6P00
IaX006LJHaUW6P0300002VLJHaYW6P00IaYS6VLJHaYW6P0015lK0P001UlK00<005lKGa/00UlK0P00
1UlK00H005lKGa]O6e/K0002Ga/02U/KGa]O6elK001K75/KFaaK6e/L0P0000eK6e/LFa]K7000FaaK
6e/LFa]K75/KFaaK6`0200001E/L001K6e/KFa`00e/K01eK75/KFa]K6`00Fa]O6e/KGa]K6elKFa]O
6e/KGa]K6elK001O6e/KGa]K6elKFa]O6e/KGa]K6elK0080000;Fa]O6e/KGa]K6elKFa]O6e/K001O
6`020008Ga/01P00GaX00000Ha]O6P9O6`06Ha]O6UlKGa]S6`000UlK00ES6elKGa]O6f<K00=O6`05
Ha/005lKGa]S6`03Ga/02F<KGa]O6elK001O6`00Ga]S6`03Ga/00f<KGa]O6`0200001elK001W6F/i
IaU[>FLI0080000WJcUW6F/iIaU[>@00JcT006/iJaU[>FLIJcU[6F/i001[>F/IJcUW6@00IaU[6@00
JaUW6F/IIaU[6FLIJaT006/I001[6FLIJaUW6F/I0080000IIaU[6FLIJaUW6F/I001[6FLIJaUW6F/I
IaU[6FLI001W6F/I001K6e[kFaaJne/KF_/00P0001=K6e[k0016g4[MA]e:gDKLB]e6g@00A]a:gDKM
B]e6g4[MA]e:g@02000014KMB]e6g4[M200000e6gD[MA]e:g@00B]e6gD[MA]e:gDKMB]d00008D_`3
00002eLLFaaG6e/LEaaK75LKFa`005/LEa/00`0000EG6e/LEaaK700000Uoo@03001ooGom01=oo@00
0gom10001Gom00<007om000010003Wom00<007omOod01Wom00<007omOod00gom00<007om00000P00
<Gom0`0087om0P0001AJEUYgEUIJMeYFFWMFEUYgFUIJM`00FWMJEUYgFUIJMeYF001RnFKi0f;i00H0
06;iI_URn6KiH_T200009FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<IIaYS6FLJHaUW6V<I
001S6FLJHaUW6V<IIaYS6FLJHaUW6P00IaYS6FLJ00<00004IaYS6FLJHaT200002FLJHaUW6V<IIaYS
6FLJ001O6`0200002elJGa]O6UlKGaYO6elJGa]O6P00GaX00P0000=O6elJGa/00UlK00IO6UlKGa]O
6`00Ga`200002e/KGaaK6elKFa]O75/KGa/005/LFa/00P0000eK75/KFaaK6e/LFa]K7000FaaK6e/L
Fa]K7002000035/KFaaK6e/L001O75/KFaaK6elLFa]K7080000;Fa/005/KGaaK6elKFa]O75/KGa]K
6`0200002UlK001O75/KGa]K6elLFa]O6e/K0P0000iO6`00GaaK6elKFa]O75/KGa]K6elLFa/005/K
0elK00EK6elKGa]O6e/K009O6`0:001O6V<KGaYS6elJHa]O6V<KGaX200002V<K001S6elJHa]O6V<K
GaYS6elJ0P0000US6`00Ha]O6V<KGaYS6elJHa/00P0005EO6V<KGaX005lJHa]O6V<KGaYS6`00Ha]O
6V<KGaX006LIJcUW6F/i001[>FLIJcUW6F/iIaU[>@00JcUW66/iIaU[>FLHJcT006/iIaQ[>FLIJcT0
06/i001[>FLHJcUW6F/iIaQ[>@00JcUW66/i001[>FLHJcUW6@00IaQ[>FLIJcUW66/i001[>@00JcUW
6F/iIaQ[>FLI001W66/iIaU[>@00FaaFn`0300004eKkFaaFne/L001:gDKLB]e6g4[MA]a:gDKL0016
g4[MA]a:gDKL00P0000IB]e6g4[MA]`004KLB]e6g4[MA]a:gDKL0016g4[MA]a:gDKLB]e6g4[M001B
oDklD_d0100000a>o5;m001K75KkFaaFne/LE_]K75KkFa`200002EKkFaaFne/LE_]K75KkFa`00008
Ood00`00Ooeoo@0COod006Ioo@03001ooGom01ioo@800005FWMJMP00FWIJM`03FWH01UYgFWIJMUYf
FWL000=JMP8000MRn@0@001RnF;iH_T006<IIaUS6FLIHaUW6F<IIaUS6FLI0002IaT01VLJHaUW6FLI
IaYS6@9W6@0@IaYS6@00IaT006<IIaYS6VLJHaUW6V<JIaX006LJHaX200004VLJ000006<IIaYS6P00
HaYW6V<JIaYS6VLJHaYW6V<JIaX000aO6`03001O6elK00YO6`05001O6elKGa]K6`03Ga/015/KGa]O
6elK0P0000eK6e/LFa]K75/KFaaK6e/LFa]K7000FaaK6`0200001e/LFa]K75/KFaaK6`0000=K6`05
FaaK6`00001K7003Fa/200001ElKFa]O6e/KGa/00P0001QK6elKFa]O6`00Ga]K6elKFa]O6e/K001K
6elKFa]O6`00Ga]K6elKFa]O6e/KGa/200000e/K001O6`07Ga/200000elK001O6P02Ga/01F<KGaYO
6elK00000elK00ES6`00Ga]O6f<K00=O6`06001O6elKGa]S6`000UlK00ES6elKGa/006<K00=O6`06
Ha/005lKGa]S6elK0P00045S6elKGa]O6f<K001[>FLIJcT006/iIaU[>FLIJcUW6F/i001[>@00JcUW
6F/iJaU[>@00JcU[6F/iIaU[>F/IJcT006/IIaU[6FLIJaUW6F/I001[6FLIJaUW6@00IaU[6FLI001W
6F/IIaU[6FLIJaT006/IIaT006LIJaUW6F/I00800006IaU[6FLIJaUW6F/I0P0000iJne/LF_]K6e[k
FaaJne/K001:gDKLB]e6gD[M200001e6g4[MB]e:g@00B]e6gD[MA]a:gDKMB]d004[MA]e:gDKMB]e6
gD[MA]d004KMB]e6gD[MA]e:gDKM00@000IBo008001G6e/LEaaK75LKFaaG7080000;Fa`005/LEa]K
75LLFaaG6e/LEa`00009Ood00`00Ooeoo@0BOod006Ioo@03001ooGom01eoo@0D001FEUYgFUIJM`00
FWMJEUYgEUIJMeYFFWMFEUYgFUH005YFFWL0009Rn@05I_URnF;iH_UVn@03H_T09000H_T006<IIaYS
6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6@00HaUW6V<IIaYS
6@D0000NHaUW6V<IIaYS6@00HaT006<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6P00Ga]O6UlKGaYO6elJ
Ga]O6UlK0P0000=O6P00GaX00elK00EO6UlKGa]O6elJ0080000:Ga/005lLFa]O6e/KGaaK6elKFa/2
00003ElK001K75/KFaaK6e/LFa]K75/KFaaK6e/L0080000<Fa]K75/KFaaK6e/LFa]K75/K001K6elL
0P0000]K6elLFa]K75/KGaaK6e/L001O75/K0080000;GaaK6elKFa]O75/K001K6elLFa]O6`020000
2e/KGa]K6elLFa/005/KGaaK6elKFa/00P0000IO6e/KGaaK6`00Fa/3Ga/01E/K000005lKFa/00UlK
0P0002ES6elJHa]O6P00GaYS6elJHa]O6V<K001S6elJHa]O6P00GaYS6elJHa]O6P00GaYS6elJHa/0
06<KGaYS6elJHa]O6V<K001S6`020000:UlJHa]O6V<KGaYS6elJHa/006/i001[>FLIJcUW6F/iIaU[
>@00JcUW6F/i001[>FLHJcT006/iIaQ[>FLIJcUW66/i001[>@00JcUW6F/iIaQ[>@80000ZIaQ[>FLI
JcUW6000IaT006LHJcUW6F/iIaQ[>@00JcUW66/iIaT006LHJcT006/iIaQ[>FLIJcUW66/i001[>@00
FaaFne/LE_]K75KkFaaFne/L1@0000a:gDKLB]e6g000A]a:gDKLB]e6g4[MA]`200004d[MA]a:gDKL
B]e6g4[M001:gDKLB]e6g4[MA]a:g@00B]e6g4[M00@0000@A]a:g@00D_e>o5;mC_aBoDklD_e>o000
E_]K75KkFa`2000035KkFaaFn`00E_]K75KkFaaFne/LE_]K708000Ioo@800003Ood007om019oo@00
IGom00<007omOod07Gom00<005YfFWL00eYf00EJM`00FWIJMUYg00=JMP04FWMJMUYfFWH2000<H_T0
3000HaUW6F<IIaUS6FLIHaUW6F<IIaT0009W6@06IaX006LIIaUW6V<I0VLI00aW6V<I001W6FLJHaUW
6VLI001S6FLJHaX300006F<JIaYS6FLJHaYW6V<IIaYS6P00HaYW6V<JIaYS6VLJHaYW6V<JIaX006LJ
HaYW6P0000MO6`03001O6elK009O6`03001O6elK00EO6`03001O6elK009O6`05001O6elKGa]K6`02
Ga/00`00Fa]O6`02Ga/02@00FaaK6e/LFa]K75/KFaaK6`02000035/L001K75/KFaaK6e/LFa]K75/K
FaaK6`80009K6`05FaaK6e/KFa]K7003Fa/03U/L000005/KGa]K6elKFa]O6e/KGa]K6`00Fa/20000
2elKFa]O6e/KGa]K6elKFa/005/KGa/00P0000QK6elKFa]O6e/KGa]K6`000UlK0P0025lK00@005lK
000000=O6`07Ha]O6elKGa]S6`00Ga/00P000elK00IS6elKGa]O6`00Ga/200001F<KGa]O6elKHa/0
0elK00ES6`00Ga]O6f<K00=O6`0eHa]O6elKGa]S6`00JcUW6F/iIaU[>FLIJcT006/iIaU[>FLIJcT0
06/i001[>F/IJcUW6F/iJaU[>@00JcUW6F/i001[6FLIJaUW6@00IaU[6FLIJaUW6F/IIaT006LIJaUW
6F/IIaU[6@0200006FLIJaUW6F/I001[6@00JaUW6F/IIaU[6FLIJaT006/IIaU[6@00Fa]Jne/LF_]K
6e[k00800004Fa/004[MA]`3B]d01DKLB]d004[MA]`00d[M00=6g4[MB]d00P0000a:gDKMB]e6g4[M
A]d004KMB]e6gD[MA]d600000d[MA]e:g@02B]d00dKM001Bo007D_`00`00FaaG6`02000035/LEa]K
75LLFaaG6`00EaaK75LKFaaG70800003FaaG700000Qoo@03001ooGom015oo@00IGom00@007om0000
01Yoo@80000CEUIJMeYFFWMFEUYgFUH005IFFWMJEUYgEUIJMeYFFWMFEUYg00000V;i00EVnF;iH_UR
nFKi00=Rn@0II_URn@00HaT006<IIaYS6FLJHaUW6V<IIaX006LJHaUW6V<IIaX006LJHaUW6V<IIaX0
0P0000MS6FLJHaUW6V<IIaYS6@0300008F<IIaYS6FLJHaUW6V<IIaYS6FLJHaT006<I001S6FLJHaUW
6V<IIaYS6FLJ001W6V<IIaYS6FLJ001O6elJGa]O6P02000025lKGaYO6elJGa]O6P00GaX3Ga/20002
Ga/025lJGa]O6`00Fa]O75/KGa/2000035/KGa]K6elLFa]O6`00FaaK6e/LFa]K7080000<Fa]K75/K
Fa`005/LFa]K75/KFaaK6e/L0P0000]K6`00Fa]O75/KFaaK6elLFa]K75/K0080000HFa`005lLFa]O
6e/KGaaK6elKFa]O75/K001K6elLFa]O6e/KGaaK6elKFa]O75/K0P0000YO75/KGa]K6elLFa]O6e/K
GaaK6`8000=O6`05Fa]O6elKGa]K6`03Ga/08@00Ha]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<K
GaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa]O6P0200002V<K001S6elJHa]O6V<KGaYS6elJ
0P0004US6`00JcUW6F/iIaU[>@00JcUW6F/iIaU[>FLIJcT006/iIaQ[>FLIJcUW66/i001[>FLHJcUW
6@00IaQ[>FLI001W66/iIaU[>FLHJcUW6@00IaP006LIJcUW66/iIaT006LHJcUW6F/iIaQ[>@00JcUW
66/iIaU[>FLHJcT006/iIaQ[>FLI001Fne/LE_]K7002000055KkFaaFn`00A]a:gDKLB]e6g4[MA]a:
g@00B]e6g4[MA]a:gDKLB]d2000014KLB]e6g4[M200001E6g4[MA]a:g@00B]e6g4[MA]a:gDKLB]e6
g000C_aBoDklD_e>o5;mC_`00`0000]Fne/LE_]K75KkFaaFne/L001K75Kk00<00006E_]K75KkFaaF
n`0027om00<007omOod047om001UOod2000KOod01000FWIJMUYg0eYf00EJMeYfFWH005Yg00=JMP08
FWMJMUYfFWIJM`00H_T000URn@80000;HaUW6V<I001S6FLIHaUW6F<IIaT00002IaT01VLJHaUW6FLI
IaX0009W6@08IaX006LJIaUW6V<IIaYW6@<0000<IaT006<IIaYS6VLJHaUW6V<JIaYS6FLJ0P0000US
6VLJHaX006<JIaYS6VLJHaX00P0000UW6V<JIaYS6VLJHaYW6P00Ga/00P002ElK00@005lK000000QO
6`06001K6`00001O6e/K0elK00MK6elKGa]O6`00FaaK6`02000035/LFa]K75/KFaaK6e/L001K75/K
FaaK6`800005FaaK6e/LFa/00003Fa/01E/LFa]K6e/K00000e/K00UK7000Ga]K6elKFa]O6e/KGa/0
0P0000YK6`00Fa]O6e/KGa]K6elKFa]O6`80000:Fa/005/KGa]K6elKFa]O6e/KGa/200000e/K001O
6`08Ga/200001ElK001O6elKHa/00elK00IS6elK000006<K0002Ga/01F<KGa]O6elKHa/00P0000=O
6`00Ga/00UlK00ES6elKGa]O6`0000=O6`05Ha/005lKGa]S6`03Ga/06@00Ga]O6elKHa/006/iIaU[
>@00JcUW6F/iIaU[>FLIJcT006/i001[>FLIJcU[6F/i0080000VIaU[>FLIJcUW6@00IaT006LIJaUW
6F/IIaU[6FLI001W6F/IIaT006LIJaUW6@00IaU[6FLIJaUW6F/I001[6@00JaUW6F/IIaU[6@800007
IaU[6FLIJaUW6@00F_/00P0000MK75[kFa]Jne/LF_/00002B]d01TKLB]e:gD[MA]`0009:g@03A]a:
gD[M00P00006B]e6g4[MB]d004KL0d[M00E6g4[MB]d004KM00=:g@05A]e:gD[MB]d00003D_`40002
D_`02@00FaaG6e/LEaaK75LKFaaG700300002ELLFaaG6e/LEaaK75LKFa`00009Ood00`00Ooeoo@0?
Ood006Eoo@03001ooGom01Uoo@0E001JMeIFFWMJEUYgEUIJMeYFFWMFEUYg001JMeIFFWMJEUYgEUIJ
M`00009Rn@05I_T006;iH_UVn@03H_T07VKi001W6V<IIaYS6FLJ001W6V<IIaYS6FLJ001W6V<IIaYS
6FLJHaUW6V<IIaX006LJ001W6V<IIaYS6@<0000cHaUW6V<I001S6@00HaUW6V<IIaYS6FLJHaUW6P00
IaYS6FLJHaUW6V<I001S6FLJHaT006<IIaYS6FLJHaUW6V<IIaYS6FLJ001O6elJGa]O6UlKGaYO6elJ
Ga]O6UlKGaX005lJ00=O6`05GaYO6elKGa]O6P02Ga/03@00Fa]O75/KGa]K6elLFa]O6e/KGaaK6elK
0080000<Fa]K75/KFaaK6e/LFa]K75/KFa`005/L0P0000aK6e/LFa]K75/KFaaK6`00Fa]O75/KFa`2
00002e/KFaaK6elLFa/005/KGaaK6elKFa/00P0001iO6e/KGaaK6`00Fa]O75/KGa]K6elL001O6e/K
GaaK6`00Fa]O75/KGa]K6elL001O75/KGaaK6`00Fa/3Ga/01E/KGa]O6`00Fa/00elK01`006<KGaYS
6elJHa]O6P00GaYS6elJHa/006<KGaYS6elJHa/006<KGaYS6elJ001O6V<KGaYS6`80000:GaYS6elJ
Ha]O6P00GaYS6elJHa/20000F5lJHa]O6V<KGaYS6`00JcT006/iIaU[>FLIJcUW6F/i001[>FLIJcT0
06/iIaQ[>FLI001W66/iIaU[>FLHJcUW6@00IaQ[>FLIJcUW66/iIaT006LHJcUW6F/iIaP006LI001W
66/iIaU[>FLHJcT006/iIaQ[>@00JcUW66/iIaT006LHJcUW6F/iIaQ[>FLI001Fne/LE_]K75KkFaaF
ne/L001:gDKLB]e6g4[M200000A6g4[MA]a:g@80000EA]a:gDKLB]e6g4[M001:gDKLB]e6g4[MA]a:
gDKL0016g4[MA]a:gDKL00H0000=D_e>o5;mC_aBoDkl001Fne/LE_]K75KkFa`00P0000]Fne/L001K
75KkFaaFne/LE_]K75Kk008000Qoo@03001ooGom00moo@00E7om1@000Wom0P0027om00<007omOod0
67om0P0000=JMUYgFWH00UYf00UJMeYfFWIJMUYgFWH005YfFWL00eYf00=JM`00H_T00f;i00<006;i
H_T016;i00d006LIHaUW6V<IIaUS6FLJ001W6F<IIaT00002IaT01VLJHaUW6FLIIaYS6@9W6@04IaX0
06LJIaT30000:FLIIaYS6FLJIaT006<IIaYW6@00HaUW6V<JIaYS6FLJ001W6V<JIaYS6VLJHaYW6V<J
001S6P00HaYW6V<JIaYS6VLJHaYW6V<JIaX006LJ00002ElK0P0000=O6`00Ga/01elK0P0000=O6`00
Fa/00elK00EK6elKGa]O6e/K0080000JGa/005/LFa]K75/KFaaK6e/LFa]K75/KFa`005/LFa]K75/K
FaaK6e/LFa]K75/K001K6`800005FaaK6e/KFa]K7003Fa/00`00Fa]O6`02000085/KGa]K6elKFa]O
6e/K001K6elKFa]O6`00Ga]K6elKFa]O6e/K001K6elKFa]O6`00Ga]K6elKFa]O6e/K0004Ga/20005
Ga/01@00Ga]O6elKHa/00P0000=O6f<KGa/00UlK00H005lKGa]O6f<K0002Ga/01V<KGa]O6elK001O
6`800005Ha]O6elKGa]S6`03Ga/01@00Ga/00000Ha/00elK051S6elKGa]O6f<K001[>FLIJcUW6F/i
IaU[>@00JcUW6F/iIaT006/IJcUW6@00IaU[>FLIJcUW6F/iIaT006LI001W6F/IIaU[6FLI001W6F/I
IaU[6FLIJaUW6@00IaU[6FLIJaUW6F/I001[6FLIJaUW6@00IaU[6FLI001W6F/IIaU[6FLIJaUW6@00
IaT005[kFa]Jne/LF_]K6e[k1P000d[M00E6g000B]e:gDKL00=:g@05A]`004[M0016g003B]d01DKL
B]d004[MA]`00d[M200000E6gD[MB]e:g@0000QBo003001G75/L00<0000;FaaG6e/LEa`005LKFaaG
75/LEa]K700200000eLKFa`00008Ood00`00Ooeoo@0>Ood005Ioo@05001ooGomOod00002Ood00`00
Ooeoo@05Ood00`00Ooeoo@0GOod04`00FWMFEP00FUIJMeIFFWMJEUYgEUIJMeYFFWMFEP00FUIJMeIF
0080009Rn@05I_URnF;iH_T00003H_T200005fLJHaUW6V<IIaYS6FLJHaUW6P00IaX006LJHaUW6V<I
IaYS6FLJHaUW6V<IIaX01000015S6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS6@00HaUW6V<I0080000T
IaYS6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6V<IIaX005lKGaYO6elJ
Ga]O6UlK001O6elJ0UlK00<005lJGa/00UlK00EO6UlK001O6elJ009O6`0F001K6elLFa]O6e/KGaaK
6`00Fa]O75/KGa/005/LFa]K75/KFaaK6e/LFa/2000065/L001K75/KFaaK6e/LFa]K75/KFaaK6`00
Fa]O75/KFaaK6elLFa]K75/KGaaK6`80000<GaaK6elKFa]O75/KGa]K6elLFa/005/K0P0000YO6e/K
GaaK6elKFa]O75/K001K6`80000:GaaK6elLFa]O75/KGaaK6`00Fa/200000elKFa]O6`02Ga/01E/K
Ga]O6`00GaX00P0000YS6elJHa]O6V<KGaYS6elJ001O6P80000NHa]O6V<KGaYS6elJHa]O6P00GaYS
6elJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6elJ0P0000MS6`00JcUW6F/iIaU[>@02
00009VLIJcUW6F/iIaT006LI001W66/iIaU[>FLHJcUW6@00IaQ[>FLI001W66/iIaT006LHJcUW6F/i
IaQ[>FLI001W6000IaU[>FLHJcT2000066LHJcUW6F/iIaP006LI001W66/iIaU[>FLHJcUW6@00IaU[
>@00FaaFne/LE_]K7080000CE_]K7000B]e6g4[MA]a:gDKLB]d004[MA]a:gDKLB]e6g4[MA]`00P00
00A:gDKLB]e6g0P0000EB]e6g4[MA]`004KLB]e6g4[MA]a:gDKL001>o5;mC_aBoDklD_e>o5;m00<0
000;FaaFne/LE_]K75KkFaaFn`00E_]K700300001E/LE_]K75Kk00002Gom00<007omOod03Gom001F
Ood01@00OoeooGom00000Wom00<007omOod01Gom0P005Wom0P0000AJMeYFFWL0009JMP05FWMJMUYf
FWIJM`03FWH01EYg001JMUYf00002F;i010006;i001S6FLIHaUW6V<IIaUS6FLJHaUW6F<IIaX0009W
6@06IaYS6FLIIaUW6V<I0VLI0`0000QW6FLJ001W6VLIIaYS6FLJ0P0002MS6FLJIaUW6V<IIaYW6@00
HaT006<JIaYS6VLJHaYW6V<JIaYS6VLJHaX006<J001S6VLJHaYW6V<JIaYS6VLJ001W6V<JIaYS6VLJ
000015lK0P001UlK00<005lKGa/00UlK00<005lKGa/015lK00<005/KGa/00UlK0P000UlK00YK6elK
Ga]O6`00FaaK6e/LFa]K7080000<Fa]K75/KFa`005/LFa]K75/KFaaK6e/L0P0000=K6`00Fa/00U/K
00EK75/KFa]K6e/L0080000VFa/005/KGa]K6elKFa]O6e/KGa]K6elKFa/005/KGa]K6elKFa]O6e/K
Ga]K6elKFa/005/KGa]K6elKFa]O6e/KGa]K6elKFa/000]O6`05001O6elKGa]S6`03Ga/01F<KGa]O
6elK00000elK00ES6elKGa]O6f<K00800003Ga/005lK009O6`05Ha]O6elKGa]S6`0200000elK001O
6`02Ga/01F<KGa]O6elK00000elK045S6`00JcUW6F/iIaT006LIJcUW6F/iIaU[>FLI001W6F/iIaU[
>FLIJcUW6@00IaU[>FLIJcUW6@00IaT006LIJaUW6F/IIaU[6FLI001W6F/I001[6FLIJaUW6@00IaU[
6FLIJaUW6F/IIaT006LIJaUW6F/IIaU[6FLI001W6F/I009W6@03001K75[k008000EJn`05001:gD[M
B]e6g003B]d01P00B]e:gD[MA]a:g@P0009:g@05A]a:g@00B]e6g003B]d01DKLB]d004[MA]d00d[M
00A6gD[MB]d000=Bo0@0009Bo00:001G75/LEa]K75LLFaaG6e/LEa`200002E/LEaaK75LKFaaG75/L
Ea/00008Ood00`00Ooeoo@0=Ood004ioo@@000Aoo@05001ooGomOod00002Ood00`00Ooeoo@04Ood0
0`00Ooeoo@0EOod04`00EUIJMeIFFWMFEUYg001JMeYFFWMFEUYgFUIJMeIFFWMJEUYg008000=Rn@05
I_URnF;iH_UVn@03H_T05`00HaUW6V<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<I
IaX00`0001mW6V<IIaYS6FLJ001W6V<IIaX006LJHaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<I
IaYS6FLJHaUW6P0200002F<IIaYS6@00HaUW6V<IIaYS6@0200002FLJHaUW6V<IIaYS6FLJ001O6`02
0002Ga/01ElJGa]O6elKGaX00UlK00H005lJ000005lKGaX3Ga/01ElJGa]O6`00Fa/00P0000aO6e/K
GaaK6elKFa]O75/KGa/005/LFa/2000035/LFa]K75/KFaaK6`00Fa]K75/KFaaK6`80000:FaaK6e/L
Fa/005/KGaaK6e/LFa/200003E/LFa]O75/K001K6elLFa]O6e/KGaaK6elK0080000:Fa/005/KGaaK
6elKFa]O75/KGa/200002U/K001K6elLFa]O75/KGaaK6elL0P0000=K6`00Fa/00elK00AK6elKGa]O
6`80000:Ga/005lJHa]O6V<KGaYS6elJHa/200007UlJ001O6V<KGaYS6elJHa/006<KGaYS6elJ001O
6V<KGaYS6elJHa/006<KGaYS6elJ001O6V<KGaYS6`800010GaYS6elJHa]O6P00IaU[>FLI001W6F/i
IaU[>FLIJcUW6@00IaT006LIJcUW66/iIaT006LHJcUW6F/iIaQ[>FLI001W66/iIaU[>FLHJcUW6@00
IaQ[>FLIJcT006/iIaT006LHJcUW6F/iIaQ[>FLI001W6@00IaU[>FLHJcT200001VLIJcUW6F/iIaU[
>@80000=E_]K75KkFaaFne/LE_]K7000B]e6g4[MA]`0200000A:gDKLB]e6g080000EB]e6g4[MA]a:
gDKL0016g4[MA]a:gDKLB]e6g4[M001:gDKLB]e6g4[M00H0000>C_aBoDklD_e>o5;m001K75KkFaaF
ne/LE_]K7080000;E_/005KkFaaFne/LE_]K75KkFa`00008Ood2000>Ood005Ioo@05001ooGomOod0
0002Ood00`00Ooeoo@04Ood00`00Ooeoo@0DOod02@00FUIJMeYFFWMJEUYgFUH00003FWH01EYgFWIJ
MUYfFWL00eYf00<006;iH_T02F;i014006<I001S6FLJHaUW6F<IIaYS6FLIHaUW6P00IaYS6FLJ0080
0003IaUW6P0000@0000FIaYW6FLJHaUW6VLIIaX006LJ001W6V<IIaYW6FLJHaUW6VLIIaYS6@00IaT2
00007VLJHaYW6V<JIaYS6VLJ001W6V<JIaYS6VLJHaX006<JIaYS6P00HaYW6V<JIaYS6VLJHaYW6V<J
IaX000aO6`03001O6elK00UO6`03001K6elK009O6`05Fa]O6elKGa]K6`03Ga/2000035/KFaaK6e/L
Fa]K75/KFaaK6`00Fa]K70800008Fa]K75/KFaaK6e/LFa/0009K6`8000=K6`0:FaaK6e/KFa/005/K
Ga]K6elKFa/200002UlKFa]O6e/K001K6elKFa]O6e/K0P0000YO6e/KGa]K6`00Fa]O6e/KGa]K6`80
0005Ga]K6elKFa/00006Ga/00`00Ga]O6`02Ga/01@00Ga]O6elKHa/00UlK00<006<KGa/00UlK00H0
05lKGa]O6f<K0002Ga/01F<KGa]O6`00Ha/00elK0P000UlK00IS6elKGa]O6`00Ga/200001F<KGa]O
6elKHa/00elK03X006LI001W6F/iIaU[>FLIJcUW6@00IaU[>FLI001W6F/iIaT006LIJcUW6F/iIaU[
>FLI001W6@00IaU[6FLIJaUW6@00IaU[6FLIJaUW6@00IaT006LIJaUW6F/IIaU[6FLI001W6F/I001[
6FLIJaT0009W6@08JaUW6FLIIaU[6@00IaT000UJn`@00005B]a:gD[LB]d00003B]d014[LB]e:gD[M
0P000T[M00I6g4[MB]e:gDKL0002B]d00dKLB]e:g@0800001D[MB]a:gD[M000025;l00D005/LEaaK
75LK0080000:FaaG6e/L001K75LKFaaG75/LEa/200000e/L001oo@03Ood300000gom001oo@0=Ood0
05Eoo@8000Aoo@8000Moo@03001ooGom01=oo@0I001FEUYgEUIJMeIFFWMFEUYg001JMeIFFWMJEUYg
EUIJMeYFFWMFEP00H_T006;iI_T00f;i01MVnF;iH_URn@00HaUW6V<I001S6FLJHaUW6V<IIaYS6FLJ
001W6V<IIaYS6FLJ00<0000nIaYS6@00HaUW6V<IIaYS6FLJHaUW6V<IIaX006LJHaUW6V<IIaYS6FLJ
HaUW6V<I001S6FLJHaUW6P00IaYS6FLJHaUW6P00IaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJ
HaUW6V<IIaYS6FLJ001W6P00Ga]O6P=O6`04GaYO6elKGa/200000elK001O6P03Ga/015lJGa]O6elK
0P0000]O6`00Fa]O75/KGa]K6elLFa]O6e/K0080000<Ga/005/LFa]K75/KFaaK6e/LFa]K75/K0P00
00YK75/KFaaK6e/LFa]K75/KFaaK6`80000=GaaK6e/LFa]O75/KFaaK6elLFa/005/KGa`00P0000YK
6elLFa]O6e/KGaaK6`00Fa]O7080000:Fa]O75/KGaaK6elLFa/005/KGa`200002E/KGaaK6elLFa]O
7000Ga]K6`02Ga/20003Ga/01e/KGa/006<KGaYS6elJ00800008Ha]O6V<KGaYS6elJ001O6P800009
Ha]O6V<KGaYS6elJHa/006<K0080001OGaYS6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<K
GaYS6elJ001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcUW6@00IaT006LHJcUW6F/iIaQ[>FLI001W66/i
001[>FLHJcUW6@00IaQ[>FLIJcUW66/iIaT006LHJcUW6F/iIaQ[>FLI001W6F/iIaU[>@00JcT006/i
IaU[>FLIJcUW6F/i001[>FLI001Fne/LE_]K75KkFaaFn`0200004E/L001:gDKLB]e6g4[MA]a:g@00
B]e6g4[MA]a:gDKLB]d00P0000A6g4[MA]a:g@P0000HA]a:gDKLB]d004[MA]a:gDKLB]e6g4[M001B
oDklD_e>o5;mC_aBoDkl001Fne/L0P0000YFne/LE_]K75KkFa`005/LE_]K70800003E_]K75Kk00D0
00Aoo@03001ooGom00aoo@00I7om00<007omOod04Wom00d005YFFWMJEUYgFUIJMeYFFWMJEUYg001J
M`03FWH00eYgFWIJMP020003H_T00`00H_URn@05H_T03000HaUS6F<IIaYS6@00HaUW6V<IIaUS6@80
0003IaYS6FLJ00<0000QIaYS6@00IaT006<IIaYW6FLJHaUW6VLIIaYS6FLJ001W6P00IaYW6FLJHaUW
6VLIIaYS6@00IaUW6V<IIaYW6FLJ0080000GHaX00000IaYS6VLJHaYW6V<JIaYS6VLJHaX006<JIaYS
6VLJHaYW6V<JIaYS6P02000016LJHaYW6P001elK00<005lKGa/00UlK00<005lKGa/00elK0P0015lK
0P000elK00EK6elK000005/K00=O6`08001K75/KFaaK6e/LFa]K7080000:Fa/005/KFaaK6e/LFa]K
75/KFa`200000e/K001K6`02Fa/01E/LFa]K6e/KFa`00e/K0P0000YO6e/KGa]K6elKFa]O6e/KGa]K
6`80000:Ga]K6elKFa]O6e/KGa]K6elKFa/200002elKFa]O6e/KGa]K6elKFa]O6`00Ga/00P0025lK
00H006<K000005lKHa/3Ga/01F<KGa]O6elK00000elK00ES6elKGa]O6f<K009O6`03001S6elK009O
6`05Ha]O6elKGa]S6`0200000elK001O6`02Ga/01F<KGa]O6elKHa/00P0000IO6`00IaU[>FLIJcT2
0000;fLIJcUW6FLiIaU[>FLI001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/IIaT006LIJaUW6F/I
IaU[6FLI001W6@00IaU[6FLIJaUW6@00IaU[6FLIJaUW6F/I00000VLI00I[6FLIIaUW6F/I0002IaT0
0f/IIaT00004F_/20003F_/02P00B]a:gD[LB]e:g4[MB]a:g@000d[M00=:g00000001P000d[M00E:
g000B]e:gD[L00=:g@05B]`004[MB]e:g003B]d00d[LB]d00007D_`300002U/LEaaK75LKFaaG75/L
Ea/005LL0P0000MK75LLFaaG6e/LEa`00007Ood00`00Ooeoo@0<Ood006Aoo@80019oo@80000CFWMF
EUYgEUIJMeIFFWMFEUYgEUH005YFFWMFEUYgFUIJM`00H_X00f;i00ERnP00H_URnFKi009Rn@80000>
HaUW6V<IIaYS6FLJHaT006<IIaYS6@00HaUW6P<0000KIaYS6FLJHaUW6V<I001S6FLJHaUW6V<IIaYS
6FLJHaUW6P00IaYS6FLJ001W6V<IIaYS6FLJ0080000YHaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW
6V<IIaYS6FLJHaUW6V<I001S6@00HaUW6V<IIaYS6FLJHaT006<IIaYS6FLJHaUW6P00Ga]O6P02Ga/2
0003Ga/01UlJGa]O6`00GaYO6`800005GaYO6elKGa]O6P03Ga/00`00GaaK6`02000035lLFa]O6e/K
GaaK6`00Fa]K75/KFaaK6`800004FaaK6e/LFa/2000015/LFa]K75/K0P0000eK75/KFaaK6`00Fa]O
75/KFaaK6elLFa]K700200002U/K001K6elLFa]O6e/KGaaK6elK0P0000YK6`00Fa]O75/KGaaK6elL
Fa]O7080000?Fa/005/KGaaK6elLFa]O75/KGaaK6elL001O6e/K00=O6`0@Fa]O6elKGa]K6elK001S
6elJHa]O6V<KGaYS6elJHa/200002ElJ001O6V<KGaYS6elJHa]O6P020000GV<K001S6elJHa]O6V<K
GaYS6`00Ha]O6V<KGaX005lJHa]O6V<KGaYS6`00Ha]O6V<K001[>FLIJcT006/iIaU[>FLIJcUW6F/i
IaT006LI001W6F/iIaQ[>FLI001W66/iIaU[>FLH001W6@00IaQ[>FLIJcUW66/iIaT006LIJcUW6@00
IaQ[>FLI001W6F/iIaU[>FLIJcT006/i001[>FLIJcUW6F/i001[>FLIJcUW6F/i001K75Kk0P0000aK
75KkFaaFne/LE_/004KLB]e6g4[MA]`7000014KLB]e6g4[M0P0001]6g4[MA]a:gDKLB]d004[MA]a:
gDKLB]e6g4[MA]`004KLB]e6g4[MA]a:gDKL001>o5;mC_`0100000]BoE;l001Fne/LE_]K75KkFaaF
ne/L00800009E_]K75KkFaaFne/LE_]K700000Qoo@03001ooGom00]oo@00I7om00<007omOod047om
014005IFFWL005YgFUIJMeYFFWMJEUYgFUIJMeYF001JMUYg009JMP03001RnF;i00ERn@06001RnF;i
H_T006LJ0f<I00QW6V<IHaUS6FLJHaT006<I100003=W6V<IIaYS6FLJHaUW6V<I001S6@00IaUW6V<I
IaYW6FLJHaUW6P00IaYS6FLJIaUW6P00IaYW6FLJ001W6VLIIaYS6FLJIaUW6V<IIaYW6@00HaT006<J
IaYS6VLJHaYW6V<JIaX00P0000=S6VLJHaX00P0000mW6V<JIaYS6P00HaYW6V<JIaYS6VLJHaYW6P00
Ga/00P002ElK0P002elK0P000UlK00EK6elKGa]O6e/K009O6`03001K6e/L0080000:Fa]K75/KFaaK
6e/LFa]K7000Fa`2000025/KFaaK6e/LFa]K75/K0003Fa/01E/LFa/00000Fa`00e/K020005/KGa]K
6elKFa]O6`00Ga]K6elKFa/005/KGa]K6elKFa]O6`00Ga]K6elKFa/005/KGa]K6elKFa]O6e/K0P00
00=O6`00Ga/01elK0P0000=O6`00Ha/00elK00ES6elKGa/006<K00=O6`09001O6elKGa]S6elK001O
6f<K009O6`03001S6elK009O6`80009O6`05Ha]O6elK001S6`03Ga/20002Ga/0>V<KGa]O6`00JcT0
06LiIaU[>FLIIcUW6F/iIaT006LIJcT006/iIaU[>FLI001W6F/iIaU[>FLIJcUW6@00IaU[6FLIJaUW
6F/IIaT006LIJaUW6F/IIaT006LI001W6F/IIaU[6FLIJaT006/IIaU[6@000VLI00E[6@00IaUW6F/I
00=W6@03JaT0000000UJn`D00005B]a:gD[LB]d00003B]d01D[LB]e:gD[M00000d[M00E:g4[MB]e:
g@0000=:g@05B]a:gD[MB]d00003B]d00d[LB]d000050006D_`01`00FaaG6e/LEaaK75LK0080000:
FaaG6`00EaaK75LKFaaG75/LEa/20007Ood00`00Ooeoo@0;Ood006=oo@03001ooGom00moo@80000A
EUIJMeIF001FEUYgEUIJMeIFFWMFEUYgEUIJM`00FWMJEP0200001F;jH_URnF;iH_X00f;i00mRnP00
H_T006LJHaUW6V<IIaYS6FLJHaUW6V<IIaX00`0000UW6V<IIaYS6FLJHaUW6V<IIaX00P0000US6FLJ
HaT006<IIaYS6FLJHaT00P0002UW6V<IIaYS6FLJHaUW6P00IaX006LJHaUW6V<IIaYS6FLJHaUW6V<I
001S6FLJHaT006<IIaYS6FLJHaUW6P00IaYS6FLJHaUW6V<IIaX006LJ0080000=HaUW6V<IIaYS6FLJ
HaUW6V<IIaX005lKGaX00elK00AO6UlKGa]O6`800003Ga/005lJ00=O6`05GaYO6elKGa]O6P020000
35lK001O75/KGa]K6elLFa]O6e/KGaaK6`80000IFaaK6e/LFa]K75/KFaaK6e/LFa]K7000FaaK6e/L
Fa]K75/KFaaK6e/LFa/005/KGa`00P0000]K6elLFa]K75/KGa`005lKFa]O75/K0080000:GaaK6elL
Fa]O7000GaaK6elLFa/200002elLFa]O75/KGa`005lLFa]O75/KGa`00P0000MK6elLFa]O7000Ga]K
6`03Ga/20002Ga/01e/KGa/006<KGaYS6elJ0080000CHa]O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O
6V<KGaYS6`00Ha/00P0000YO6V<KGaYS6elJHa]O6V<K001S6`80001BGaYS6elJHa]O6V<KGaYS6`00
JcUW6F/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/iIaT006LHJcUW6F/iIaQ[>FLI001W6@00IaU[>FLH
JcUW6@00IaU[>FLIJcUW6F/iIaT006LIJcUW6F/iIaU[>@00JcUW6F/iIaU[>@00JcT006/iIaU[>FLI
JcUW6F/i001[>@00FaaFne/LE_]K75KkFa`200004EKk0016g4[MA]a:gDKLB]e6g000A]a:gDKLB]e6
g4[MA]`00P0000a:gDKLB]e6g4[MA]`004KLB]e6g4[MA]`8000044[MA]a:gDKL001Bo5;mC_aBoE;l
D_e>o5;m001K75Kk0`0000YFne/LE_]K7000FaaFne/LE_]K70800003E_]K700000Ioo@03001ooGom
00]oo@00Hgom00<007omOod03Wom018005YgEUIJMeIGFWMFEP00FUIJMeYFFWMJEUYgFUIJMeYFFWL2
000<H_T00`00IaYS6@02HaT01FLJHaUS6F<IIaX0100000eS6@00HaUW6V<IIaYS6FLJHaUW6P00IaYS
6@03IaX07F<I001W6FLJHaT006LIIaYS6FLJIaUW6V<IIaYW6FLJ001W6VLIIaYS6FLJIaUW6V<IIaYW
6@00HaT00fLJ01mS6@00HaYW6V<JIaX006LJHaYW6V<JIaYS6VLJHaYW6P00IaYS6VLJHaYW6V<JIaYS
6VLJHaYW6P00HaX00007Ga/00`00Ga]O6`02Ga/00`00Ga]O6`05Ga/00`00Ga]O6`02Ga/01@00Ga]O
6elKFa/00elK0P0000]O6`00Fa]K75/KFaaK6e/LFa]K75/K0080000<Fa`005/LFa]K75/KFaaK6e/L
Fa]K75/K0P000U/K00EK75/KFa]K6e/L009K6`0>001O6`00001K6elKFa]O6e/KGa]K6elK001O6`80
000;Fa]O6e/KGa]K6elKFa]O6`00Ga]K6`02000025lKFa]O6e/KGa]K6elK0002Ga/20007Ga/01P00
Ha/00000Ga]S6`=O6`05Ha]O6elK001S6`0200000elKHa]O6`02Ga/01F<KGa]O6`00Ha/00elK00ES
6elKGa]O6f<K009O6`03001S6elK009O6`04Ha]O6elKGa/20000>5lK001[>FLIIcUW6F/iIaT006LI
JcUW6FLiIaT006LI001W6F/iIaU[>FLIJcUW6@00IaU[>FLI001W6F/IIaT006LIJaUW6F/IIaU[6FLI
001W6@00IaU[6FLIJaT006/IIaU[6FLIJaUW6F/I0002IaT01V/IIaUW6FLIJaT0009W6@03JaT005[k
00=Jn`8000=Jn`0;001:gD[LB]e:g4[MB]a:gD[L001:g003B]d00d[LB]e:g@020003B]d800001D[L
B]e:gD[M00000d[M00E:g4[MB]e:g@0000QBo0<0000;Ea]K75LLFaaG6e/LEaaK7000FaaG70020000
1U/LEaaK75LKFa`000Eoo@03001ooGom00]oo@00Hgom00<007omOod03Gom01H005YgEUIJMeIFFWMF
EUYg001JMeIFFWMFEUYgEUIJMeIFFWMFEP00H_URnP=Rn@05H_YRnF;iH_URnP02H_T02@00IaX006LJ
HaUW6V<IIaYS6@0200009FLJHaT006<IIaYS6@00HaUW6V<IIaYS6FLJ001W6V<IIaYS6FLJHaUW6V<I
001S6@00HaUW6V<IIaYS6FLJHaUW6V<IIaX006LJ00800006HaUW6V<IIaYS6FLJ0P0000US6FLJHaUW
6V<IIaYS6@00HaT00P0001AW6V<IIaYS6FLJHaUW6V<IIaX006LJ001W6V<IIaYS6FLJHaUW6V<I0P00
00=W6V<IIaX00P0000EO6UlKGa]O6`0000=O6`05GaYO6elK001O6P03Ga/20002Ga/02ElJGa]O6elK
001O75/KGa]K6`02000015lKFa]O75/K0P0000EK75/KFaaK6e/L0080000<Fa]K75/KFa`005/LFa]K
75/KFaaK6e/L0P0002AK6`00Fa]O75/KFaaK6elLFa]K75/KGa`005lLFa]O75/KGaaK6elLFa]O75/K
Ga`005lLFa]O75/KGaaK6elLFa]O75/KGa`200002U/KGaaK6elLFa]O75/KGaaK6elL0P0000EK6elK
Ga]O6e/K00=O6`0GFa]O6`00Ha]O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa]O6P02
00002V<K001S6elJHa]O6V<KGaYS6elJ0P00055S6`00Ha]O6V<KGaYS6elJ001O6V<KGaYS6`00JcUW
6F/iIaT006LIJcUW6F/iIaU[>FLI001W66/iIaU[>FLHJcUW6@00IaU[>FLIJcUW6@00IaT006LIJcUW
6F/iIaU[>FLI001W6F/i001[>FLIJcT006/iIaU[>FLIJcUW6F/i001[>@00JcUW6F/iIaU[>@00JcUW
6F/iIaU[>@00Fa`00P0001AFne/LE_]K75KkFa`004[MA]a:gDKLB]e6g4[M001:gDKLB]e6g4[M1`00
01U:gDKLB]e6g000A]a:gDKLB]e6g4[MA]`004KLB]e6g4[MA]a:gDKLB]d005;mD_aBo@0400002dkl
D_d005/LE_]K75KkFaaFne/LE_/00`0000QFne/LE_]K75KkFaaFn`001Gom00<007omOod02gom001S
Ood3000<Ood05P00FWMFEUYgEUMJMeIFFWMFE`00FUIJMeYFFWMJEUYgFUIJMeYF001Rn@002V;i00L0
06LJHaUS6P00IaYS6@030003HaT02P00HaUW6V<JIaYS6@00HaUW6V<I0P0000=W6V<IIaX00VLJ01eS
6FLJIaYW6V<I001W6FLJHaUW6VLIIaYS6FLJIaUW6P00IaYW6FLJHaT006LIIaYS6FLJ001W6V<I00=W
6P0LHaUW6VLJIaYS6@00HaYW6V<JIaYS6VLJHaYW6V<JIaX006LJHaYW6P00IaYS6VLJHaYW6V<J0003
HaX01VLJHaYS6V<J001O6`8000QO6`04001O6`000009Ga/01@00Ga/00000Fa/00elK00MK6elKGa]O
6`00FaaK6`02000035/LFa]K75/KFaaK6`00Fa]K75/KFaaK6`800005FaaK6e/LFa/00003Fa/015/L
Fa]K6e/K0P0000YK6`00Ga]K6elKFa]O6e/KGa]K6`80000:Ga/005lKFa]O6e/KGa]K6elKFa/20000
2UlK001O6e/KGa]K6elKFa]O6e/K0P0000=O6`00Ga/01elK0P0000=O6`00Ha/00elK00AS6elKGa]O
6`800003Ga/006<K00=O6`05Ha]O6`00Ga]S6`02Ga/00`00Ha]O6`02Ga/01F<KGa/005lKHa/00UlK
00<006<KGa/00UlK03X005lKGa]O6f<KGa/006LIJcUW6@00IaU[>FLIIcUW6F/iIaT006LI001W6F/i
IaU[>FLI001W6F/iIaU[>FLIJcUW6@00IaU[6FLIJaUW6F/IIaT006LIJaUW6F/I001[6@00JaUW6F/I
IaU[6FLIJaT0009W6@06001W6FLIIaU[6@000VLI00I[6FLIIaUW6F/I0008F_/01P00B]a:gD[LB]e:
g0P00006B]e:g4[MB]d004[L0d[M00E:g4[MB]d004[L00=:g@05B]a:gD[M001:g003B]d00d[L0000
00040006D_`01`00EaaK75LKFaaG75/L0080000:EaaK7000FaaG75/LEa]K75LLFa`20004Ood00`00
Ooeoo@0;Ood006=oo@03001ooGom00]oo@0J001JMeIFFWMFEUYgEUIJMeIFFWMFEP00EUIJMeIFFWMF
EUYgEUH006;iH_YRn@00H_URnP=Rn@08H_YRnF;i001W6V<IIaYS6@<00004HaUW6V<IIaX200009f<I
IaYS6FLJHaUW6V<I001S6@00HaUW6V<IIaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJHaUW6V<I
IaX006LJHaUW6V<IIaYS6@020000;VLJ001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJ
HaUW6V<IIaX006LJHaUW6V<IIaX006LJHaUW6V<I001S6FLJHaUW6V<IIaYS6FLJHaT005lJ0elK00EO
6UlKGa]O6elJ009O6`03001O6UlK009O6`05GaYO6elKGa]O6P03Ga/03000GaaK6elKFa]O75/KGa]K
6elLFa]O6`80000<Fa]K75/KFaaK6e/LFa]K75/K001K6e/L0P0000aK6e/LFa]K75/KFa`005/LFa]O
75/KFa`2000015/KFaaK6elL0P0000AK6elLFa]O70800004Fa]O75/KGa`2000015/KGaaK6elL0P00
01=K6elLFa]O7000GaaK6elLFa]O75/K001K6elLFa]O7000Ga]K6`03Ga/08U/K001O6elKFa]O6`00
Ha]O6V<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<KGaX005lJHa]O6V<K0P0000QO
6V<KGaYS6elJHa/006<K0P0002QO6V<KGaYS6elJHa]O6P00IaT006LIJcUW6F/iIaU[>FLI001W6F/j
IaT006LHJcUW6@00IaU[>FLIJcUW6F/iIaT006LI001W6F/iIaU[>@80000XIaU[>FLIJcUW6F/i001[
>FLIJcUW6F/iIaU[>@00JcUW6F/iIaT006LIJcT006/iIaU[>FLIJcUW6F/i001[>@00FaaFne/LE_]K
75KkFa`6000034KLB]e6g4[M001:gDKLB]e6g4[MA]a:g@80000<A]a:gDKLB]e6g4[MA]`004KLB]e6
g4[M20000116g4[MA]a:g@00D_eBo5;mC_aBoE;lD_e>o000E_]K70<0000:FaaFne/LE_/005KkFaaF
ne/LE_/200000e/LE_/00003Ood00`00Ooeoo@0;Ood006=oo@03001ooGom00Uoo@<0000DEUIJMeIG
FWMFEUYgEUMJMeIFFWL005YgFUIJMeYFFWMJEP00H_URnP=Rn@03001RnF;i00=Rn@800003IaYS6@00
00800004HaUS6P00IaX2HaT03000IaYS6FLJHaYW6V<IIaYS6VLJHaT0009W6P05HaUW6VLJIaYS6@03
IaX02f<I001W6VLJHaT006LIIaYS6FLJIaT00P0000aW6VLIIaYS6FLJIaUW6V<IIaX006LJHaT3IaX0
1V<IIaYW6VLJHaT0009W6P07HaT006<JIaYS6VLJHaX00P0000UW6V<JIaYS6VLJHaYW6P00IaX00P00
0f<J00UW6V<JHaYS6VLJHaX006<J000025lK0P0000=O6`00Ga/025lK0P0000=O6`00Ga/00UlK00EK
6elKGa]O6e/K0080000<Ga/005/LFa]K75/KFaaK6e/LFa]K75/K0P0000aK75/KFaaK6e/LFa]K75/K
Fa`005/LFa/200001E/LFa]K6e/KFa`00e/K00h005/K000005lKFa]O6e/KGa]K6elKFa/005/K0P00
00]O6e/KGa]K6elKFa/005/KGa]K6elK00800006Fa]O6e/KGa]K6`0015lK0P001ElK00<005lKHa/0
0UlK0P000elK00ES6elKGa/006<K00800003Ga]S6elK009O6`04Ha]O6`00Ga/20002Ga/01F<KGa]O
6elKHa/00UlK00<006<KGa/00UlK03IS6elKGa]O6f<KGa/006LIJcUW6FLiIaU[>FLI001W6F/iIaUW
>FLI001W6@00IaU[>FLIJcUW6F/iIaT006LIJcT006/IIaU[6@00JaUW6F/IIaU[6FLIJaT006/I001[
6FLIJaUW6F/I0002IaT01V/IIaUW6@00JaT0009W6@06JaUW6FLIIaU[6@000VLI00<005[kF_/00e[k
0P000U[k00T004[LB]e:g4[MB]a:gD[L00000T[M00I:g4[MB]e:gD[LB]d2000014[LB]e:gD[M1`00
00I:gD[LB]e:g@00B]`3B]d014[LB]e:g@0025;l0`0000]K75LKFaaG75/LEa]K75LL001G6e/L0080
0006Ea]K75LLFaaG6`000Wom00<007omOod02gom001SOod00`00Ooeoo@07Ood200004UIFEUMFE`00
EUIJMeIFFWMFEUYgEUIJMeIFFWL005YgEUIJM`80000=H_URnV;iH_YRnF;jH_T006;iH_YRn@00HaT0
0`0006ES6FLJHaUW6V<IIaX006LJ001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJHaUW
6V<IIaYS6@00HaUW6V<IIaYS6@00HaUW6V<I001S6FLJHaUW6V<IIaYS6FLJHaUW6P00IaX006LJHaUW
6V<IIaYS6FLJHaT006<IIaYS6FLJHaT006<IIaYS6@00HaUW6V<IIaYS6FLJHaUW6V<IIaX006LJHaUW
6V<IIaYS6FLJHaUW6V<I001S6FLJHaX005lJ00=O6`05GaYO6`00Ga]O6P02Ga/00`00GaYO6`02Ga/0
1ElJGa]O6`00GaX00elK01@005lLFa]O6e/KGaaK6`00Fa]O75/KGa/005/LFa]K75/KFaaK6e/L0P00
00aK6`00Fa]K75/KFaaK6e/LFa]K75/KFa`200008e/KGaaK6e/LFa]O75/KFaaK6elLFa/005/KGaaK
6elLFa]O75/KGaaK6elLFa/005/KGaaK6elLFa]O75/KGaaK6`00Fa/00P0000YO75/KGaaK6elLFa]O
75/K001O6`8000=O6`07Fa]O6elKGa]K6`00GaX00P0001iS6elJHa]O6V<KGaYS6elJHa/006<KGaYS
6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaX200002F<K001S6elJHa]O6V<KGaYS6`02
0000AUlJ001W6F/iIaU[>FLI001W6F/jIaU[>FLIJcYW6@00IaU[>FLIJcUW6F/iIaT006LIJcUW6F/i
001[>@00JcUW6F/iIaU[>FLIJcT006/iIaT006LIJcUW6F/i001[>FLIJcUW6F/iIaU[>@00JcUW6F/i
IaU[>FLIJcT006/iIaU[>FLI001Fne/L0P0001=Fne/LF_]K7000B]e6g4[MA]a:gDKLB]e6g000A]a:
gDKLB]e6g008000064[MA]a:gD[L0016g4[MB]a:gDKLB]d004[MA]a:gDKLB]e6g4[MA]`004klD_eB
o0@0000;D_e>o000E_]K75KkFaaFne/LE_]K7003000025/LE_]K75KkFaaFne/L0003Ood00`00Ooeo
o@0:Ood0069oo@<000Moo@03001FEeIG00=FE`0?001JMeIFFWMFEeYgEUIJMeIGFWMFEP00FUIJM`00
009Rn@05H_YRnF;iH_URnP03H_T00`00H_T0000200006F<IHaYS6FLJHaUS6V<IIaYS6F<J001W6V<I
IaYS6VLJHaUW6V<JIaYS6@00HaYW6V<J00800003IaYS6FLJ009W6P80009W6P0IHaUW6VLJIaYS6@00
IaT006<IIaYW6FLJHaUW6VLIIaYS6FLJ001W6V<IIaX006LJHaT00fLJ0P000VLJ01ES6FLJIaYW6V<I
001S6P00HaYW6V<JIaYS6VLJHaYW6V<JIaX006LJ00000V<J00UW6V<JHaYS6VLJHaX006<JIaX00V<J
00<005lKGa/00UlK0P001UlK00<005lKGa/00UlK0P001ElK00<005/KGa/00UlK0P000UlK00UK6elK
Ga]O6`00FaaK6e/LFa/00P0000aK75/KFaaK6`00Fa]K75/KFaaK6e/LFa/200000e/L001K7003Fa/0
1E/LFa]K6e/KFa`00P0000YK6`00Fa]O6e/KGa]K6elKFa]O6`80000HFa/005/KGa]K6elKFa]O6e/K
Ga]K6`00Fa]O6e/KGa]K6elKFa]O6e/KGa]K6`002elK00<005lKHa/00elK00AS6elKGa]O6`800003
Ga/006<K00=O6`03Ha]O6elK00800004Ga/005lKHa/3Ga/02F<KGa/005lKHa]O6`00Ga]S6`03Ga/0
<V<K001O6elKHa]O6`00IaU[>FLI001W6F/iIaUW>FLIJcUW6@00IaT006LIJcUW6F/iIaT006LIJcUW
6F/iIaU[>@00JaUW6F/IIaU[6FLIJaT006/IIaU[6FLI001W6F/I0002IaT02F/IIaUW6FLIJaT006LI
001[6@03IaT20002IaT016/IIaUW6FLI0P001e[k00H004[MB]a:gD[LB]d80002B]d01D[LB]d004[M
B]`00d[M00E:g4[M001:gD[L00=:g@05B]a:g@00B]e:g003B]d60006D_`01`00FaaG75/LEa]K75LL
0080000:Fa`005/LEa]K75LLFaaG6e/LEa`20002Ood00`00Ooeoo@0:Ood0069oo@03001ooGom00Eo
o@800003EUMFEUIG009FE`0=EUIFE`00FWMFEUYgEUIJMeIFFWMFEUYgEUH00P0000YRnV;iH_YRnF;j
H_URnV;iH_YRn@<0000MHaUW6V<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<IIaYS
6@00HaUW6V<IIaYS6@020000@fLJHaUW6P00IaYS6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6FLJHaUW
6V<IIaYS6FLJ001W6V<IIaYS6FLJ001W6V<IIaX006LJHaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW
6V<IIaYS6FLJHaUW6P00IaYS6FLJ001W6V<IIaYS6FLJ00800008HaUW6V<JIaYS6FLJ001O6`80009O
6`05GaYO6elKGa]O6P02Ga/01P00GaX00000Ga]O6P=O6`05GaYO6elK001K6`0200002elKFa]O75/K
Ga]K6elLFa]O6`00Fa`00P0000aK6e/LFa]K75/KFaaK6`00Fa]K75/KFa`2000015/KFaaK6e/L0P00
00EK6elLFa]K75/K0080000GFaaK6elLFa/005/KGaaK6elLFa]O7000GaaK6elLFa/005/KGaaK6elL
Fa]O700200002U/K001K6elLFa]O75/KGaaK6elL0P0000EK6`00Ga]O6e/K00=O6`0RFa]O6`00001K
6`00GaYS6elJHa]O6V<KGaX005lJHa]O6V<K001S6elJHa]O6V<K001S6elJHa]O6P00GaYS6elJHa/2
00002ElJHa]O6V<KGaX005lJHa]O6P0200009f<KGaYS6elJHa]O6P00IaT006LIJcYW6F/iIaU[>VLI
001W6F/j001[>FLIJcUW6@00IaU[>FLIJcUW6F/i001[>@00JcUW6F/iIaU[>@020000:6LIJcUW6F/i
001[>@00JcUW6F/iIaU[>FLIJcT006/iIaT006LIJcUW6@00IaU[>FLIJcUW6F/iIaT006LI001Fne/L
F_]K75KkFaaJne/L1@0000a:gD[LB]e6g000B]a:gDKLB]e:g4[MA]`2000034[MA]a:gD[LB]e6g4[M
001:gDKLB]e:g0P0000@B]e6g4[MB]`004klD_eBo5;mC_aBoE;lD_d005/LE_/300002UKkFaaFne/L
001K75KkFaaFne/L0P0000EFne/L001oo@0000aoo@00HWom00<007omOod00gom0P002EIG00`005IG
FWMFEUYgEUMJMeIFFWMFEeYg0002H_T01V;jH_URnF;iH_YRn@<0000=H_T006<J001S6F<JHaUW6V<I
HaYS6FLJHaT00P0000UW6V<JHaX006LJHaUW6V<JIaX00P0000]S6VLJHaYW6V<JIaYS6VLJ001W6P00
00=W6P05HaUW6VLJIaYS6@02IaX02P00HaX00000IaYS6FLJIaUW6V<I0P0000=W6V<IIaX00VLJ00ES
6FLJ001W6P0000=W6P05HaUW6VLJIaYS6@02IaX03@00HaT006<JIaYS6VLJHaYW6V<JIaX006LJ00=S
6P06IaX006<JHaYW6P000V<J00EW6V<JHaYS6VLJ009S6P03001O6elK00YO6`03001O6elK00UO6`03
001K6elK009O6`05Fa]O6elKGa]K6`03Ga/03@00FaaK6e/LFa]K75/KFaaK6e/LFa/005/K00800009
FaaK6e/LFa]K75/KFaaK6`00009K6`8000=K6`08FaaK6e/K001O6e/KGa]K6`80000:Ga]K6elKFa]O
6`00Ga]K6elKFa/2000015lKFa]O6e/K0P0000AO6e/KGa]K6`800005Ga]K6elKFa/00005Ga/20004
Ga/00`00Ga]S6`02Ga/20003Ga/01F<KGa/005lKHa/00UlK00<006<KGa/00UlK00AS6elK001O6`80
009O6`07Ha]O6elKGa]S6`00Ga/00P000elK02iS6elKGa]O6f<KGa/006LIJcUW6FLiIaU[>FLI001W
6F/iIaUW>@00JcUW6@00IaU[>FLIJcUW6F/i001[>FLIJcT006/IIaU[6FLI001W6F/IIaU[6FLIJaT0
009W6@06JaUW6FLIIaU[6@000VLI00E[6FLI001W6@0000=W6@05JaUW6FLIIaT00002IaT00`00F_]J
n`04F_/200002U[k001:gD[LB]e:g4[MB]a:g@000d[M00E:g4[MB]e:gD[L00800004B]e:g4[MB]d7
0002B]d01D[LB]d004[MB]`00d[M00=:g4[M000025;l0`0000YG75/LEa]K75LLFaaG6`00EaaK70<0
0005FaaG6e/LEaaK7002000<Ood0069oo@04001ooGomOod20000159H001FEeIF0eIG01IFEUIGEUMF
EeIF001FEUYgEUIJMeIFFWMFEUYg001RnP00H_YRnF;jH_URnP800007H_URnV;i001S6FLJHaT00P00
059W6V<IIaYS6FLJHaT006<IIaYS6FLJHaUW6P00IaYS6FLJ001W6V<IIaYS6FLJHaUW6V<IIaYS6FLJ
001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaUW6V<IIaX006LJHaUW6V<I001S6FLJHaUW6V<IIaYS6FLJ
HaUW6P00IaYS6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6@00HaUW6V<IIaYS6@80000HIaYS6FLJHaUW
6V<IIaX006LJ001W6V<IIaYS6VLJHaUW6V<JIaX006LJ001O6elJ0elK00AO6UlKGa]O6`800003Ga/0
05lJ00=O6`04GaYO6elKGa/200002elK001K6elLFa]O6e/KGaaK6elKFa/00P0000]O6`00FaaK6e/L
Fa]K75/KFaaK6e/L0080000;Fa]K75/KFaaK6e/LFa]K75/KFaaK6`0200002elLFa]K75/KGaaK6e/L
Fa]O7000Ga`00P0000YK6elLFa]O75/KGaaK6elL001O7080000:Fa]O75/KGaaK6elLFa]O7000Ga`2
000025/KGaaK6elLFa]O75/K0002Ga/20002Ga/01e/KGa]O6elKFa/005lJ0080000:Ha]O6V<KGaYS
6elJHa]O6P00GaX200007F<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa]O6V<K001S6elJ
Ha]O6V<KGaYS6elJHa/00P0004IO6P00IaU[>FLIJcYW6@00IaU[>VLIJcUW6@00IaT006LIJcUW6F/i
IaU[>@00JcUW6F/iIaT006LIJcUW6@00IaU[>FLIJcUW6F/i001[>@00JcUW6F/iIaU[>@00JcUW6F/i
IaU[>FLI001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcT005/LE_]K7080000BE_]K75[kFa`004[MB]a:
gDKLB]e:g4[M001:gD[LB]e6g4[M200001Y:g4[MA]a:g@00B]e6g4[MB]a:gDKL001:g4[MA]a:gD[L
B]e6g4[M001BoDklD_eBo5;m0P0000]Bo5;m001K75KkFaaFne/LE_]K75Kk00800008FaaFne/LE_]K
75KkFaaFn`8000aoo@00HWom00@007om000000ABE`03001FEeIG00MFE`07001JMeIGFWMFEUYgEUL0
0P000f;j00<006;i00000P000V;i00=RnV;i00001F<J0P0000MS6V<IIaYS6@00HaYW6P03HaX05VLJ
HaYS6P00IaX006LJHaYW6V<JIaYS6VLJHaYW6V<JIaX006LJ001W6V<I0fLJ00ES6FLJIaX006<J00=W
6P06HaYW6P00001S6@000VLJ00ES6FLJIaYW6V<I00=W6P05001W6P00IaYS6@03IaX01F<IIaYW6P00
HaT00fLJ00QS6@00HaYW6V<J001S6VLJ0f<J00IW6V<JHaYS6VLJ0002HaX01FLJHaYS6V<JIaX00V<J
00D006LJHaYS6P0000MO6`03001O6elK009O6`8000AO6`8000AO6`8000=O6`05Fa]O6`00001K6`03
Ga/01`00FaaK6e/LFa]K75/K0080000;FaaK6`00Fa]K75/KFaaK6e/LFa]K700200000e/K001K6`02
Fa/01E/LFa]K6e/KFa`00U/K02<005lKFa]O6e/KGa]K6elKFa]O6e/KGa/005lKFa]O6e/KGa]K6elK
Fa]O6e/KGa/005lKFa]O6e/KGa]K6elKFa]O6e/K008000YO6`03001O6f<K00=O6`09Ha]O6elKGa]S
6elK001O6f<K00=O6`03Ha]O6elK00800004Ga/005lKHa/3Ga/01V<KGa/00000Ha/0009O6`06Ha]O
6elKGa]S6`000UlK01ES6`00IcUW6F/iIaT006LIJcUW6FLiIaU[>FLI001W6F/iIaU[>FLIJcT00P00
01=W6F/iIaU[>FLI001W6@00IaU[6FLIJaUW6F/I001[6FLIJaT00002IaT01F/I001W6FLIJaT00fLI
00D006LI001W6F/I00=W6@08001W6FLIIaU[6FLI001Jn`8000IJn`08001:g4[MB]a:gD[LB]e:g0H0
0005B]e:g4[MB]`00002B]d01T[LB]e:gD[MB]`0009:g@06B]a:gD[MB]e:g0000T[M00I:g4[MB]e:
gD[L0002D_`30004D_`01`00Ea]K75LLFaaG6e/L0080000<Ea/005LLFaaG6e/LEaaK75LKFaaG7000
37om001ROod200001e9HCSMBF4hgDUQ>=`00009FE`05EUIFEeIGEUMFEP03EUL02P00FWMFEUYgEUH0
05kiH_YNnF;j0`0000ERnV;iH_YRnF;j0080000:HaUW6V<IHaYS6FLJHaUS6P00IaX200005F<IIaYS
6FLJHaUW6V<IIaYS6FLJ001W6V<IIaYS6FLJHaUW6V<IIaYS6@0200002FLJHaUW6P00IaYS6FLJHaUW
6P0200007V<IIaYS6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS6FLJHaUW6V<IIaX006LJHaUW6P00IaYS
6FLJHaUW6P80000MHaUW6V<IIaYS6FLJHaT006<I001S6FLJHaUW6V<IIaYS6FLJHaUW6P00IaX006LJ
HaYW6V<IIaYS6P02000026LJHaYW6V<IIaX005lKGaX2Ga/20003Ga/01UlJGa]O6elK001O6`800005
FaYO6elKGa]K6P03Ga/00`00GaaK6`0200002UlLFa]O6e/KGaaK6elK001K75/K0`0000]K6e/LFa]K
75/K001K6e/LFa]K75/K0080000<FaaK6e/LFa/005/KGaaK6e/LFa]O75/K0P0000YO7000GaaK6elL
Fa]O75/KGaaK6`80000:Ga`005lLFa]O75/KGaaK6elLFa/200002ElL001O75/KGaaK6elLFa]O7002
00001E/K001O6elKFa/00elK00iK6elK000005/K001O6V<KGaYS6elJHa]O6V<K0P0001eO6P00GaYS
6elJHa]O6V<K001S6elJHa]O6P00GaYS6elJHa]O6P00GaYS6elJHa/006<KGaYS6elJ0080001CHa]O
6V<KGaYS6`00JcYW6@00IaU[>VLIJcUW6F/jIaT006LI001W6F/iIaU[>FLI001W6F/iIaU[>FLIJcUW
6@00IaU[>FLIJcUW6F/i001[>FLIJcUW6F/i001[>@00JcUW6F/iIaU[>FLI001W6F/iIaT006LIJcUW
6@00IaU[>FLIJcUW6F/iIaT005[kFaaFne/LF_]K75KkFaaJn`00A]a:g@0400002T[LB]d004[MB]a:
gDKLB]e:g4[M0P0001A:g4[MA]a:gD[LB]e6g000B]a:gDKLB]e:g4[M001:gD[LB]e6g4[M1@0000aB
oDklD_eBo5;mC_aBoE;l001Fne/LE_/200002e/LE_]K7000FaaFne/LE_]K75KkFa`00`0037om001Q
Ood20008DUL00`00EUMFE`07EUL01`00EUIJMeIG001RnF;j00<000=RnP05001RnF;iH_X0000;HaX0
1000HaYS6VLJ0f<J00MW6V<JHaYS6VLJ001S6P0200005F<JIaYS6VLJHaYW6V<J001S6VLJHaYW6V<J
IaX006LJHaUW6P00IaYS6P03IaX02F<JIaYW6VLJHaX006<J001S6@03IaX01F<IIaYW6VLJ00000fLJ
00US6FLJ001W6V<IIaX006LJHaT00fLJ00QS6FLJIaYW6V<I001S6VLJ0f<J00AW6V<JHaYS6P80009S
6P09IaX00000HaYW6V<J001S6VLJ00=S6P05IaYS6V<J001O6`02000:Ga/00`00Ga]O6`09Ga/20002
Ga/01E/KGa]O6elKFa/00elK0P0000aK6e/LFa]K75/KFaaK6e/LFa/005/KFa`2000025/KFaaK6e/L
Fa]K7000Fa`3Fa/01E/L000005/KFa`00U/K00H005lKFa]O6e/KGa/200002U/KGa]K6elK001O6e/K
Ga]K6elK0P00011K6elKFa]O6`00Ga]K6elKFa]O6`00Ga]K6elKFa/000IO6`03001O6elK009O6`03
001O6f<K00=O6`09Ha/005lKGa]S6elK001O6f<K009O6`03001S6elK009O6`09Ha/005lKGa]S6elK
001O6f<K00=O6`03Ha/005lK008000=O6`0^Ha]O6elKGa/006LI001W6F/iIaUW>FLIJcUW6@00IaU[
>FLI001W6F/iIaT006LIJcUW6F/iIaU[>FLI001W6@00IaU[6FLIJaT006/IIaU[6FLIJaUW6F/I0002
IaT01F/IIaUW6FLI00000fLI00E[6FLI001W6@0000=W6@07JaUW6FLIIaT006LI000025[k0`0000m:
gD[LB]e:g4[MB]`004[LB]e:g4[MB]a:gD[LB]d00P000T[M00E:g4[MB]e:g@0000=:g@03B]`00000
00H000=:g@03B]`005;l00MBo00?001K7000001G75/LEa]K75LLFa`005/LEaaK75LK0080009oo@03
001ooGom00Yoo@00HGom00/0059HCSMBF4hgDUQ>=e9HCSMBF00000=FE`05EUIFEeIGEUMFEP02EUL6
000086;jG_URnUkiH_YNnF;j001RnP00HaYS6FLJHaUS6V<IIaYS6F<JHaUW6P00IaX006LJHaUW6V<I
IaYS6FLJHaT20000:VLJHaUW6V<J001S6FLJHaUW6V<I001S6FLJHaUW6V<IIaYS6FLJ001W6P00IaYS
6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6@00HaUW6V<IIaYS6@80000fIaYS6FLJHaUW6V<IIaX006LJ
001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJHaUW6V<I001S6VLJHaUW6V<JIaYS6@00
HaX006<IIaYS6VLJHaUW6V<JIaYS6FLJ001O6elJ0elK00EO6UlKGa]O6elJ00800003Ga/005lK009O
6`05FaYO6elKGa]K6P0200002UlK001O75/KGa]K6elLFa]O6e/K0P0000aO6`00FaaK6e/LFa]K75/K
FaaK6e/LFa/2000035/LFa]K75/KFaaK6e/LFa]K7000FaaK6`80000:FaaK6elLFa]K75/KGa`005lL
Fa/200002UlLFa]O75/KGaaK6elL001O75/K0P00019O75/KGaaK6elLFa/005/KGaaK6elL001O75/K
GaaK6elL0003Ga/01E/K000005lKFa/00elK00D006<KGaYS6elJ00800008Ha]O6V<KGaYS6elJ001O
6P800009Ha]O6V<KGaYS6elJHa/006<K0080001KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS6elJ
Ha]O6V<KGaX006LIJcYW6F/iIaU[>VLI001W6F/jIaU[>FLI001W6@00IaU[>FLIJcUW6F/iIaT006LI
JcT006/iIaU[>@00JcUW6F/iIaU[>FLIJcT006/i001[>FLIJcUW6@00IaU[>FLIJcUW6F/iIaT006LI
JcUW6F/iIaU[>FLI001W6F/i001K75[kFaaFne/LF_/00P00019K75[k0016g4[MB]a:gDKLB]e:g000
A]a:gD[LB]e6g4[MB]`2000014[MB]a:gDKL1`0001E6g4[MB]a:g@00B]e:g4[MA]a:gD[LB]d005;m
D_aBoDklD_eBo5;mC_`00P0000]K75KkFaaFne/LE_]K75Kk001Fne/L008000Eoo@03001ooGom00Uo
o@00Egom0P0027om0P00259G00<005IGEUL025IG0`000f;j00ERnF;jH_YRnV;i00=RnP03001S6V<J
00QS6P8000=S6P04001S6V<JIaX3HaX01@00HaYS6V<JIaX00f<J0P00011W6P00001S6VLJHaYW6V<J
IaYS6VLJHaYW6P00IaYS6P=W6P0=HaYW6VLJIaYS6P00HaYW6V<JIaYS6P00HaT00VLJ00<006<IIaX0
0VLJ00US6FLJIaYW6V<IIaX006LJHaT00fLJ00AS6FLJIaYW6P80009W6P04HaT00000IaX3HaX01@00
HaYS6V<JIaX00f<J00EW6V<J001S6VLJ00=S6P08IaYS6V<JHaYW6P00HaX000QO6`03001O6elK009O
6`03001O6elK00AO6`03001O6elK009O6`05001O6elKGa]K6`02Ga/00`00Fa]O6`02Ga/02000FaaK
6e/LFa]K75/KFa`2000035/K001K6e/LFa]K75/KFaaK6e/LFa]K708000=K6`05FaaK6e/KFa]K7002
Fa/200002U/KGa]K6elKFa]O6e/KGa]K6elK0P0000]K6elKFa]O6e/KGa]K6elKFa/005/K00800009
Ga]K6elKFa]O6e/KGa/005lK008000QO6`04001O6`000003Ga/02F<KGa]O6elKHa]O6`00Ga]S6`03
Ga/01V<KGa]O6elKHa/0009O6`06Ha]O6elKGa]S6elK0P0000ES6`00Ga]O6f<K00=O6`0ZHa/00000
Ga/006LIIcUW6F/iIaT006LIJcUW6FLiIaU[>FLI001W6F/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/I
001[6FLIJaUW6F/IIaU[6@000VLI00D006LIIaUW6@0000=W6@09JaUW6FLIIaT006LI001W6F/I00=W
6@06001W6FLIIaU[6@000U[k0`0015[k00h004[MB]a:gD[LB]e:g4[M001:gD[LB]e:g4[M200000E:
g4[MB]e:g@0000=:g@05B]a:gD[M001:g003B]d01D[LB]e:gD[M00000e;l10000U;l00P005/LEa]K
75LLFaaG6e/L0`001gom00<007omOod02Gom001FOod01000Ooeoo@001gom0P0000]>=e9HCSMBF4hg
DUQ>=e9HCSL005IF00=FE`03EUIFE`000080000mGa/006;jG_URnUkiH_YNnF;jG_URnUkiH_X006<J
001W6V<IHaYS6FLJHaUS6V<I001S6VLJHaYW6V<JIaX006LJHaUW6V<I001S6VLJHaUW6V<JIaYS6FLJ
HaYW6P00IaYS6FLJHaUW6V<IIaYS6FLJHaUW6P00IaX00P0000IS6FLJHaUW6V<IIaX20000:6<IIaYS
6FLJHaUW6V<I001S6@00HaUW6V<IIaYS6FLJHaUW6V<IIaX006LJ001W6V<IIaYS6FLJHaUW6P00IaYS
6FLJHaUW6V<IIaX006LJ0P0001=S6VLJHaUW6V<JIaYS6FLJHaX006<I001S6VLJHaUW6V<JIaYS6@02
00000fLJHaUW6P02000015lJGa]O6elK0P000UlK00EO6UlKGa/005/J00=O6`80009O6`0EFaYO6elK
Ga/005lLFa]O6e/K001K6elKFa]O75/KGa/005/LFa]K75/K0080000<FaaK6e/LFa/005/KFaaK6e/L
Fa]K75/K0P0000YK7000FaaK6elLFa]K75/KGaaK6`80000:Ga`005lLFa]O75/KGaaK6elLFa/20000
65lL001O75/KGaaK6elLFa]O75/KGaaK6`00Fa]O75/KGaaK6elLFa]O75/KGa`000=O6`05Fa]O6elK
Ga]K6`03Ga/02P00Ha]O6V<KGaYS6elJHa]O6V<K0P0000UO6P00GaYS6elJHa]O6V<KGaX00P00019S
6`00Ha]O6V<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaX20000AF<KGaYS6elJ001W6F/jIaT006LI
JcYW6F/iIaU[>VLI001W6@00IaU[>FLIJcUW6@00IaU[>FLIJcUW6F/i001[>FLIJcUW6F/iIaU[>@00
JcUW6F/iIaT006LI001W6F/iIaU[>FLIJcUW6@00IaU[>@00JcUW6F/iIaT006LIJcUW6F/iIaU[>@02
00003E[kFaaFne/LF_]K75KkFa`004[MA]a:gD[L00P00004B]e:g4[MB]`2000054[MB]a:gDKLB]e:
g000A]a:gD[LB]e6g4[MB]`004KLB]e:g4[MA]`600000e;lC_aBo@02D_`01dkl001Fne/LE_]K75Kk
008000Yoo@03001ooGom00Uoo@00FGom00<007omOod01Gom0`00259G00@005IGEUMFE`D000=NnP03
001RnV;i00=RnP03H_URnV;j008000=S6P03001S6V<J00AS6P03001S6V<J00IS6P04001S6P000003
HaX01FLJHaYS6V<JIaX00V<J00/006LJ001W6V<JIaYS6VLJHaYW6V<J00800006IaYS6VLJHaX006<J
0fLJ00d006LJHaYW6V<JIaYS6VLJHaYW6V<J001S6@03IaX02V<IIaYW6VLJHaUW6P00IaYS6FLJ0P00
00ES6FLJIaYW6P0000=W6P08HaUW6VLJIaYS6FLJ001W6P=S6P0=IaYS6V<JHaYW6V<J001S6VLJHaX0
06<JIaX00f<J00D006<JHaYS6VLJ00=S6P04001O6`000008Ga/01000Ga/000002ElK00D005lK0000
05/K00=O6`06Fa]O6elKGa/005/L0P0000aK6e/LFa]K75/KFaaK6`00Fa]K75/KFa`2000015/KFaaK
6e/L0P000e/K00EK7000001K6e/L009K6`0D001O6e/KGa]K6elKFa/005/KGa]K6elK001O6e/KGa]K
6elKFa]O6`800009Fa/005/KGa]K6elKFa]O6e/K00800003Ga/005lK00MO6`800005Ga/005lKGa]S
6`03Ga/01V<K001O6elKHa/0009O6`03Ha]O6elK008000=O6`09Ha/005lKGa]S6elK001O6f<K00=O
6`03Ha/005lK008000=O6`0VHa]O6elKGa/006LI001W6F/iIaUW>FLIJcUW6@00IaU[>FLI001W6F/i
IaT006LIJcUW6F/iIaU[>@00JaT006/IIaU[6FLIJaT0009W6@05JaUW6FLIIaT00003IaT01F/IIaUW
6FLI00000fLI00E[6@00IaUW6@0000=W6@06JaUW6FLI001[6@0025[k1@0000a:g4[MB]a:g@00B]e:
g4[MB]a:gD[LB]d200001D[LB]e:gD[MB]`00T[M00<004[LB]d00T[M200000E:g4[MB]e:g@0000QB
o003001G75/L008000aoo@03001ooGom00Uoo@00D7om10000gom0P0027om00`007om001BF4hgDUQ>
=e9HCSMBF4hgDUP30002EUL03`00G_YO6ekjGa]NnUlK001RnUkiH_YNnF;jG_T00002HaX025lJHa]S
6V<J001W6V<IHaX20000:F<JIaYS6VLJHaYW6V<JIaYS6VLJ001W6V<JIaYS6FLJHaYW6V<IIaYS6VLJ
001W6V<JIaX006LJHaUW6V<IIaYS6@00HaUW6V<JIaYS6FLJHaX00P00021W6P00IaYS6FLJHaUW6V<I
IaYS6FLJHaT006<I001S6FLJHaUW6V<IIaYS6FLJ001W6V<IIaYS6FLJHaT006<I0P0002YW6V<IIaYS
6FLJHaUW6V<IIaX006LJ001W6V<IIaYS6VLJHaUW6V<J001S6FLJHaYW6P00IaYS6VLJHaT006<JIaYS
6FLJHaYW6V<IIaYS6P00GaX3Ga/01ElJGa]O6elKGaX00UlK00<005/JGa/00UlK00EK6UlKGa]O6e/J
00=O6`0I001O75/KGa]K6elLFa]O6e/KGaaK6elK001K75/KFaaK6e/LFa]K75/KFaaK6`00Fa/00P00
00YK75/KFaaK6e/LFa]K75/K001K6`80000;FaaK6elLFa]K75/K001K6elLFa]O700200002e/KGaaK
6elLFa/005/KGaaK6elLFa/00P0000UO75/KGaaK6`00Fa]O75/KGa`00P0000EK6elLFa]O700000=O
6`05Fa]O6`00001K6`03Ga/01@00Ha]O6V<KGaX00P0000QS6elJHa]O6V<K001S6elJ0P0000US6elJ
Ha]O6V<KGaYS6`00Ha/00P00045O6V<KGaYS6elJHa]O6V<K001S6elJHa]O6V<KGaYS6elJHa]O6P00
IaU[>VLIJcUW6F/jIaT006LIJcYW6F/iIaT006LI001W6F/iIaU[>FLIJcT006/iIaU[>@00JcUW6F/i
001[>FLIJcUW6F/iIaT006LI001W6F/iIaU[>FLI0080000GJcUW6F/iIaT006LI001W6F/iIaU[>FLI
JcT006/IIaT005KkFaaJne/LE_]K700200004UKkFa`004[MB]a:gD[LB]e:g000B]a:gD[LB]e:g4[M
B]a:g@800004A]a:gD[LB]d700003d[MB]a:gD[L001:g4[MB]a:gD[LB]e:g000C_aBo@02D_`014kl
D_eBo5;l0`003Wom00<007omOod02Gom001GOod00`00Ooeoo@07Ood01000Ooeoo@001U9G0`000eIG
00<005kjG_X01Ukj00<006;jH_T00V;j00<006<JHaX01V<J00<006<J00002f<J00<006<J00000V<J
00EW6V<JHaYS6VLJ009S6P03001W6V<J009S6P0RIaX006LJHaYW6V<J001S6VLJHaYW6V<JIaYS6VLJ
HaYW6P00IaYS6VLJHaYW6V<JIaYS6VLJHaX006<JIaYS6P00HaT3IaX01F<I000006LJHaT00fLJ00ES
6FLJIaX006<I00=W6P0<HaUW6VLJIaYS6FLJ001W6V<JIaX006LJ0f<J00EW6P00001S6VLJ00=S6P03
IaX006<J008000=S6P09IaYS6V<JHaYW6V<J001S6P0000QO6`800003Ga/005lK00QO6`800003Ga/0
05lK009O6`05Fa]O6elKGa]K6`0200002elK001K75/KFaaK6e/LFa]K75/KFa`00P0000aK6e/LFa]K
75/KFaaK6e/LFa]K75/K0003Fa/025/LFa]K6e/KFaaK6`00Fa/200002elKFa]O6e/KGa]K6elKFa/0
05/KGa/00P0000UK6elKFa]O6e/KGa]K6`00Fa/00P0000QO6e/KGa]K6elKFa]O6`000UlK0P001elK
00@005lK000000=O6`05Ha]O6elKGa]S6`0200000elKHa]O6`02Ga/01V<KGa]O6elKHa/0009O6`06
Ha]O6elKGa]S6elK0P0000ES6`00Ga]O6f<K00=O6`0RHa/00000Ga/006LIIcUW6F/iIaT006LIJcUW
6FLiIaU[>FLI001W6F/iIaU[>FLIJcT006/IIaU[6FLIJaT006/I0002IaT01F/IIaUW6FLI00000fLI
00H006LIIaUW6F/I0002IaT01F/IIaUW6FLI00000fLI00E[6FLIIaT006/I00=W6@03001Jne[k00<0
00AJn`0>001:g4[MB]a:gD[LB]e:g000B]a:gD[LB]e:g0P00006B]e:g4[MB]d004[L0d[M00E:g4[M
001:gD[L00=:g@04B]a:gD[M0003D_`4000AOod00`00Ooeoo@09Ood005Moo@<000Ioo@08001ooGom
Ood004hgDUQ>=`<00003CSMBF4hg00<0000<G_YO6ekjGa]NnUlKG_YO6ekjGa/006;j0P000V<J00IO
6V<KHaYS6UlJHa/2HaX04000IaYS6VLJHaYW6V<JIaYS6VLJHaYW6P00Ia]S6VLJ0P0000ES6VLJHaUW
6V<J00800009IaYS6VLJHaUW6V<JIaX006LJ0080001BHaUW6V<JIaYS6FLJHaYW6V<IIaX006LJ001W
6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<I001S6FLJHaT006<IIaYS6FLJHaUW6V<IIaYS6@00HaT0
06<IIaYS6FLJHaUW6V<IIaX006LJHaUW6V<IIaX006LJHaUW6P00IaYS6FLJHaYW6V<IIaYS6VLJ001W
6V<JIaYS6FLJHaYW6V<IIaX200001F<IIaYS6P00GaX00elK00EO6UlK001O6elJ009O6`8000=O6`05
FaYO6`00001K6P03Ga/01P00GaaK6elKFa]O7080000;Fa]O75/KGa/005/LFa]K75/KFaaK6`020000
2e/LFa/005/KFaaK6e/LFa]K75/KFa`00P0001MK6`00Fa]O75/KFaaK6elLFa]K75/K001K6elLFa]O
75/KGaaK6elLFa]O75/K0080000EGaaK6elLFa]O75/KGaaK6elLFa/005/KGaaK6elLFa]O75/KGaaK
6elL0080009O6`05Fa]O6elKGa]K6`03Ga/02@00Ha]O6V<KGaYS6elJHa]O6P0200002V<K001S6elJ
Ha]O6V<KGaYS6elJ0P0005QS6`00Ha]O6V<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS6`00Ha]O
6V<KGaX006LIJcYW6@00IaU[>VLIJcUW6F/jIaT006LI001W6F/iIaU[>@00JcUW6F/iIaU[>FLIJcT0
06/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/iIaU[>@00JcUW6F/iIaU[>FLI001W6@00IaU[>FLIJcT0
06/IIaU[6FLIJaUW6@80000=FaaJne/LE_]K75[kFaaFn`00B]a:gD[LB]d0200000A:g4[MB]a:g@80
000DB]a:gD[LB]e:g4[M001:gD[LB]e:g4[MB]a:g@00B]e:g4[MB]a:g@H001Eoo@03001ooGom00Uo
o@00H7om00<007omOod00Wom0`001E9G0P003Ekj00<006<JHaX02F<J00<006<K00002F<J00<006<J
HaX00f<J0P0000IS6VLJHaX006<JIaX3HaX06fLJHaYS6V<JIaX006LJHaYW6V<JIaYS6VLJHaYW6V<J
IaX006LJHaYW6P00IaYS6VLJHaYW6P0200002V<JIaYS6VLJHaYW6V<J001S6@000VLJ00ES6FLJIaYW
6V<I009W6P06001S6FLJIaX006<I0fLJ00ES6@00001W6V<J00=W6P05HaYW6P00IaX00002HaX01FLJ
HaYS6V<JIaX00V<J00<006LJ00000V<J00IW6V<JHaYS6VLJ0002HaX01FLJHaYS6V<J000015lK00<0
05lKGa/01ElK00<005lKGa/00P001elK00<005lKGa/00P000elK00MK6elKGa]O6`00FaaK6`030000
2e/KFaaK6e/LFa/005/KFaaK6e/LFa/00P0000EK75/KFaaK6`0000=K6`03FaaK6e/K0080000:Fa/0
05/KGa]K6elKFa]O6e/KGa/200002U/K001K6elKFa]O6e/KGa]K6elK0P0000UK6`00Fa]O6e/KGa]K
6elKFa/00P0000=O6`00Ga/01elK0P0000EO6`00Ga]O6f<K00=O6`06001O6elKGa]S6`000UlK00ES
6elKGa]O6`0000=O6`05001O6elKGa]S6`0200000elKHa]O6`02Ga/01P00Ga]O6elKHa/0009O6`0Q
Ha]O6elKGa/006LI001W6F/iIaUW>FLIJcUW6@00IaU[>@00JcUW6F/i001[6FLIJaUW6F/IIaU[6@00
JaT006/I00=W6@80009W6@06JaUW6FLI001[6@000VLI00E[6FLIIaUW6@00009W6@06001[6FLIIaT0
06/I0fLI00E[6FLI001W6@0000QJn`D0000<B]e:g4[MB]`004[LB]e:g4[MB]a:gD[L0P0000=:gD[L
B]d00T[M00E:g4[M001:gD[L009:g@P001aoo@03001ooGom00Qoo@00H7om1P0000EBF4hgDUQ>=e9H
0080000=E_]Jo000Ga]NnUlKG_YO6ekjGa]NnUlKG_X00P0000ES6`00HaYO6V<K009S6P03GaYS6f<J
00800003Ha]S6V<K00800005HaYW6V<JIaYS6P020000HfLKHaYW6V<JIa]S6VLJHaX006<J001S6FLJ
HaYW6V<IIaYS6VLJHaUW6P00IcX006LJHaYW6V<IIaYS6VLJHaUW6P00IaYS6FLJHaYW6P00IaYS6FLJ
001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<I001S6FLJ
HaT006<IIaYS6FLJHaUW6V<IIaYS6FLJ001W6V<IIaYS6VLJHaUW6V<JIaX006LJHaYW6P0200003f<J
IaYS6FLJ001W6V<IIaYS6VLJHaUW6V<J001O6P0200000elKGaYO6`02Ga/015lJGa]O6elK0P000UlK
00EK6UlKGa]O6e/J00=O6`80000:Fa]O6e/KGaaK6elKFa]O75/KGa/2000035/KFaaK6e/LFa]K75/K
FaaK6`00Fa]K7080000;Fa]K75/KFaaK6e/L001K75/KGaaK6`02000015lLFa]K75/K0P0000AO75/K
GaaK6`80000:GaaK6elLFa/005/KGaaK6elLFa/200002ElLFa]O75/K001K6elLFa]O700200001E/K
GaaK6elL00000elK00EK6elK000005/K00=O6`0@001S6elJHa]O6P00GaYS6elJHa]O6P00GaYS6elJ
Ha/200001elJHa]O6V<KGaX005lJ0080000:Ha]O6V<KGaYS6elJHa]O6P00GaX20000CV<KGaYS6elJ
Ha]O6V<KGaX006LIJcYW6F/iIaU[>VLI001W6F/jIaU[>@00JcT006/iIaU[>FLIJcUW6F/i001[>FLI
001W6F/iIaU[>@00JcUW6F/iIaU[>FLIJcT006/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/i001[6FLI
JaUW6F/IIaT006LIJaT005/LE_]K75[kFaaFn`80000BFaaFn`00B]a:gD[LB]e:g4[M001:gD[LB]e:
g4[MB]a:gD[L0P0000A:gD[LB]e:g0L002Aoo@03001ooGom00Qoo@00H7om0P0017om00<0059G0000
0P0000EFo5KkE_]FneKl008000MNnP03001O6elK009O6`03001S6V<J00AS6P03001S6V<K00=S6P03
Ha/0000000=S6P03001S6V<J00US6P03001S6VLJ00=S6P06IaYS6V<JHaYW6P000V<J00QW6P00001S
6VLJHaYW6V<J0P0001QW6V<JIaYS6VLJHaYW6P00IaX006LJHaYW6V<JIaYS6VLJHaYW6V<J001S6P00
HaT3IaX01F<IIaX00000HaT00fLJ00IS6FLJIaX006<I0002IaX01F<JIaYW6VLJHaX00fLJ00@006LJ
001W6P=S6P05IaYS6P00001W6P03HaX016LJHaX006<J0P000V<J00EW6V<JHaYS6VLJ00=S6P03001O
6elK00MO6`800003Ga/005lK00MO6`800003Ga/005lK009O6`05Fa]O6elKGa]K6`02000035lK001K
75/KFaaK6e/LFa]K75/KFaaK6`80000;FaaK6e/LFa]K75/KFaaK6e/L001K700200000e/KFaaK6`02
Fa/01E/LFa]K6`00Ga/00P0000YK6elKFa]O6e/KGa]K6`00Fa]O6`800009Fa]O6e/KGa]K6elKFa/0
05/K00800008Ga]K6elKFa]O6e/KGa/0009O6`8000MO6`04001O6`000003Ga/01V<KGa]O6elK001O
6`800005Ha]O6elKGa]S6`03Ga/01@00Ga]O6elKHa/00elK00ES6elKGa]O6`0000=O6`05Ha]O6elK
Ga]S6`0200001UlK001W6FLiIaU[>@80000GIaU[>FLIIcUW6F/i001[6FLIJaUW6F/IIaU[6@00JaUW
6F/IIaT006LIJaT00002IaT02F/IIaUW6FLIJaT006LI001[6@03IaT01@00IaUW6FLIJaT00VLI00<0
06/IIaT00VLI00=[6FLI000016LI00<005[kF_/00`0015[k00h004[MB]a:gD[LB]e:g4[M001:gD[L
B]e:g4[M2000:gom00<007omOod027om001QOod00`00Ooeoo@02Ood200002E[lE_]Jo5KkF_aFne[l
E_]Jo002000015kjGa]NnUlK0P0003AO6V<KGaYO6elJHa/006<JGaYS6f<J001O6V<KHaYS6elJHa]S
6V<KGaX006<J001S6VLKHaYW6V<JIa]S6VLJHaYW6f<J001S6P00HaYW6V<IIaYS6VLJHaUW6P00IcYS
6VLjHaYW>P80000HHaYW6V<I001S6VLJHaUW6V<JIaYS6FLJHaYW6P00IaYS6FLJHaUW6V<IIaYS6FLJ
0P0000=S6FLJHaT00P0001QW6V<IIaX006LJHaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<IIaYS
6FLJHaT200000fLJHaUW6P0200007F<IIaYS6P00HaUW6V<JIaYS6FLJHaYW6V<I001S6VLJHaUW6V<J
IaYS6FLJHaYW6V<I001S6P00GaX00elK00EO6UlKGa/005lJ00=O6`05001O6elKGa]K6P02Ga/00`00
FaYO6`02Ga/05000GaaK6elKFa]O75/K001K6elLFa]O6`00FaaK6e/LFa]K75/KFa`200002e/K001K
6e/LFa]K75/KFaaK6e/LFa/00P0001IK75/KGaaK6e/LFa]O75/KFaaK6elL001O75/KGaaK6elLFa]O
75/KGaaK6`80000EGaaK6elLFa]O75/KGaaK6elLFa/005/KGaaK6elLFa]O75/KGaaK6elL0080009O
6`05Fa]O6elKGa]K6`03Ga/05000Ha]O6V<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa/2
00002UlJ001O6V<KGaYS6elJHa]O6V<K0P0004aO6P00GaYS6elJHa]O6V<K001S6elJHa/006/iIaU[
>P00JcUW6F/jIaU[>FLIJcX006/i001[>FLIJcUW6F/i001[>FLIJcUW6F/i001[>@00JcUW6F/iIaU[
>FLIJcT006/iIaT006LIJcUW6@00IaU[>FLIJcUW6F/i001[>@00JaUW6F/IIaT006LIJaUW6F/IIaU[
6@80000=E_]K75[kFaaFne/LF_]K7000B]e:g4[MB]`0200017om00<007omOod0;7om00<007omOod0
27om001ROod20003Ood00`00E_]Fo003E_/025KlE_]FneKkE_aFn`00G_X20009Ga/01P00HaX00000
HaYS6`=S6P07Ha]S6V<JHaYS6f<J00002V<J0P000f<J00<006<JIaX00f<J0P000V<J02YW6V<JHaYS
6VLJHaX006<J001S6VLJHaYW6V<JIaYS6VLJHaYW6P00IaX006LJHaYW6V<JIaYS6VLJ001W6V<JIaYS
6VLJHaYW6P00IaX006LJHaT3IaX02F<IIaYW6VLJHaT006LJ001S6P03IaX01F<JIaYW6P00HaX00fLJ
00QS6VLJIaX006<J001S6VLJ0f<J00UW6V<JHaYS6P00HaX006<JIaX00f<J00=W6V<JHaX00P000f<J
00<005lKGa/00UlK0P001ElK00<005lKGa/00UlK0P001ElK00<005/KGa/00UlK0P000UlK00UK6elK
Ga/005/KFaaK6e/LFa/00P0000]K75/KFaaK6`00Fa]K75/KFaaK6e/L00800004Fa]K7000Fa`3Fa/0
15/LFa]K6e/K0P0000UK6`00Ga]K6elKFa]O6e/KGa/00P0000YK6`00Fa]O6e/KGa]K6elKFa]O6`80
0009Fa/005/KGa]K6elKFa]O6e/K00800003Ga/005lK00MO6`800005Ga/005lKGa]S6`03Ga/01F<K
000005lK00000elK00ES6elKGa/006<K00=O6`06001O6elKGa]S6elK0P0000ES6elKGa/006<K00=O
6`80009O6`0NHa]O6elK001[>@00IcUW6F/iIaUW>FLIJcT006LiIaT006LIJaUW6F/I001[6FLIJaUW
6F/IIaU[6@000VLI00I[6FLIIaUW6F/I0002IaT01F/IIaT006LI00000fLI00][6FLIIaT006/IIaT0
06LIJaUW6@0000IW6@03001W6@0000UJn`@000eoo@03001ooGom02]oo@03001ooGom00Qoo@00I7om
02`007omOoeoo@00E_]Jo5KkF_aFne[lE_]Jo5KkF_aFn`00GaYO6elJHa]O6UlKGaYS6elJGa]O6V<K
001S6elJHa]S6V<KGaYS6f<JHa]O6V<KHaX005lJ0P0002QW6V<JIa]S6VLJHaYW6`00HcYS6VLkHaYS
>V<J001S6VLJHaT006<JIcYS6VLjHaYW>V<JIcYS6VLjHaX006<JIaYS6FLJHaYW6V<IIaYS6P800003
IcYS6VLj0080000MHaUW6V<IIaX006LJHaUW6V<IIaYS6FLJHaUW6P00IaYS6FLJHaUW6V<IIaYS6FLJ
HaT006<IIaYS6@020000;6LJHaUW6V<I001S6FLJHaUW6V<IIaYS6FLJHaT006<IIaYS6VLJHaUW6V<J
IaYS6@00HaYW6V<I001S6VLJHaUW6V<JIaX006LJHaYW6V<IIaYS6P00GaX200000elKGaYO6`02Ga/0
1ElJGa]O6`00FaX00P0000=O6e/JGa/00UlK00EK6UlKGa/005/K0080000;Ga]K6elLFa]O6e/KGaaK
6`00Fa]K700200002U/KFaaK6e/LFa]K75/K001K6e/L0`0000]K75/KFaaK6e/L001K75/KGaaK6e/L
00800009Fa]K75/KGa`005lLFa]O75/K0080000LGaaK6elLFa/005/KGaaK6elLFa]O7000GaaK6elL
Fa/005/KGaaK6elLFa/005/KGaaK6elL0003Ga/01E/KGa]O6`00Fa/00elK01X006<KGaYS6elJHa/0
06<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS6elJ001O6V<K0P0000QO6V<KGaYS6elJHa/006<K
0P0002MO6V<KGaYS6elJHa]O6V<K001[>FLIJcYW6F/iIaU[>P00JcUW6F/jIaT006LIJcT006/iIaU[
>FLIJcUW6F/i001[>@00JcUW6F/iIaT00P0002I[>FLIJcUW6F/iIaT006LIJcUW6F/iIaU[>@00JcUW
6F/iIaT006LI001W6F/IIaU[6FLIJaT006/IIaU[6@00FaaFne/LF_]K75Kk0P004Wom00<007omOod0
:Wom00<007omOod027om001UOod01`00OoeooGom001FneKl00=Fn`03E_aFneKk00800003Ea`005lK
00QO6`800003Ga/006<K00=S6P05Ha]S6V<JHaYS6`0200001F<JHa]S6V<K00001F<J00<006<JHaX0
1V<J00<006<J00000f<J00EW6V<JHaYS6VLJ00=S6P0D001S6P00HaYW6V<JIaYS6VLJHaX006<JIaYS
6VLJHaYW6V<J001S6P80000<IaYS6VLJHaYW6V<JIaYS6VLJ001W6P000fLJ00IS6FLJIaYW6V<I0002
IaX01V<JIaYW6VLJ001W6P800005HaYW6VLJIaYS6P03IaX016<J001W6P000f<J00EW6V<JHaYS6P00
00=S6P05IaYS6P00HaYW6P02HaX00`00IaYS6P02HaX01FLJHaYS6V<J00002elK00<005lKGa/02ElK
00<005/KGa/00UlK00EK6elKGa]O6e/K009O6`80000:FaaK6e/LFa]K75/KFaaK6e/LFa/2000035/L
Fa]K75/KFaaK6e/LFa]K7000FaaK6`800005FaaK6e/KFa]K7002Fa/03`00Ga/00000Fa]O6e/KGa]K
6elK001O6e/KGa]K6`0200004ElKFa]O6e/KGa/005lKFa]O6e/K001K6elKFa]O6e/K000015lK0P00
1ElK00H005lKGa]O6f<K0002Ga/01V<KGa]O6elK001O6`800005Ha]O6elKGa]S6`03Ga/20002Ga/0
1F<KGa]O6elKHa/00UlK00<006<KGa/00UlK00AS6elKGa]O6`800007Ga/006/iIaUW>FLIJcT00P00
00mW6F/iIaUW>@00JaT006/IIaU[6FLIJaUW6F/I00000VLI00D006LIIaUW6@0000=W6@09JaUW6FLI
IaT006LI001W6F/I009W6@03001[6FLI009W6@03JaUW6@0000IW6@03001W6FLI009W6@03001Jne[k
009Jn`8001Eoo@03001ooGom02Uoo@03001ooGom00Qoo@00IWom00X007omOoeoo@00E_]Jo5KkF_aF
n`80000AFaaG75/LEa`005lJGa]O6V<KGaYO6elJ001O6elkGa]S>`0200003UlJHa]S6V<KGaYS6`00
Hc]O6V<kHaYS>elJHc/2000066<J000006<jHaYW>f<JHcYS6VLkHaYS>V<J001S6VLjHaYW>V<JIcYS
6VLjHaYW>P800003HaYW>V<J0080000SIaYS6FLJHaX006<IIcYS6VLjHaUW>V<JIcYS6@00HaUW6V<I
IaYS6FLJHaUW6V<IIaX006LJHaYW6P00IaYS6FLJHaUW6P0200009f<IIaYS6FLJHaUW6V<IIaX006LJ
HaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaT006<IIaYS6VLJHaT006<JIaYS6FLJHaYW6V<I001S6P02
000036LJHaYW6V<IIaYS6VLJHaT006<J001O6P=O6`04GaYO6elKGa/200000elK001K6P03Ga/015/J
Ga]O6elK0P0000YO6`00Fa]O75/KGa]K6elLFa]O6`80000:Fa/005/KFaaK6e/LFa]K75/KFa`20000
35/K001K6e/LFa]K75/KFaaK6e/LFa]K7080000FFa]O75/KFaaK6elLFa]K75/KGa`005lLFa]O75/K
GaaK6elLFa]O7000Ga`200002U/KGaaK6elLFa]O75/KGa`005lL0P0000UK6elLFa]O75/KGaaK6`00
Fa/00P0000=O6e/KGa/00UlK00EK6elKGa/005lJ0080000AHa]O6V<KGaYS6elJHa]O6P00GaYS6elJ
Ha]O6V<KGaYS6`0200002ElJ001O6V<KGaYS6elJHa]O6P020000CV<K001S6elJHa]O6V<KGaX005lJ
Ha]O6V<K001[>FLIJcYW6@00IaU[>VLIJcUW6F/j001[>FLIJcUW6F/iIaU[>@00JcUW6F/iIaT006LI
001W6F/iIaU[>FLIJcUW6@00IaU[>@00JcUW6F/i001[>FLIJcUW6F/iIaT006LI001W6F/IIaU[6@00
JaUW6F/IIaU[6FLI001Jn`8001Moo@03001ooGom02Uoo@03001ooGom00Qoo@00Igom0P000Wom00<0
05KkE_`00P0000=G75/LEa`00ULL00=K75LL000015lK0P001UlK0P000f<J00eS6`00Ha]S6V<KHaYS
6f<JHa]S6V<KHaX0000;HaX01@00HaX00000IaX00f<J00EW6V<JHaX006LJ00=S6P05IaYS6V<J001W
6P0200006f<JIaYS6VLJHaYW6V<JIaYS6P00HaX006<JIaYS6VLJHaYW6V<JIaX006LJHaYW6V<JIaX0
0003IaX01@00IaYW6VLJHaX00fLJ00ES6VLJ001W6P0000=W6P06HaYW6VLJIaYS6P000VLJ00AS6VLJ
IaX000=S6P05001S6V<JHaYW6P03HaX01FLJHaX006<JIaX00f<J00EW6V<JHaYS6P0000=S6P03001O
6elK00AO6`03001O6elK009O6`8000AO6`8000AO6`8000=O6`05Fa/00000Ga]K6`02Ga/2000015/L
Fa]K75/K0P0000aK75/KFaaK6`00Fa]K75/KFaaK6e/LFa/200000e/L001K7003Fa/015/LFa]K6e/K
0P0002=K6`00Ga]K6elKFa]O6e/KGa]K6elK001O6e/KGa]K6elKFa]O6e/KGa]K6elK001O6e/KGa]K
6elKFa]O6e/KGa]K6`0000]O6`05001O6elKGa]S6`03Ga/01F<K000005lK00000elK00ES6elKGa/0
06<K00=O6`09001O6elKGa]S6elK001O6f<K009O6`03001S6elK009O6`0J001O6elKGa]S6elK001W
6F/iIaT006LIJcUW6FLiIaU[>@00IcT006/IIaU[6FLIJaT0009W6@05JaUW6FLIIaT00003IaT01F/I
IaUW6FLI00000fLI00E[6@00IaT006/I00=W6@06JaUW6@00IaU[6@000fLI00<006LIIaT01VLI00<0
07omOod067om00<007omOod0:Gom00<007omOod01gom001YOod00`00Ooeoo@02000035/LEaaK75LL
FaaG75/LEaaK75LL001O6P80000<Hc]O6elkGa]S>elKGc]O6f<kGa/005lJ0P0001ES>elJHc]S6V<k
GaYS>f<JHc]O6P00HaX006<JIc]S6V<jHaYW>f<JHcX00P0002US6V<kHaYW>`00IcYS6VLjHaYW>P00
IcYS6VLjHaYW>V<JIcYS6VLj001W>V<IIcYS6VLjHaUW>V<JIcYS6@00HaYW>V<J001S6FLJHaUW6V<I
0080000MIaYS6VLJHaUW6V<JIaX006LJ001W6V<IIaYS6FLJHaUW6V<IIaX006LJHaUW6P00IaYS6FLJ
HaUW6P02000076<IIaYS6FLJHaUW6V<I001S6@00HaYW6V<IIaYS6VLJHaUW6V<J001S6@00HaYW6V<I
IaYS6VLJ0P0000MS6VLJHaUW6V<J001O6P03Ga/01@00Ga]O6elKGaX00elK00D005lK000005/J00=O
6`06FaYO6elKGa/005lL0P0000YK6elLFa]O6e/KGaaK6elK001K7080000<Fa]K75/KFaaK6e/LFa/0
05/KFaaK6e/L0P0000YK6e/LFa]K7000FaaK6elLFa]K7080000;Fa]K75/KGa`005lLFa]O75/KGaaK
6`0200002UlL001O75/KGaaK6elLFa]O75/K0P0000UO7000GaaK6elLFa]O75/KGa`00P0000=K6`00
Fa/00elK00AK6elKGa]O6`80000VGa/005lJHa]O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<K001S
6elJHa]O6V<K001S6elJHa]O6P00GaYS6elJHa]O6V<K001S6`800016GaYS6elJHa]O6V<KGaX006LI
001W6F/jIaU[>FLIJcX006/iIaU[>P00JcUW6F/i001[>FLIJcUW6F/iIaT006LI001W6F/iIaU[>FLI
001W6F/iIaU[>FLIJcT006/iIaU[>FLIJcUW6@00IaU[>FLIJcT006/I001[6FLIJaUW6F/IIaU[6FLI
000LOod00`00Ooeoo@0XOod00`00Ooeoo@07Ood006Yoo@06001ooGom001G75/L0eLL00MK75LLEaaG
75/LEa`0000=Ga/02`00HaYS6f<JHa]S6V<KHaYS6f<JHa/00P0000AS6V<kHaX000IS6P08001S>V<J
HcYS6V<jHaYS>P800004HaX00000IaX3HaX04FLJHaYS6V<JIaX006<J001W6V<JIaYS6VLJHaYW6V<J
00000f<J019W6V<J001S6VLJHaX006<JIaYS6VLJHaYW6V<JIaYS6VLJ0003IaX02F<JIaYW6VLJHaYW
6P00IaYS6P03IaX01@00IaYW6VLJ00000fLJ00ES6VLJIaYW6V<J009W6P05001S6V<JHaYW6P03HaX0
1VLJ000006<JIaYS6P800005IaYS6V<J001W6P03HaX01VLJHaYS6V<J001O6`8000UO6`03001O6elK
00UO6`05001O6elKGa]K6`03Ga/04E/KGa]O6elK001K75/KFaaK6e/LFa]K75/KFaaK6`00Fa/00P00
00YK75/KFaaK6e/LFa]K7000FaaK6`80000;FaaK6e/KFa]K75/K001K6elKFa]O6`0200002U/KGa]K
6elK001O6e/KGa]K6elK0P0000UK6elKFa]O6`00Ga]K6elKFa/00P0000EO6e/KGa]K6`0000EO6`80
00AO6`06001O6elKGa]S6`000UlK00IS6elKGa]O6`00Ga/200001F<KGa]O6elKHa/00UlK00H006<K
000005lKHa/3Ga/01F<KGa]O6`00Ha/00elK01IS6elKGa]O6f<KGa/006LIJcUW6FLiIaU[>@00IcUW
6F/iIaUW>@00JaT0009W6@05JaUW6FLIIaT00003IaT01@00IaUW6FLI00000fLI00I[6FLIIaT006/I
0002IaT01F/IIaT006LIJaT00fLI00=[6@00IaT01fLI00<007omOod077om00<007omOod09gom00<0
07omOod01gom001[Ood00`00Ooeoo@0200001e/LEaaK75LLFaaG75/L0080000<Ea`005lKGc]O6f<k
Ga]O>elKHc]O6elk0P0003IO6`00001S>f<JHc]O6V<kHaYS>`00Hc]S6V<kGaYS>f<J001S6VLkHaYS
>P00Ic]S6V<kHaYW>f<JHc]S6VLkHaX006<JIcYS6VLjHaYW>V<JIcYS6VLj001W>V<JIc/006LjHaUW
>V<JIcX200007F<JIcYS6VLjHaYW>V<J001S6@00HaUW6V<JIaYS6FLJHaYW6V<IIaX006Lj001W6V<I
IaYS6FLJHaT00P0003AW6V<IIaYS6FLJHaUW6P00IaX006LJHaUW6V<IIaYS6FLJHaUW6V<I001S6@00
HaUW6V<JIaYS6FLJ001W6V<IIaYS6VLJHaUW6P00IaX006LJHaYW6V<IIaYS6VLJHaUW6V<J001O6P=O
6`05GaYO6elKGa]O6P0200000elK001O6`02Ga/01E/JGa]O6elKFaX00P0000YO6`00GaaK6elKFa]O
75/KGa]K6`80000;Ga/005/LFa]K75/KFaaK6e/LFa]K700200002U/KFaaK6e/LFa]K75/KFaaK6e/L
0P0000]K6elLFa]K75/KGaaK6e/LFa/005/K0080000:GaaK6elLFa]O75/KGa`005lLFa/200002ElL
Fa]O75/KGaaK6elL001O700200002U/KGaaK6elLFa]O75/K001K6elK0P0000EK6elKGa]O6e/K009O
6`0P001O6P00001S6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS
6elJHa]O6P800009Ha/006<KGaYS6elJHa]O6V<K0080000jGaX006LIJcUW6F/j001[>FLIJcYW6F/i
IaU[>P00JcUW6F/iIaU[>FLI001W6F/iIaU[>FLI001W6@00IaU[>FLIJcUW6F/i001[>FLI001W6F/i
IaT006LIJcUW6F/iIaU[>@00JcT006/IIaU[6FLIJaT2000OOod00`00Ooeoo@0WOod00`00Ooeoo@07
Ood006aoo@06001ooGomOod005/L0eLL0P000ULL00AK75LL000000MO6`0G001O>elKGc]O6elk001S
6f<JHa]S6V<K001S>f<JHc]S6V<kHaYS>f<J001S6P0200003F<jHaYS>V<JHcYS6V<jHaYS>V<J001S
6P0000=S6P06IaYS6V<JHaYW6P001F<J00H006LJHaYW6P00IaX3HaX046LJHaYS6V<JIaYS6P00HaYW
6V<JIaYS6VLJHaYW6V<J0P0000=W6V<JIaX00P000VLJ00ES6P00IaYW6V<J00=W6P05HaYW6VLJIaX0
0003IaX01V<JIaYW6VLJHaYW6P800004HaYW6V<J0003HaX01FLJ001S6V<JIaX00f<J00EW6V<JHaX0
06LJ00=S6P09IaYS6V<JHaYW6V<J001S6P0000MO6`03001O6elK009O6`03001O6elK00AO6`03001O
6elK009O6`06001O6elKGa]K6elK0P0000]K6elKGa]O6`00FaaK6e/LFa]K75/K0080000:FaaK6`00
Fa]K75/KFaaK6e/LFa/200000e/L001K7003Fa/04E/LFa]K6e/KFaaK6`00Fa]O6e/KGa]K6elKFa]O
6e/KGa/00P0001EK6elKFa]O6e/KGa]K6elKFa]O6`00Ga]K6elKFa]O6e/KGa]K6elKFa/00P002UlK
00D005lKGa]O6f<K00=O6`05Ha/00000Ga/00003Ga/016<KGa]O6elK0P0000=O6`00Ha/00elK00US
6elK001O6f<KGa/005lKHa/00elK0P000UlK015S6`00IcUW6F/i001W>FLIJcUW6FLiIaU[>@00IcT0
06/I00=W6@05001W6FLIIaU[6@03IaT01@00IaUW6FLIJaT00VLI00<006/IIaT00VLI00D006LI001W
6F/I00=W6@03JaT006LI009W6@05001W6FLIIaT0000ROod00`00Ooeoo@0VOod00`00Ooeoo@07Ood0
06eoo@80009oo@0;001K7000001G75/MEaaK7ELLFaeG7002000015lkGa]S>elK0P0000MS?5lKGcaO
6f<lGa]O?002000066<J000006<kHaYS>elJHc]S6V<kGaYS>f<J001S6VLkHaYS>f<JIc]S6V<kHaYW
>`800009HaYW>f<J001S6VLjHaYW>V<J00800016IcYS6VLkHaYW>V<JIc/006Lj001W>V<JIcYS6VLj
HaYW>V<JIcYS6P00HaX006<JIaYS6FLJHaYW6V<I001S6VLjHaUW>V<JIcYS6@00HaT006<IIaYS6FLJ
HaUW6V<IIaYS6FLJ001W6P00IaYS6FLJHaUW6V<IIaX006LJHaUW6V<IIaYS6@00HaT200004fLJHaUW
6V<JIaYS6FLJHaYW6P00IaX006LJHaUW6V<JIaYS6FLJ00800005HaUW6V<J001O6P03Ga/20002Ga/0
1ElJGa]O6`00FaX00elK0P000UlK00MK6UlKGa]O6`00GaaK6`0200002UlLFa]O6e/KGaaK6elK001K
75/K0`0000YK6e/LFa]K75/K001K6e/LFa]K7080000<Fa]K75/KFa`005/LFa]O75/KFaaK6elL0P00
00UK6`00Fa]O75/KGaaK6elLFa/00P0000YO7000GaaK6elLFa]O75/KGaaK6`800009Ga`005lLFa]O
75/KGaaK6elL00800003Fa/005/K00=O6`04Fa]O6elKGa/200004UlK001O6V<KGaYS6elJHa/006<K
GaYS6`00Ha]O6V<KGaYS6`800008GaYS6elJ001O6V<KGaYS6`800008GaYS6elJHa]O6P00GaYS6`80
000mGaYS6elJHa]O6V<K001[>P00JcUW6F/jIaU[>FLIJcX006/iIaT006LIJcUW6@00IaU[>FLIJcUW
6F/iIaT006LI001W6F/iIaU[>@00JcUW6F/iIaU[>FLI001W6F/iIaU[>FLIJcT006/iIaU[>FLIJcT0
06/I000097om00<007omOod09Gom00<007omOod01gom001_Ood01@00Ooeoo@00Fa`00eLL00EK75LL
EaaG75/L009G700J001O6`00001O6elkGa]O>elKGc]O6elkGa]O>elK001S6V<kHaYS>f<JHc]S6V<k
HaYS>`80000BHc/00000HcYS6V<jHaYS>V<JHcX006<jHaYS>f<JHcYS6P000f<J00<006<JHaX026<J
00<006LJHaX00V<J00EW6V<JHaYS6VLJ00800003HaYW6V<J0080000?IaYS6VLJHaX006<JIaYS6VLJ
HaYW6V<JIaYS6P00009W6P05HaYW6VLJIaYS6P02IaX20003IaX20002IaX036<JIaX006LJHaYW6V<J
IaYS6VLJHaX000=S6P05IaYS6V<JHaYW6P02HaX01P00IaYS6V<J001W6P=S6P05IaX006<JHaYW6P03
HaX01000Ga/0000025lK00@005lK000000UO6`80009O6`05Fa]O6elKGa]K6`03Ga/200002e/KFaaK
6e/LFa]K75/KFaaK6`00Fa/00P0000UK75/KFaaK6e/LFa/005/KFa`00e/K0P000U/K00MK75/K001K
6elKFa]O6`0200002U/KGa]K6elK001O6e/KGa]K6elK0P0000UK6elKFa]O6`00Ga]K6elKFa/00P00
00EO6e/KGa]K6`0000EO6`8000=O6`03001S6elK009O6`80009O6`06Ha]O6elK001S6elK0P0000QS
6elKGa]O6f<KGa/005lK0P000UlK00IS6elKGa]O6f<KGa/200001F<KGa]O6elKHa/00elK015S6`00
IcUW6F/iIaUW>FLIJcT006LiIaUW>FLI001W6@0000=W6@05JaUW6FLIIaT00002IaT01P00JaUW6FLI
001[6@=W6@05JaUW6@00IaT00003IaT00f/I001W6@06IaT00`00Ooeoo@0SOod00`00Ooeoo@0UOod0
0`00Ooeoo@07Ood0071oo@03001ooGom00800009EaaK7ELLFaeG75/MEaaK7ELL0080000;GcaO6f<l
Ga]O?5lKHcaO6ellGa]S?0020000@5lK001S6V<kGaYS>f<JHc]O6V<k001S>elJHc]O6V<k001W>f<J
Hc]S6VLk001S>f<JIc]S6V<kHaYW>f<J001S6P00HaYW>V<JIc]S6VLjHaYW>f<JIcX006Lk001W>V<J
IcYS6VLjHaYW>P00IcYS6VLjHaYW>V<JIcX006LJ0P0001eS6VLjHaUW>V<JIcYS6FLjHaX006<I001S
6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS6FLJHaT006<I0080000XIaYS6FLJHaUW6V<IIaYS6@00HaT0
06<IIaYS6VLJHaUW6V<JIaX006LJHaYW6V<I001S6VLJHaUW6P00IaYS6FLJHaYW6V<IIaYS6P00GaX3
Ga/01ElJGa]O6elKGaX00UlK00<005/JGa/00UlK00EK6UlKGa]O6e/J0080000:Ga/005lLFa]O6e/K
GaaK6elKFa/200006ElK001K75/KFaaK6e/LFa]K75/KFaaK6`00Fa]K75/KFaaK6e/LFa]K75/K001K
6e/L00800009Fa]K75/KGaaK6e/LFa/005/K0080000:GaaK6elLFa]O75/KGa`005lLFa/200002ElL
Fa]O75/KGaaK6elL001O700200002U/KGaaK6elLFa]O75/K001K6elK0P0000QK6elKGa]O6e/KGa/0
06<K0P0000QO6V<KGaYS6elJHa]O6V<K0P00019O6V<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS
6elJHa/200002ElJ001O6V<KGaYS6elJHa]O6P020000=6<K001[>VLIJcUW6F/j001[>FLIJcYW6F/i
IaT006LIJcUW6F/iIaU[>FLI001W6F/iIaU[>@00JcT006/iIaU[>FLIJcUW6@00IaU[>@00JcUW6F/i
001[>FLIJcUW6F/iIaU[>@009gom00<007omOod097om00<007omOod01gom001aOod01@00OoeooGom
00000eLL00=K75LLEa`00P000ULL0P0000UO6elkGa]O>elKGc]O6elk000015lk0P0000AS>f<JHc]S
6P8000=S>`04HcYS>f<kHc/200003V<J000006<jHaYS>f<JHcYS6V<kHaYS>V<J0009HaX20003HaX2
0003HaX01FLJ001S6V<JIaX00f<J019W6V<JHaX006LJHaYW6V<JIaYS6VLJHaYW6V<J001S6VLJHaX2
00001VLJHaYW6VLJ001S6P=W6P0DHaYW6VLJIaYS6P00HaYW6V<JIaYS6VLJHaYW6V<J001S6VLJHaX0
00=S6P05IaYS6P00001W6P03HaX016LJHaX006<J0P000V<J00UW6V<JHaYS6VLJHaX006<J000025lK
0P0000=O6`00Ga/01UlK00<005lKGa/00UlK00D005lKGa]O6e/K009O6`03001K6elK009O6`08001K
75/KFaaK6e/LFa]K7080000:Fa/005/KFaaK6e/LFa]K75/KFa`300001E/LFa]K6e/KFa`00e/K00eK
75/K001K6elKFa]O6e/KGa]K6elKFa]O6`0200005E/KGa]K6elKFa]O6e/KGa]K6elK001O6e/KGa]K
6elKFa]O6e/KGa]K6`020009Ga/00`00Ha]O6`02Ga/016<KGa]O6elK0P0000=O6`00Ha/00elK00=S
6elKGa/00P0000AO6`00Ga]S6`=O6`09Ha/005lKGa]S6elK001O6f<K009O6`8000=O6`0AHa/006Li
IaU[>@00IcUW6FLiIaUW>FLI001W6@00IaU[6@03IaT01@00IaUW6FLIJaT00VLI00<006/IIaT00VLI
00E[6FLI001W6F/I009W6@03001[6@0000MW6@03001ooGom02Moo@03001ooGom02Aoo@03001ooGom
00Ioo@00LWom0P000Wom0P00011K7ELL000005/mEaaK?ELLFceG7000Ga]S?5lKGcaO6`800009GcaO
6ellGa]O?5lKGc`006<k0080000FGaYS>elJHc]O6V<kGaYS>elJHc]O6P00HaYS>f<JIc]S6V<kHaYW
>f<JHc/200004f<J001S6VLkHaYW>V<JIc]S6P00HaYW>f<JIcYS6VLkHaX006<J0080000MIcYS6VLj
HaYW>V<JIcYS6VLj001W>P00IcYS6FLjHaYW>V<IIcYS6P00HaUW>V<JIcYS6FLj001W6P020000=F<I
IaYS6FLJHaUW6V<IIaYS6@00HaT006<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<I001S6FLJHaX006<I
IaYS6VLJHaUW6V<JIaYS6@00HaYW6V<IIaYS6VLJHaUW6V<J001S6FLJHaX00P000elK00EO6P00001O
6elJ009O6`8000=O6`05FaX005lKGa]K6P03Ga/04@00GaaK6elKFa/005/KGa]K6elLFa/005/KFaaK
6e/LFa/00P0000YK75/KFaaK6`00Fa]K75/KFaaK6`80000;FaaK6`00Fa]K75/KGaaK6e/LFa]O7002
00002E/K001K6elLFa]O75/KGaaK6`0200002UlL001O75/KGaaK6elLFa]O75/K0P0000UO7000GaaK
6elLFa]O75/KGa`00P0000=K6`00Fa/00elK00=K6elKGa/00P0002IO6`00Ha]O6V<KGaYS6elJ001O
6V<KGaYS6`00Ha]O6V<KGaYS6`00Ha]O6V<KGaX005lJHa]O6V<K001S6elJHa]O6V<KGaX005lJ0P00
03IS6elJHa]O6V<KGaYS6`00JcX006/iIaU[>VLIJcUW6@00IaU[>FLI001W6F/iIaT006LIJcUW6F/i
IaU[>@00JcX006/iIaU[>FLI001W6F/iIaU[>FLIJcT006/iIaU[>FLIJcUW6F/i000[Ood00`00Ooeo
o@0SOod00`00Ooeoo@06Ood007Aoo@04001ooGomOod200000eLLEaeG7002Ea`015LMEaaG75LL0P00
00=O>`0000002Ulk00<006<kHcX00f<k00ES>V<kHc]S>f<j009S>`0@001S>`00HaYS>f<JHcYS6V<k
HaYS>P00Hc]S6V<jHaX20004HaX00`00HaYS6P07HaX01@00HaYS6V<JIaX00f<J00EW6V<JHaX006LJ
009S6P06001W6V<JIaYS6VLJ0P0000]S6VLJHaYW6V<JIaYS6VLJ001W6V<J00=W6P06HaYW6VLJIaYS
6P000VLJ01AS6P00HaYW6V<JIaYS6P00HaYW6V<JIaYS6VLJHaX006<J001S6VLJ0f<J00UW6V<JHaYS
6P00HaX006<JIaX00f<J00EW6P00001S6VLJ00=S6P03IaX005lK008000QO6`04001O6`000008Ga/0
1@00Ga/00000Fa/00elK00IK6elKGa/005/KFa`200002U/KFaaK6e/LFa]K75/K001K6e/L0P0000QK
6e/LFa]K75/K001K6e/L0e/K0P000U/K00MK75/K001K6elKFa]O6`0200002U/KGa]K6elK001O6e/K
Ga]K6elK0P0000UK6elKFa]O6`00Ga]K6elKFa/00P0000EO6e/KGa]K6`0000AO6`8000AO6`03001S
6elK009O6`09001O6elKGa]S6elK001O6f<K009O6`03001S6elK009O6`04Ha]O6`00Ga/20002Ga/0
2F<KGa]O6elKHa]O6`00Ga]S6`03Ga/05F<KGa]O6elKHa/006LiIaUW>FLIIcUW6@00IaUW>FLIIcUW
6@00IaT00003IaT03F/IIaUW6@00JaUW6@00IaU[6FLI001W6F/I00=W6@04JaT006LI0005IaT00`00
Ooeoo@0ZOod00`00Ooeoo@0SOod00`00Ooeoo@06Ood007Eoo@0?001ooGomOod005/mEaaK?ELLFceG
75/mEaaK?ELL0080000:GcaO6ellGa]O?5lKGcaO6ellGa/200002ell001S>elJHc]O6V<kGaYS>elJ
Hc/00P0000=O6V<kGaX00P0000AS>f<JIc]S6P800009Hc]S6V<kHaYS>f<JHc/006Lk0080000;HaYW
>f<JIcYS6VLkHaYW>V<J001S6P0200001VLjHaYW>V<JIcYS6P800010IcYS6VLjHaYW>P00IcYS6FLj
001W>V<IIcYS6VLjHaUW>V<JIcX006Lj001W6V<IIaYS6FLJHaUW6V<I001S6FLJHaUW6V<I001S6FLJ
HaT006<IIaYS6FLJHaUW6V<IIaYS6@00HaUW6V<JIaYS6FLJHaYW6V<I001S6VLJHaT200003VLJHaUW
6P00IaYS6FLJHaYW6V<IIaYS6VLJ0003Ga/01ElJGa]O6elKGaX00elK00D005lKGa]O6e/J00=O6`0?
FaYO6elKGa/005lLFa]O6e/KGaaK6elKFa]O75/K0080000:FaaK6e/LFa]K75/KFaaK6e/LFa/20000
2elLFa]K75/KGaaK6e/LFa/005/KFa`00P0000UK6e/LFa]O75/KFaaK6`00Fa/00P0000YO75/KGaaK
6elLFa]O7000GaaK6`800009GaaK6elLFa]O75/KGa`005lL00800009Fa]O75/KGaaK6elLFa/005/K
00800003Ga]K6elK009O6`04Fa]O6`00Ha/200002ElJHa]O6V<KGaYS6elJ001O6P0200004F<KGaYS
6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa/00P0000UO6P00GaYS6elJHa]O6V<KGaX00P0002aS
6`00JcYW6F/iIaT006LIJcUW6F/jIaU[>FLI001W6F/iIaU[>FLIJcT006/jIaU[>FLI001W6@00IaU[
>FLIJcUW6F/i001[>FLIJcX006/iIaU[>@00;Wom00<007omOod08Wom00<007omOod01Wom001fOod0
1000OoeooGom0P0000=G75LMEa`00ULL00EG7@00001G75LM008000MO>`03001O>ell009O>`800007
HcYS>f<kHc]S>V<k00001f<k00l006<k000006<JHc]S6V<jHaYS>f<JHcYS6V<k00002V<J00<006<J
HaX00V<J00P006<JHaYW6V<J001S6VLJ0f<J01IW6V<JHaX006LJ001W6V<JIaYS6VLJHaYW6V<JIaX0
06LJHaYW6P00IaYS6P=W6P80009W6P0DHaYW6VLJIaYS6P00HaX006<JIaYS6VLJHaYW6V<JIaYS6P00
HaX000=S6P03IaYS6V<J008000=S6P06IaYS6V<J001W6P000V<J00EW6V<JHaYS6VLJ009S6P03001S
6P0000QO6`800003Ga/005lK00MO6`800003Ga/005lK009O6`04Fa]O6elKGa/200002UlK001K6e/L
Fa]K75/KFaaK6e/L0P0000YK6`00Fa]K75/KFaaK6e/LFa]K70<00005FaaK6e/KFa]K7003Fa/03E/L
Fa/005/KGa]K6elKFa]O6e/KGa]K6elK0080000FFa]O6e/KGa]K6elKFa]O6e/KGa/005lKFa]O6e/K
Ga]K6elKFa]O6e/K000:Ga/00`00Ha]O6`02Ga/02F<KGa]O6elKHa]O6`00Ga]S6`03Ga/00f<KGa]O
6`02000015lK001O6f<K0elK00IS6`00Ga]O6f<K0002Ga/01F<KGa]O6elK00000elK014006LIIcUW
6@00IaUW>FLIIcUW6FLiIaT006LI001W6F/I009W6@03001[6FLI009W6@05JaUW6@00IaU[6@03IaT0
1F/I001W6FLIJaT00VLI00<006LI0000<7om00<007omOod08Gom00<007omOod01Wom001gOod20003
Ood00`00EaaK?@0300004e/mEaaK?ELLFceG7000Ga]O?5lKGcaO6`00Fa]O?5lKGcaK6ell0080000L
GaYS>elJHc/006<kGaYS>elJHc]O6V<kGaYS>`00Hc]S6V<kHaYS>f<JHc]S6V<kHaYS>`00Hc/20000
1V<JIcYS6VLkHaYW>P800006HaYW>V<JIc]S6VLj0P0003AS6P00HaYW>V<JIcYS6VLjHaYW>V<JIcX0
06LjHaUW>V<JIcYS6FLjHaYW>P00IcYS6VLjHaUW>P00IaYS6FLJ001W6V<IIaYS6FLJHaUW6V<IIaYS
6@00HaUW6V<IIaYS6FLJHaUW6P800003HaUW6V<I0080000FIaYS6VLJ001W6V<JIaYS6FLJHaYW6V<I
IaX006LJHaUW6V<JIaYS6FLJHaX2000016LJHaYW6P000elK00EO6UlK000005lJ00=O6`06001O6elK
Ga]K6UlK0P0000UK6UlKGa]O6`00GaaK6elKFa/00P0000AO6e/KGaaK6`800004FaaK6e/LFa/20000
2U/LFa]O75/K001K6elLFa]K75/K0P0000]K75/K001K6e/LFa]O75/KFaaK6elL00800009Fa/005/K
GaaK6elLFa]O75/K0080000:Ga`005lLFa]O75/KGaaK6elLFa/200002ElL001O75/KGaaK6elLFa]O
700200000e/K001K6`03Ga/00e/KGa]O6`0200002ElK001S6elJHa]O6V<KGaYS6`02000075lJ001O
6V<KGaYS6elJHa/006<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS6`00Ha]O6V<K0P0002eO6V<K
GaYS6elJ001W6@00IaU[>FLIJcYW6F/iIaT006LIJcT006/iIaU[>@00JcYW6F/iIaU[>VLI001W6@00
IaU[>FLIJcT006/iIaU[>VLIJcUW6F/j0000<Wom00<007omOod087om00<007omOod01Wom001iOod0
1000OoeooGom0P0000YG7ELLEaeG75LMEaaG7ELLEaeG70800005Gc/00000Gc]O?003Gc/01UllGc]O
>elk001S>P8000US>`0;001S>`00Hc]S6V<jHaYS>f<JHcYS6P0200001F<jHaYS>f<J000016<J00<0
06<JHaX026<J00<006<JIaX00f<J00iW6V<JHaYS6VLJ001S6P00IaYS6VLJHaYW6V<J0P0000YW6V<J
IaYS6VLJHaYW6P00IaX000=W6P05HaYW6VLJIaYS6P02IaX05@00HaX006<JIaYS6VLJHaYW6P00IaYS
6VLJHaYW6V<JIaX006<J001W6P03HaX02FLJHaYS6V<JIaX006<J001W6P03HaX00fLJHaX00006HaX0
0`00Ga]O6`020007Ga/00`00Ga]O6`020007Ga/01@00Ga/00000Fa/00elK00IK6elKGa]O6`00Fa`2
00002U/KFaaK6e/LFa]K75/K001K6e/L0P0000EK6e/LFa]K75/K00800004FaaK6e/KFa/20002Fa/0
1e/LFa/005/KGa]K6elK0080000:Fa]O6e/KGa/005lKFa]O6e/KGa/200002E/KGa]K6`00Fa]O6e/K
Ga]K6`0200001ElKFa]O6e/K00001ElK00<005lKGa/00UlK00<006<KGa/00UlK0P000UlK00ES6elK
001O6f<K009O6`03001S6elK009O6`04Ha]O6`00Ga/20002Ga/01V<KGa]O6elK001O6`800005Ha]O
6elKGa]S6`03Ga/04@00IaUW>FLIIcUW6FLiIaT006LIIcUW6FLi001W6@00JaT00fLI00I[6FLI001W
6F/I0002IaT01F/I001W6FLIJaT00fLI00=[6@00Ood0<Wom00<007omOod087om00<007omOod01Wom
001jOod0:000OoeooGom001G75/mEaaK?ELLFceG75/mEaaK?ELLFcd005llFa]O?5lKGcaK6ellGa]O
?5/KGcaO6`00GaYS>elJHc]O6V<kGaYS>elJ0P00019S>elJHc/006<kHaYS>f<JHc]S6P00HaYS>f<J
Hc]S6V<kHaX200006fLj001W>f<JIcYS6VLkHaYW>V<JIc]S6P00HaX006<JIcYS6VLjHaYW>V<JIcX0
06LjHaYW>P02000066<IIcYS6P00HaUW>V<JIcYS6FLjHaYW>V<IIcX006LJHaUW6V<IIaYS6FLJHaUW
6P80000KHaUW6V<I001S6FLJHaUW6P00IaYS6FLJHaUW6V<IIaYS6FLJ001W6V<JIaYS6FLJHaYW6V<I
0080000AIaYS6FLJ001W6V<IIaYS6P00HaUW6V<JIaYS6FLJHaYW6P020002Ga/01ElJGa]O6elKGaX0
0elK0P000UlK00EK6UlKGa]O6e/J00=O6`0G001O75/KGa]K6elLFa]O6e/KGaaK6elK001O75/KFaaK
6elLFa]K75/KGaaK6`0200002elLFa]K75/KGaaK6e/LFa]O7000Fa`00P0000UK6e/LFa]O75/KFaaK
6`00Fa/00P0000YO75/KGaaK6elLFa]O7000GaaK6`800009GaaK6elLFa]O75/K001K6elL00800009
Fa]O75/KGaaK6elL001O6e/K009O6`03001K6elK009O6`04Fa]O6`00Ha/200002ElJHa]O6V<KGaYS
6elJ001O6P0200006f<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<KGaYS6elJHa]O6P00GaYS6elJHa]O
6V<KGaYS6`0200009ElJ001W6F/jIaU[>FLI001W6F/iIaU[>VLIJcT006/jIaU[>FLIJcYW6@00IaU[
>VLIJcT006/i001[>FLIJcYW6F/iIaU[>P0003Eoo@03001ooGom01moo@03001ooGom00Ioo@00Ngom
00@007omOoeoo@800008EaeG75LMEaaG7ELLEaeG70800003Ecd005ll00=O>`05GcaO>elkGc]O?002
00000elk001S>`06Hc/00`00Gc]S>`02Hc/04elkHc/006<kHaYS>V<J001S6V<jHaYS>f<JHcYS6V<k
HaYS>P0000US6P800006HaYS>V<J001S6VLJ0f<J0P000V<J01IW6V<JHaYS6P00HaX006<JIaYS6VLJ
HaYW6V<JIaYS6VLJ001S6P00IaYS6P=W6P0;HaYW6P00IaYS6VLJHaYW6V<J001S6P02000036LJHaYW
6V<JIaYS6VLJHaYW6P00IaX0009S6P05IaYS6V<JHaX00003HaX01FLJHaYS6P00IaX00P0026<J00<0
06<J000025lK0P0000=O6`00Ga/01elK0P0000=O6`00Ga/00UlK00EK6elKGa]O6e/K00800009Ga/0
05/LFa]K75/KFaaK6e/L0080000>Fa/005/KFaaK6e/LFa]K75/KFaaK6e/L001K70=K6`0AFaaK6e/K
Fa]K75/K001K6elKFa]O6e/KGa]K6elKFa]O6`0200002E/KGa]K6elKFa]O6e/KGa]K6`0200002elK
Fa]O6e/KGa]K6elKFa]O6`00Ga/00P0025lK00<006<KGa/00UlK00US6elKGa]O6f<KGa/005lKHa/0
0elK00=S6elKGa/00P0000AO6`00Ga]S6`=O6`05Ha/00000Ga/00003Ga/01F<KGa]O6`00Ha/00elK
00h006LIIcUW6@00IaUW>FLIIcUW6FLi001W>@000VLI00E[6FLI001W6F/I00=W6@05JaT006LIIaU[
6@03IaT00f/I001oo@0fOod00`00Ooeoo@0OOod00`00Ooeoo@05Ood007aoo@03001ooGom009oo@06
001K?ELLFceG75/m0P0000AG75LmEaaK?@800005Fa]O?5lKGcaK6`02000015llFa]O?5lK0P0000mS
>elJHc]O6P00GaYS>elJHc]O6V<kGaYS>`00Hc/00P0003=S6V<kHaYS>f<JHc]S6V<kHaYS>`00Hc/0
06LjHaYW>f<JIcYS6VLk001S>f<JIc]S6V<kHaX006<JIcYS6P00HaYW>V<JIcYS6VLjHaYW>V<J001S
6FLjHaYW>V<IIcYS6VLjHaT00P0000=W>V<IIcX00P0001MS6FLJHaUW6P00IaYS6FLJHaUW6V<IIaYS
6@00HaUW6V<IIaYS6FLJHaUW6V<I0080000PIaYS6FLJ001W6V<JIaYS6@00HaYW6V<IIaYS6VLJHaUW
6P00IaYS6FLJHaYW6V<IIaYS6VLJ001W6V<JIaX000=O6`05GaYO6elK001O6P03Ga/01P00Ga]O6elK
FaYO6`80000:FaYO6elKGa/005lLFa]O6e/KGa`200002E/KGaaK6elK001O75/KFaaK6`02000035/L
Fa]O75/K001K6elLFa]K75/KGaaK6`800009Ga`005/LFa]O75/KFaaK6elL00800009Fa/005/KGaaK
6elLFa]O75/K00800009Ga`005lLFa]O75/KGaaK6elL0080000?Fa/005/KGaaK6elLFa]O75/KGaaK
6elL001O6e/K00=O6`03Fa]O6elK00800009Ga/006<KGaYS6elJHa]O6V<K0080000AGaX005lJHa]O
6V<KGaYS6`00Ha]O6V<K001S6elJHa]O6P020000<6<KGaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaYS
6elJ001W6@00IaU[>FLIJcYW6F/i001[>VLI001W6F/jIaT006LIJcYW6F/iIaU[>P00JcT006/jIaU[
>FLIJcX003Qoo@03001ooGom01moo@03001ooGom00Eoo@00OGom0P000gom00<005LMEa`00P0000UG
?ELLEceG75LmEaaG?ELL00000Ulk0P0000YO>ellGc]O?5lkGcaO>ell001S>`800005Gc]S>f<kHc]O
>`03Hc/03ElkHc/006<kHaYS>V<JHc]S6V<jHaYS>f<J00800003Hc]S6V<k008000AS6P0<001S>V<J
HcYS6V<jHaYS>V<J001S6P000f<J015W6V<JHaYS6VLJHaX006<J001S6VLJHaYW6V<JIaYS6P0000=S
6P06IaYS6V<JHaX006<J0P0001]W6V<JIaYS6VLJHaYW6V<J001S6P00HaYW6V<JIaYS6VLJHaX006<J
IaYS6VLJHaYW6P00HaX00P000f<J00QW6V<JHaYS6VLJ001S6P001V<J0P001F<J00<005lKGa/00UlK
00<005lKGa/015lK00<005lKGa/00P001elK00<005lKGa/00P000elK00IK6elKGa]O6`00Fa`20000
35/KFaaK6e/LFa]K7000FaaK6e/LFa]K70800006Fa]K75/KFa`005/L0e/K0P000U/K00MK75/K001K
6elKFa]O6`0200005e/KGa]K6elK001O6e/KGa]K6elK001O6e/KGa]K6`00Fa]O6e/KGa]K6elKFa/0
0P0000=O6`00Ga/01ElK00L005lKGa]O6`00Ga]S6`03Ga/20002Ga/01V<K001O6elKHa]O6`800007
Ha]O6elKGa]S6`00Ga/00P000elK00IS6elKGa]O6`00Ga/200001F<KGa]O6elKHa/00elK014006LI
IcUW6FLiIaUW>@00IcUW6FLiIaT006LI001W6F/I00=W6@06JaT006LIIaU[6@000VLI00=[6@00Ood0
>Gom00<007omOod07Wom00<007omOod01Gom001oOod01000OoeooGom0P0000]G75/mEaaG?ELLFceG
75LmEaaK?ELL0080000FGcaO6ellFa]O?5lKGcaK6ellGa]O?000Hc]O6V<kGaYS>elJHc]O6V<kGaX2
000056<k000006<JHc]S6V<kHaYS>f<J001S6V<kHaYS>f<JHc]S6P00HaX2000066<kHaYW>f<JHc]S
6VLkHaYS>f<J001S6VLjHaYW>V<JIcYS6VLjHaX006<JIc]S6P80000LIcYS6VLjHaT006<JIcYS6FLj
HaYW>V<IIcYS6P00HaUW6V<IIaYS6FLJHaUW6V<I001S6FLJHaT200006fLJHaUW6V<I001S6FLJHaUW
6V<IIaYS6FLJ001W6V<JIaYS6FLJHaYW6V<IIaX006LJHaUW6P0200003V<IIaYS6P00HaUW6V<JIaYS
6FLJHaYW6P00Ga/200001ElJGa]O6elKGaX00elK0P000UlK00EK6UlKGa]O6e/J00=O6`80000GFa]O
6e/KGaaK6elKFa]O75/KGa/005lLFa]K75/KGaaK6e/LFa]O7000FaaK6`0200002E/LFa]O75/KFaaK
6elL001K700200002E/KFaaK6elLFa]K75/K001K6`0200005elLFa]O75/KGaaK6`00Fa]O75/KGa`0
05lLFa]O75/KGa`005lLFa]O75/KGa`00P0000AK6elLFa/0009O6`05Fa]O6`00001K6`03Ga/015/K
001O6V<K0P0000QO6V<KGaYS6elJHa/006<K0P0001aO6V<KGaYS6elJHa]O6V<K001S6elJHa]O6V<K
GaYS6elJHa]O6P00GaYS6elJHa]O6V<KGaYS6`80000MGaX006LIJcYW6F/i001[>VLIJcYW6F/jIaT0
06LIJcYW6F/iIaU[>P00JcUW6F/jIaU[>@00JcX0000lOod00`00Ooeoo@0MOod00`00Ooeoo@05Ood0
081oo@04001ooGomOod2000025LLEceG75LmEaaG?ELLEcd200002eLM000005llGc]O?5lkGcaO>ell
Gc/00P0000=O?00000000V<k00IO>f<kHc]S>elk0002Hc/095lkHc]S>`00HaYS>V<JHc]S6P00HaYS
>f<JHc]S6V<kHaYS>f<J001S6V<jHaYS>V<JHcYS6V<jHaYS>V<J001S6P00HaYW6P=S6P03IaX00000
00IS6P04001W6P000003HaX03fLJHaYS6V<JIaYS6P00HaX006<JIaYS6VLJHaYW6P02000026<JIaYS
6VLJHaYW6P00IaX200002f<JIaYS6VLJHaYW6V<JIaX006LJ00000V<J00AW6V<JHaYS6P80009S6P07
IaYS6V<JHaX006<J00002V<J00<005lKGa/01UlK0P0000=O6`00Ga/01elK0P0000=O6`00Ga/00UlK
00EK6elKGa]O6e/K0080000:Ga/005/LFa]K75/KFaaK6e/LFa/3000035/KFaaK6e/LFa]K75/KFaaK
6e/L001K70=K6`0BFaaK6e/KFa]K75/K001K6elKFa]O6e/KGa]K6elKFa/005/K0P0000YO6e/KGa]K
6elKFa]O6`00Ga]K6`800008Ga]K6elKFa]O6e/K001O6`8000QO6`800005Ha]O6elKGa]S6`03Ga/0
1F<K001O6elKHa/00elK00IS6elK000006<K0002Ga/01F<KGa]O6elKHa/00P0000=O6`00Ga/00UlK
00ES6elKGa/006<K009O6`0>001W>FLIIcT006LiIaUW>FLIIcUW6@00IaT000=W6@05JaT006LIIaU[
6@03IaT00f/I001oo@0mOod00`00Ooeoo@0LOod00`00Ooeoo@05Ood0085oo@03001ooGom009oo@06
001G75/mEaaG?ELL0P0000]G?ELLFceG75Lm001O?5lKGcaK6ell0080000CFc]O?5/kGcaK>`00GaYS
>elJHc]O6P00GaYS>elKHc]O6V<kGa/00P0001MS>`00001S6V<kHaYS>f<JHc]S6V<kHaX006<J001S
6VLkHaYS>f<JIc]S6V<k00800003HaYS>f<J0080000GIcYS6VLj001W>V<JIc]S6VLjHaYW>f<JIcX0
06LjHaYW>V<IIcYS6VLjHaUW>P0200000f<JIcYS6P0200006fLJHaUW6P00IaYS6FLJHaUW6V<IIaYS
6FLJ001W6V<IIaYS6FLJHaUW6V<IIaX006LJHaUW6P0200006f<JIaYS6@00HaYW6V<IIaYS6VLJHaUW
6V<J001S6FLJHaYW6V<IIaYS6VLJHaUW6P00IaX00003Ga/01ElJGa]O6`00GaX00elK00D005lKGa]O
6e/J009O6`03001K6UlK009O6`06001O75/KGa]K6elL0P0000YK6elLFa]O6`00GaaK6e/LFa]O7080
000;Fa]O7000FaaK6elLFa]K75/KGaaK6`0200002ElL001K75/KGaaK6e/LFa]O700200005U/K001K
6elLFa]O75/KGaaK6elLFa/005/KGaaK6elLFa]O75/KGaaK6elL0P0000YK6elLFa]O75/KGaaK6elL
Fa/0009O6`06Fa]O6elKGa]K6elK0P0000UK6`00GaYS6elJHa]O6V<KGaX00P00019S6`00Ha]O6V<K
GaYS6elJ001O6V<KGaYS6`00Ha]O6V<KGaX2000026<KGaYS6`00Ha]O6V<KGaX200007V<KGaYS6elJ
Ha/006/i001[>VLIJcYW6F/jIaT006LIJcX006/iIaU[>P00JcUW6F/jIaU[>FLIJcX003moo@03001o
oGom01aoo@03001ooGom00Eoo@00PWom0P000gom0P0000]G?@00001G75LmEaeG?ELLEceG7ELm0080
000;Gc/00000GcaO>ellGc]O?5lkGcaO>`0200000f<k00000002Hc/01ElkHc]S>f<kGc/00f<k00X0
06<kHaYS>f<JHc]S6V<kHaYS>`80000EHaYS>f<J001S6V<jHaYS>V<JHcX006<jHaYS>V<JHcYS6V<j
001W6P0000US6P03001S6P00009S6P06IaYS6V<JHaYW6P000V<J01YW6V<JHaYS6VLJ001W6P00IaYS
6VLJHaYW6V<JIaYS6VLJ001W6P00IaYS6VLJHaYW6V<J0P0000UW6V<JIaYS6VLJHaX006<J00000f<J
00UW6V<JHaYS6VLJHaX006<J00001f<J0P000f<J00<005lKGa/00UlK00<005lKGa/015lK00<005lK
Ga/00UlK00<005lKGa/015lK00<005lKGa/00P000elK00MK6elKGa]O6`00FaaK6`0200002e/LFa]K
75/KFa`005/LFa]K75/KFa`00P0000IK6e/LFa]K7000Fa`3Fa/20002Fa/02E/LFa/005/KGa]K6elK
Fa]O6`0200002E/K001K6elKFa]O6e/KGa]K6`0200002ElK001O6e/KGa]K6elKFa]O6`0200000e/K
001O6`05Ga/00`00Ga]O6`02Ga/00`00Ga]S6`02Ga/20003Ga/02F<K001O6elKHa]O6`00Ga]S6`03
Ga/00f<K001O6`020003Ga/01F<KGa]O6`00Ha/00P0000=O6f<KGa/00UlK019S6elKGa/006LiIaUW
>FLIIcUW6@00IaUW>FLIIcT006/I0002IaT01V/IIaUW6FLIJaT0045oo@03001ooGom01]oo@03001o
oGom00Eoo@00Q7om00<007omOod00Wom02D005/mEaaG?ELLFceG75LmEaaK?ELLEceG7000Fc]O?5/k
GcaK>ellFc]O?5/kGcaK>ell001S>elJHc]O6f<kGaYS>elKHc]O6P020000;F<k001S>f<JHc]S6V<k
HaYS>`00Hc]S6V<kGaYS>f<J001S6VLkHaYS>`00Ic]S6V<kHaYW>f<JHc]S6VLk001W>V<JIc]S6VLj
HaYW>f<JIcX006LkHaYW>P0200005f<JIcYS6FLj001W>V<JIcYS6VLjHaYW>V<JIcX006LJHaUW6V<I
IaYS6FLJHaT00P0000=W6V<IIaX00P0001IS6FLJHaT006<IIaYS6FLJHaUW6V<IIaYS6@00HaYW6V<I
IaYS6VLJHaUW6P80000BHaYW6V<J001S6FLJHaYW6V<I001S6VLJHaYW6V<JIaX005lK0P0000EO6UlK
Ga]O6elJ00=O6`05001O6`00001K6P03Ga/015/JGa]O6elK0P0000YK6elKFa]O75/KGa]K6elLFa]O
6`80000;Fa]K75/KGaaK6e/LFa]O7000FaaK6`0200002E/LFa]O75/KFaaK6elL001K700200002e/K
GaaK6elLFa]O7000GaaK6elLFa/00P0000UO75/KGaaK6`00Fa]O75/KGa`00P0000UK6elLFa]O7000
GaaK6elLFa/00P0000EO75/KGaaK6`00009O6`05Fa]O6`00Ga]K6`03Ga/00e/K001O6P0200002F<K
GaYS6elJHa]O6V<K001S6`0200006elJHa]O6V<KGaYS6elJHa/006<KGaYS6elJHa]O6V<KGaYS6`00
Ha]O6V<KGaYS6elJHa]O6P0200005V<K001[>VLIJcYW6@00IaU[>VLIJcYW6F/j001[>FLIJcYW6F/i
IaU[>P00@gom00<007omOod06gom00<007omOod017om0025Ood00`00Ooeoo@02Ood02P00EceG7ELm
EaaG?ELMEceG75Lm0P0000]G7000Gc]O?5lkGcaO>ellGc]O?5lk00800004Gc`006<kGc/3Hc/025lk
Hc]S>`00Gc]S>elkHc/200003f<JHc]S6V<k001S>f<JHc]S6V<kHaYS>f<J001S6P02000036<jHaYS
>V<JHcYS6V<jHaYS>P00HcX000IS6P8000IS6P04001S6P000002HaX01FLJHaYS6V<JIaX00V<J0280
06LJ001W6V<JIaYS6VLJHaX006<JIaYS6VLJHaYW6V<J001S6P00HaYW6V<JIaYS6VLJHaYW6V<J001S
6P00HaYW6P=S6P03IaX006<J00AS6P03001S6V<J009S6P03001S6V<J00IS6P03001O6elK00UO6`03
001O6elK00IO6`800003Ga/005lK009O6`05Fa]O6elKGa]K6`0200002UlK001K75/KFaaK6e/LFa]K
75/K0`0000aK6e/LFa]K75/KFaaK6e/LFa]K7000Fa`3Fa/01e/LFa]K6e/KFa`005lK00800009Fa]O
6e/KGa]K6elKFa/005/K00800009Ga]K6elKFa]O6e/KGa/005lK00800009Fa]O6e/KGa]K6elKFa/0
05lK008000QO6`03001O6f<K00=O6`06Ha]O6elKGa]S6`000UlK00IS6elKGa]O6f<KGa/200001F<K
001O6elKHa/00elK0P0000=O6`00Ha/00elK01ES6elK001O6f<KGa/006LIIcUW6@00IaUW>FLIIcUW
6FLi001W6@00JaT00fLI00=[6@00Ood0@gom00<007omOod06gom00<007omOod017om0026Ood00`00
Ooeoo@02Ood200001ELLEceG75/mEa`00P0000AG?ELLEceG70800005GcaK>ellFc]O?002000015/k
GcaK>ell0P0000AO6V<kGa]S>`800009Ga]S>elJHc]O6f<kGaX006<J0080000DHc]S6V<kGaYS>f<J
Hc]O6V<kHaX006<JIc]S6V<kHaYW>f<JHc]S6P800003Hc]S6VLk0080000GHaYW>f<J001S6VLkHaYW
>V<JIc]S6VLjHaX006<JIcYS6VLjHaYW>V<JIcYS6P0200006fLjHaYW>P00IaYS6FLJHaT006<IIaYS
6FLJHaUW6V<IIaYS6@00HaUW6V<IIaYS6FLJHaUW6P0200004V<JIaYS6@00HaYW6V<IIaX006LJHaYW
6V<JIaYS6VLJ001W6P80000;HaYW6V<JIaYS6VLJHaYW6P00IaX00003Ga/01ElJGa]O6elKGaX00P00
00=O6`00Ga/00UlK00EK6UlKGa/005/J00=O6`06001O75/KGa]K6elL0P0000YK6elLFa]O6`00GaaK
6e/LFa]O7080000;Fa]O7000FaaK6elLFa]K75/KGaaK6`0200002UlL001O75/KGaaK6elLFa]O75/K
0P00025O75/KGaaK6elLFa]O75/KGaaK6`00Fa]O75/KGaaK6elLFa]O75/KGa`005lLFa]O75/KGaaK
6elLFa]O75/K00000UlK00IK6elKGa]O6e/KGa/200002E/K001O6V<KGaYS6elJHa]O6P0200004F<K
001S6elJHa]O6V<KGaX005lJHa]O6P00GaYS6elJHa/00P00025O6V<KGaYS6`00Ha]O6V<KGaX005lJ
Ha]O6V<KGaX006LI001W6F/jIaU[>VLIJcX006/jIaU[>P00JcUW6F/j0000AWom00<007omOod06Wom
00<007omOod017om0027Ood20004Ood00`00EaeG?@0200002eLMEceG75LmEaeG?ELLEcd005llGc/0
0P0000=O?5lkGc`00Ull00EO>ellGc`005lk0080000EHc]O>f<kGc]S>elkHc]O>f<kGc/006<JHc]S
6V<kHaYS>f<JHc]S6V<k0080000DHa/006<JHcYS6V<jHaYS>V<J001S6V<jHaYS>V<JHcYS6P00HaX0
00US6P05001S6P00HaYW6P03HaX01FLJHaX006<JIaX00f<J00=W6P00IaX00P0001]S6VLJHaYW6V<J
IaYS6VLJHaX006<J001S6VLJHaYW6V<JIaX006LJHaYW6V<JIaYS6P00HaX00P002F<J00<006<JHaX0
1f<J00D006<JHaYS6P0000EO6`8000AO6`03001O6elK009O6`03001O6elK00AO6`03001O6elK0080
00=O6`07Fa]O6elKGa/005/LFa/00P0000]K75/KFaaK6e/L001K75/KFaaK6e/L00800006Fa]K75/K
001K6e/L0e/K00eK7000001K6e/L001O6e/KGa]K6elKFa]O6`0200002E/K001K6elKFa]O6e/KGa]K
6`0200002ElK001O6e/KGa]K6elKFa]O6`0200000e/K001O6`05Ga/00`00Ga]O6`02Ga/00`00Ga]S
6`02Ga/20003Ga/01@00Ga]O6elKHa/00P0000=O6f<KGa/00UlK00D005lK000006<K00=O6`05Ha]O
6elK001S6`0200000elKHa]O6`02Ga/02V<KGa/006LIIcUW6FLiIaUW>@001FLI00<006/I0000B7om
00<007omOod06Gom00<007omOod017om0029Ood00`00Ooeoo@02Ood200002eLmEaaG?ELLEceG75Lm
EaaG?ELLEcd00P0001IK>ellFc]O?5/kGcaK>ellFc]O?5/k001O6V<kGa]S>elJHc]O6f<kGaYS>`80
000?Ga/006<JHc]O6V<kHaYS>elJHc/006<kGaYS>f<J0080000LIc]S6V<kHaX006<JHc]S6VLkHaYS
>f<JIc]S6P00HaYW>f<JIcYS6VLkHaYW>V<J001S6VLjHaX20000?VLjHaYW>V<J001S6VLjHaYW>V<J
IcYS6VLj001W6V<IIaYS6FLJHaUW6V<IIaYS6@00HaUW6V<J001S6FLJHaUW6P00IaYS6VLJHaUW6V<J
IaYS6@00HaYW6V<JIaYS6VLJHaYW6V<JIaX006LJ001W6V<JIaYS6VLJHaX200001VLJHaYW6V<JIaX0
009O6`8000=O6`06GaYO6elKGa/005lK0P0000EK6UlKGa]O6e/J00=O6`80000:Fa]O6e/KGaaK6elK
Fa]O75/KGa/200002e/KFaaK6elLFa]K75/KGa`005/LFa/00P0000UK75/KGaaK6e/LFa/005/KGa`0
0`0000YO75/KGaaK6elL001O75/KGaaK6`800009GaaK6elLFa/005/KGaaK6elL00800009Fa]O75/K
Ga`005lLFa]O75/K00800005GaaK6elKFa/00002Ga/01E/KGa/005lKFa/00elK00=K6`00GaX00P00
00QS6elJHa]O6V<KGaX005lJ0P0001]S6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaYS
6`00Ha]O6V<KGaYS6elJHa/00P0000mO6P00IaU[>VLIJcX006/jIaU[>VLIJcYW6F/j0000BWom00<0
07omOod067om00<007omOod017om002:Ood00`00Ooeoo@02Ood2000025LmEaaG?ELMEceG75LmEad2
000015Lm000005lk0ell00AO>ellGcaO?080000;Gc`005lkHc]O>f<kGc]S>elkHc/00002Gc/026<k
Gc/00000Hc]S6V<kHaX200002F<kHa]S>f<JHc]S6f<k001S>P02000036<JHcYS6V<jHaYS>V<JHcYS
6P00HaX000IS6P8000IS6P06001W6P00001S6VLJ0f<J01IW6V<JHaX006LJ001W6V<JIaYS6VLJHaYW
6V<J001S6VLJHaYW6V<J001S6P80000;IaYS6VLJHaYW6V<JIaYS6P00HaX00008HaX01000HaYS6V<J
0P000f<J00<006<JHaX01V<J0P002UlK00<005lKGa/01UlK0P0000=O6`00Ga/00UlK00EK6elKGa]O
6e/K0080000:Ga/005/LFa]K75/KFaaK6e/LFa/300002E/KFaaK6e/LFa]K75/KFaaK6`0200001E/L
Fa]K6e/KFa`00e/K00=K7000Ga/00P0000UK6elKFa]O6e/KGa]K6`00Fa/00P0000UO6e/KGa]K6elK
Fa]O6`00Ga/00P0000UK6elKFa]O6e/KGa]K6`00Ga/00P0025lK00<005lKHa/00elK00ES6elKGa]O
6`0000=O6`05Ha]O6elKGa]S6`0200000elK001O6`02Ga/016<KGa]O6elK0P0000=O6`00Ha/00elK
0P000UlK00IS6`00IcUW6FLi0007IaT00`00Ooeoo@19Ood00`00Ooeoo@0HOod00`00Ooeoo@04Ood0
08]oo@03001ooGom00=oo@06001G?ELLEceG75Lm0P0000]G75LmEaaG?ELL001K>ellFc]O?5/k0080
0004GcaK6ellFa/2000016<kGa]S>elJ0P0000US>elKHc]O6f<kGa]S>`00Hc/00P0001AS6V<kGaYS
>f<JHc]O6V<kHaYS>`00Ic]S6V<kHaYW>f<JHc]S6VLk0P0000=S6V<kHaX00P00025W>f<JIcX006Lk
HaYW>V<JIc]S6VLjHaYW>`00IcYS6VLjHaYW>V<JIcYS6VLj001W>V<JIcX006LJHaUW6V<IIaX00P00
01]S6FLJHaYW6V<IIaYS6P00HaUW6V<JIaYS6FLJHaYW6V<I001S6VLJHaT006<JIaYS6VLJHaX00P00
01AW6V<JIaYS6VLJHaX006<J001S6VLJHaYW6V<JIaYS6VLJ001W6P000elK00EO6UlKGa]O6elJ0080
0003Ga/005lK009O6`05FaYO6elK001K6P03Ga/2000015/KGa]K6elL0P0000YK6elLFa]O6`00GaaK
6e/LFa]O7080000:Fa]O7000FaaK6elLFa]K75/KGa`200002e/K001K6elLFa]O75/KGaaK6elLFa/0
0P00025O75/KGaaK6elLFa]O75/KGaaK6`00Fa]O75/KGaaK6elLFa]O75/KGa`005lKFa]O75/KGa]K
6elLFa]O6e/K00000UlK00IK6elKGa]O6e/KGa/2000025/K001O6V<KGaYS6elJHa/200004UlJ001O
6V<KGaYS6elJHa/006<KGaYS6`00Ha]O6V<KGaYS6`800006GaYS6elJHa/006<K0P00015O6V<KGaYS
6elJHa/006/j001[>VLIJcYW6F/jIaU[>P0004eoo@03001ooGom01Moo@03001ooGom00Aoo@00S7om
0P0017om0P0000]G7000001G?ELLEceG7ELmEaaG?ELM00800004Gc`00000Fc/3Gc`01U/kGcaO?5ll
001S>`8000=O>`05Hc]O>elkGc]S>`02Gc/02`00Hc]S6V<kHa]S>f<JHc]S6f<kHaX00P0001AS>`00
HcYS6V<jHaYS>V<JHcX006<jHaYS>f<JHcYS6V<k001S6P002F<J00@006<J001W6P=S6P05IaYS6V<J
001W6P03HaX07fLJ001W6V<JIaX006LJHaYW6V<JIaYS6VLJHaX006<J001S6VLJHaYW6V<JIaYS6P00
HaYW6V<JIaYS6P0000=S6P03001S6V<J00MS6P03001S6V<J00IS6P04001S6V<JHaX20004Ga/20004
Ga/00`00Ga]O6`02Ga/00`00Ga]O6`05Ga/01000Ga/000000elK00MK6elKGa]O6`00FaaK6`020000
2U/LFa]K75/KFa`005/LFa]K75/K0P0000MK75/KFaaK6`00Fa]K7003Fa/03E/L000005/KFa`005lK
Fa]O6e/KGa]K6elK00800009Fa/005/KGa]K6elKFa]O6e/K00800009Ga/005lKFa]O6e/KGa]K6elK
00800003Fa/005lK00EO6`05001O6elKGa/00002Ga/01F<KGa/00000Ha/00elK00H005lKGa]O6f<K
0002Ga/01V<KGa]O6`00Ha]O6`800005Ha]O6elKGa]S6`02Ga/00`00Ha]O6`02Ga/01V<KGa]O6elK
Ha/000MW6@03001ooGom04eoo@03001ooGom01Ioo@03001ooGom00Aoo@00SWom00<007omOod00gom
00`005LLEceG75LmEaaG?ELLEceG75LmEa`200005UllFa]O?5/KGcaK6ellFa]O?5/KGc`006<kGa]S
>elKHc]O6f<kGa]S>elK0P0000mS?000Hc]O6V<kHaYS>elJHc]S6P00GaYS>elJHc/00P0001MS6V<k
HaYW>`00Hc]S6V<kHaYS>f<JHc]S6V<k001W>f<JIcYS6VLkHaYW>V<J00800012IcYS6VLk001W>V<J
IcYS6VLj001W>V<JIcYS6VLjHaYW>P00IaX006LJHaUW6V<JIaYS6FLJHaX006<IIaYS6P00HaUW6V<J
IaYS6@00HaYW6V<IIaYS6VLJHaT006<J001S6VLJHaYW6V<JIaYS6VLJHaX006<J001S6VLJHaYW6V<J
0P0000QW6V<JIaYS6VLJHaX005lK0P000elK00IO6UlKGa]O6`00Ga/200001E/JGa]O6elKFaX00elK
00aK6P00Fa]O6e/KGaaK6elKFa]O75/KGa/200002U/KFaaK6elLFa]K75/KGa`005/L0P0000YK6e/L
Fa]O75/KFaaK6`00Fa]O70<0000:GaaK6elLFa/005/KGaaK6elLFa/200002ElLFa]O7000GaaK6elL
Fa]O700200002E/KGa]K6`00Fa]O6e/KGaaK6`02000015lLFa]O6`000elK00EK6`00001O6e/K00=O
6`0=001S6`00001O6V<KGaYS6elJHa]O6P00GaX00P0000MS6elJHa]O6V<KGaYS6`0200001elJHa]O
6V<KGaYS6elJ00800008Ha/006<KGaYS6elJHa]O6P800008Ha/006/jIaU[>VLIJcX0055oo@03001o
oGom01Ioo@03001ooGom00=oo@00Sgom00<007omOod00gom0P0000MG?ELMEceG75LmEaeG?@020000
0eLMEcd00003Gc`01E/kGcaO?5llFc/00P0000EO?000001O>f<k00=O>`05Hc]O>`00Gc]S>`02Gc/2
000016<JHc]S6f<k0P0000US6f<kHaYS>f<KHc]S6P00HaX00P0000aS>V<JHc]S6V<jHaYS>f<JHcX0
06<k0006HaX00`00HaYS6P04HaX01P00IaYS6V<J001W6P=S6P0SIaYS6V<JHaYW6P00IaYS6VLJHaYW
6V<JIaYS6P00HaYW6V<JIaYS6P00HaYW6V<J001S6VLJHaYW6V<JIaYS6VLJHaX00008HaX20003HaX0
1@00HaYS6V<J00002F<J00<005lKGa/025lK00<005lKGa/01elK0P0000EO6`00Ga]O6e/K00=O6`0=
Fa/00000Ga/005/LFa]K75/KFaaK6e/LFa/00P0000YK75/KFaaK6e/LFa]K75/KFaaK6`800005FaaK
6e/KFa]K7003Fa/00`00Fa]O6`0200002E/KGa]K6elKFa]O6`00Ga]K6`0200002ElKFa]O6e/KGa]K
6`00Fa]O6`02000025/KGa]K6elKFa]O6`00Ga/20008Ga/01000Ga]O6f<K0elK00ES6elKGa]O6`00
00=O6`04Ha]O6elKGa/200000elK001S6`03Ga/02F<KGa/005lKHa]O6`00Ga]S6`02Ga/20003Ga/0
0f<K001W6@02IaT00`00Ooeoo@1@Ood00`00Ooeoo@0FOod00`00Ooeoo@03Ood0091oo@03001ooGom
00Aoo@800003EaaG?@0000800005EceG75LmEaaG?@02000015/KGcaK6ell0P0001EK6ellFa]O?5/K
001O6f<kGa]S>elK001O6f<lGa]S>elKHcaO6`00GaX00P0001AS>elJHc]O6V<kGaYS>elJHc]O6P00
HaYS>f<JHc]S6V<kHaYS>f<J0P0005US>f<JHc/006LkHaYW>V<J001S6VLjHaYW>f<JIcYS6VLk001W
>P00IcYS6VLjHaYW>V<JIcYS6VLj001W>P00IaYS6VLJHaUW6V<J001S6FLJHaYW6V<IIaYS6P00HaT0
06<JIaYS6FLJHaYW6V<IIaYS6P00HaT006<JIaYS6VLJHaYW6P00IaYS6VLJHaYW6V<J001S6P00HaYW
6V<JIaYS6VLJHaYW6V<J001S6P00009O6`05GaYO6elKGa]O6P0200000elK001O6`02Ga/01E/JGa]O
6elK00000elK019K6P00Fa]O6e/KGaaK6`00Fa]O75/KGa/005lLFa]K75/KGa`200002U/KGa`005/L
Fa]O75/KFaaK6elL0P0000YK6`00Fa]O75/KGaaK6elLFa]O70<00009GaaK6elLFa]O75/KGaaK6elL
00800009Fa]O75/KGa]K6elLFa]O6e/K0080000:Ga]K6elLFa]O6e/KGaaK6elK0003Ga/01E/KGa]O
6elKFa/00P0000UO6`00Ha]O6V<KGaYS6elJHa/00P0001UO6P00GaYS6elJHa]O6P00GaYS6elJHa/0
06<KGaYS6elJ001O6V<KGaYS6elJ001O6P0200002V<KGaYS6elJHa]O6V<K001[>P00E7om00<007om
Ood05Gom00<007omOod00gom002AOod00`00Ooeoo@05Ood2000035LmEaaG?ELMEceG75LmEaeG?ELL
001O?0800008GcaK?5llFcaO?5/lGcaK?0800005Hc/00000Gc]S>`03Gc/03f<kGc]O>elk001S6V<k
Ha]S>f<JHc]S6f<kHaYS>`0200004V<K001S6V<kHaYS>V<JHc]S6P00HaYS>f<JHcYS6V<k001S6P80
00YS6P03001W6V<J009S6P06IaYS6V<JHaYW6P000V<J01UW6P00001S6VLJHaX006<JIaYS6VLJHaYW
6V<JIaYS6P00HaYW6V<JIaYS6VLJHaYW6P02000016<JIaYS6P0016<J00<006<JHaX01V<J00<006<J
HaX01V<J0P000f<J00<005lKGa/00UlK0P0015lK00<005lKGa/00UlK0P001ElK00H005lKGa]O6e/K
0002Ga/01e/KGa]O6elK001K75/K0080000:FaaK6e/LFa]K7000FaaK6e/LFa/200001e/LFa]K75/K
001K6e/L00=K6`80009K6`08001K6elKFa]O6e/KGa]K6`800009Ga/005lKFa]O6e/KGa]K6elK0080
0009Fa/005/KGa]K6elKFa]O6e/K00800003Ga/005lK00EO6`03001O6elK009O6`05001O6elKHa]O
6`0200001F<KGa]O6`00Ha/00elK00D005lKGa]O6f<K009O6`06001S6`00001O6f<K0elK00ES6elK
001O6f<K00=O6`06Ha]O6elKGa]S6`00EWom00<007omOod057om00<007omOod00gom002BOod20006
Ood02`00EaaG?ELLEceG75LmEaaG?ELLEcd00P0001IK6ellFa]O?5/KGcaK6ellFa]O?5/KGc`006<k
Ga]S?5lKHc]O6f<lGa]S>`80000?Ga/005lJHc]O6V<kGaYS>elJHc/006<kGaYS>elJ0080000HHc]S
6V<kHaX006<JHc]S6V<kHaYS>f<JHc/006LkHaYW>V<JIc]S6VLjHaYW>f<J0P0000QW>`00IcYS6VLj
HaYW>V<J0P0002AW>V<JIcYS6VLjHaX006<J001S6FLJHaYW6V<IIaYS6VLJHaT006<J001S6FLJHaYW
6V<IIaX006LJHaUW6V<JIaYS6@00HaX200006VLJHaYW6V<JIaYS6VLJHaX006<J001S6VLJHaYW6V<J
IaX006LJHaYW6V<JIaYS6P00Ga/20003Ga/01UlJGa]O6elK001O6`800005FaYO6elKGa]K6P03Ga/0
3000Ga`00000Fa]O75/KGa]K6elLFa]O6`80000:Fa]K75/KGaaK6e/LFa]O7000Fa`200002U/KFaaK
6elLFa]K75/K001K6elL0P0000YK6elLFa]O75/K001K6elLFa]O70800009Fa]O6e/KGa`005lKFa]O
75/K00800009GaaK6elKFa/005/KGa]K6elL00800005Fa]O75/KGa/00003Ga/01E/K001O6elKFa/0
0elK00`006<K000005lJHa]O6V<KGaYS6`00Ha/2000045lJHa]O6V<KGaYS6elJHa/006<KGaYS6elJ
Ha]O6V<K0P0000UO6P00GaYS6elJHa]O6V<KGaX00P00Egom00<007omOod057om00<007omOod00gom
002DOod00`00Ooeoo@04Ood200001ULmEaaG?ELMEceG7080000<EceG7000FcaO?5/lGcaK?5llFcaO
?5/l0P0000=O?000Hc/00elk00AS>elkGc/000AO>`800004Hc]S6f<kHaX200002F<kHa]S>f<KHc]S
6f<k001S>`0200002f<JHc]S6V<jHaYS>f<JHcX006<k000026<J00<006<JHaX00V<J0P000f<J00D0
06<JHaYS6VLJ00=S6P0;IaYS6P00HaYW6V<JIaYS6VLJHaYW6P0200004V<JIaYS6P00HaYW6V<JIaX0
06LJHaYW6V<JIaYS6VLJHaX000US6P05001S6V<JHaX00004HaX00`00HaYS6P06HaX00`00Ga]O6`08
Ga/00`00Ga]O6`09Ga/01@00Ga]O6elKFa/00elK00eK6`00001O6`00FaaK6e/LFa]K75/KFaaK6`02
00002U/LFa]K75/KFaaK6e/LFa]K75/K0P0000EK75/KFa]K6e/L00=K6`0=001K6`00001O6e/KGa]K
6elKFa]O6`00Ga/00P0000UK6elKFa]O6e/KGa]K6`00Fa/00P0000UO6e/KGa]K6elKFa]O6`00Ga/0
0P0025lK00@005lKGa]S6`=O6`05Ha]O6elK001S6`03Ga/016<KGa]O6elK0P0000=O6`00Ha/00elK
00US6`00Ga]O6f<KGa/005lKHa/00UlK0P00FWom00<007omOod04gom00<007omOod00gom002EOod0
0`00Ooeoo@05Ood00`00EceG700300001E<LEceG75LmDa`00P0000EO?5/KGcaK6ell00800004Fa]O
?5/KGc`200003UlKHcaO6f<k001S?5lKHc]O6f<lGa]S>`00Hc/2000065lJHc]O6V<kGaYS>elJHc]O
6V<k001S>f<JHc]S6V<kHaYS>f<JHc/006<kHaYS>`800004HaYW>V<JIc/200009F<JIc]S6V<jHaYW
>f<J001S6P00HaYW>V<JIcYS6VLjHaYW>V<J001S6P00HaYW6V<IIaYS6VLJ001W6V<JIaYS6FLJHaX0
06<I0080000AIaYS6FLJHaYW6V<IIaYS6P00HaT006<JIaYS6VLJHaYW6P0200001f<JIaYS6VLJHaX0
06<J0080000;IaYS6VLJHaYW6V<JIaYS6P00HaX00002Ga/01ElJGa]O6elKGaX00P0000=O6`00Ga/0
0UlK00EK6UlKGa]O6e/J0080000CGa/005lLFa]O6e/KGaaK6`00Fa]O75/KGa/005lLFa]K75/KGa`0
0P0000YK6elL001K75/KGaaK6e/LFa]O7080000:Fa/005/KGaaK6elLFa]O75/KGa`200002E/KGaaK
6elKFa]O75/KGa]K6`0200002ElKFa]O75/KGa]K6elLFa]O6`0200002E/KGa]K6elLFa]O6e/KGaaK
6`020003Ga/01E/KGa]O6elKFa/00P0000QO6`00Ha]O6V<KGaYS6elJ0P0000MS6`00001O6V<KGaYS
6`0200004ElJHa]O6P00GaYS6elJHa/006<KGaYS6elJHa]O6P00GaX00P00GGom00<007omOod04Wom
00<007omOod00gom002FOod00`00Ooeoo@05Ood200003ELLEceG7ELmEaaG?ELMEceG75Lm001O?5/l
0080000:GcaK?5llFcaO?5/lGcaK?000Gc/20009Gc/02`00Hc]S6f<kHa]S>f<KHc]S6f<kHa/00P00
00QS>`00Hc]S6V<jHaYS>f<J0P0000QS>f<JHcYS6V<kHaX006<J0P002V<J00D006<JHaYS6VLJ00=S
6P03IaX0000000=S6P0L001S6VLJHaYW6P00IaYS6VLJHaYW6V<JIaYS6P00HaYW6V<JIaYS6VLJHaYW
6V<J001S6VLJHaX20003HaX00`00HaYS6P06HaX00`00HaYS6P07HaX01@00HaYS6V<J000015lK0P00
15lK00<005lKGa/00elK0P0015lK00H005lKGa]O6e/K0002Ga/01e/KGa]O6elK001K75/K0080000:
FaaK6e/LFa]K7000FaaK6e/LFa/200001e/LFa]K75/K001K6e/L00=K6`80009K6`800005Ga]K6elK
Fa]O6`0200002E/KGa/00000Fa]O6e/KGa]K6`0200002ElKFa/00000Ga]K6elKFa]O6`0200000e/K
Ga/00005Ga/20003Ga/01@00Ga]O6elKHa/00P0000AO6f<KGa]O6`800004Ga/00000Ha/3Ga/016<K
Ga/005lK0P000UlK00MS6elKGa]O6f<KGa/0001POod00`00Ooeoo@0AOod00`00Ooeoo@03Ood009Mo
o@8000Ioo@800009DaaG?ELLEceC75LmEaaG?E<L00<0000EFa]O?5/KGcaK6ellFa]O?5/KGcaK6`00
Ga]S?5lKHc]O6f<lGa]S>elK0080000?Hc/006<kGaYS>elJHc]O6V<kGaX005lJHc]O6V<k0080000H
HaYS>f<J001S6V<kHaYS>f<JHc]S6V<kHaX006<JHcYS6VLkHaYS>V<JIc]S6V<j0P00015S6P00HaYW
>V<JIcYS6VLj001W>V<JIcYS6VLjHaX006<J0080000AIaYS6VLJHaUW6V<JIaYS6@00HaX006<IIaYS
6VLJHaUW6P0200006V<IIaYS6VLJHaUW6P00IaX006LJHaYW6V<JIaYS6VLJHaX006<J001S6VLJHaYW
6V<JIaX200001f<JIaYS6VLJHaX005lK008000=O6`05GaYO6elKGa/00002Ga/20003Ga/01U/JGa]O
6elK001O70800008Fa]O75/KGa]K6elLFa]O6`80000:Fa]K75/KGaaK6e/LFa]O7000Fa`200002U/K
FaaK6elLFa]K75/K001K6elL0P0000EK6elLFa]O75/K00800009GaaK6`00001O75/KGa]K6elL0080
0009Fa]O7000001K6elLFa]O6e/K0080000:Ga]K6`00001O6e/KGaaK6elK0002Ga/20003Ga/01E/K
Ga]O6`00GaX00P0001]S6elJHa]O6V<KGaYS6elJ001O6V<KGaYS6elJHa]O6V<KGaX005lJHa]O6V<K
GaYS6elJHa/00P00HGom00<007omOod04Wom00<007omOod00Wom002IOod00`00Ooeoo@05Ood01`00
EaaG?ELMEceG75Lm0080000<EaeG?@00GcaK?5llFcaO?5/lGcaK?5ll0P0000=K?000Gc/01Ulk00<0
05lkGc/00Ulk0P0000AS6f<kHa]S>`80000FGa]S>f<KHc]O6f<kHa/006<J001S6V<kHaYS>V<JHc]S
6V<jHaX006<J0008HaX00`00HaYS6P02HaX01P00HaYS6V<JIaX000QS6P0>001S6VLJHaYW6V<JIaYS
6VLJHaX006<JIaYS6P800004IaYS6VLJ0002HaX01FLJHaYS6V<JIaX00V<J00<006<JHaX01V<J00@0
06<JHaYS6P8000=S6P03001S6V<J00IS6P03001O6elK00QO6`8000YO6`05001O6elKGa]K6`03Ga/0
3E/K000005lK001K75/KFaaK6e/LFa]K75/K0080000:FaaK6e/LFa]K75/KFaaK6e/LFa/200001E/L
Fa]K6e/KFa`00e/K00aK7000001K6elKFa]O6e/KGa]K6elKFa/200002ElKFa]O6e/KGa]K6elKFa]O
6`02000025/KGa]K6elKFa]O6e/KGa/20009Ga/01@00Ga]O6elKHa/00elK00ES6`00001O6`0000=O
6`03Ha]O6elK00800004Ga/005lKHa/3Ga/00f<K001oo@1SOod00`00Ooeoo@0AOod00`00Ooeoo@02
Ood009Yoo@03001ooGom00Eoo@800009EceG7000001G?ELLEceC75Lm00800005Fa]O?5/KGcaK6`02
000015llFa]O?5/K0P0000iS?5lKHc]O6`00Ga]S>elKHcaO6f<kGa/005lJ0P0001QS>elJHc]O6V<k
GaYS>elJHc]O6P00HaYS>f<JHc]S6V<kHaYS>f<J001S6V<kGaX2000016<jHaYW>f<J0P0000QW>f<J
Hc]S6VLkHaX006<J0P00015W>V<JIcYS6VLjHaYW>V<J001S6P00HaYW6V<IIaYS6VLJ0080000JHaYW
6V<IIaYS6VLJ001W6P00IaYS6FLJHaYW6V<IIaYS6VLJ001W6P00IaYS6VLJHaYW6P80000DHaYW6V<J
IaYS6VLJ001W6P00IaYS6VLJHaYW6V<JIaYS6P00HaX0009O6`05GaYO6elKGa]O6P0200000elK001O
6`02Ga/01E/JGa]O6elKFaX00P0000MO6`00001K6elKFa]O700200002U/KGaaK6elK001O75/KFaaK
6elL0P0000YK6elL001K75/KGaaK6e/LFa]O70800009Fa/005/KGaaK6elLFa]O75/K00800009Ga`0
05lLFa]O6e/KGaaK6elK00800009Fa/005/KGaaK6elKFa]O75/K00800008Ga`005lKFa]O75/KGa]K
6`800003Ga/005lK009O6`04Fa]O6elKGa/200004ElK001O6V<KGaYS6elJHa/006<KGaYS6`00Ha]O
6V<KGaX00P0000YS6elJHa]O6P00GaYS6elJHa/006Ioo@03001ooGom011oo@03001ooGom009oo@00
Vgom00<007omOod01Wom0P0000aG7ELmEaeG?ELMEceG7ELmEad005/lGc`20003Fc`01ellFcaK?5/l
Gc`005lk008000UO>`0;001S6f<kGa]S>f<KHc]O6f<kHa]S>`02000026<K001S6V<jHaYS>f<JHcX2
000026<JHc]S6V<kHaYS>`00HaX20009HaX00`00HaYS6P07HaX01000HaYS6V<J0P0000iW6V<JIaX0
06LJHaYW6V<JIaYS6VLJHaYW6P000V<J00IW6V<JHaYS6VLJHaX2000016LJHaYS6P000f<J00<006<J
HaX01f<J00<006<JHaX01V<J00D006<JHaYS6P0000AO6`8000AO6`03001O6elK00=O6`8000AO6`80
0003Ga/0000000=O6`07Fa]O6elKGa/005/LFa/00P0000YK75/KFaaK6e/L001K75/KFaaK6`800007
FaaK6e/LFa/005/KFa`00U/K0P000e/K00IK7000Ga]K6elKFa/200002ElKFa]O6e/K001K6elKFa]O
6`02000025/KGa]K6`00Fa]O6e/KGa/200001E/KGa]K6elK000015lK0P0015lK00H005lKGa]O6f<K
0002Ga/01F<KGa]O6`00Ha/00P0000=O6f<KGa/00UlK00AS6elK001O6`8006Qoo@03001ooGom00mo
o@03001ooGom009oo@00W7om0P001gom00X005LmEaaG?E<LEceG75LmDaaG?@<0000EGcaK6ellFa]O
?5/KGcaK6ellFa]O?000HcaO6f<kGa]S?5lKHc]O6f<l0080000?Ga/005lJHc]O6V<kGaYS>elJHc/0
06<kGaYS>elJ0080000GHc]S6V<k001S>f<JHc]O6V<kHaYS>elJHc/006<kHaYW>f<JHc]S6VLkHaYS
>`02000026<J001S6VLjHaYW>V<JIcX20000=V<JIcYS6VLjHaYW>P00IaX006LJHaYW6V<IIaYS6VLJ
HaUW6P00IaX006LJHaYW6V<IIaYS6P00HaUW6V<JIaYS6FLJ001W6P00IaYS6VLJHaYW6V<JIaYS6VLJ
001W6P00IaYS6VLJHaYW6P800007HaYW6V<JIaYS6P00Ga/00P000elK00EO6UlKGa]O6`00009O6`80
00=O6`0@FaYO6elKGa]K6P00Fa]O6e/KGaaK6elKFa]O75/KGa/200002U/KFaaK6elLFa]K75/KGa`0
05/L0P0000UK6e/LFa]O75/KFaaK6`00Fa/00P0000UO75/KGaaK6elLFa]O7000Ga`00P0000UK6elL
Fa]O6e/KGaaK6`00Fa/00P0000QO6e/KGaaK6elKFa/005/K0P0000UO75/KGa]K6elLFa]O6`00Ga/0
0P0000EK6elKGa]O6e/K009O6`0G001O6P00001S6elJHa]O6V<KGaYS6`00Ha]O6V<KGaYS6elJHa]O
6V<KGaX0001ZOod00`00Ooeoo@0?Ood00`00Ooeoo@02Ood009ioo@03001ooGom00Eoo@800005EaeG
?ELMEceG7@0200000eLmEad00003Fc`01UllFcaK?5/lGcaK?0800003Gc`005lk00IO>`03001O>elk
009O>`800004Hc]O6f<kHa/200005V<kHa]S>elKHc]S6f<k001S>P00Hc]S6V<kHaYS>f<JHc]S6V<k
001S>`001f<J00<006<JHaX00V<J0P000f<J00<006<JHaX01f<J00T006LJHaYW6V<JIaYS6VLJHaX0
0P000V<J00UW6P00HaYS6VLJHaX006<JIaX00f<J00AW6V<JHaX000QS6P8000=S6P05001S6V<JHaX0
0008HaX00`00Ga]O6`08Ga/20008Ga/200001ElK001O6elKFa/00elK00eK6`00001O6`00FaaK6e/L
Fa]K75/KFaaK6`0200003E/LFa]K75/KFaaK6e/LFa]K75/K001K6e/L00=K6`0VFaaK6e/KFa]K7000
Ga]K6elKFa]O6e/KGa]K6elKFa/005/KGa]K6elKFa]O6e/KGa]K6`00Fa]O6e/KGa]K6elKFa]O6e/K
Ga/000YO6`05001O6elKGa]S6`03Ga/200000elK001S6`03Ga/00f<KGa]O6`02001/Ood00`00Ooeo
o@0>Ood00`00Ooeoo@02Ood009moo@03001ooGom00Ioo@03001G75Lm00800005EaaG?E<LEceG7002
00001EllFa]O?5/KGc`00P0000AK6ellFaaO?080000>Ga]S>elKHc`005llGa]S?5lKGcaO6f<l001S
>`80000HGaYS>elJHc]O6V<kGaYS>elJHc/006<kHaYS>elJHc]S6V<kGaYS>`00Hc]O6V<k0P0002YS
6VLkHaYS>`00Ic]S6V<kHaYW>f<JHc/006Lj001W>V<JIcYS6VLjHaYW>V<JIcX006Lk001W6V<IIaYS
6VLJHaT006<JIaYS6FLJHaYW6P00IaX200009V<IIaYS6VLJHaUW6V<JIaX006LJ001W6V<JIaYS6VLJ
HaX006<JIaYS6VLJHaYW6P00IaX006LJHaYW6V<JIaYS6VLJHaX006<J0002Ga/01ElJGa]O6elKGaX0
0P0000=O6`00Ga/00UlK00EK6UlKGa]O6`0000=O6`06FaX005/KGa]K6elL0P0000YK6elLFa]O6`00
GaaK6e/LFa]O7080000:Fa]O7000FaaK6elLFa]K75/KGa`200002E/K001K6elLFa]O75/KGaaK6`02
00002ElL001O75/KGa]K6elLFa]O6`02000025/K001K6elLFa]O6e/KGa`200002E/K001K6elKFa]O
75/KGa]K6`0200000elK001O6`02Ga/015/KGa]O6elK0P00015O6`00GaYS6elJHa]O6P00GaYS6elJ
001O6V<KGaYS6elJ008006moo@03001ooGom00eoo@03001ooGom009oo@00X7om00<007omOod01Wom
0P0000YG?ELMEceG7ELmEaeG?ELMEcd0009K?080009K?008GcaK?5/lFcaO?5/l001O>`8000UO>`0;
001S>elKHc]S6f<kGa]S>f<KHc]O6`02000026<k001S>f<JHc]S6V<kHaX2000026<kHaYS>f<JHc]S
6P00HaX20009HaX00`00HaYS6P06HaX20003HaX01P00IaYS6VLJHaX000=S6P06IaYS6V<JHaYW6P00
0V<J00EW6V<JHaYS6VLJ009S6P05001W6V<JHaX00004HaX00`00HaYS6P06HaX00`00HaYS6P06HaX0
1@00HaYS6V<J000015lK0P0015lK00<005lKGa/00UlK0P001UlK00@005lK000000=O6`07Fa]O6elK
Ga/005/LFa/00P0000YK75/KFaaK6e/L001K75/KFaaK6`800007FaaK6e/LFa/005/KFa`00U/K0P00
0e/K00H005/KGa]K6elKFa/2000025lKFa]O6`00Ga]K6elKFa/200002ElKFa]O6e/K001K6elKFa]O
6`02000015/KGa]K6`001ElK0P000elK00<006<KGa/00UlK00T005lKGa]O6f<KGa/005lKHa/00P00
LGom00<007omOod03Wom00<007omOod00Gom002QOod20007Ood02P00EaaG?E<LEceG75LmDaaG?ELL
0`0001EK75llFa]O?5/LGcaK6ellFaaO?5/K001O6ellGa]S?5lKGcaO6f<lGa/00P0000mS?000Hc]O
6V<kGaYS>elJHc]O6P00GaYS>elKHc/00P0001MS6V<kGaX006<JHc]O6V<kHaYS>elJHc]S6P00HaYW
>f<JHc]S6VLkHaYS>f<J0080000AHc/006LjHaYW>V<JIcYS6P00HaYW>f<JIcYS6VLk001W6P020000
4F<JIaYS6FLJHaYW6V<IIaX006LJ001W6V<JIaYS6FLJHaX00P0000MW6V<JIaYS6FLJ001W6P020000
46<JIaYS6VLJHaYW6V<JIaX006LJ001W6V<JIaYS6VLJ0P0000=S6VLJHaX00V<J00@005lK000000=O
6`06GaYO6elKGa/005lK0P0000EK6UlKGa]O6e/J00=O6`0<FaX005/KGa]K6elLFa]O6e/KGaaK6elK
0P0000YK6e/LFa]O75/KFaaK6elL001K70800009Fa]K75/KGaaK6e/LFa/005/K00800009GaaK6elL
Fa]O75/K001K6elL00800008Fa]O75/KGa]K6elL001O6`800009Fa]O6e/KGaaK6elKFa/005/K0080
0009GaaK6elKFa]O75/K001K6elK00800008Fa]O6elKGa]K6elK001S6`800007GaYS6elJHa]O6V<K
GaX00P00M7om00<007omOod03Gom00<007omOod00Gom002SOod00`00Ooeoo@05Ood200001ELmEaeG
?ELMEcd00P0000IG7ELm000005/lGc`3Fc`00ellFcaK?00200000e/l00000005Gc/20004Gc/20000
15lKHc]S6f<k0P0001IO6f<kGa]S>elKHc]O6`00HaX006<JHc]S6V<kHaYS>f<JHc]S6P00HaX000MS
6P03001S6V<J009S6P03001S6V<J009S6P03001S6V<J00IS6P03001W6V<J009S6P06IaYS6V<JHaYW
6P000V<J00UW6P00001S6VLJHaX006<JIaX00f<J00AW6V<JHaX000QS6P8000=S6P05001S6V<JHaX0
0008HaX00`00Ga]O6`08Ga/00`00Ga]O6`07Ga/200001ElK001O6elKFa/00elK00eK6`00001O6`00
FaaK6e/LFa]K75/KFaaK6`0200002E/LFa]K75/KFaaK6e/LFa]K700200000e/KFaaK6`02Fa/015/L
Fa]K6e/K0P0001iO6e/KGa]K6elKFa]O6e/KGa/005lKFa]O6e/KGa]K6elKFa]O6e/K001K6elKFa]O
6e/KGa]K6elKFa/20009Ga/00`00Ha]O6`02Ga/00f<KGa]O6`02001gOod00`00Ooeoo@0<Ood00`00
Ooeoo@01Ood00:Aoo@03001ooGom00Ioo@03001G?E<L0080000<EceC75LmDaaG?E<L001K75llFa]O
?5/L0P0000EO?5/LGcaK6ell0080000=Ga/00000GcaO6f<lGa]O?5lKHcaO6`00GaX00P0001=S>elJ
Hc]O6f<kGaYS>elKHc]O6P00HaYS>elJHc]S6V<kGaYS>`02000025lJHc]S6P00HaYW>f<JHc/20000
26<JHc]S6V<kHaYS>`00IcX200001f<JIc]S6VLjHaYW>f<J00800008Ic/006LJHaUW6V<JIaYS6@80
000@IaYS6FLJHaYW6V<I001S6P00HaUW6V<JIaYS6FLJHaX200004VLJ001W6V<JIaYS6VLJHaX006<J
IaYS6VLJHaYW6P00IaX0009S6P09IaYS6V<JHaYW6V<J001S6P00009O6`05GaYO6elKGa]O6P020000
0elK001O6`02Ga/01E/JGa]O6elK00000elK00H005lLFa]O6e/KGa`200002U/KGaaK6`00Fa]O75/K
FaaK6elL0P0000UK6elL001K75/KGaaK6e/LFa/00P0000UK75/K001K6elLFa]O75/KGa`00P0000UK
6`00Fa]O75/KGa]K6elLFa/00P0000UO7000Ga]K6elLFa]O6e/KGa`00P0000QK6`00Fa]O6e/KGaaK
6elK0P0000=K6`00Fa/00elK00=K6elKGa/00P0000QO6`00Ha]O6V<KGaYS6`00NWom00<007omOod0
2gom00<007omOod00Gom002UOod00`00Ooeoo@06Ood200002ELMEceG7ELmEaeG?ELMEceG7@020000
0ell00000009Fc`00`00Gc]O>`09Gc/02`00Ga]S>elKHc]O6f<kGa]S>elKHc/00P00015O6`00HaYS
>f<JHc]S6V<k001S>f<JHc]S6V<kHaX006<J008000US6P03001S6V<J00IS6P03001S6V<J009S6P80
00=S6P05001S6V<JHaYW6P03HaX01FLJHaX006<JIaX00f<J00EW6V<J001S6VLJ009S6P03001S6V<J
009S6P03001S6V<J00IS6P03001S6V<J00IS6P05001S6V<JHaX00004Ga/20004Ga/00`00Ga]O6`02
Ga/20005Ga/00`00Ga]O6`020003Ga/01U/KGa]O6`00Fa]K70<00008FaaK6e/LFa]K7000FaaK6`<0
0005Fa]K75/KFa`00002Fa/01E/LFa/00000Fa`00e/K00D005/KGa]K6elK00800009Fa]O6e/KGa/0
05lKFa]O6e/K00800008Ga]K6elK001O6e/KGa]K6`800005Ga]K6elKFa/00004Ga/20003Ga/00`00
Ga]S6`02Ga/00`00Ooeoo@1iOod00`00Ooeoo@0;Ood00`00Ooeoo@01Ood00:Ioo@03001ooGom00Io
o@800009DaaG?E<LEceC75LmDaaG?E<L00800009GcaK6ellFaaO?5/KGcaK75ll0080000:Fa`005lK
HcaO6ellGa]S?5lKGc`200009elK001O6V<kGa]S>elJHc]O6f<k001S>elKHc]O6P00HaYS>elJHc/0
06<kGaYS>f<JHc]O6V<kHaX006<JHc]S6V<kHaYS>f<JHc]S6P0200007V<k000006<JIcYS6VLkHaX0
06<JIc]S6VLjHaYW>f<J001S6@00HaYW6V<IIaYS6VLJHaUW6V<J001S6@80000=IaYS6FLJHaX006<I
IaYS6VLJHaUW6P00IaX00P0000MS6VLJHaYW6V<JIaYS6P0200000f<J001W6P03HaX01FLJ000006<J
IaX00f<J00@005lK000000=O6`06GaYO6elKGa/005lK0P0000EK6UlKGa]O6e/J00=O6`800009Fa]O
6e/KGaaK6elKFa]O75/K00800009GaaK6e/LFa]O75/KFaaK6elL0080000:Fa]O75/KFaaK6elLFa]K
7000Ga`200002E/KGaaK6elLFa]O75/K001K6`0200002ElKFa]O75/KGa]K6elL001O6`02000025/K
Ga]K6elLFa]O6`00Ga`200002E/KGaaK6elKFa]O75/K001K6`0200000elKFa]O6`02Ga/00e/K001O
6P02001mOod00`00Ooeoo@0:Ood00`00Ooeoo@01Ood00:Moo@8000Qoo@800003EceG7ELm00@00004
EaeG?@000005Fc`20004Fc`20004Gc/2000015llGc]O>elk0P0000AS>elKHc]O6`800008Hc]O6f<k
Ga]S>elK001S6P800007Hc]S6V<kHaYS>f<JHc/00P0000=S6`00HaX01V<J00<006<JHaX00f<J0P00
00=S6P0000002F<J00D006<JHaYS6VLJ00=S6P06IaX00000HaYW6V<J0P0000EW6P00001S6VLJ00=S
6P04IaYS6V<J0008HaX00`00HaYS6P02HaX01@00HaYS6V<J000026<J00<005lKGa/025lK00<005lK
Ga/01UlK0P0000=O6`00Ga/00UlK00AK6elKGa]O6`800009Ga/005/KFaaK6e/LFa]K75/K0080000:
Fa`005/LFa]K75/KFaaK6e/LFa/20002Fa/01E/LFa]K6e/KFa`00e/K024005/KGa]K6elKFa]O6e/K
Ga]K6elK001O6e/KGa]K6elKFa]O6e/KGa/005lKFa]O6e/KGa]K6elKFa]O6e/K00002ElK00<007om
Ood0OWom00<007omOod02Gom00<007omOod00Gom002YOod00`00Ooeoo@07Ood3000025LmDaaG?E<L
EceC75LmDa`200003Ell000005/KGcaK75/lFa]O?5/LFc`006<l0080000:Ga]O?5lKGcaO6ellGa]O
?000Hc/200005elJHc]O6f<kGaYS>elKHc]O6P00HaYS>elJHc]S6V<kGaYS>`00Hc]O6V<kGaX00P00
01MS>f<JHc]S6P00HaYS>f<JHc]S6V<kHaYS>`00IcYS6VLkHaYW>V<JIc]S6VLj0080000IHaX006<I
IaYS6VLJHaUW6P00IaYS6FLJHaYW6V<IIaX006LJHaUW6V<JIaYS6FLJHaX00P0000UW6P00001S6VLJ
HaYW6V<J00000f<J00IW6V<JHaX006LJ0002HaX02FLJHaYS6V<JIaYS6P00HaX00002Ga/01ElJGa]O
6elKGaX00P0000=O6`0000000UlK00EK6UlK000005/J00=O6`05001O75/KGa]K6`0200002ElKFa]O
75/K001K6elLFa]K700200002U/KFaaK6elL001K75/KGaaK6e/L0P0000YK6e/L001O75/KGaaK6elL
Fa]O70800009Fa/005/KGaaK6elKFa]O75/K00800008Ga`005lKFa]O75/KGa]K6`800009Ga/005lL
Fa]O6e/KGaaK6elK00800003Fa/005/K00=O6`04Fa]O6`000022Ood00`00Ooeoo@08Ood00`00Ooeo
o@01Ood00:Yoo@03001ooGom00Moo@0;001G?ELMEceG7ELmEaeG?ELMEceG7@02000;Fc`01000Gc]O
>ell0elk00mO?5lkGc]O>ell001S>elKHc]O6f<kGa]S>elKHc/00P00019O6`00001S>f<JHc]S6V<k
001S>f<KHc]S6V<kHa]S>`00HaX20008HaX00`00HaX00007HaX00`00HaYS6P02HaX01P00HaYS6V<J
IaX0009S6P09IaYS6V<JHaYW6P00HaX006LJ00=S6P05IaYS6P00HaYW6P03HaX200000f<J00000008
HaX00`00HaYS6P06HaX01@00HaYS6V<J000015lK0P0015lK0P0000=O6`0000001elK00D005lK0000
05/K00=O6`05Fa]O6elK001K6`0200002U/LFa]K75/KFaaK6e/L001K75/K0P0000IK75/KFaaK6e/L
0002Fa/01E/LFa/00000Fa`00e/K00D005/KGa]K6elK00800008Fa]O6e/K001K6elKFa]O6`800009
Fa]O6e/KGa/005lKFa]O6e/K00800004Ga]K6elK0004Ga/20024Ood00`00Ooeoo@09Ood10001Ood1
Ood00:]oo@03001ooGom00Moo@800006DaaG?E<LEceC75Lm0P0000]C75Lm001O?5/LFcaK6ellFaaK
?5/K0080000:Fc`005llGa]O?5lKGcaO6ellGa/2000025ll000005lKHc]O6V<kGa/200001F<kGa]S
>elJHc/00P0001YO6P00001S>elJHc]O6V<kGaYS>elJHc/006<kHaYS>f<JHc]S6V<kHaYS>`00Hc]S
6V<k0P0000IS6VLkHaYW>P00Ia/3HaX016LKHaX006<I0P0001]W6V<IIaYS6VLJHaUW6P00IaYS6FLJ
001W6V<IIaYS6P00HaUW6V<JIaYS6FLJHaYW6P00IaX00f<J00AW6V<JHaYS6P800003HaX006LJ00=S
6P05IaX00000HaYW6P03HaX01000Ga/000000elK00IO6UlKGa]O6elJ0002Ga/01E/JGa]O6elKFaX0
0elK01H005lLFa]O6e/KGaaK6elKFa]O75/K001K6elLFa]K75/KGaaK6e/LFa]O7080000:Fa]O75/K
FaaK6elLFa]K7000Ga`200002E/KGaaK6elLFa]O75/K001K6`02000025lKFa]O75/KGa]K6`00Fa/2
00002ElLFa]O6e/KGaaK6elK001O7002000025/KGaaK6elKFa]O7000Ga/20027Ood00`00Ooeoo@08
Ood10001Ood1Ood00:aoo@8000Uoo@03001G7ELm00<000EG7@8000AK?08000AK?0800004Gc]O?5lk
Gc/20003Gc/01EllGc/00000Hc/00P0001=O6f<kGa]O>elKHc]O6elkGa/006<JHc]S6f<kHaYS>f<K
Hc]S6P0200000f<k001S6P05HaX20002HaX01V<KHaYS6V<J001S6P8000QS6P05001S6V<JHaYW6P03
HaX20002HaX01FLJHaYS6P00IaX00P0000=S6VLJHaX00V<J00IW6V<JHaX006LJ0006HaX00`00HaYS
6P02HaX01@00HaYS6V<J000026<J00<005lKGa/01UlK0P0000=O6`00Ga/01UlK0P0000=O6`00Ga/0
0UlK00AK6elKGa]O6`800009Ga/005/KFaaK6e/LFa]K75/K0080000:Fa/005/LFa]K75/KFaaK6e/L
Fa/20002Fa/01E/LFa]K6e/KFa`00U/K0P0001=K6elKFa]O6e/KGa]K6elKFa/005/KGa]K6elKFa]O
6e/KGa]K6`02000025lKFa]O6e/KGa]K6elKFa/2002:Ood00`00Ooeoo@07Ood10001Ood1Ood00:io
o@03001ooGom00Moo@80000<EceC75LmDaaG?E<LEceC75LmDa`005/L0P0000YO?5/LFcaK75llFaaK
?5/L001O6`80000CGcaO6ellFa]O?5lKGcaK6ell001S>elJHc]O6f<kGaYS>elKHc/00P0000iO6`00
GaYS>elJHc]O6V<kGaX005lJHc]O6V<k0P00011S6V<kHaX006<JHc]S6V<kHaYS>f<JHc]S6P00HaYW
6`=S6P03Ia]S6V<J0080000IHaX00000IaYS6VLJHaT006<JIaYS6FLJHaYW6V<IIaX006LJHaUW6V<J
IaYS6FLJHaX00P0000EW6V<JIaX006LJ00=S6P05001S6V<JHaYW6P02HaX00`00IaX00002HaX01FLJ
HaYS6V<JIaX00P0000ES6P00Ga]O6elJ00=O6`06001O6elKGa]O6P000UlK00EK6UlK000005/J00=O
6`05001O75/KGa]K6`0200002ElKFa]O75/K001K6elLFa]K700200002U/KFaaK6elL001K75/KGaaK
6e/L0P0000UK6e/L000005/KGaaK6elLFa/00P0000UO75/K001K6elLFa]O6e/KGa`00P0000QK6`00
001O6e/KGaaK6elK0P0000QK6elK001O75/KGa]K6elL0P00S7om00<007omOod01gom0@000Gom0Gom
002_Ood00`00Ooeoo@07Ood00`00EaeG7@08Ead2000;Fc`00`00Gc]O?003Gc/015llGc]O>elk0P00
00iO>`00Hc]O6elkGa]S>elKGc/006<kGa]O>elK0P0000mS>f<KHc]S6P00Ha]S>f<JHc]S6f<kHaX0
06<J00000f<J00US6f<JHaYS6V<KHaX006<J00001V<J00<006<JHaX00f<J0P0000=S6P00HaX00V<J
00UW6V<JHaYS6VLJ001S6P00IaX00f<J00EW6V<J001S6VLJ00=S6P03IaX006<J008000QS6P03001S
6V<J00ES6P03001S6V<J009S6P03001O6elK009O6`03001O6elK00AO6`04001O6`000007Ga/01@00
Ga/00000Fa/00elK00EK6elKGa/005/K00800005FaaK6e/KFa]K7002Fa/00`00FaaK6`0200001E/L
Fa]K75/KFa`00P0000IK6e/L000005/KFa`2Fa/01@00Ga]K6elKFa/00P0000AO6e/KGa]K6`80000<
Ga]K6`00001O6e/KGa]K6elK001O6e/K0P00Sgom00<007omOod01Wom0@000Gom0Gom002`Ood00`00
Ooeoo@07Ood200001ULmDaaG?E<LEceC7080000;EceC7000FaaK?5/LGcaK75/lFaaO?00200003U/L
001O6ellFa]O?5lKGcaK6`00Ga]O?5/KGc`200003UlJHc]O6f<k001S>elKHc]O6f<kGa]S>`00Hc/2
00004UlJHc]O6V<kGaYS>elJHc]O6P00HaYS>f<JHc]S6V<kHaYS>`800006HaYS>f<J001S6VLK0V<J
00<006LKHaX00V<J025W6f<JHaYS6P00HaYW6V<IIaYS6VLJHaUW6P00IaYS6VLJ001W6V<IIaYS6P00
HaUW6V<JIaYS6FLJHaYW6P00IaX00f<J00AW6V<JHaYS6P800003HaX0000000=S6P05IaX006<JHaYW
6P03HaX01000Ga/000000elK00IO6UlKGa]O6elJ0002Ga/01E/JGa]O6elKFaX00elK01D005lLFa]O
6e/KGaaK6elKFa]O75/K001K6elLFa]K75/KGaaK6e/LFa/00`0000UK6elLFa]K75/KGaaK6e/LFa/0
0P0000UO75/KGaaK6elLFa]O7000Ga/00P0000QK6elKFa]O75/KGa]K6elL0P0000QK6elLFa]O6e/K
GaaK6elK0P00TWom00<007omOod01Gom0@000Gom0Gom002aOod20009Ood00`00EaeG7@030005Ead2
0004Fc`20004Fc`200001EllGc]O>elk00000elk00IO?5lkGc]O>`00Ga/200004f<kGa]O>elKHc]O
6elkGa]S>`00Hc]S6f<kHaYS>f<KHc]S6V<k00800004HaX006<JHa/3HaX01F<K001S6V<JHa/00f<J
00@006<J000000QS6P05001S6P00HaYW6P03HaX20002HaX01FLJHaYS6P00IaX00P0000=S6VLJHaX0
0V<J00IW6V<JHaX006LJ0006HaX00`00HaYS6P02HaX200000f<J00000008HaX00`00Ga]O6`06Ga/2
00000elK001O6`06Ga/200000elK001O6`02Ga/015/KGa]O6elK0P0000=O6`0000000U/K00=K75/K
Fa/00P000U/K00P005/LFa]K75/KFaaK6e/L0P0000AK6`00Fa]K70=K6`0<FaaK6`00001O6e/KGa]K
6elKFa]O6e/K0P0000QO6`00Ga]K6elKFa]O6e/K0P00UGom00<007omOod017om0@000Gom0Gom002c
Ood00`00Ooeoo@07Ood2000035<LEceC75LmDaaG?E<LEceC75Lm001K?080000:FaaK?5/LFcaK75/l
FaaK?000Gc`200004elKGcaK6ellGa]O?5/KGcaO6`00Ga]S>elKHc]O6f<kGa]S>elK0080000OHc/0
06<kGaYS>elJHc]O6V<k001S>elJHc]O6P00HaYS>f<JHc/006<kHaYS>f<JHc]S6V<kHaX006<JIa/0
0f<J00=W6f<JHaX00P000f<J01d006<JIaYS6@00HaYW6V<JIaYS6VLJHaYW6P00IaYS6FLJHaYW6V<I
IaYS6VLJ001W6V<JIaX006LJ00=S6P05001S6V<JHaYW6P03HaX01@00HaYS6V<JIaX00f<J00AW6P00
001S6P800004Ga]O6UlKGa/20003Ga/01UlJ001O6elKFaYO6`800009FaYO6elKGa/005lLFa]O6e/K
00800004Ga]K6elLFa/200003UlLFa/00000GaaK6e/LFa/005/KFaaK6elLFa/200002ElLFa]K7000
GaaK6elLFa]O7002000025/KGa`00000Fa]O75/KGa/2000025/KGa]K6`00Fa]O6e/KGa`2002GOod0
0`00Ooeoo@04Ood10001Ood1Ood00;Aoo@03001ooGom00Moo@8000UG7@8000YK?0800005GcaO>elk
Gc]O?003Gc/05Ull000005lk001O6elkGa]S>elKGc]O6`00Ga]O>elKGc/006<kHa]S>f<J0P0000=S
6f<JHa/00V<K00=S6P00HaX00P000V<J00ES6f<JHaYS6V<K00800003HaX006<J00ES6P03001S6V<J
00AS6P03001S6P0000=S6P09IaYS6V<JHaYW6P00HaX006LJ00=S6P05IaYS6P00001W6P03HaX00fLJ
001S6P020007HaX00`00HaX00006HaX00`00HaYS6P02HaX200000elK00000007Ga/01000Ga/00000
1elK00D005lK000005/K00=O6`04Fa]O6elKGa/200000e/KFaaK6`02Fa/01E/LFa/005/KFa`00P00
00=K6e/LFa/00U/K00AK7000Fa]K6`80009K6`03FaaK6e/K0080000;Fa/00000Ga]K6elKFa]O6e/K
001K6`02002JOod00`00Ooeoo@04Ood10001Ood00;Eoo@03001ooGom00Qoo@800003EceC75Lm00@0
000:DaaG?@00001K75/lFaaK?5/LFc`200002E/LFc`00000Fa]O?5lKGcaK6`0200002EllFa]O?5/K
001O6f<kGa]S>`02000025lKHc]O6f<kGa]S>`00Hc/200006UlJHc]O6V<kGaYS>elJHc]O6P00HaYS
>f<JHc]S6V<kHaYS>`00Hc]O6V<kHaX006<JIa/2HaX00`00Ia]S6P02HaX04FLKHaYS6V<J001S6VLJ
HaYW6V<JIaYS6VLJ001W6V<JIaX00P0000iS6FLJHaX006<IIaYS6VLJHaUW6V<JIaX006LJ0f<J00EW
6V<JHaYS6P0000=S6P06001S6V<JHaYW6P000V<J00QW6V<JHaYS6VLJ001O6elJ0elK00IO6UlKGa]O
6elJ0002Ga/01E/JGa]O6elKFaX00elK00T005lLFa]O6e/KGaaK6elKFa/00P0000UO6`00GaaK6e/L
Fa]O75/KFa`00`0000QK75/KGaaK6e/LFa]O75/K0`0001AK6elLFa]O75/KGaaK6elLFa/005/KGaaK
6elKFa]O75/KGa]K6`00WGom00<007omOod00gom0@000Gom002fOod00`00Ooeoo@09Ood300000eLM
DaeG7@02Ead015<MEad000000U/l0`001E/l0P000Ulk0P0000UO>ellGc]O?5lkGcaO>`00Ga/00P00
00YO>elKGc]O6elkGa]O>elKGc/000=S6`06HaYS6f<KHa]S6V<K0P0000AO6P00001S6`=S6P05Ha/0
06<JHaYS6`03HaX01000HaX0000026<J00D006<J001S6VLJ00=S6P80009S6P09IaYS6V<JHaX006<J
001S6VLJ00=S6P06IaYS6V<J001W6P001F<J0P001F<J00@006<J000000MS6P03001S6P0000MO6`80
0003Ga/005lK00IO6`800003Ga/00000009O6`05Fa]O6`00001K6`02Ga/01P00Fa]K6e/KFaaK6`80
0005FaaK6`00001K7003Fa/01U/L000005/KFa`0009K6`05FaaK6e/KFa]K7002000025/K001K6elK
Fa]O6e/KGa/2002NOod00`00Ooeoo@03Ood10001Ood00;Moo@8000Yoo@0:001G?E<LEceC75LmDaaG
?E<LEcd300002U/lFaaK?5/LFcaK75/lFaaK?5/L0P0001AO?5/KGcaK6ellFa]O?5/KGcaK6`00Ga]S
>elKHc]O6f<kGa]S>elK0P0000mS>`00Hc]O6V<kGaYS>elJHc/006<kGaYS>elJHc/00P0000iS6P00
001S>elJHc]S6V<kGaYS>f<J001S6VLK0f<J00EW6f<JHaYS6P0000=S6P0M001S6VLJHaX006<JIaYS
6VLJHaYW6V<JIaYS6P00HaUW6V<JIaYS6FLJHaYW6P00IaYS6VLJ001W6P02HaX00`00IaYS6P02HaX0
1FLJHaYS6V<J00000f<J00IW6V<JHaYS6VLJ0002HaX016LJ001O6elJ0UlK0P000elK00IO6P00Ga]O
6e/JGa/2000015/JGa]O6elK0P0000aK6`00001O75/KGa]K6elLFa/005/KGa`200001E/KGaaK6e/L
Fa/00P0000iK75/K000005/LFa]O75/KFa`005lLFa]O75/K0P0000QO75/KGa`005lKFa]O75/K0P00
XGom00<007omOod00Wom0@000Gom002iOod00`00Ooeoo@08Ood20002Ead00e<MEaeG7@020002Ead0
0`00FcaK?006Fc`200002U/l001O>ellGc]O?5lkGcaO>ell0P0000QO>`00001O>elKGc]O6elk0P00
00AO6elkGa]O>`80009S6`05HaYS6`00Ha]O6P03Ha/015lJHa]S6`000f<J00ES6f<JHaYS6V<K0080
0003HaX006<J00ES6P8000ES6P03001S6P0000=S6P09IaYS6V<JHaYW6V<J001S6P0000=S6P05IaYS
6P00001W6P03HaX016LJ001S6P0026<J00<006<J00001F<J0P001F<J00@005lK000000MO6`04001O
6`000008Ga/01000Ga]O6e/K0elK00=K6elKGa/00P000U/K00EK75/KFa]K6e/L009K6`8000=K6`07
FaaK6e/KFa]K7000Fa/00P000e/K00EK75/KFa/005lK00800:Aoo@05001ooGomOod00001Ood00;Yo
o@03001ooGom00Uoo@03001C75Lm00800005DaaG?E<LEceC7002000015/lFaaK?5/L0P0000AK?5/L
FcaK70800004GcaK6ellFa/200001EllFa]O?5/KGc`00P0000eO6`00001S?5lKHc]O6f<lGa]S>elK
001O6P0200001f<kGaYS>elJHc]O6V<k0080000=GaX005lJHc]S6V<kGaYS>`00Hc]O6V<kHaX00P00
00EW6f<JHaX006LK00=S6P0=Ia]S6V<JHaX006<JIaYS6VLJHaYW6V<JIaX00P00019S6VLJHaX006<I
IaYS6P00HaYW6V<JIaYS6VLJHaYW6P00IaX3HaX01FLJHaYS6V<J00000f<J00D006<JHaYS6P0000=S
6P08IaYS6V<JHaYW6P00Ga]O6P=O6`06GaYO6elKGa]O6P000UlK00IK6UlKGa]O6e/JGa/2000025/J
001K6elKFa]O75/KGa/200002E/K001K6elLFa]K75/KGaaK6`0200002UlL001K75/KGaaK6e/LFa]O
75/K0P0000QO75/KGaaK6elLFa]O75/K0P00Ygom00@007omOod0005oo@00^gom00<007omOod02Gom
0P0000=G7E<MEad00ULM00IC7ELMEaeG7@00Fc`20008Fc`06P00Gc`00000Gc]O?5lkGcaO>ellGc]O
?5lk001O6elkGa]O>elKGc]O6elkGa]O>elK0002Ha/02ElJHa]S6f<KGaYS6`00Ha]O6`02Ha/01P00
HaYS6V<JHa/0009S6P08Ha]S6V<JHaYS6`00HaX000MS6P800004HaX006<JIaX3HaX01FLJ001S6V<J
IaX00f<J00D006<J001S6VLJ00=S6P06IaYS6P00001S6P001F<J0P001F<J00<006<J000026<J00<0
06<J00001elK0P0000=O6`00000015lK0P000elK00D005lKGa]O6e/K00800005Ga]K6elKGa/00003
Fa/01E/L000005/KFa`00U/K00<005/LFa/00U/K00IK7000001K6e/L0002Fa/00e/LFa]K6`02002Y
Ood01000Ooeoo@000Gom002lOod2000:Ood2000025LmDaaG?E<LEceC75LmDa`200002U/lFaaK?5/L
FcaK75/lFaaK?5/L0P0000UO?5/KGcaK6ellFa]O?5/KGc`00P0000YK6`00Ga]S>elKHcaO6f<kGa]S
?0800007Ga/00000Hc]O6V<kGaX00P0000QS>elJHc]O6V<kGaX005lJ0P0000]S>elJHc]S6V<kGaYS
>f<JHc/006LK00=S6P0UIa]S6V<J001W6f<JHa]S6P00HaYW6V<JIaX006LJHaYW6V<JIaYS6VLJHaX0
06<JIaYS6VLJHaYW6V<J001S6VLJHaYW6P00IaX00V<J00<006LJHaX00V<J00EW6V<JHaYS6P0000=S
6P06IaYS6V<JHaYW6P000V<J00AW6P00Ga]O6P9O6`8000=O6`04GaX00000Ga/20002Ga/01U/JGa]O
6elK001O70800009Fa]O75/KGa]K6elLFa/005/K0080000:FaaK6elLFa]K75/KGa`005/LFa/20000
25/LFa]O75/KFa`005lLFa/2002/Ood00`00Ood00001Ood00;ioo@03001ooGom00Uoo@800003DaeG
7@0000<0009G7@8000IK?080009K?0800005Gc]O?5lkGcaO>`02000015llGc]O?5/k0P0000AO>elK
Gc]O6`800004Gc]O6elkGa/200000f<K00000002Ha/01ElKHa]S6f<KGa/00V<K00D006<JHaYS6V<K
00=S6P05Ha]S6P00001S6`020004HaX00`00HaYS6P04HaX01000HaX000000V<J00EW6V<JHaYS6VLJ
00800003HaX00000009S6P03IaYS6P0000IS6P03001S6P0000MS6P800003HaX006<J00AS6P8000ES
6P04001O6`000008Ga/00`00Ga]O6`07Ga/01@00Ga]O6elKFa/00elK00AK6elKGa/000=K6`05FaaK
6e/KFa]K7002Fa/20003Fa/01E/LFa]K6e/KFa`00P00[gom0@000Gom0@00002oOod00`00Ooeoo@0:
Ood2000025LmDaaG?E<LEceC75LmDa`200002U/lFa`00000FcaG75/mFaaK?5LL0P0000eO?000001K
6ellFa]O?5/KGcaK6ell001S>`0200004UlKGc]O6f<lGa]O>elKHc`006<kGaYS>elJHc]O6V<kGaYS
>`80000>GaX005lJHc]S6V<kGaYS>f<J001O6V<kHaYS>`80000IHaX00000Ia]S6V<KHaYW6f<JHa]S
6P00HaYW6V<JIaYS6VLJHaYW6P00IaYS6VLJHaX00P0000eW6P00001S6VLJHaYW6V<JIaYS6VLJ001W
6P03HaX01FLJHaYS6P00IaX00f<J00D006<JHaYS6P0000=S6P08IaYS6V<JHaYW6P00Ga]O6P=O6`03
GaYO6elK00800004Ga/005lKFaX3Ga/035/J000005lK001O75/KGa]K6elLFa]O6`800009Fa/005/K
GaaK6e/LFa]O75/K00800008Ga`005/LFa]O75/KFaaK6`800;9oo@800000`7om00<007omOod02Wom
00<005<MEad00ULM00EC7ELMEaeG7E<M00<000YK?00E001O?5/kGcaO>ellFc]O?5lkGcaK>ell001O
>elKGc]O6elkGa]O>elK00800004Gc/006<KGa/3Ha/025lKHa/006<KGa]S6elK0003HaX02f<K0000
06<JHa]S6V<KHaYS6f<J000026<J0P0000AS6P00001W6P=S6P03IaX006<J00IS6P03001S6V<J00IS
6P800003HaX0000000AS6P03001S6V<J00AS6P03001S6P0000MS6P800003HaX005lK00EO6`05001O
6elKGa/00004Ga/20004Ga/01@00Ga]O6elKFa/00P0000EO6e/KGa]O6`0000=K6`09Fa`00000Fa]K
75/K001K6e/L009K6`800;Aoo@800000`Gom0P002gom0P0000EG?E<LEceC75Lm0080000;DaaG?@00
FcaG75/mFaaK?5LLFceK700200002U/m001O?5/KGcaK6ellFa]O?5/K0P0000eO?000Gc]O6f<lGa]O
>elK001O6elkGa]S?00200003ElJHc]O6V<k001S>elJHc]O6V<kGaX005lJ00800007Hc]O6V<kHaYS
>elJHc/00P0000iO6P00HaYS6f<JIa]S6V<K001S6f<JHa]S6V<K0P0001QS6P00001W6V<JIaYS6VLJ
HaYW6P00IaX006LJHaYW6V<JIaYS6P00HaYW6V<JIaX2000016<J000006LJ0f<J00EW6V<JHaYS6P00
00=S6P05IaYS6V<JHaX00003HaX016LJ001O6elJ0UlK00<005lJGa/00UlK00=O6P00Ga/00P000elK
00IK6UlKGa]O6`00Ga`200002E/KGaaK6elKFa]O75/K001K6`02000025/LFa]O75/KFaaK6`00Fa/2
002fOod200000<=oo@03001ooGom00Yoo@03001G7ELM008000=G7@04DaeG7@000004Fc`200002U/L
FcaK75/l001O?5/kGcaO>ell0P0001=O75llFa]O?000Gc]O6elkGa/005lKGc]O6elkGa]O>elK001O
6`0200005f<KGa]S6elKHa]O6f<KGa/006<JHa]S6V<KHaYS6f<JHa/006<KHaYS6f<J000016<J00<0
06<JHaX01V<J00<006<JHaX01V<J00D006<JHaYS6P0000AS6P03001S6V<J00ES6P03001S6V<J00IS
6P800003HaX0000000AS6P03001S6V<J00AS6P04001O6`000007Ga/00`00Ga]O6`08Ga/01@00Ga]O
6elKFa/00elK00AK6elK000000=K6`05FaaK6e/KFa]K7002002dOod40002Ood00<Aoo@03001ooGom
00Yoo@80000;DaaG?E<LEceC75LmDaaG?E<L001G700200002U/lEaaK?E/LFcaG75/m001O?5/K0P00
00UO?5/KGcaK6ellFa]O?000Gc/00P00019O6elkGa]S?5lKGc]O6f<lGa/005lJHc]O6V<kGaYS>elJ
Hc/200004ElJ000006<kHaYS>elJHc/006<kGaYS>elJHc]O6P00HaX00P00011S6f<JHa]S6V<KHaYS
6f<J001S6P00HaYW6V<JIaYS6P800007IaYS6VLJHaYW6P00IaX00P0000YS6VLJHaYW6V<JIaYS6P00
HaX000=S6P05IaYS6V<J001W6P03HaX200000f<J00000003HaX026LJHaYS6V<JIaX005lKGaX3Ga/0
1UlJGa/00000GaX0009O6`05FaYO6elKGa]K6P02000025lK000005/KGa]K6elLFa/2000025lLFa/0
05/KGaaK6e/LFa/2002bOod40006Ood00<Eoo@03001ooGom00Yoo@80009G7@06DaeG7ELMEaeC7ELM
0P0000UK75/lFaaK?5/LFcaK75/lFa`00`0001AK6ellGaaO?5/KGcaO75llFa]O?000Gc]O6elkGa]O
>elKGc]O6elk0P0000iO6`00Ga]S6elKHa]O6f<K001S6elKHa]O6f<K0P0000aS6P00001S6f<JHa]S
6V<KHaYS6f<J0008HaX20003HaX01@00HaYS6V<J000026<J00<006<JHaX01V<J00D006<JHaYS6P00
00AS6P03001S6V<J00ES6P03001S6V<J00IS6P800003HaX005lK00=O6`8000AO6`03001O6elK009O
6`8000AO6`80009O6`80009O6`04Fa]O6elK0002Fa/2002`Ood4000:Ood00<Ioo@8000aoo@800003
EceC700000<00009EceC7000001K?E/LFcaG75/m0080000;EaaK?@00GcaK6ellFa]O?5/KGcaK6`02
000025ll000005lKHcaO6elkGa/200006ellGa]S?5lK001O6V<kGaYS>`00Hc]O6V<kGaYS>elJHc]O
6P00GaYS>elJHc]O6V<kGaYS>`0200008UlJ001S6V<KHaYS6f<JHa/006<KHaYS6f<JHa]S6P00HaX0
06<JIaYS6VLJHaYW6V<JIaX006LJ001W6V<JIaYS6VLJ0P0000MS6VLJHaYW6V<J001S6P0200001FLJ
HaYS6V<JIaX00V<J00<006LK00000V<J00EW6V<JHaYS6P0000=S6P03Ia/005lK0080009O6`07GaYO
6elKGa]O6P00Ga/00P000elK00EK6UlKGa]O6e/J00800008Ga]K6elLFa]O6e/KGaaK6`800:ioo@@0
00ioo@00b7om00<007omOod02gom0P0000EC7ELMEaeG7E<M009G7@800009FcaK7000001K?5/LFcaK
75/l00800004Fa]O?5lLGc`200001E/LGcaK6ellFa`00P0000aO>`00001O6elkGa]O>elKGc]O6`00
Ga/200001f<KGa]S6elKHa]O6f<K0080000>Ga/006<JHa]S6V<KHaYS6`00Ha]S6V<KHaX000AS6P03
001S6V<J00IS6P03001S6V<J00IS6P05001S6V<JHaX00003HaX00`00HaYS6P06HaX00`00HaYS6P06
HaX01@00HaYS6V<J000016<J00<006<JHaX016<J00<005lKGa/025lK00<005lKGa/01UlK0P0000EO
6`00Ga]O6e/K00=O6`800:aoo@@0019oo@00bGom00<007omOod02gom00T005LmDaaG?E<LEceC75Lm
Da`00`0000]G75/lEaaK?ELLFcaG75/mEa`005/K0080000`GcaK6ellFa]O?5/KGcaK6ell001S?5lK
GcaO6f<lGa]O?5lKHcaO6`00GaYS>elJHc]O6V<kGaYS>`00Hc]O6f<kGaX005lJHc]O6V<k001S>elJ
Hc]O6V<kGaX006<J0P0000MS6f<JHa]S6V<KHaYS6`0200001f<J001S6VLJHaYW6V<J0080000?IaYS
6VLJHaYW6P00IaX006LJHaYW6V<JIaYS6VLJ00800003HaX006<J009S6P05IaYS6P00001W6`03HaX0
0fLK001S6P020003HaX026LKHaX00000Ia/005lKGaX3Ga/01ElJGa/00000GaX00P0000AO6e/JGa]O
6`8000=O6`05001O75/KGa]K6`02002ZOod4000FOod00<Yoo@03001ooGom00]oo@03001G7E<M00=G
7@80000<DaeG7@00FcaK75/lFaaK?5/LFcaK75/l0P0000UK6ellFaaO?5/KGcaK75llFa/00P0000UO
?000Gc]O6elkGa]O>elKGc/00P00015O6`00001S6elKHa]O6f<K001S6elKHa]O6f<KGa/006<J0080
0009Ha]S6V<KHaYS6f<JHa]S6P0000QS6P03001S6V<J009S6P05001S6V<JHaX00008HaX00`00HaYS
6P05HaX00`00HaYS6P02HaX01@00HaYS6V<J000026<J00<006<JHaX016<J00<006<JHaX00V<J00<0
05lKGa/00UlK0P0015lK0P0000=O6`0000001UlK00@005lK00000:Uoo@<001Yoo@00bgom00<007om
Ood02gom00<005LmDa`00P0000EG7E<LEaeC75LM00800005EaaK?5LLFceG700200002E/mEa`00000
GcaK6ellFa]O?00200002E/KGcaK6ell001S?5lKGcaO6`0200001EllGa]O?5lKGc`00P0001AO6P00
001S>elKHc]O6V<kGa]S>elJ001O6V<kGaYS>elJHc]O6V<k0P0001UO6P00001S6f<JHa]S6V<K001S
6f<JHa]S6V<KHaX006<J001S6VLJHaYW6V<JIaYS6P0200004fLJ000006<JIaYS6VLJ001W6V<JIaYS
6VLJHaX006<J001S6VLK00=S6P06Ia]S6P00001W6`000V<J00EW6f<J001S6VLK00=S6P03Ia/005lK
0080009O6`09GaYO6elKGa]O6UlK001O6e/J00=O6`05FaYO6elKGa/0002WOod4000MOod00<aoo@80
00aoo@80000<DaeG7E<MEaeC7ELMDaeG7E<M001K75/l0P0000IK75/lFaaK?5/LFc`2000035/L0000
05llFaaO?5/KGcaK75ll001O>`80000BGa]O>elKGc]O6elkGa]O>elK001O6f<KGa]S6elKHa]O6f<K
0P0000iO6`00HaYS6f<JHa]S6V<K001S6f<JHa]S6V<K0P0000=S6P00000026<J00<006<JHaX01F<J
00<006<JHaX00V<J0P0000=S6P00000026<J00<006<JHaX01F<J00<006<JHaX00V<J00@006<J0000
00QS6P03001O6elK00IO6`800003Ga/005lK00EO6`800:Aoo@@0025oo@00cWom00<007omOod02Wom
0P0000QC75LMDaaG7E<LEaeC75LM0`0000UK?5LLFceG75/lEaaK?ELLFc`00P0000UK6ellFa]O?5/K
GcaK6ellFa/00P0000UO?5lKGcaO6ellGa]O?5lKGc`00P0002AK6`00Ga]S>elJHc]O6f<k001S>elK
Hc]O6P00GaYS>elJHc/006<kGaYS>elJHc]O6V<kGaX006<JHa]S6V<KHaYS6f<JHa/2000066<J0000
06LJHaYW6V<J001S6VLJHaYW6V<JIaYS6P00HaYW6V<JIaYS6VLJHaYW6P800003HaX00000009S6P05
Ia]S6P00HaYW6`03HaX01FLK001S6V<JIa/00f<J00EW6f<J000006LK00800004GaYO6elKGa/20002
Ga/01UlJ001O6elKFaYO6`800:9oo@@002Eoo@00cgom00<007omOod02gom0P0000=G7E<M00000`00
00YG7E<M000005/lFaaK?5/LFcaK70800009FcaG7000001O?5/KGcaK75ll00800009FaaO?000001O
6elkGa]O>elK0080000;Gc]O6elkGa/005lKHa]O6f<K001S6`03Ga/016<KGa/006<J0P0000MS6f<J
Ha]S6V<KHaYS6`0200000f<K001S6P05HaX00`00HaYS6P02HaX200000f<J00000007HaX00`00HaX0
0006HaX00`00HaYS6P02HaX200000f<J00000006HaX00`00HaX00006HaX00`00HaYS6P02HaX20000
0elK00000006Ga/01000Ga/00000X7om1000:Gom003@Ood00`00Ooeoo@0<Ood2000025<LEaeC75LM
DaaG7E<LEad200002ELLFcd00000EaaK?ELLFcaG700200002UllFa/00000GcaK6ellFa]O?5/K0P00
00aO?000001O6ellFa]O?5lKGcaK6`00Ga/20000?V<kGa]S>elJHc]O6f<kGaX005lJHc]O6V<kGaYS
>elJHc/006<kGaYS>elJ001S6V<KHaYS6`00Ha]S6V<KHaYS6f<JHa/006LJHaYW6V<JIaYS6VLJHaX0
06<JIaYS6P00HaYW6V<JIaX006LJHaYW6V<JIaYS6VLJ0002HaX01VLKHaYS6V<JIa/0009S6P09Ia/0
06<JHaYW6f<J001S6VLK00=S6P04Ia]S6P00GaX3Ga/01UlJGa]O6elKGaX009ioo@@002eoo@00dGom
0P003Gom00X005LMDaeG7E<MEaeC7ELMDaeG7@<00009FcaK75/lEaaK?5/LFcaG75/l0080000HFaaK
?5/LGcaK75/lFaaO?5/LFc`005lkGa]O>elKGc]O6elkGa]O>elK001O6f<K0elK00=S6elKGa/00P00
00UO6`00001S6f<JHa]S6V<K00000f<K00ES6V<KHa/006<J008000IS6P800003Ha/006<J00AS6P80
00ES6P04001S6P000006HaX200000f<J001S6P04HaX00`00HaYS6P03HaX01000HaX000001f<J00<0
06<J00001UlK0P00Vgom1000<Gom003COod00`00Ooeoo@0;Ood200001E<LEaeC75LMDa`00P0000YG
7E<L001G75/mEaaK?5LLFceG7080000:Fcd005llFa]O?5/KGcaK6ellFa/200002Ell001O?5/KGcaO
6ellFa]O?00200001e/K000006<kGaYS>elK00800005Hc]O6f<kGaYS>`020000;UlJ000006<kGaYS
>elJHc]O6V<kGaX006<JHa]S6V<KHaYS6f<J001O6V<KHaYS6`00IaYS6VLJ001W6V<JIaYS6VLJHaYW
6V<J001S6VLJHaYW6V<JIaYS6P000f<J00IW6P00HaYS6VLK0002HaX01VLKHaYS6V<JIa/0009S6P0<
Ia]S6V<JHaYW6f<J001S6V<KHaX005lJ0elK00<007omOod0V7om0`00=Gom003DOod00`00Ooeoo@0<
Ood00`00DaeG7@0200002U<MEaeC7ELMDad005LLFcaK75/l0P0000AK75/lEaaK?0800004FaaK?5/L
Gc`200002E/LGcaK75/l001O>elKGc]O6`02000015lkGa]O?5lK0P0000ES6`00001O6f<K00=O6`06
Ha]O6elKGa/006<J0f<K00AS6V<KHa]S6`800003Ha/0000000AS6P03001S6V<K00=S6P04Ha/006<J
0007HaX200000f<J00000004HaX00`00HaYS6P04HaX00`00HaX00006HaX200000f<J001S6P04HaX2
0005HaX01000Ga/00000Ugom1000>7om003EOod00`00Ooeoo@0<Ood200002ULMDaaG7E<LEaeC75LM
Da`005LL0P0000YK?ELLFceG75/mEaaK?ELL001K6`800009GcaK6ellFa]O?5/KGc`005ll0080000B
Ga]O?5/KGcaO6ellFa]O?000Hc]O6V<kGa]S>elJHc]O6f<k0P0000eO6`00GaYS>elJHc]O6V<k001S
>elJHc]O6P0200005F<K000005lJHa]S6V<KGaYS6f<JHa/006LJHaYW6V<JIaYS6VLJ001W6P03HaX2
00000fLJ00000003HaX01VLJHaYS6V<JIaX0009S6P05Ia]S6V<JHaX00003HaX01VLK001S6V<JIa/0
009S6P07Ha]S6V<JHaYS6f<J0000UGom1000?7om003FOod2000=Ood200001eLMDaeG7E<MEaeC7ELM
0080000:EaaK?5/LFcaG75/lFaaK?5LLFc`200002E/LFcaK75llFaaK?5/LGcaK7002000025llGa]O
>elKGcaO6elkGa/200000elk001S6`03Ga/016<KGa]O6`0015lK00<006<JHa/00V<K00D006<KHa]S
6elJ00=S6`04001S6V<JHa/3HaX01F<KHaX00000Ha/00P0016<J00<006<JHaX01F<J00<006<JHaX0
1V<J0P0000=S6P00HaX00f<J00<006<JHaX016<J00<006<J00001f<J0P00TWom1000@7om003HOod0
0`00Ooeoo@0<Ood00`00EaeC700400002ULMDa`00000FceG75/mEaaK?ELL0P0000UK?ELL000005ll
Fa]O?5/KGc`00P0000QK6ell000005/KGcaO6ell0P0000AK6ellFa]O?080000=GaYS>elKHc/006<k
Ga]S>elJHc]O6`00GaX00P0000IS>elJHc]O6V<kGaX200003F<k001S6f<JHa]O6V<KHaX005lJHa]S
6V<K00800004HaX00000IaX3HaX01VLJHaYS6P00Ia/0009S6P05IaYS6V<JHaX00003HaX00fLJ001S
6P020003HaX01VLKHaYS6V<JIa/0009S6P06Ha]S6V<JHaYS6`00T7om1000A7om003IOod00`00Ooeo
o@0<Ood2000025<MEaeC7ELMDaeG7E<MEad200002E/LFc`00000EaaK?5LLFcaG700200002E/lFa`0
0000FcaK75/lFaaK?00200003ElK000005llGa]O>elKGcaO6elkGa/005lK008000QO6`03001O6V<K
009S6`05GaYS6f<K001O6P03Ha/02000HaYS6V<KHaX006<JHa/3HaX00f<KHaX00008HaX01@00HaYS
6V<J000016<J00<006<JHaX016<J00<006<JHaX01V<J0P0000=S6P00000016<J00<007omOod0Rgom
1000B7om003JOod00`00Ooeoo@0<Ood2000025<LEaeC75LMDaaG7E<LEad3000025/mEaaK?ELLFceG
75/mEa`3000055/KGcaK6ellFa]O?5/KGcaK6`00Fa]O?5/KGcaK6ellFa]O?5/KGc`2000025lJHc]O
6f<kGaYS>elKHc/2000045lK000006<kGaYS>elJ001O6V<kGaYS>elJHc/006<K0P0000IO6V<KHaYS
6elJHa/200000elJ001S6P02HaX01FLJHaX00000Ia/00f<J00=W6`00HaX00P000f<J00IW6V<J0000
06LJ0002HaX01FLKHaYS6V<J00000f<J00AS6`00001S6P8008]oo@<004aoo@00fgom00<007omOod0
3Gom0P0000=G7E<M00000`0000UG7E<M000005/lEaaK?5LLFc`00P0000YG75/l001K?5/LFcaK75/l
FaaK?0800009Fa`00000Gc]O6ellGa]O>elK00800004Gc]O6`000004Ga/20004Ga/2000016<K0000
05lJ0f<K00EO6V<KHa]S6`00009S6P06Ha]S6V<JHaYS6`000V<J00=S6f<J00000f<J00<006<JHaX0
1V<J00<006<JHaX016<J00<006<JHaX00V<J00<006<JHaX00V<J00<006<JHaX01F<J00<007omOod0
Qgom1000Cgom003LOod2000?Ood200001e<MEaeC75LMDaeG7E<L0080000>FceG7000001K?ELLFceG
75/m001O?5/KGcaK6`800004GcaK6ellFa/200000ellFa/0000200001E/KGcaK6ellFa/00P0001AS
>`00001O6f<kGa]S>elKHc]O6f<k001S>elJHc]O6V<kGaYS>elJ0P0001=S>`00001S6V<KGaYS6`00
Ha]O6V<KHaYS6elJ001S6P00HaYW6`03HaX01VLKHaX00000Ia/0009S6P05IaYS6P00HaYW6P03HaX0
0fLJ001S6P020003HaX00f<KHaYS6P020026Ood4001COod00=ioo@03001ooGom00eoo@09001G7E<M
EaeC7ELMDaeG7E<M00<0000:EaaK?5LLFcaG75/lEaaK?000Fc`2000025/LFcaK75/lFaaK?5/LFc`2
00002elKGcaO6elkGa]O?5lKGc]O6ell000025lK0P0000=O6`0000000V<K00EO6V<K000005lJ00=S
6`800003HaX00000009S6P07Ha]S6V<JHaYS6f<J00001f<J00<006<JHaX00V<J00@006<J000000QS
6P03001S6V<J00ES6P03001ooGom089oo@@005Moo@00ggom00<007omOod03Gom00H005LMDaeG7E<L
Ead200002e<LEad005/mEaaK?ELLFceG75/mEa`00P0000QO?5/KGcaK6ellFa]O?5/K0P0000YK?000
GcaK6ellFa]O?5/KGcaK6`800007Gc`00000Ga]S>elKHc/00P0000AO6f<kGa]S>`80000DGaX00000
Hc]O6V<kGaYS>elJHc]O6P00HaYS6elJHa]S6V<KGaYS6`800003GaX00000009S6P05Ia]S6P00HaYW
6`03HaX01FLK001S6V<JIaX00f<J00EW6V<J000006LK00800005HaYS6f<JHaX00021Ood4001KOod0
0>1oo@03001ooGom00eoo@03001G7E<M0080000;EaeC7ELMDaeG7@00FcaG75/lEaaK?00200003ULL
Fa`00000FaaK?5/LFcaK7000FaaK?5/LFc`2000015lKGcaO6elk0P0000AK6elKGa]O70800003Ga/0
000000QO6`04001S6f<KGaX3Ha/025lJHa/00000GaX006<JHa/3HaX01V<K001S6V<JHa]S6P800003
HaX0000000IS6P03001S6P0000IS6P03001S6V<J009S6P800003HaX0000007ioo@@005moo@00hGom
0P003Wom0P0000]C7ELMDaaG7E<MEaeC75LM001K?ELL00800006FceG75/mEaaK?ELL0P0000aO?000
001K75/lFa]O?5/LFcaK6`00Fa/200004EllFa]O?5/KGcaK6ellFa/005lKHc]O6f<kGa]S>elKHc/0
0P0001]O6`00GaYS>elJHc]O6V<k001S>elJHc]O6P00HaYS6elJHa/006<KGaYS6f<JHa]O6V<K0000
0V<J00IW6f<JHaYS6VLK0002HaX02FLK001S6V<JIaYS6P00HaYW6`03HaX00fLKHaX0001lOod4001S
Ood00>=oo@03001ooGom00aoo@800007DaeG7E<MEaeC7ELMDad00`0000UG75/LEaaK75LLFaaG75/L
Ea`00P0000UK?5/LFcaK75/lFaaK?5/LFc`00P0000=O6elLFa/00UlK00=O75/KGa/00P0000=K6`00
Ga/01ElK00<005lKGa/00UlK00h006<KHa]O6V<K001S6elJHa]O6f<KGaX006<J0P000V<J00AS6f<J
HaYS6P800003HaX006<J00AS6P03001S6V<J00=S6P04001S6P000006HaX2001jOod3001WOod00>Ao
o@03001ooGom00eoo@03001C7ELM00@0000:DaaG7@00001G75/mEaaK?ELLFcd200002ELLFcd00000
Fa]O?5/LFcaK6`02000025/lFa/00000GcaK6ellFa/200004UllFa]O?5/K001O6f<kGa]S>`00Gc]O
6f<kGa]O>elK001O6P80000FHc]O6V<kGaYS>elJHc]O6P00HaYS6elJHa]S6V<KGaX005lJHa]O6V<K
0002HaX01FLK001S6V<JIa/00f<J00EW6`00HaYS6VLK00=S6P03Ia/007om07Moo@@006Yoo@00iGom
00<007omOod03Gom0P0000EG7E<MDaeC7ELM00=C7@800004FaaG70000002Ea`00e/MEaaG70020000
15/LFc`000001E/L0P0000aO7000001O6elLFa]O75lKGaaK6`00Ga/20008Ga/02@00Ga]S6elJHa]O
6f<KGaYS6`02000015lK000006<K0f<J00D006<JHaYS6V<K009S6P03001S6P0000IS6P800003HaX0
000000AS6P03001ooGom07=oo@@006ioo@00iWom0P003Wom0P0000QG7E<LEaeC7ELMDaaG7E<M0`00
00QG75/mEaaK?ELLFceG75/m0`0000QO?5/LFcaK6ellFaaK?5/K0P0000UO?5/KGcaK6ellFa]O?5/K
Gc`00P0000QO6elkGa]S>elKGc]O6f<k0P0000MO6`00001S>elJHc]O6P02000016<kGaYS>elJ0P00
00aS6`00001O6V<KGaYS6elJHa]O6V<K0002HaX01FLKHaYS6V<J00000f<J00AW6`00001S6P80079o
o@@0079oo@00j7om00<007omOod03Gom0P000U<M100000IC7ELM000005LLFad3Ea`20002Ea`20005
Fa`20002Fa`200001E/KGaaO6elLFa/00P0000AO75/K000000AO6`8000AO6`80000=Ha/00000Ga]S
6elKHa]O6f<KGa]S6`00Ha/00f<J00AS6f<JHaYS6P800003Ha/006<J00=S6P03001S6V<J00ES6P03
001ooGom06ioo@@007Ioo@00jGom00<007omOod03Wom0P0000MG7E<MEaeC75LMDaeG7@0200002ELL
Fcd00000EaaK?ELLFceG700200002EllFa`00000FcaK75/lFa]K?00200002E/KGc`00000Fa]O?5/K
GcaK6`02000055lk000005lKGc]O6f<lGa]O>elKHc`006<kGaYS>elJHc]O6V<kGaX200001f<k0000
05lJHa]O6V<K00800006GaYS6elJHa/006<J0P000f<J00=W6f<JHaX00P00KGom1000NWom003ZOod0
0`00Ooeoo@0>Ood20002Dad01ELMDaeC7E<MEad00`0000EK75LLEaaG75/L00=G70<000UK7080000:
GaaO6elLFa]O75lKGaaK6elL0008Ga/200003ElK001S6elKHa]O6f<KGa/005lKHa]O6f<K0080000;
HaX00000Ha]S6V<KHaYS6f<JHa/00007HaX00`00Ooeoo@1YOod4001nOod00>]oo@80011oo@03001G
7E<M00@00009EaeC7000001K?ELLFceG75/m0080000:EaaK?@00FcaK75/lFa]K?5/LFc`200002E/L
001K6ellFa]O?5/KGcaK6`0200001ell000005lKHcaO6elk0080000LGa]O>elKHc`006<kGaYS>elJ
001O6V<kGaYS>elJHc]O6P00GaYS6elJHa]O6V<KGaYS6`00Ha/200001F<JIa]S6V<J0000JGom0`00
PWom003]Ood00`00Ooeoo@0>Ood200000e<MEaeC7@02Dad01ULMDad00000FaaG70800006FaeG75LL
EaaK7@0015/L0P0015/L00D005/KGaaO6elL00800004Fa]O75/KGa`200000elK00000007Ga/02P00
Ha/00000Ga]S6elKHa]O6f<K0P0000aO6`00HaYS6f<JHa]S6V<K001S6f<JHa/200000f<J0000001V
Ood40025Ood00>ioo@03001ooGom00ioo@800007DaaG7E<LEaeC75LMDa`00`0000YG75/mEaaK?ELL
FceG75/m001K?0800009Fa]K?5/LFcaK6e/lFa`005/K0080000TGcaK6ellFa]O?5/KGcaK6`00Ga]S
?5lKGc]O6f<lGa]O>elKHc`006<kGaYS>elJHc]O6V<k001S>elJHc]O6P00GaYS6elJ0P0000MS6elJ
Ha]O6V<KGaX0001TOod40029Ood00>moo@03001ooGom00moo@03001C7ELM00@0009C7@8000=G7004
FaeG75LLEa`20009Fa`2000025/KGaaK6elLFa]O75/KGa`200000e/L001O6`06Ga/2000025lK0000
05lKHa]O6f<K0002Ga/03F<KGa]O6elK001S6P00HaYS6f<JHa]S6V<K0080065oo@@008eoo@00l7om
00<007omOod03gom0P0000MG7E<LEaeC75LMDaaG7@0200000eLLFcd0000300002ELLFcd00000FaaK
?5/KFcaK7002000025/lFa`00000GcaK6ellFa/200002EllFa]O?5/K001O6f<lGa]O>`02000015lK
Gc]O6ell0P0001=O6P00001S>elJHc]O6V<kGaYS>elJ001O6V<KGaYS6elJHa/0001OOod4002AOod0
0?5oo@80011oo@03001C7ELM00=C7@04EaeC7E<MDad20002Ea`01ELMEaaG75LLEad00P000U/L0P00
1E/L0P0000aO7000001K6elLFaaO75/KGaaK7000Ga/20008Ga/01@00Ga]O6elKHa/00elK00YS6`00
001O6`00HaYS6f<JHa/005aoo@@009Eoo@00lgom00<007omOod03Wom0P0000EG7E<LEaeC75LM0080
000:Da`005LLFceG75/mEaaK?ELLFcd3000025/lFa]K?5/LFcaK6e/lFa`200002EllFa]O?5/KGcaK
6ellFa]O?002000025lKGcaO6elkGa]O?5lKGc/200001elK000006<kGaYS>elJ00800006Hc]O6V<k
GaX005lJ0P00FGom1000VGom003dOod00`00Ooeoo@0?Ood00`00EaeC7@0200001ELMDaeC7E<M0000
0eLL00IG7ELL000005LMEa`20005Fa`20002Fa`200001E/LGaaK6elLFa`00P000U/L0P0015lK0P00
15lK0P0000=O6`0000000elK00ES6elKGa]O6`0005Qoo@<009eoo@00mGom00<007omOod03gom0P00
00YC75LMDaaG7E<LEaeC7000EaaK?@800005EaaK?ELLFceG700200002E/lFa/00000FcaG75/lFaaK
?00200002E/KGc`00000Fa]O?5/KGcaK6`0200004ell000005/KGcaO6ellFa]O?5lKGc`006<kGaYS
>elJHc]O6V<k008005Eoo@@00:1oo@00mWom0P0047om0P000e<M00=G7E<MDad00`000ULL00EG7ELL
EaaG75LM009G708000QK70<00006GaaK6e/LFaaO75/K0U/L0P0025lK0P0000EO6`00001O6f<K009O
6`03001ooGom055oo@@00:Aoo@00n7om00<007omOod03gom00<005<LEad00`0000YG7E<L000005/m
EaaK?ELLFceG70800008Fcd00000EaaK?5/LFcaG70800009FcaG7000001O?5/KGcaK6ell00800008
Fa]O?000001O6ellFa]O?0800004Fa]O?5lKGc`200000elJ0000001@Ood4002XOod00?Uoo@03001o
oGom00moo@80009C7@05EaeC7E<MDaeG7@0200001ULLEad00000EaaG7@9G7080009K708000EK7080
0006GaaK6`00001O75/K0U/L00AO7000001O6`8000QO6`03001ooGom04aoo@@00:aoo@00nWom00<0
07omOod03gom0P0000MG7E<LEaeC75LMDaaG7@03000025/mEaaK?ELLFceG75/mEa`2000025/lFaaK
?5LLFcaK75/lEa`3000025/KGcaK6ellFa]O?5/KGc`2000025lKGcaK6ellGa]O?5/KGc`2001;Ood4
002`Ood00?]oo@80015oo@03001C7E<M00@00005EaeC7@00001G7@03Ea`015LM000005LL0P001E/L
0P000U/L0P0000EK6e/LFaaO75/K00800004FaaK6`000004Ga/20019Ood4002dOod00?eoo@03001o
oGom00moo@800007DaaG7E<LEaeC75LMDa`00P0000QK?ELL000005/mEaaK?ELL0P0000UK?5/L0000
05/lEaaK?5LLFc`00P0000UK6ell000005/KGcaK6ellFa/00P0000=O?0000000B7om0`00^7om003n
Ood00`00Ooeoo@0?Ood200000e<MEaeC7@02Dad00eLMDad000020003Ea`01ELMEaaG75LLEad00P00
25/L0`000e/L00EK6e/LFaaK75/K008004Ioo@@00;]oo@00ogom00<007omOod047om00<005<LEad0
100000UC75LM000005LLFceG75/mEa`00P0000QK?@00001G75/lEaaK?5LL0P0000UK?5LL000005ll
Fa]O?5/KGc`00P00A7om1000_gom003oOod1Ood2000AOod200001ELMDaeC7E<MEad00U<M0P000ULL
0P000eLL00=G7@0000000U/L0P001E/L0P000U/L0P00@Wom1000`gom003oOod3Ood00`00Ooeoo@0?
Ood200001eLMDaaG7E<LEaeC75LM00<00008FceG75/mEaaK?ELLFceG70800008FcaG75/lEaaK?5LL
FcaG70<0041oo@@00<Moo@00ogom17om00<007omOod047om00<005LMDad010000U<M0P000ULL00=G
7ELLEa`00P0000=G700000001E/L0P00?gom1000bgom003oOod5Ood00`00Ooeoo@0@Ood200001e<L
EaeC7ELMDaaG7E<M00800008FceG7000001K7ELLEaeG70800004FcaG7000000mOod4003?Ood00?mo
o@Ioo@03001ooGom011oo@8000=C7@04EaeC7E<MDad300000eLLEaeG7002Ea`00eLMEaaG7002000l
Ood3003COod00?moo@Moo@80019oo@03001C75LM00@00009DaeG7@00001G75LMEaaK7ELL008003Yo
o@@00=Ioo@00ogom2Gom00<007omOod047om0P000U<M00EG7E<MDaeC7ELM00800004EaaG7@00000h
Ood4003JOod00?moo@Yoo@03001ooGom011oo@800007EaeC7ELMDaaG7E<MEad00`00=Wom1000gWom
003oOod;Ood00`00Ooeoo@0AOod00`00DaeC7@04000eOod4003ROod00?moo@aoo@80019oo@8003Eo
o@@00>Ioo@00ogom3Wom00<007omOod03gom00<007omOod0<Gom0`00jWom003oOod?Ood00`00Ooeo
o@0>Ood00`00Ooeoo@0]Ood4003]Ood00?mooA1oo@03001ooGom00aoo@03001ooGom02Yoo@@00?5o
o@00ogom4Gom0P0037om00<007omOod09Wom1000mGom003oOodCOod00`00Ooeoo@09Ood00`00Ooeo
o@0ROod4003iOod00?mooAAoo@03001ooGom00Qoo@03001ooGom01ioo@@00?eoo@00ogom5Gom00<0
07omOod01gom00<007omOod06Wom1000ogom0Wom003oOodFOod00`00Ooeoo@06Ood00`00Ooeoo@0G
Ood3003oOod6Ood00?mooAMoo@8000Ioo@03001ooGom01=oo@@00?moo@Uoo@00ogom6Gom00<007om
Ood00gom00<007omOod03gom1000ogom3Gom003oOodJOod00`00Ooeoo@02Ood00`00Ooeoo@0;Ood4
003oOodAOod00?mooA]oo@05001ooGomOod00009Ood4003oOodEOod00?mooAaoo@800003Ood007om
00Aoo@@00?mooAUoo@00ogom7Wom0P0000=oo@0000000P00ogom7Gom003oOodOOod2003oOodQOod0
0?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogo
Ooe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom
003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogom
ogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9o
o@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mo
oOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2
Ood00?mooOmooD9oo@00ogomogom@Wom003oOogoOoe2Ood00?mooOmooD9oo@00\
\>"],
  ImageRangeCache->{{{0, 575.75}, {466.875, 0}} -> {-0.19103, -0.0162313, \
0.00198632, 0.00198632}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Normalizations and sum rules", "Section",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(pmin = 
        First[qmesh];\)\[IndentingNewLine] (*\ \(pmax = 
          Last[qmesh];\)\ \ *) \), "\[IndentingNewLine]", 
    \(\ \(pmax = 6.5;\)\ \), "\[IndentingNewLine]", 
    \(emin0 = ener[\([1]\)]; 
    emin1 = ener[\([2]\)];\), "\[IndentingNewLine]", 
    \(\(emax = 190. ;\)\ \)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nd0 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*d0[p], {p, pmin, 1. , pmax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc0t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c0t0[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc0t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c0t1[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(n0p = \((nd0 + nc0t0 + nc0t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n0n = \((2. *nc0t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<No. protons = \>", n0p, "\<\tNo. neutrons = \>", 
      n0n, \[IndentingNewLine]"\<\nnd0 = \>", nd0, "\<, nc0t0 = \>", \ 
      nc0t0, "\<, nc0t1 = \>", nc0t1\ ]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("No. protons = "\[InvisibleSpace]1.9980444256030467`\
\[InvisibleSpace]"\tNo. neutrons = "\[InvisibleSpace]0.9987563415514977`\
\[InvisibleSpace]"\nnd0 = "\[InvisibleSpace]0.45149670167576583`\
\[InvisibleSpace]", nc0t0 = "\[InvisibleSpace]0.048058716600000134`\
\[InvisibleSpace]", nc0t1 = "\[InvisibleSpace]0.16645939025858295`\),
      SequenceForm[ 
      "No. protons = ", 1.9980444256030467, 
        "\tNo. neutrons = ", .99875634155149773, 
        "\nnd0 = ", .45149670167576583, ", nc0t0 = ", .048058716600000134, 
        ", nc0t1 = ", .16645939025858295],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \( (***) \)], "Input"],

Cell[BoxData[
    InterpretationBox[\("No. protons = "\[InvisibleSpace]1.9983798564246422`\
\[InvisibleSpace]"\tNo. neutrons = "\[InvisibleSpace]0.998753892850605`\
\[InvisibleSpace]"\nnd0 = "\[InvisibleSpace]0.45160863792611633`\
\[InvisibleSpace]", nc0t0 = "\[InvisibleSpace]0.048058998740330254`\
\[InvisibleSpace]", nc0t1 = "\[InvisibleSpace]0.1664589821417675`\),
      SequenceForm[ 
      "No. protons = ", 1.9983798564246422, 
        "\tNo. neutrons = ", .99875389285060501, 
        "\nnd0 = ", .45160863792611633, ", nc0t0 = ", .048058998740330254, 
        ", nc0t1 = ", .16645898214176749],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nd1 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*d1[p], {p, pmin, 1. , pmax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc1t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c1t0[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc1t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c1t1[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(n1p = \((nd1 + nc1t0 + nc1t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n1n = \((2. *nc1t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<Proton polarization = \>", 
      n1p, "\<\tNeutron polarization = \>", 
      n1n, \[IndentingNewLine]"\<\nnd1 = \>", nd1, "\<, nc1t0 = \>", \ 
      nc1t0, "\<, nc1t1 = \>", nc1t1\ ]\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nc1t0\)\" is similar to \
existing symbol \"\!\(c1t0\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nc1t1\)\" is similar to \
existing symbol \"\!\(c1t1\)\"."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Proton polarization = \
"\[InvisibleSpace]\(-0.04404712697657415`\)\[InvisibleSpace]"\tNeutron \
polarization = "\[InvisibleSpace]0.8841944093099886`\[InvisibleSpace]"\nnd1 = \
"\[InvisibleSpace]\(-0.150536135817869`\)\[InvisibleSpace]", nc1t0 = "\
\[InvisibleSpace]\(-0.011511974725987143`\)\[InvisibleSpace]", nc1t1 = "\
\[InvisibleSpace]0.1473657348849981`\),
      SequenceForm[ 
      "Proton polarization = ", -.044047126976574147, 
        "\tNeutron polarization = ", .8841944093099886, 
        "\nnd1 = ", -.15053613581786901, ", nc1t0 = ", -.011511974725987143, 
        ", nc1t1 = ", .1473657348849981],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nd2 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*d2[p], {p, pmin, 1. , pmax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc2t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c2t0[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(nc2t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*c2t1[e, p], {p, pmin, 1. , pmax}, {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\[IndentingNewLine]", 
    \(\(n2p = \((nd2 + nc2t0 + nc2t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n2n = \((2. *nc2t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<Proton tensor pol. = \>", n2p, "\<\tNeutron tensor pol. = \>", 
      n2n, \[IndentingNewLine]"\<\nnd1 = \>", nd2, "\<, nc2t0 = \>", \ 
      nc2t0, "\<, nc2t1 = \>", nc2t1\ ]\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nc2t0\)\" is similar to \
existing symbol \"\!\(c2t0\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nc2t1\)\" is similar to \
existing symbol \"\!\(c2t1\)\"."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Proton tensor pol. = \
"\[InvisibleSpace]\(-0.23339912408185917`\)\[InvisibleSpace]"\tNeutron tensor \
pol. = "\[InvisibleSpace]0.03516916031497026`\[InvisibleSpace]"\nnd1 = "\
\[InvisibleSpace]\(-0.0780685712301736`\)\[InvisibleSpace]", nc2t0 = "\
\[InvisibleSpace]\(-0.005592663516274491`\)\[InvisibleSpace]", nc2t1 = "\
\[InvisibleSpace]0.00586152671916171`\),
      SequenceForm[ 
      "Proton tensor pol. = ", -.23339912408185917, 
        "\tNeutron tensor pol. = ", .035169160314970263, 
        "\nnd1 = ", -.078068571230173606, ", nc2t0 = ", -.0055926635162744914,
         ", nc2t1 = ", .0058615267191617099],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Momentum distribution", "Section",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pmin = First[qmesh];\)\), "\[IndentingNewLine]", 
    \(pmax = Last[qmesh]; \ pmax = 6.5;\), "\[IndentingNewLine]", 
    \(emin0 = ener[\([1]\)]; 
    emin1 = ener[\([2]\)];\), "\[IndentingNewLine]", 
    \(\(emax = Last[ener];\)\ \)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(emax\)\" is similar to \
existing symbol \"\!\(pmax\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[{
    \(\(md0[p_] := 
        d0[p] + NIntegrate[c0t0[e, p], {e, emin1, 10. , emax}, 
            intops // Evaluate];\)\), "\n", 
    \(\(md1[p_] := 
        NIntegrate[c0t1[e, p], {e, emin1, 10. , emax}, 
          intops // Evaluate];\)\), "\n", 
    \(\(mdp[p_] := 4*Pi*\((md0[p] + md1[p])\);\)\), "\n", 
    \(\(mdn[p_] := 8*Pi*md1[p];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NIntegrate[p^2*mdp[p], {p, pmin, 1. , pmax}, 
      intops // Evaluate]\), "\[IndentingNewLine]", 
    \(NIntegrate[p^2*mdn[p], {p, pmin, 1. , pmax}, 
      intops // Evaluate]\)}], "Input"],

Cell[BoxData[
    \(1.9983670015741506`\)], "Output"],

Cell[BoxData[
    \(0.9987451496868934`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{mdp[p]/2, 
        mdn[p], \((mdp[p] + mdn[p])\)/3}\[IndentingNewLine], {p, pmin, 
        pmax/6}\[IndentingNewLine], PlotRange \[Rule] All\[IndentingNewLine], 
      PlotStyle \[Rule] sty]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0205465 0.882133 0.0120278 0.0138395 [
[.19697 -0.00047 -9 -9 ]
[.19697 -0.00047 9 0 ]
[.3734 -0.00047 -9 -9 ]
[.3734 -0.00047 9 0 ]
[.54983 -0.00047 -9 -9 ]
[.54983 -0.00047 9 0 ]
[.72625 -0.00047 -9 -9 ]
[.72625 -0.00047 9 0 ]
[.90268 -0.00047 -3 -9 ]
[.90268 -0.00047 3 0 ]
[.00805 .15042 -12 -4.5 ]
[.00805 .15042 0 4.5 ]
[.00805 .28882 -12 -4.5 ]
[.00805 .28882 0 4.5 ]
[.00805 .42721 -12 -4.5 ]
[.00805 .42721 0 4.5 ]
[.00805 .56561 -12 -4.5 ]
[.00805 .56561 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19697 .01203 m
.19697 .01828 L
s
[(0.2)] .19697 -0.00047 0 1 Mshowa
.3734 .01203 m
.3734 .01828 L
s
[(0.4)] .3734 -0.00047 0 1 Mshowa
.54983 .01203 m
.54983 .01828 L
s
[(0.6)] .54983 -0.00047 0 1 Mshowa
.72625 .01203 m
.72625 .01828 L
s
[(0.8)] .72625 -0.00047 0 1 Mshowa
.90268 .01203 m
.90268 .01828 L
s
[(1)] .90268 -0.00047 0 1 Mshowa
.125 Mabswid
.06465 .01203 m
.06465 .01578 L
s
.10876 .01203 m
.10876 .01578 L
s
.15287 .01203 m
.15287 .01578 L
s
.24108 .01203 m
.24108 .01578 L
s
.28519 .01203 m
.28519 .01578 L
s
.32929 .01203 m
.32929 .01578 L
s
.41751 .01203 m
.41751 .01578 L
s
.46161 .01203 m
.46161 .01578 L
s
.50572 .01203 m
.50572 .01578 L
s
.59393 .01203 m
.59393 .01578 L
s
.63804 .01203 m
.63804 .01578 L
s
.68215 .01203 m
.68215 .01578 L
s
.77036 .01203 m
.77036 .01578 L
s
.81447 .01203 m
.81447 .01578 L
s
.85857 .01203 m
.85857 .01578 L
s
.94679 .01203 m
.94679 .01578 L
s
.99089 .01203 m
.99089 .01578 L
s
.25 Mabswid
0 .01203 m
1 .01203 L
s
.02055 .15042 m
.0268 .15042 L
s
[(10)] .00805 .15042 1 0 Mshowa
.02055 .28882 m
.0268 .28882 L
s
[(20)] .00805 .28882 1 0 Mshowa
.02055 .42721 m
.0268 .42721 L
s
[(30)] .00805 .42721 1 0 Mshowa
.02055 .56561 m
.0268 .56561 L
s
[(40)] .00805 .56561 1 0 Mshowa
.125 Mabswid
.02055 .03971 m
.0243 .03971 L
s
.02055 .06739 m
.0243 .06739 L
s
.02055 .09506 m
.0243 .09506 L
s
.02055 .12274 m
.0243 .12274 L
s
.02055 .1781 m
.0243 .1781 L
s
.02055 .20578 m
.0243 .20578 L
s
.02055 .23346 m
.0243 .23346 L
s
.02055 .26114 m
.0243 .26114 L
s
.02055 .3165 m
.0243 .3165 L
s
.02055 .34417 m
.0243 .34417 L
s
.02055 .37185 m
.0243 .37185 L
s
.02055 .39953 m
.0243 .39953 L
s
.02055 .45489 m
.0243 .45489 L
s
.02055 .48257 m
.0243 .48257 L
s
.02055 .51025 m
.0243 .51025 L
s
.02055 .53793 m
.0243 .53793 L
s
.02055 .59329 m
.0243 .59329 L
s
.25 Mabswid
.02055 0 m
.02055 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02846 .6024 L
.03279 .60154 L
.03523 .60106 L
.03643 .60082 L
.03754 .6006 L
.03881 .59998 L
.0402 .59919 L
.04262 .5978 L
.05285 .59198 L
.05786 .58915 L
.06005 .58792 L
.06244 .58658 L
.06369 .58573 L
.06485 .58443 L
.06713 .58187 L
.07218 .57625 L
.0829 .56449 L
.10458 .5393 L
.14371 .47704 L
.18529 .40165 L
.22536 .33451 L
.26391 .27144 L
.30491 .21738 L
.3444 .17172 L
.38237 .13761 L
.4228 .10858 L
.4617 .08656 L
.50307 .06875 L
.54291 .0556 L
.58124 .04578 L
.62202 .03781 L
.66129 .03197 L
.69904 .02761 L
.73924 .02402 L
.77793 .02138 L
.81907 .01923 L
.85869 .01764 L
.8968 .01643 L
.93736 .01544 L
.97619 .01472 L
s
1 0 0 r
.02381 .39236 m
.02846 .39195 L
.03279 .39157 L
.03523 .39135 L
.03643 .39124 L
.03754 .39115 L
.03881 .39087 L
.0402 .39051 L
.04262 .38988 L
.05285 .38726 L
.05786 .38598 L
.06005 .38542 L
.06244 .38481 L
.06369 .38443 L
.06485 .38383 L
.06713 .38266 L
.07218 .38008 L
.0829 .37467 L
.09406 .36911 L
.10458 .36289 L
.1251 .34668 L
.14371 .33266 L
.18226 .29629 L
.22326 .25848 L
.26275 .21919 L
.30072 .18749 L
.34115 .15387 L
.38006 .12785 L
.42142 .1043 L
.46126 .08527 L
.49959 .07083 L
.54037 .05835 L
.57964 .04852 L
.61739 .04114 L
.65759 .03499 L
.69628 .0302 L
.73742 .02617 L
.77705 .02319 L
.81515 .02095 L
.85571 .01909 L
.89476 .0176 L
.93626 .01639 L
.97619 .0155 L
s
.2 1 0 r
.02381 .533 m
.02846 .53225 L
.03279 .53155 L
.03523 .53116 L
.03643 .53096 L
.03754 .53078 L
.03881 .53028 L
.0402 .52963 L
.04262 .5285 L
.05285 .52374 L
.05786 .52143 L
.06005 .52042 L
.06244 .51932 L
.06369 .51863 L
.06485 .51756 L
.06713 .51546 L
.07218 .51086 L
.0829 .50122 L
.10458 .48049 L
.14371 .42891 L
.18529 .36557 L
.22536 .30841 L
.26391 .25368 L
.30491 .20614 L
.3444 .16497 L
.38237 .13389 L
.4228 .10691 L
.4617 .08607 L
.50307 .06906 L
.54291 .05628 L
.58124 .04658 L
.62202 .03866 L
.66129 .03281 L
.69904 .02837 L
.73924 .02469 L
.77793 .02196 L
.81907 .01973 L
.85869 .01808 L
.8968 .0168 L
.93736 .01575 L
.97619 .01498 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{534, 330.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008F0001BQ000`40O003h00Oogomogom67om001Z
Ood20004Ood20003Ood4001<Ood20004Ood20005Ood3001<Ood20004Ood20003Ood3001=Ood20004
Ood20004Ood2001BOod5000eOod006Uoo@04001ooGom0008Ood00`00Ooeoo@1<Ood01000Ooeoo@00
2gom00<007omOod0BWom00@007omOod000Qoo@04001ooGom001;Ood01000Ooeoo@0027om00@007om
Ood005=oo@03001ooGom03Eoo@00JGom00@007omOod000Uoo@03001ooGom04]oo@04001ooGom0008
Ood5001;Ood01000Ooeoo@0027om00@007omOod004]oo@04001ooGom0008Ood01000Ooeoo@00Dgom
00<007omOod0=Gom001YOod01000Ooeoo@002Wom00<007omOod0BWom00@007omOod000Qoo@04001o
oGom001<Ood01000Ooeoo@0027om0`00C7om00@007omOod000Uoo@8005Aoo@03001ooGom03Eoo@00
JGom00@007omOod000Qoo@04001ooGom001;Ood01000Ooeoo@002Gom00<007om0000C7om00@007om
Ood000Uoo@03001ooGom04]oo@04001ooGom0008Ood01000Ooeoo@00Dgom00<007omOod0=Gom001Z
Ood2000:Ood2001=Ood2000;Ood2001=Ood2000:Ood3001<Ood2000:Ood2001COod2000gOod00?mo
oOmooAQoo@00ogomogom67om003oOogoOodHOod001Ioo@03001ooGom0?mooOioo@005Wom00<007om
Ood0ogomoWom000FOod00`00Ooeoo@3oOognOod001Ioo@03001ooGom0?mooOioo@005Wom00<007om
Ood0ogomoWom000FOod00`00Ooeoo@3oOognOod000]ooOl00?l000T000Aoo@005Wom00<007omOod0
57om00<007omOod04gom00<007omOod057om00<007omOod057om00<007omOod057om00<007omOod0
57om00<007omOod057om00<007omOod04gom00<007omOod057om00<007omOod057om00<007omOod0
57om00<007omOod057om00<007omOod057om00<007omOod04gom00<007omOod057om00<007omOod0
57om00<007omOod057om00<007omOod057om00<007omOod04gom00<007omOod057om00<007omOod0
57om00<007omOod00Wom2aOP1gom00<007omOod01gom000FOod00`00Ooeoo@0DOod00`00Ooeoo@0C
Ood00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0D
Ood00`00Ooeoo@0COod00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0D
Ood00`00Ooeoo@0DOod00`00Ooeoo@0COod00`00Ooeoo@0DOod00`00Ooeoo@0DOod00`00Ooeoo@0D
Ood00`00Ooeoo@0DOod00`00Ooeoo@0COod00`00Ooeoo@08OodX5n0;O007Ood00`00Ooeoo@07Ood0
01Ioo@03001ooGom05Qoo@03001ooGom05Qoo@03001ooGom05Uoo@03001ooGom05Qoo@03001ooGom
03QooA@Gh1=l035oo@005Wom00<007omOod0ogomTGom5AOP4W`0AWom000FOod00`00Ooeoo@3oOoel
OodE5n0CO01JOod001Ioo@03001ooGom0?mooFeoo@lGh1=l06moo@005Wom00<007omOod0ogomHgom
2QOP3W`0Pgom000FOod00`00Ooeoo@3oOoeHOod200095n09O02BOod001Ioo@03001ooGom0?mooDio
o@D000LGh0Ml09eoo@005Wom00<007omOod0ogomAWom1`001QOP1G`0YWom000FOod00`00Ooeoo@3o
OodoOod700075n04O02]Ood001Ioo@03001ooGom0?mooCUoo@H000LGh0El0;=oo@005Wom00<007om
Ood0ogom<gom1P001QOP1G`0^Wom000FOod3003oOod^Ood500065n04O031Ood001Ioo@03001ooGom
0?mooBQoo@H000DGh0Al0<Moo@005Wom00<007omOod0ogom8gom1@001QOP0g`0cGom000FOod00`00
Ooeoo@3oOodNOod500055n04O03BOod001Ioo@03001ooGom0?mooAYoo@@000DGh0Al0=Moo@005Wom
00<007omOod0ogom5Wom100011OP17`0g7om000FOod00`00Ooeoo@3oOodBOod400045n03O03QOod0
01Ioo@03001ooGom0?moo@ioo@@000@Gh0=l0>Eoo@005Wom00<007omOod0ogom2gom0`0011OP0g`0
jGom000FOod00`00Ooeoo@3oOod8Ood300035n03O03]Ood001Ioo@03001ooGom0?moo@Eoo@8000@G
h09l0?5oo@005Wom00<007omOod0ogom0Wom0P000aOP0g`0m7om000FOod00`00Ooeoo@3oOod01000
5n0Gh1OP0W`0n7om000FOod00`00Ooeoo@3lOod45n02O03kOod001Ioo@03001ooGom0?Uoo@<Gh09l
0?moo@005Wom0`00mWom0aOP0W`0ogom0gom000FOod00`00Ooeoo@3dOod25n000g`0Ooeoo@3oOod5
Ood001Ioo@03001ooGom0?5oo@<Gh?moo@Yoo@005Wom00<007omOod0kgom0QOP00=l07omOod0ogom
2Wom000FOod00`00Ooeoo@3/Ood35n3oOod?Ood001Ioo@03001ooGom0>Yoo@8Gh003O01ooGom0?mo
o@moo@005Wom00<007omOod0j7om0QOPogom57om000FOod00`00Ooeoo@3UOod35n3oOodFOod001Io
o@03001ooGom0>=oo@8Gh?mooAUoo@005Wom00<007omOod0h7om00=l01OP5n00ogom6gom000FOod0
0`00Ooeoo@3NOod00g`05n0Gh03oOodMOod001Ioo@03001ooGom0=aoo@03O00Gh1OP0?mooAmoo@00
5Wom00<007omOod0fWom00=l01OP5n00ogom8Gom000FOod00`00Ooeoo@3HOod017`05n0Gh000ogom
8Wom000FOod3003FOod017`05n0Gh000ogom97om000FOod00`00Ooeoo@3DOod2O0000aOP001oo@3o
OodUOod001Ioo@03001ooGom0=9oo@9l008Gh003001ooGom0?mooBEoo@005Wom00<007omOod0d7om
0W`00QOP00<007omOod0ogom9gom000FOod00`00Ooeoo@3>Ood2O0025n000`00Ooeoo@3oOodYOod0
01Ioo@03001ooGom0<aoo@9l008Gh0800?mooBaoo@005Wom00<007omOod0bWom0W`000AooAOP0000
0?mooBioo@005Wom00<007omOod0b7om0W`000AooAOP5n000?mooC1oo@005Wom00<007omOod0aWom
0W`00Wom00<Gh0000000ogom<Gom000FOod00`00Ooeoo@35Ood00g`0Ooeoo@025n000`00Ooeoo@3o
OodaOod001Ioo@03001ooGom0<=oo@9l009oo@035n1oo@000?mooCAoo@005Wom00<007omOod0`Gom
0W`00Wom0QOP0P00ogom=Gom000FOod00`00Ooeoo@2oOod2O003Ood00aOPOod0003oOodgOod001Io
o@03001ooGom0;ioo@04O01ooGomOod25n02003oOodhOod001Ioo@<00;aoo@9l00=oo@035n1oo@00
0?mooCYoo@005Wom00<007omOod0^Wom0W`00gom0QOP00=oo@00Ood0ogom>Wom000FOod00`00Ooeo
o@2hOod2O004Ood011OPOod00000ogom?7om000FOod00`00Ooeoo@2gOod00g`0Ooeoo@02Ood25n00
0gom001oo@3oOodmOod001Ioo@03001ooGom0;Eoo@9l00Aoo@045n1oo@00003oOodoOod001Ioo@03
001ooGom0;Aoo@03O01ooGom009oo@8Gh003Ood007om0?mooD1oo@005Wom00<007omOod0/Wom0W`0
17om00@Gh7omOod00?mooD9oo@005Wom00<007omOod0/Gom00=l07omOod00gom00@Gh7om00000?mo
oD=oo@005Wom00<007omOod0[gom0W`017om0QOP00=oo@00Ood0ogomA7om000FOod00`00Ooeoo@2]
Ood2O005Ood011OPOoeoo@00ogomAWom000FOod00`00Ooeoo@2/Ood00g`0Ooeoo@04Ood011OPOoeo
o@00ogomAgom000FOod00`00Ooeoo@2ZOod2O006Ood011OPOoeoo@00ogomB7om000FOod00`00Ooeo
o@2YOod00g`0Ooeoo@04Ood25n000gom0000003oOoe9Ood000Aoo@D0009oo@8000Uoo@03001ooGom
0:Moo@9l00Ioo@045n1ooGom003oOoe;Ood000Ioo@05001ooGomOod00002Ood00`00Ooeoo@06Ood0
0`00Ooeoo@2VOod00g`0Ooeoo@05Ood011OPOoeoo@00ogomC7om0006Ood01@00OoeooGom00000Wom
00<007omOod01Wom1000Xgom0W`01gom00@Gh7omOod00?mooDeoo@001Wom00D007omOoeoo@00009o
o@03001ooGom00Ioo@03001ooGom0:=oo@03O01ooGom00Eoo@8Gh09oo@03001ooGom0?mooDaoo@00
1Wom00D007omOoeoo@00009oo@03001ooGom00Ioo@03001ooGom0:9oo@03O01ooGom00Eoo@055n1o
oGomOod0003oOoe?Ood000Eoo@8000Aoo@8000Uoo@03001ooGom0:5oo@03O01ooGom00Eoo@055n1o
oGomOod0003oOoe@Ood001Ioo@03001ooGom09moo@9l00Moo@055n1ooGomOod0003oOoeAOod001Io
o@03001ooGom09ioo@03O01ooGom00Eoo@8Gh0=oo@03001ooGom0?mooE1oo@005Wom00<007omOod0
WGom00=l07omOod01Gom00@Gh7omOoeoo@800?mooE=oo@005Wom00<007omOod0W7om00=l07omOod0
1Gom00DGh7omOoeoo@000?mooEEoo@005Wom00<007omOod0Vgom00=l07omOod01Gom00DGh7omOoeo
o@000?mooEIoo@005Wom00<007omOod0VWom00=l07omOod01Gom00DGh7omOoeoo@000?mooEMoo@00
5Wom00<007omOod0V7om0W`01gom00DGh7omOoeoo@000?mooEQoo@005Wom00<007omOod0Ugom00=l
07omOod01Wom00DGh7omOoeoo@000?mooEUoo@005Wom00<007omOod0UWom00=l07omOod01Wom00DG
h7omOoeoo@000?mooEYoo@005Wom00<007omOod0UGom00=l07omOod01Wom00DGh7omOoeoo@000?mo
oE]oo@005Wom0`00U7om00=l07omOod01Wom00DGh7omOoeoo@000?mooEaoo@005Wom00<007omOod0
Tgom00=l07omOod01Wom00<Gh7omOod00Wom00<007omOod0ogomFWom000FOod00`00Ooeoo@2AOod2
O008Ood00aOPOoeoo@02Ood00`00Ooeoo@3oOoeKOod001Ioo@03001ooGom091oo@03O01ooGom00Mo
o@035n1ooGom009oo@03001ooGom0?mooEaoo@005Wom00<007omOod0Sgom00=l07omOod027om00DG
h7omOoeoo@000?mooEmoo@005Wom00<007omOod0SWom00=l07omOod027om00DGh7omOoeoo@000?mo
oF1oo@005Wom00<007omOod0SGom00=l07omOod027om00DGh7omOoeoo@000?mooF5oo@005Wom00<0
07omOod0Rgom0W`02Wom00DGh7omOoeoo@000?mooF9oo@005Wom00<007omOod0RWom00=l07omOod0
2Gom00DGh7omOoeoo@000?mooF=oo@005Wom00<007omOod0RGom00=l07omOod02Gom00<Gh7omOod0
0Wom00<007omOod0ogomHGom000FOod00`00Ooeoo@28Ood00g`0Ooeoo@09Ood00aOPOoeoo@02Ood0
0`00Ooeoo@3oOoeROod001Ioo@03001ooGom08Ioo@9l00]oo@035n1ooGom009oo@03001ooGom0?mo
oF=oo@005Wom00<007omOod0QGom00=l07omOod02Wom00<Gh7omOod00Wom00<007omOod0ogomI7om
000FOod00`00Ooeoo@24Ood00g`0Ooeoo@0:Ood00aOPOoeoo@02Ood00`00Ooeoo@3oOoeUOod001Io
o@<008=oo@03O01ooGom00Yoo@035n1ooGom009oo@03001ooGom0?mooFIoo@005Wom00<007omOod0
PGom0W`037om00<Gh7omOod00Wom00<007omOod0ogomIgom000FOod00`00Ooeoo@20Ood00g`0Ooeo
o@0;Ood00aOPOoeoo@02Ood00`00Ooeoo@3oOoeXOod001Ioo@03001ooGom07moo@03O01ooGom00]o
o@035n1ooGom00=oo@03001ooGom0?mooFQoo@005Wom00<007omOod0OWom00=l07omOod037om00<G
h7omOod00Wom00<007omOod0ogomJGom000FOod00`00Ooeoo@1lOod2O00>Ood00aOPOoeoo@02Ood0
0`00Ooeoo@3oOoeZOod001Ioo@03001ooGom07]oo@03O01ooGom00eoo@035n1ooGom009oo@03001o
oGom0?mooF]oo@005Wom00<007omOod0NWom00=l07omOod03Gom00<Gh7omOod00Wom00<007omOod0
ogomK7om000FOod00`00Ooeoo@1iOod00g`0Ooeoo@0=Ood00aOPOoeoo@03Ood00`00Ooeoo@3oOoe/
Ood001Ioo@03001ooGom07Qoo@03O01ooGom00eoo@035n1ooGom00=oo@03001ooGom0?mooFeoo@00
5Wom00<007omOod0Mgom00=l07omOod03Wom00<Gh7omOod00Wom00<007omOod0ogomKWom000FOod0
0`00Ooeoo@1fOod00g`0Ooeoo@0>Ood00aOPOoeoo@02Ood00`00Ooeoo@3oOoe_Ood001Ioo@03001o
oGom07Eoo@03O01ooGom00ioo@035n1ooGom00=oo@03001ooGom0?mooFmoo@005Wom00<007omOod0
M7om00=l07omOod03Wom00<Gh7omOod00gom00<007omOod0ogomL7om000FOod3001cOod00g`0Ooeo
o@0>Ood00aOPOoeoo@03Ood00`00Ooeoo@3oOoeaOod001Ioo@03001ooGom079oo@03O01ooGom00io
o@035n1ooGom00=oo@03001ooGom0?mooG9oo@005Wom00<007omOod0LGom00=l07omOod03gom00<G
h7omOod00gom00<007omOod0ogomLWom000FOod00`00Ooeoo@1`Ood00g`0Ooeoo@0?Ood00aOPOoeo
o@03Ood00`00Ooeoo@3oOoecOod001Ioo@03001ooGom06moo@03O01ooGom00moo@035n1ooGom00=o
o@03001ooGom0?mooGAoo@005Wom00<007omOod0KWom00=l07omOod03gom00<Gh7omOod00gom00<0
07omOod0ogomMGom000FOod00`00Ooeoo@1]Ood00g`0Ooeoo@0?Ood00aOPOoeoo@04Ood00`00Ooeo
o@3oOoeeOod001Ioo@03001ooGom06aoo@03O01ooGom00moo@035n1ooGom00Aoo@03001ooGom0?mo
oGIoo@005Wom00<007omOod0Jgom00=l07omOod047om00<Gh7omOod00gom00<007omOod0ogomMgom
000FOod00`00Ooeoo@1ZOod00g`0Ooeoo@0@Ood00aOPOoeoo@03Ood00`00Ooeoo@3oOoehOod001Io
o@03001ooGom06Uoo@03O01ooGom011oo@035n1ooGom00Aoo@03001ooGom0?mooGQoo@005Wom00<0
07omOod0J7om00=l07omOod047om00<Gh7omOod017om00<007omOod0ogomNGom000FOod00`00Ooeo
o@1WOod00g`0Ooeoo@0@Ood00aOPOoeoo@04Ood00`00Ooeoo@3oOoejOod001Ioo@03001ooGom06Io
o@03O01ooGom015oo@035n1ooGom00=oo@03001ooGom0?mooG]oo@005Wom00<007omOod0IGom00=l
07omOod04Gom00<Gh7omOod017om00<007omOod0ogomNgom000FOod3001TOod00g`0Ooeoo@0AOod0
0aOPOoeoo@04Ood00`00Ooeoo@3oOoelOod001Ioo@03001ooGom06=oo@03O01ooGom015oo@035n1o
oGom00Aoo@03001ooGom0?mooGeoo@005Wom00<007omOod0HWom00=l07omOod04Wom00<Gh7omOod0
0gom00<007omOod0ogomOWom000FOod00`00Ooeoo@1POod2O00DOod00aOPOoeoo@04Ood00`00Ooeo
o@3oOoenOod001Ioo@03001ooGom05moo@03O01ooGom01=oo@035n1ooGom00Aoo@03001ooGom0?mo
oGmoo@005Wom00<007omOod0GWom00=l07omOod057om00<Gh7omOod00gom00<007omOod0ogomP7om
000FOod00`00Ooeoo@1MOod00g`0Ooeoo@0DOod00aOPOoeoo@03Ood00`00Ooeoo@3oOof1Ood001Io
o@03001ooGom05aoo@03O01ooGom01Aoo@035n1ooGom00Aoo@03001ooGom0?mooH5oo@005Wom00<0
07omOod0Fgom00=l07omOod057om00<Gh7omOod017om00<007omOod0ogomPWom000FOod00`00Ooeo
o@1JOod00g`0Ooeoo@0EOod00aOPOoeoo@04Ood00`00Ooeoo@3oOof2Ood001Ioo@03001ooGom05Uo
o@03O01ooGom01Eoo@035n1ooGom00Aoo@03001ooGom0?mooH=oo@005Wom00<007omOod0F7om00=l
07omOod05Gom00<Gh7omOod017om00<007omOod0ogomQ7om0004Ood40003Ood20009Ood00`00Ooeo
o@1GOod00g`0Ooeoo@0FOod00aOPOoeoo@04Ood00`00Ooeoo@3oOof4Ood000Aoo@03001ooGom00=o
o@04001ooGom0008Ood00`00Ooeoo@1EOod2O00HOod00aOPOoeoo@04Ood00`00Ooeoo@3oOof5Ood0
00Eoo@03001ooGom009oo@04001ooGom0008Ood4001COod00g`0Ooeoo@0GOod00aOPOoeoo@05Ood0
0`00Ooeoo@3oOof5Ood000Ioo@05001ooGomOod00002Ood00`00Ooeoo@06Ood00`00Ooeoo@1COod0
0g`0Ooeoo@0GOod00aOPOoeoo@05Ood00`00Ooeoo@3oOof6Ood000Aoo@04001ooGom0002Ood01000
Ooeoo@0027om00<007omOod0DWom00=l07omOod067om00<Gh7omOod017om00<007omOod0ogomQgom
0005Ood20004Ood20009Ood00`00Ooeoo@1AOod00g`0Ooeoo@0HOod00aOPOoeoo@05Ood00`00Ooeo
o@3oOof7Ood001Ioo@03001ooGom051oo@03O01ooGom01Qoo@035n1ooGom00Eoo@03001ooGom0?mo
oHQoo@005Wom00<007omOod0Cgom00=l07omOod06Gom00<Gh7omOod01Gom00<007omOod0ogomR7om
000FOod00`00Ooeoo@1>Ood00g`0Ooeoo@0IOod00aOPOoeoo@05Ood00`00Ooeoo@3oOof9Ood001Io
o@03001ooGom04eoo@03O01ooGom01Uoo@035n1ooGom00Eoo@03001ooGom0?mooHYoo@005Wom00<0
07omOod0C7om00=l07omOod06Gom00<Gh7omOod01Wom00<007omOod0ogomRWom000FOod00`00Ooeo
o@1;Ood00g`0Ooeoo@0JOod00aOPOoeoo@05Ood00`00Ooeoo@3oOof;Ood001Ioo@03001ooGom04Yo
o@03O01ooGom01Yoo@035n1ooGom00Eoo@03001ooGom0?mooHaoo@005Wom00<007omOod0BGom00=l
07omOod06Wom00<Gh7omOod01Wom00<007omOod0ogomS7om000FOod00`00Ooeoo@18Ood00g`0Ooeo
o@0KOod00aOPOoeoo@05Ood00`00Ooeoo@3oOof=Ood001Ioo@03001ooGom04Moo@03O01ooGom01]o
o@035n1ooGom00Ioo@03001ooGom0?mooHeoo@005Wom0`00AWom00=l07omOod06gom00<Gh7omOod0
1Wom00<007omOod0ogomSWom000FOod00`00Ooeoo@15Ood00g`0Ooeoo@0LOod00aOPOoeoo@05Ood0
0`00Ooeoo@3oOof?Ood001Ioo@03001ooGom04Aoo@03O01ooGom01aoo@035n1ooGom00Ioo@03001o
oGom0?mooHmoo@005Wom00<007omOod0@gom00=l07omOod077om00<Gh7omOod01Wom00<007omOod0
ogomT7om000FOod00`00Ooeoo@12Ood00g`0Ooeoo@0LOod00aOPOoeoo@07Ood00`00Ooeoo@3oOof@
Ood001Ioo@03001ooGom045oo@03O01ooGom01eoo@035n1ooGom00Ioo@03001ooGom0?mooI5oo@00
5Wom00<007omOod0@7om00=l07omOod07Gom00<Gh7omOod01Wom00<007omOod0ogomTWom000FOod0
0`00Ooeoo@0oOod00g`0Ooeoo@0MOod00aOPOoeoo@07Ood00`00Ooeoo@3oOofBOod001Ioo@03001o
oGom03ioo@03O01ooGom01ioo@035n1ooGom00Ioo@03001ooGom0?mooI=oo@005Wom00<007omOod0
?Gom00=l07omOod07Wom00<Gh7omOod01gom00<007omOod0ogomTgom000FOod00`00Ooeoo@0kOod2
O00POod00aOPOoeoo@07Ood00`00Ooeoo@3oOofDOod001Ioo@03001ooGom03Yoo@03O01ooGom021o
o@035n1ooGom00Ioo@03001ooGom0?mooIEoo@005Wom00<007omOod0>7om0W`08Wom00<Gh7omOod0
1gom00<007omOod0ogomUGom000FOod00`00Ooeoo@0gOod00g`0Ooeoo@0QOod00aOPOoeoo@07Ood0
0`00Ooeoo@3oOofFOod001Ioo@03001ooGom03Ioo@03O01ooGom025oo@035n1ooGom00Qoo@03001o
oGom0?mooIIoo@005Wom0`00=7om0W`097om00<Gh7omOod01gom00<007omOod0ogomUgom000FOod0
0`00Ooeoo@0cOod00g`0Ooeoo@0SOod00aOPOoeoo@07Ood00`00Ooeoo@3oOofHOod001Ioo@03001o
oGom035oo@9l02Eoo@035n1ooGom00Qoo@03001ooGom0?mooIQoo@005Wom00<007omOod0<7om00=l
07omOod09Gom00<Gh7omOod01gom00<007omOod0ogomVGom000FOod00`00Ooeoo@0_Ood00g`0Ooeo
o@0UOod00aOPOoeoo@08Ood00`00Ooeoo@3oOofIOod001Ioo@03001ooGom02eoo@9l02Moo@035n1o
oGom00Qoo@03001ooGom0?mooIYoo@005Wom00<007omOod0;7om00=l07omOod09gom00<Gh7omOod0
1gom00<007omOod0ogomVgom000FOod00`00Ooeoo@0[Ood00g`0Ooeoo@0WOod00aOPOoeoo@08Ood0
0`00Ooeoo@3oOofKOod001Ioo@03001ooGom02Uoo@9l02Uoo@035n1ooGom00Qoo@03001ooGom0?mo
oIaoo@005Wom00<007omOod0:7om00=l07omOod0:7om00<Gh7omOod02Gom00<007omOod0ogomW7om
000FOod00`00Ooeoo@0WOod00g`0Ooeoo@0YOod00aOPOoeoo@08Ood00`00Ooeoo@3oOofMOod001Io
o@03001ooGom02Eoo@9l02]oo@035n1ooGom00Qoo@03001ooGom0?mooIioo@005Wom00<007omOod0
97om00=l07omOod0:Wom00<Gh7omOod02Gom00<007omOod0ogomWWom000FOod00`00Ooeoo@0ROod2
O00]Ood00aOPOoeoo@08Ood00`00Ooeoo@3oOofOOod001Ioo@<0021oo@9l02ioo@035n1ooGom00Uo
o@03001ooGom0?mooImoo@005Wom00<007omOod07Wom0W`0;gom00<Gh7omOod02Gom00<007omOod0
ogomX7om000FOod00`00Ooeoo@0LOod2O00aOod00aOPOoeoo@08Ood00`00Ooeoo@3oOofQOod001Io
o@03001ooGom01Yoo@9l039oo@035n1ooGom00Uoo@03001ooGom0?mooJ5oo@005Wom00<007omOod0
67om0W`0=7om00<Gh7omOod027om00<007omOod0ogomXWom000FOod00`00Ooeoo@0FOod2O00eOod0
0aOPOoeoo@09Ood00`00Ooeoo@3oOofROod001Ioo@03001ooGom01Aoo@9l03Ioo@035n1ooGom00Uo
o@03001ooGom0?mooJ=oo@005Wom00<007omOod03gom1G`0>7om00<Gh7omOod027om00<007omOod0
ogomY7om000FOod00`00Ooeoo@0;Ood4O00lOod00aOPOoeoo@09Ood00`00Ooeoo@3oOofTOod001Io
o@03001ooGom00Qoo@=l03moo@035n1ooGom00Uoo@03001ooGom0?mooJEoo@005Wom00<007omOod0
0Wom1W`0@Wom00<Gh7omOod02Gom00<007omOod0ogomYGom000FOod00`00Ooel0002O017Ood00aOP
Ooeoo@09Ood00`00Ooeoo@3oOofVOod001Ioo@03001ooGom04Qoo@035n1ooGom00Uoo@03001ooGom
0?mooJMoo@005Wom00<007omOod0B7om00<Gh7omOod02Gom00<007omOod0ogomYgom000FOod30017
Ood00aOPOoeoo@09Ood00`00Ooeoo@3oOofXOod001Ioo@03001ooGom04Moo@035n1ooGom00Uoo@03
001ooGom0?mooJQoo@005Wom00<007omOod0AWom00<Gh7omOod02Gom00<007omOod0ogomZGom000F
Ood00`00Ooeoo@15Ood00aOPOoeoo@09Ood00`00Ooeoo@3oOofZOod001Ioo@03001ooGom04Eoo@03
5n1ooGom00Uoo@03001ooGom0?mooJYoo@005Wom00<007omOod0A7om00<Gh7omOod02Gom00<007om
Ood0ogomZgom000FOod00`00Ooeoo@13Ood00aOPOoeoo@0:Ood00`00Ooeoo@3oOof[Ood001Ioo@03
001ooGom04=oo@035n1ooGom00Uoo@03001ooGom0?mooJaoo@005Wom00<007omOod0@Wom00<Gh7om
Ood02Wom00<007omOod0ogom[7om000FOod00`00Ooeoo@11Ood00aOPOoeoo@0:Ood00`00Ooeoo@3o
Oof]Ood001Ioo@03001ooGom045oo@035n1ooGom00Yoo@03001ooGom0?mooJeoo@005Wom00<007om
Ood0@7om00<Gh7omOod02Wom00<007omOod0ogom[Wom000FOod00`00Ooeoo@10Ood00aOPOoeoo@0:
Ood00`00Ooeoo@3oOof^Ood000Eoo@8000Aoo@8000Uoo@03001ooGom03moo@035n1ooGom00Yoo@03
001ooGom0?mooJmoo@0017om00@007omOod0009oo@04001ooGom0008Ood00`00Ooeoo@0nOod00aOP
Ooeoo@0;Ood00`00Ooeoo@3oOof_Ood000Ioo@05001ooGomOod00002Ood00`00Ooeoo@06Ood4000m
Ood00aOPOoeoo@0:Ood00`00Ooeoo@3oOof`Ood000Moo@04001ooGom0002Ood00`00Ooeoo@06Ood0
0`00Ooeoo@0mOod00aOPOoeoo@0:Ood00`00Ooeoo@3oOofaOod000Aoo@04001ooGom0002Ood01000
Ooeoo@0027om00<007omOod0?7om00<Gh7omOod02gom00<007omOod0ogom/Gom0005Ood20004Ood2
0009Ood00`00Ooeoo@0kOod00aOPOoeoo@0;Ood00`00Ooeoo@3oOofbOod001Ioo@03001ooGom03]o
o@035n1ooGom00]oo@03001ooGom0?mooK9oo@005Wom00<007omOod0>Wom00<Gh7omOod02gom00<0
07omOod0ogom/gom000FOod00`00Ooeoo@0iOod00aOPOoeoo@0<Ood00`00Ooeoo@3oOofcOod001Io
o@03001ooGom03Qoo@035n1ooGom00aoo@03001ooGom0?mooKAoo@005Wom00<007omOod0=gom00<G
h7omOod03Gom00<007omOod0ogom]7om000FOod00`00Ooeoo@0gOod00aOPOoeoo@0<Ood00`00Ooeo
o@3oOofeOod001Ioo@03001ooGom03Ioo@035n1ooGom00eoo@03001ooGom0?mooKEoo@005Wom00<0
07omOod0=Gom00<Gh7omOod03Gom00<007omOod0ogom]Wom000FOod00`00Ooeoo@0dOod00aOPOoeo
o@0>Ood00`00Ooeoo@3oOoffOod001Ioo@03001ooGom03=oo@035n1ooGom00ioo@03001ooGom0?mo
oKMoo@005Wom0`00<gom00<Gh7omOod03Gom00<007omOod0ogom^7om000FOod00`00Ooeoo@0bOod0
0aOPOoeoo@0>Ood00`00Ooeoo@3oOofhOod001Ioo@03001ooGom035oo@035n1ooGom00ioo@03001o
oGom0?mooKUoo@005Wom00<007omOod0<7om00<Gh7omOod03gom00<007omOod0ogom^Gom000FOod0
0`00Ooeoo@0_Ood00aOPOoeoo@0?Ood00`00Ooeoo@3oOofjOod001Ioo@03001ooGom02ioo@035n1o
oGom011oo@03001ooGom0?mooKYoo@005Wom00<007omOod0;Wom00<Gh7omOod03gom00<007omOod0
ogom^gom000FOod00`00Ooeoo@0]Ood00aOPOoeoo@0@Ood00`00Ooeoo@3oOofkOod001Ioo@03001o
oGom02aoo@035n1ooGom011oo@03001ooGom0?mooKaoo@005Wom00<007omOod0:gom00<Gh7omOod0
4Gom00<007omOod0ogom_7om000FOod00`00Ooeoo@0ZOod00aOPOoeoo@0AOod00`00Ooeoo@3oOofm
Ood001Ioo@03001ooGom02Yoo@035n1ooGom015oo@03001ooGom0?mooKeoo@005Wom00<007omOod0
:Gom00<Gh7omOod04Gom00<007omOod0ogom_Wom000FOod00`00Ooeoo@0XOod00aOPOoeoo@0AOod0
0`00Ooeoo@3oOofoOod001Ioo@<002Moo@035n1ooGom019oo@03001ooGom0?mooKmoo@005Wom00<0
07omOod09Wom00<Gh7omOod04Wom00<007omOod0ogom`7om000FOod00`00Ooeoo@0UOod00aOPOoeo
o@0BOod00`00Ooeoo@3oOog1Ood001Ioo@03001ooGom02Aoo@035n1ooGom01=oo@03001ooGom0?mo
oL5oo@005Wom00<007omOod08gom00<Gh7omOod04gom00<007omOod0ogom`Wom000FOod00`00Ooeo
o@0ROod00aOPOoeoo@0COod00`00Ooeoo@3oOog3Ood001Ioo@03001ooGom025oo@035n1ooGom01Ao
o@03001ooGom0?mooL=oo@005Wom00<007omOod087om00<Gh7omOod057om00<007omOod0ogoma7om
000FOod00`00Ooeoo@0OOod00aOPOoeoo@0DOod00`00Ooeoo@3oOog5Ood001Ioo@03001ooGom01io
o@035n1ooGom01Eoo@03001ooGom0?mooLEoo@005Wom00<007omOod07Gom00<Gh7omOod05Gom00<0
07omOod0ogomaWom000FOod00`00Ooeoo@0LOod00aOPOoeoo@0EOod00`00Ooeoo@3oOog7Ood001Io
o@03001ooGom01]oo@035n1ooGom01Ioo@03001ooGom0?mooLMoo@005Wom00<007omOod06Wom00<G
h7omOod05Wom00<007omOod0ogomb7om000FOod00`00Ooeoo@0IOod00aOPOoeoo@0GOod00`00Ooeo
o@3oOog8Ood001Ioo@<001Qoo@035n1ooGom01Moo@03001ooGom0?mooLUoo@005Wom00<007omOod0
5Wom0QOP6Gom00<007omOod0ogombWom000FOod00`00Ooeoo@0EOod00aOPOoeoo@0IOod00`00Ooeo
o@3oOog:Ood001Ioo@03001ooGom01Eoo@035n1ooGom01Qoo@03001ooGom0?mooL]oo@005Wom00<0
07omOod04Wom0aOP6Wom00<007omOod0ogomc7om000FOod00`00Ooeoo@0AOod00aOPOoeoo@0KOod0
0`00Ooeoo@3oOog<Ood001Ioo@03001ooGom00moo@8Gh1eoo@03001ooGom0?mooLeoo@005Wom00<0
07omOod03Gom0QOP7Wom00<007omOod0ogomcWom000FOod00`00Ooeoo@0:Ood35n0POod00`00Ooeo
o@3oOog>Ood001Ioo@03001ooGom00Qoo@8Gh29oo@03001ooGom0?mooLmoo@005Wom00<007omOod0
1Gom0aOP8gom00<007omOod0ogomd7om000FOod00`00OodGh0055n0VOod00`00Ooeoo@3oOog@Ood0
01Ioo@03001ooGom02Yoo@03001ooGom0?mooM5oo@005Wom00<007omOod0:Gom00<007omOod0ogom
dWom000FOod3000YOod00`00Ooeoo@3oOogBOod001Ioo@03001ooGom02Qoo@03001ooGom0?mooM=o
o@005Wom00<007omOod09gom00<007omOod0ogome7om000FOod00`00Ooeoo@0VOod00`00Ooeoo@3o
OogEOod001Ioo@03001ooGom02Eoo@03001ooGom0?mooMIoo@005Wom00<007omOod09Gom00<007om
Ood0ogomeWom000FOod00`00Ooeoo@0TOod00`00Ooeoo@3oOogGOod001Ioo@03001ooGom02=oo@03
001ooGom0?mooMQoo@005Wom00<007omOod08Wom00<007omOod0ogomfGom000FOod00`00Ooeoo@0Q
Ood00`00Ooeoo@3oOogJOod001Ioo@03001ooGom021oo@03001ooGom0?mooM]oo@005Wom00<007om
Ood087om00<007omOod0ogomfgom0006Ood30002Ood20009Ood00`00Ooeoo@0OOod00`00Ooeoo@3o
OogLOod000Moo@04001ooGom0002Ood00`00Ooeoo@06Ood00`00Ooeoo@0NOod00`00Ooeoo@3oOogM
Ood000Aoo@D00005Ood007omOod00008Ood4000LOod00`00Ooeoo@3oOogNOod000Aoo@04001ooGom
0002Ood01000Ooeoo@0027om00<007omOod077om00<007omOod0ogomggom0005Ood00`00Ood00002
Ood01000Ooeoo@0027om00<007omOod06gom00<007omOod0ogomh7om0006Ood20003Ood20009Ood0
0`00Ooeoo@0KOod00`00Ooeoo@3oOogPOod001Ioo@03001ooGom01Yoo@03001ooGom0?mooN5oo@00
5Wom00<007omOod06Gom00<007omOod0ogomhWom000FOod00`00Ooeoo@0HOod00`00Ooeoo@3oOogS
Ood001Ioo@03001ooGom01Moo@03001ooGom0?mooNAoo@005Wom00<007omOod05Wom00<007omOod0
ogomiGom000FOod00`00Ooeoo@0EOod00`00Ooeoo@3oOogVOod001Ioo@03001ooGom01Aoo@03001o
oGom0?mooNMoo@005Wom00<007omOod04Wom0P00ogomjWom000FOod00`00Ooeoo@0AOod00`00Ooeo
o@3oOogZOod001Ioo@03001ooGom00moo@800?mooNeoo@005Wom00<007omOod03Gom0P00ogomkgom
000FOod3000;Ood2003oOogaOod001Ioo@03001ooGom00Uoo@800?mooO=oo@005Wom00<007omOod0
27om00<007omOod0ogomlgom000FOod00`00Ooeoo@06Ood2003oOogfOod001Ioo@03001ooGom00H0
0?mooOQoo@005Wom00<007om0000ogomoWom000FOod00`00Ooeoo@3oOognOod001Ioo@03001ooGom
0?mooOioo@005Wom00<007omOod0ogomoWom000FOod00`00Ooeoo@3oOognOod001Ioo@03001ooGom
0?mooOioo@005Wom00<007omOod0ogomoWom000FOod00`00Ooeoo@3oOognOod00001\
\>"],
  ImageRangeCache->{{{0, 533}, {329.063, 0}} -> {-0.0488762, -2.15998, \
0.00219066, 0.139633}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 686}},
WindowSize->{736, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 91, 2, 120, "Title"],
Cell[1870, 57, 193, 3, 70, "Input"],
Cell[2066, 62, 62, 1, 30, "Input"],
Cell[2131, 65, 76, 1, 30, "Input"],
Cell[2210, 68, 136, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[2371, 74, 78, 1, 30, "Input"],
Cell[2452, 77, 65, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2554, 83, 99, 1, 75, "Section"],
Cell[2656, 86, 783, 21, 353, "Text"],
Cell[3442, 109, 274, 5, 110, "Input"],

Cell[CellGroupData[{
Cell[3741, 118, 1388, 23, 470, "Input"],
Cell[5132, 143, 60, 1, 29, "Output"],
Cell[5195, 146, 183, 3, 42, "Message"],
Cell[5381, 151, 44, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5462, 157, 83, 1, 63, "Subsection"],
Cell[5548, 160, 58, 1, 49, "Text"],
Cell[5609, 163, 153, 4, 49, "Text"],
Cell[5765, 169, 294, 6, 70, "Input"],
Cell[6062, 177, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6135, 182, 324, 8, 70, "Input"],
Cell[6462, 192, 150, 4, 70, "Output"],
Cell[6615, 198, 150, 4, 70, "Output"],
Cell[6768, 204, 150, 4, 70, "Output"]
}, Open  ]],
Cell[6933, 211, 125, 3, 49, "Text"],
Cell[7061, 216, 570, 12, 130, "Input"],
Cell[7634, 230, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7707, 235, 279, 6, 70, "Input"],
Cell[7989, 243, 170, 4, 70, "Output"],
Cell[8162, 249, 170, 4, 70, "Output"],
Cell[8335, 255, 170, 4, 70, "Output"]
}, Open  ]],
Cell[8520, 262, 59, 1, 49, "Text"],
Cell[8582, 265, 194, 4, 68, "Text"],
Cell[8779, 271, 570, 12, 130, "Input"],
Cell[9352, 285, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[9425, 290, 279, 6, 70, "Input"],
Cell[9707, 298, 170, 4, 70, "Output"],
Cell[9880, 304, 170, 4, 70, "Output"],
Cell[10053, 310, 170, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10272, 320, 74, 1, 47, "Subsection"],
Cell[10349, 323, 58, 1, 49, "Text"],
Cell[10410, 326, 153, 4, 49, "Text"],
Cell[10566, 332, 354, 9, 70, "Input"],
Cell[10923, 343, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[10996, 348, 333, 8, 70, "Input"],
Cell[11332, 358, 150, 4, 29, "Output"],
Cell[11485, 364, 150, 4, 29, "Output"],
Cell[11638, 370, 150, 4, 29, "Output"]
}, Open  ]],
Cell[11803, 377, 226, 3, 70, "Input"],
Cell[12032, 382, 125, 3, 49, "Text"],
Cell[12160, 387, 591, 12, 130, "Input"],
Cell[12754, 401, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[12827, 406, 288, 6, 70, "Input"],
Cell[13118, 414, 170, 4, 29, "Output"],
Cell[13291, 420, 170, 4, 29, "Output"],
Cell[13464, 426, 170, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13671, 435, 277, 5, 70, "Input"],
Cell[13951, 442, 181, 3, 42, "Message"],
Cell[14135, 447, 181, 3, 42, "Message"],
Cell[14319, 452, 181, 3, 42, "Message"]
}, Open  ]],
Cell[14515, 458, 59, 1, 49, "Text"],
Cell[14577, 461, 194, 4, 68, "Text"],
Cell[14774, 467, 591, 12, 130, "Input"],
Cell[15368, 481, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[15441, 486, 288, 6, 70, "Input"],
Cell[15732, 494, 170, 4, 29, "Output"],
Cell[15905, 500, 170, 4, 29, "Output"],
Cell[16078, 506, 170, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16285, 515, 277, 5, 70, "Input"],
Cell[16565, 522, 181, 3, 42, "Message"],
Cell[16749, 527, 181, 3, 42, "Message"],
Cell[16933, 532, 181, 3, 42, "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17175, 542, 59, 1, 75, "Section"],
Cell[17237, 545, 285, 5, 110, "Input"],

Cell[CellGroupData[{
Cell[17547, 554, 207, 4, 90, "Input"],
Cell[17757, 560, 19780, 610, 302, 6382, 440, "GraphicsData", "PostScript", \
"Graphics"],
Cell[37540, 1172, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37707, 1180, 334, 7, 130, "Input"],
Cell[38044, 1189, 22409, 667, 300, 6672, 468, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60456, 1858, 130, 3, 29, "Output"]
}, Open  ]],
Cell[60601, 1864, 26, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[60652, 1868, 313, 6, 130, "Input"],
Cell[60968, 1876, 21061, 573, 334, 5596, 378, "GraphicsData", "PostScript", \
"Graphics"],
Cell[82032, 2451, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82199, 2459, 437, 8, 150, "Input"],
Cell[82639, 2469, 383631, 6756, 476, 132944, 3657, "GraphicsData", \
"PostScript", "Graphics"],
Cell[466273, 9227, 137, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[466459, 9236, 82, 1, 55, "Section"],
Cell[466544, 9239, 323, 7, 110, "Input"],

Cell[CellGroupData[{
Cell[466892, 9250, 878, 16, 190, "Input"],
Cell[467773, 9268, 639, 11, 44, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468449, 9284, 40, 1, 30, "Input"],
Cell[468492, 9287, 637, 11, 44, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469166, 9303, 901, 17, 190, "Input"],
Cell[470070, 9322, 182, 3, 42, "Message"],
Cell[470255, 9327, 182, 3, 42, "Message"],
Cell[470440, 9332, 688, 12, 44, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471165, 9349, 892, 16, 190, "Input"],
Cell[472060, 9367, 182, 3, 42, "Message"],
Cell[472245, 9372, 182, 3, 42, "Message"],
Cell[472430, 9377, 693, 12, 44, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[473172, 9395, 75, 1, 55, "Section"],

Cell[CellGroupData[{
Cell[473272, 9400, 268, 5, 90, "Input"],
Cell[473543, 9407, 181, 3, 42, "Message"]
}, Open  ]],
Cell[473739, 9413, 369, 8, 90, "Input"],

Cell[CellGroupData[{
Cell[474133, 9425, 211, 4, 50, "Input"],
Cell[474347, 9431, 53, 1, 29, "Output"],
Cell[474403, 9434, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474493, 9440, 229, 4, 90, "Input"],
Cell[474725, 9446, 25793, 598, 339, 4907, 336, "GraphicsData", "PostScript", \
"Graphics"],
Cell[500521, 10046, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

