(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14656,        404]*)
(*NotebookOutlinePosition[     15299,        426]*)
(*  CellTagsIndexPosition[     15255,        422]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(He\^3\ spectral\ function\)], "Title",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics3D`\), "\[IndentingNewLine]", 
    \(<< NumericalMath`NIntegrateInterpolatingFunct`\)}], "Input"],

Cell[BoxData[
    \(SetDirectory["\<e:/kulagin/phys/spin/SpFn\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["Read spectral function from data file", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
Read spectral function from data file. Note the following rules:
C     The spectral function is given for the pair-isospin 
C     T=0 and T=1
C     The two-body breakup is given in the first columne, i.e.,
C     R0T0(1,J) etc.
C     R0T0(2..NERG,J) contains the three-body breakup.
C     The normalization is chosen such that the proton and  neutron \
contribution is given by:
C
C      R0P = (F0T0 + F0T1)*4.*PI/3.
C      R0N = 2.*F0T1*4.*PI/3.
C
C     with R0P = 2/3
C     and  R0N = 1/3
C     
C     Since the spectral function is given on a finite mesh the sumrule is \
not exactly fullfilled !
C     The mesh was chosen for a particular kinematic situation.
C     The momentum mesh is given for Gaussian points.        \
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(nmesh = 30;\)\), "\[IndentingNewLine]", 
    \(\(r0t0 = 
        Table[0, {i, 1, nmesh}, {j, 1, nmesh}];\)\), "\[IndentingNewLine]", 
    \(r1t0 = r0t0; r2t0 = r0t0;\), "\[IndentingNewLine]", 
    \(r0t1 = r0t0; r1t1 = r0t0; r2t1 = r0t0;\)}], "Input"],

Cell[BoxData[{
    \(rawdat = OpenRead["\<spfn.dat\>"]\), "\[IndentingNewLine]", 
    \(\(nerg = Read[rawdat, Number];\)\), "\[IndentingNewLine]", 
    \(\(nq = Read[rawdat, Number];\)\), "\[IndentingNewLine]", 
    \(\(ener = ReadList[rawdat, Number, nerg];\)\), "\[IndentingNewLine]", 
    \(\(qmesh = ReadList[rawdat, Number, nq];\)\), "\[IndentingNewLine]", 
    \(\(qweigh = ReadList[rawdat, Number, nq];\)\), "\[IndentingNewLine]", 
    \(\(Do[\((\[IndentingNewLine]Do[\ \((\[IndentingNewLine]r0t0[\([i, 
                    j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r1t0[\([i, j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r2t0[\([i, j]\)] = 
                Read[rawdat, 
                  Number]\[IndentingNewLine])\)\[IndentingNewLine], {j, 1, 
              nq}])\)\[IndentingNewLine], {i, 1, 
          nerg}];\)\), "\[IndentingNewLine]", 
    \(\(Do[\((\[IndentingNewLine]Do[\ \((\[IndentingNewLine]r0t1[\([i, 
                    j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r1t1[\([i, j]\)] = 
                Read[rawdat, Number]; \[IndentingNewLine]r2t1[\([i, j]\)] = 
                Read[rawdat, 
                  Number]\[IndentingNewLine])\)\[IndentingNewLine], {j, 1, 
              nq}])\)\[IndentingNewLine], {i, 1, 
          nerg}];\)\), "\[IndentingNewLine]", 
    \(Close[rawdat]\)}], "Input"],

Cell["\<\
Making the tables of values of the functions and interpolation:\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell["Isospin 0", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron in the final state (2-body breakup) corresponds to i=1. We treat \
it separately.\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(deut0 = 
        Table[{qmesh[\([j]\)], r0t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\), "\n", 
    \(\(deut1 = 
        Table[{qmesh[\([j]\)], r1t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\), "\n", 
    \(\(deut2 = 
        Table[{qmesh[\([j]\)], r2t0[\([1, j]\)] // Log}, {j, 1, 
            nq}];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[BoxData[{
    \(d0 = 
      Interpolation[deut0, 
        InterpolationOrder \[Rule] intord]\ \), "\[IndentingNewLine]", 
    \(d1 = 
      Interpolation[deut1, 
        InterpolationOrder \[Rule] intord]\), "\[IndentingNewLine]", 
    \(d2 = 
      Interpolation[deut2, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell["\<\
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t0 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t0[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t0 = Flatten[con0t0, 1];\)\), "\n", 
    \(\(con1t0 = Flatten[con1t0, 1];\)\), "\n", 
    \(\(con2t0 = Flatten[con2t0, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[BoxData[{
    \(c0t0 = 
      Interpolation[con0t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c1t0 = 
      Interpolation[con1t0, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c2t0 = 
      Interpolation[con2t0, InterpolationOrder \[Rule] intord]\)}], "Input"],

Cell["Isospin 1.", "Text",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The deuteron (two-body breakup) does not contribute in this channel.
Two nucleons in the continuum in the final state (3-body breakup):\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(con0t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r0t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con1t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r1t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con2t1 = 
        Table[{ener[\([i]\)], qmesh[\([j]\)], r2t1[\([i, j]\)] // Log}, {i, 
            2, nerg}, {j, 1, nq}];\)\), "\n", 
    \(\(con0t1 = Flatten[con0t1, 1];\)\), "\n", 
    \(\(con1t1 = Flatten[con1t1, 1];\)\), "\n", 
    \(\(con2t1 = Flatten[con2t1, 1];\)\)}], "Input"],

Cell[BoxData[
    \(\(intord = 1;\)\)], "Input"],

Cell[BoxData[{
    \(c0t1 = 
      Interpolation[con0t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c1t1 = 
      Interpolation[con1t1, InterpolationOrder \[Rule] intord]\), "\n", 
    \(c2t1 = 
      Interpolation[con2t1, InterpolationOrder \[Rule] intord]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots", "Section",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(pmin = First[qmesh];\)\), "\[IndentingNewLine]", 
    \(pmax = Last[qmesh]; \ pmax = 5. ;\), "\[IndentingNewLine]", 
    \(emin0 = ener[\([1]\)]; 
    emin1 = ener[\([2]\)];\ \), "\[IndentingNewLine]", 
    \(\(emax = Last[ener];\)\  (*\ \(emax = 100. ;\)\ *) \)}], "Input"],

Cell[BoxData[
    \(sty = {Hue[1], Hue[0.3], Hue[0.6]}\)], "Input"],

Cell[BoxData[
    \(Plot[{d0[
          p], \((d1[p] // Re)\), \((d2[p] // Re)\)}\[IndentingNewLine], {p, 
        pmin, pmax}\[IndentingNewLine], 
      PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty]\)], "Input"],

Cell[BoxData[
    \( (***) \)], "Input"],

Cell[BoxData[{
    \(\(p = 1;\)\), "\[IndentingNewLine]", 
    \(Plot[{c0t0[e, p], c1t0[e, p] // Re, 
        c2t0[e, p] // Re}\[IndentingNewLine], {e, emin1, 
        emax/3}\[IndentingNewLine], 
      PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty]\), "\[IndentingNewLine]", 
    \(p =. \)}], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[{
    \(e = emin1; 
    Plot[{c0t0[e, p] // Re, c1t0[e, p] // Re, c2t0[e, p] // Re}, {p, pmin, 
        pmax}\[IndentingNewLine], PlotRange \[Rule] All\ \[IndentingNewLine], 
      PlotStyle \[Rule] sty]\), "\[IndentingNewLine]", 
    \(e =. \)}], "Input"],

Cell[BoxData[
    \(Plot3D[\[IndentingNewLine]c1t0[e, p] // Re, {p, pmin, pmax/3}, {e, 
        emin1, emax/20}, PlotPoints \[Rule] 30, 
      AxesLabel \[Rule] {"\<p\>", "\<E\>", "\<S(E,p)//Log\>"}\
\[IndentingNewLine], 
      PlotRange \[Rule] 
        All\[IndentingNewLine] (*\ \(,\)\(Shading \[Rule] 
          False\)\ *) \[IndentingNewLine] (*\(,\)\(ViewPoint -> {1.2, 0.9, 
            1.1}\)*) \[IndentingNewLine]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Normalizations and sum rules", "Section",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(\(\(pmin = First[qmesh];\)\[IndentingNewLine]
    pmax = Last[qmesh]; \ pmax = 5. ;\[IndentingNewLine]
    emin0 = ener[\([1]\)]; emin1 = ener[\([2]\)];\[IndentingNewLine]
    \(emax = 
        Last[ener];\)\)\(\ \)\( (*\ \(emax = 100. ;\)\ *) \)\)\)], "Input"],

Cell[BoxData[{
    \(\(nd0 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*\((\(d0[p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, 
            PrecisionGoal \[Rule] 4, \ MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc0t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c0t0[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc0t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c0t1[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(n0p = \((nd0 + nc0t0 + nc0t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n0n = \((2. *nc0t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<No. protons = \>", n0p, "\<\nNo. neutrons = \>", 
      n0n]\)}], "Input"],

Cell[BoxData[
    \( (**) \)], "Input"],

Cell[BoxData[
    \(nd0*3\)], "Input"],

Cell[BoxData[
    \( (***) \)], "Input"],

Cell[BoxData[
    \( (****) \)], "Input"],

Cell[BoxData[{
    \(\(nd1 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*\((\(d1[p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, 
            PrecisionGoal \[Rule] 4, \ MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc1t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c1t0[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc1t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c1t1[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(n1p = \((nd1 + nc1t0 + nc1t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n1n = \((2. *nc1t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<Proton polarization = \>", 
      n1p, "\<\nNeutron polarization = \>", n1n]\)}], "Input"],

Cell[BoxData[
    \( (**) \)], "Input"],

Cell[BoxData[
    \(nd1*3\)], "Input"],

Cell[BoxData[
    \( (***) \)], "Input"],

Cell[BoxData[
    \( (****) \)], "Input"],

Cell[BoxData[{
    \(\(nd2 = \((4. *Pi/3. )\)*
          NIntegrate[p^2*\((\(d2[p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, 
            PrecisionGoal \[Rule] 4, \ MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc2t0 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c2t0[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(nc2t1 = \((4. *Pi/3. )\)*
          NIntegrate[
            p^2*\((\(c2t1[e, p] // Exp\) // Re)\), {p, pmin, 0.5, pmax}, {e, 
              emin1, 10. , emax}, PrecisionGoal \[Rule] 4, \ 
            MinRecursion \[Rule] 3, \ 
            MaxRecursion \[Rule] 26];\)\), "\[IndentingNewLine]", 
    \(\(n2p = \((nd2 + nc2t0 + nc2t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(\(n2n = \((2. *nc2t1)\)*3. ;\)\), "\[IndentingNewLine]", 
    \(Print["\<Proton tensor pol. = \>", n2p, "\<\nNeutron tensor pol. = \>", 
      n2n]\)}], "Input"],

Cell[BoxData[
    \( (**) \)], "Input"],

Cell[BoxData[
    \( (***) \)], "Input"],

Cell[BoxData[
    \( (*\[IndentingNewLine]R0P = \(NIntegrateInterpolatingFunction[
              p^2 \((s0t0[e, p] + s0t1[e, p])\), {p, pmin, 0.5, pmax}, {e, 
                emin, 5. , 10. , emax}, PrecisionGoal \[Rule] 3, \ 
              MinRecursion \[Rule] 3, \ MaxRecursion \[Rule] 20]*4. *
            Pi/3. \n\[IndentingNewLine]R0N = 
          2. *NIntegrateInterpolatingFunction[
              p^2*s0t1[e, p], {p, pmin, 0.5, pmax}, {e, emin, 10. , emax}, 
              PrecisionGoal \[Rule] 3, \ MinRecursion \[Rule] 3, \ 
              MaxRecursion \[Rule] 26]*4. *
            Pi/3. \)\[IndentingNewLine]*) \)], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 686}},
WindowSize->{736, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 91, 2, 120, "Title"],
Cell[1870, 57, 193, 3, 70, "Input"],
Cell[2066, 62, 78, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2169, 67, 91, 1, 75, "Section"],
Cell[2263, 70, 783, 21, 353, "Text"],
Cell[3049, 93, 274, 5, 110, "Input"],
Cell[3326, 100, 1388, 23, 470, "Input"],
Cell[4717, 125, 122, 3, 49, "Text"],
Cell[4842, 130, 58, 1, 49, "Text"],
Cell[4903, 133, 153, 4, 49, "Text"],
Cell[5059, 139, 354, 9, 70, "Input"],
Cell[5416, 150, 48, 1, 30, "Input"],
Cell[5467, 153, 324, 8, 70, "Input"],
Cell[5794, 163, 125, 3, 49, "Text"],
Cell[5922, 168, 591, 12, 130, "Input"],
Cell[6516, 182, 48, 1, 30, "Input"],
Cell[6567, 185, 279, 6, 70, "Input"],
Cell[6849, 193, 59, 1, 49, "Text"],
Cell[6911, 196, 194, 4, 68, "Text"],
Cell[7108, 202, 591, 12, 130, "Input"],
Cell[7702, 216, 48, 1, 30, "Input"],
Cell[7753, 219, 279, 6, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8069, 230, 59, 1, 55, "Section"],
Cell[8131, 233, 297, 5, 110, "Input"],
Cell[8431, 240, 67, 1, 30, "Input"],
Cell[8501, 243, 240, 5, 90, "Input"],
Cell[8744, 250, 40, 1, 30, "Input"],
Cell[8787, 253, 329, 7, 130, "Input"],
Cell[9119, 262, 26, 0, 30, "Input"],
Cell[9148, 264, 269, 5, 90, "Input"],
Cell[9420, 271, 436, 8, 150, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9893, 284, 82, 1, 55, "Section"],
Cell[9978, 287, 283, 5, 110, "Input"],
Cell[10264, 294, 1089, 20, 190, "Input"],
Cell[11356, 316, 39, 1, 30, "Input"],
Cell[11398, 319, 38, 1, 30, "Input"],
Cell[11439, 322, 40, 1, 30, "Input"],
Cell[11482, 325, 41, 1, 30, "Input"],
Cell[11526, 328, 1105, 20, 190, "Input"],
Cell[12634, 350, 39, 1, 30, "Input"],
Cell[12676, 353, 38, 1, 30, "Input"],
Cell[12717, 356, 40, 1, 30, "Input"],
Cell[12760, 359, 41, 1, 30, "Input"],
Cell[12804, 362, 1103, 20, 190, "Input"],
Cell[13910, 384, 39, 1, 30, "Input"],
Cell[13952, 387, 40, 1, 30, "Input"],
Cell[13995, 390, 633, 10, 170, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

